
# CIM17v40 Profile Specification

Profile namespace: `http://www.ucaiug.org/profile#`

## CIM17v40 Profile


## Classes

{#CIM17v40-ACDCConverter}
### ACDCConverter

Inheritance path = [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ACDCConverter {

+ baseS : ApparentPower [0..1]
+ idc : CurrentFlow [0..1]
+ idleLoss : ActivePower [0..1]
+ maxP : ActivePower [0..1]
+ maxUdc : Voltage [0..1]
+ minP : ActivePower [0..1]
+ minUdc : Voltage [0..1]
+ numberOfValves : Integer [0..1]
+ p : ActivePower [0..1]
+ poleLossP : ActivePower [0..1]
+ q : ReactivePower [0..1]
+ ratedUdc : Voltage [0..1]
+ resistiveLoss : Resistance [0..1]
+ switchingLoss : ActivePowerPerCurrentFlow [0..1]
+ targetPpcc : ActivePower [0..1]
+ targetUdc : Voltage [0..1]
+ uc : Voltage [0..1]
+ udc : Voltage [0..1]
+ valveU0 : Voltage [0..1]
}

class ConductingEquipment {

}

ConductingEquipment <|-- ACDCConverter : inherits from
class Terminal {

}

ACDCConverter --> "0..1" Terminal : PccTerminal
```

A unit with valves for three phases, together with unit control equipment, essential protective and switching devices, DC storage capacitors, phase reactors and auxiliaries, if any, used for conversion.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| baseS [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | Base apparent power of the converter pole. The attribute shall be a positive value. | |
| idc [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Converter DC current, also called Id. It is converter�s state variable, result from power flow. | |
| idleLoss [0..1] | [ActivePower](#CIM17v40-ActivePower) | Active power loss in pole at no power transfer. It is converter�s configuration data used in power flow. The attribute shall be a positive value. | |
| maxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | Maximum active power limit. The value is overwritten by values of VsCapabilityCurve, if present. | |
| maxUdc [0..1] | [Voltage](#CIM17v40-Voltage) | The maximum voltage on the DC side at which the converter should operate. It is converter�s configuration data used in power flow. The attribute shall be a positive value. | |
| minP [0..1] | [ActivePower](#CIM17v40-ActivePower) | Minimum active power limit. The value is overwritten by values of VsCapabilityCurve, if present. | |
| minUdc [0..1] | [Voltage](#CIM17v40-Voltage) | The minimum voltage on the DC side at which the converter should operate. It is converter�s configuration data used in power flow. The attribute shall be a positive value. | |
| numberOfValves [0..1] | [Integer](#CIM17v40-Integer) | Number of valves in the converter. Used in loss calculations. | |
| p [0..1] | [ActivePower](#CIM17v40-ActivePower) | Active power at the point of common coupling. Load sign convention is used, i.e. positive sign means flow out from a node.Starting value for a steady state solution in the case a simplified power flow model is used. | |
| poleLossP [0..1] | [ActivePower](#CIM17v40-ActivePower) | The active power loss at a DC Pole= idleLoss + switchingLoss*{vbar}Idc{vbar} + resitiveLoss*Idc^2.For lossless operation Pdc=Pac.For rectifier operation with losses Pdc=Pac-lossP.For inverter operation with losses Pdc=Pac+lossP.It is converter�s state variable used in power flow. The attribute shall be a positive value. | |
| q [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Reactive power at the point of common coupling. Load sign convention is used, i.e. positive sign means flow out from a node.Starting value for a steady state solution in the case a simplified power flow model is used. | |
| ratedUdc [0..1] | [Voltage](#CIM17v40-Voltage) | Rated converter DC voltage, also called UdN. The attribute shall be a positive value. It is converter�s configuration data used in power flow. For instance a bipolar HVDC link with value 200 kV has a 400kV difference between the dc lines. | |
| resistiveLoss [0..1] | [Resistance](#CIM17v40-Resistance) | It is converter�s configuration data used in power flow. Refer to poleLossP. The attribute shall be a positive value. | |
| switchingLoss [0..1] | [ActivePowerPerCurrentFlow](#CIM17v40-ActivePowerPerCurrentFlow) | Switching losses, relative to the base apparent power 'baseS'. Refer to poleLossP. The attribute shall be a positive value. | |
| targetPpcc [0..1] | [ActivePower](#CIM17v40-ActivePower) | Real power injection target in AC grid, at point of common coupling. Load sign convention is used, i.e. positive sign means flow out from a node. | |
| targetUdc [0..1] | [Voltage](#CIM17v40-Voltage) | Target value for DC voltage magnitude. The attribute shall be a positive value. | |
| uc [0..1] | [Voltage](#CIM17v40-Voltage) | Line-to-line converter voltage, the voltage at the AC side of the valve. It is converter�s state variable, result from power flow. The attribute shall be a positive value. | |
| udc [0..1] | [Voltage](#CIM17v40-Voltage) | Converter voltage at the DC side, also called Ud. It is converter�s state variable, result from power flow. The attribute shall be a positive value. | |
| valveU0 [0..1] | [Voltage](#CIM17v40-Voltage) | Valve threshold voltage, also called Uvalve. Forward voltage drop when the valve is conducting. Used in loss calculations, i.e. the switchLoss depend on numberOfValves * valveU0. | |
| PccTerminal [0..1] | [Terminal](#CIM17v40-Terminal) | Point of common coupling terminal for this converter DC side. It is typically the terminal on the power transformer (or switch) closest to the AC network. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ACDCConverterDCTerminal}
### ACDCConverterDCTerminal

Inheritance path = [DCBaseTerminal](#CIM17v40-DCBaseTerminal) => [ACDCTerminal](#CIM17v40-ACDCTerminal) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ACDCConverterDCTerminal {

+ polarity : enum:DCPolarityKind [0..1]
}

class DCBaseTerminal {

}

DCBaseTerminal <|-- ACDCConverterDCTerminal : inherits from
class ACDCConverter {

}

ACDCConverterDCTerminal --> "1" ACDCConverter : DCConductingEquipment
```

A DC electrical connection point at the AC/DC converter. The AC/DC converter is electrically connected also to the AC side. The AC connection is inherited from the AC conducting equipment in the same way as any other AC equipment. The AC/DC converter DC terminal is separate from generic DC terminal to restrict the connection with the AC side to AC/DC converter and so that no other DC conducting equipment can be connected to the AC side.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| polarity [0..1] | [DCPolarityKind](#CIM17v40-DCPolarityKind) | Represents the normal network polarity condition. Depending on the converter configuration the value shall be set as follows:- For a monopole with two converter terminals use DCPolarityKind �positive� and �negative�.- For a bi-pole or symmetric monopole with three converter terminals use DCPolarityKind �positive�, �middle� and �negative�. | |
| DCConductingEquipment [1] | [ACDCConverter](#CIM17v40-ACDCConverter) | A DC converter terminal belong to an DC converter. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DCNode [0..1] | [DCNode](#CIM17v40-DCNode) | see [DCBaseTerminal](CIM17v40-DCBaseTerminal) | |
| DCTopologicalNode [0..1] | [DCTopologicalNode](#CIM17v40-DCTopologicalNode) | see [DCBaseTerminal](CIM17v40-DCBaseTerminal) | |
| connected [0..1] | [Boolean](#CIM17v40-Boolean) | see [ACDCTerminal](#CIM17v40-ACDCTerminal) | |
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | see [ACDCTerminal](#CIM17v40-ACDCTerminal) | |
| BusNameMarker [0..1] | [BusNameMarker](#CIM17v40-BusNameMarker) | see [ACDCTerminal](CIM17v40-ACDCTerminal) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ACDCTerminal}
### ACDCTerminal

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ACDCTerminal {

+ connected : Boolean [0..1]
+ sequenceNumber : Integer [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ACDCTerminal : inherits from
class BusNameMarker {

}

ACDCTerminal --> "0..1" BusNameMarker : BusNameMarker
```

An electrical connection point (AC or DC) to a piece of conducting equipment. Terminals are connected at physical connection points called connectivity nodes.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| connected [0..1] | [Boolean](#CIM17v40-Boolean) | The connected status is related to a bus-branch model and the topological node to terminal relation. True implies the terminal is connected to the related topological node and false implies it is not.In a bus-branch model, the connected status is used to tell if equipment is disconnected without having to change the connectivity described by the topological node to terminal relation. A valid case is that conducting equipment can be connected in one end and open in the other. In particular for an AC line segment, where the reactive line charging can be significant, this is a relevant case. | |
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | The orientation of the terminal connections for a multiple terminal conducting equipment. The sequence numbering starts with 1 and additional terminals should follow in increasing order. The first terminal is the "starting point" for a two terminal branch. | |
| BusNameMarker [0..1] | [BusNameMarker](#CIM17v40-BusNameMarker) | The bus name marker used to name the bus (topological node). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ACLineSegment}
### ACLineSegment

Inheritance path = [Conductor](#CIM17v40-Conductor) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ACLineSegment {

+ b0ch : Susceptance [0..1]
+ bch : Susceptance [0..1]
+ g0ch : Conductance [0..1]
+ gch : Conductance [0..1]
+ r : Resistance [0..1]
+ r0 : Resistance [0..1]
+ shortCircuitEndTemperature : Temperature [0..1]
+ x : Reactance [0..1]
+ x0 : Reactance [0..1]
}

class Conductor {

}

Conductor <|-- ACLineSegment : inherits from
class GroundAction {

}

ACLineSegment --> "0..1" GroundAction : LineGroundingAction
class JumperAction {

}

ACLineSegment --> "0..1" JumperAction : LineJumpingAction
class PerLengthImpedance {

}

ACLineSegment --> "0..1" PerLengthImpedance : PerLengthImpedance
class WireSpacingInfo {

}

ACLineSegment --> "0..1" WireSpacingInfo : WireSpacingInfo
```

A wire or combination of wires, with consistent electrical characteristics, building a single electrical system, used to carry alternating current between points in the power system.

For symmetrical, transposed three phase lines, it is sufficient to use attributes of the line segment, which describe impedances and admittances for the entire length of the segment. Additionally impedances can be computed by using length and associated per length impedances.

The BaseVoltage at the two ends of ACLineSegments in a Line shall have the same BaseVoltage.nominalVoltage. However, boundary lines may have slightly different BaseVoltage.nominalVoltages and variation is allowed. Larger voltage difference in general requires use of an equivalent branch.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| b0ch [0..1] | [Susceptance](#CIM17v40-Susceptance) | Zero sequence shunt (charging) susceptance, uniformly distributed, of the entire line section. | |
| bch [0..1] | [Susceptance](#CIM17v40-Susceptance) | Positive sequence shunt (charging) susceptance, uniformly distributed, of the entire line section. This value represents the full charging over the full length of the line. | |
| g0ch [0..1] | [Conductance](#CIM17v40-Conductance) | Zero sequence shunt (charging) conductance, uniformly distributed, of the entire line section. | |
| gch [0..1] | [Conductance](#CIM17v40-Conductance) | Positive sequence shunt (charging) conductance, uniformly distributed, of the entire line section. | |
| r [0..1] | [Resistance](#CIM17v40-Resistance) | Positive sequence series resistance of the entire line section. | |
| r0 [0..1] | [Resistance](#CIM17v40-Resistance) | Zero sequence series resistance of the entire line section. | |
| shortCircuitEndTemperature [0..1] | [Temperature](#CIM17v40-Temperature) | Maximum permitted temperature at the end of SC for the calculation of minimum short-circuit currents. Used for short circuit data exchange according to IEC 60909. | |
| x [0..1] | [Reactance](#CIM17v40-Reactance) | Positive sequence series reactance of the entire line section. | |
| x0 [0..1] | [Reactance](#CIM17v40-Reactance) | Zero sequence series reactance of the entire line section. | |
| LineGroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | Ground action involving clamp usage (for the case when the ground is applied along the line segment instead of at its terminals). | |
| LineJumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | Jumper action involving clamp usage (for the case when the jumper is applied along the line segment instead of at its terminals). | |
| PerLengthImpedance [0..1] | [PerLengthImpedance](#CIM17v40-PerLengthImpedance) | Per-length impedance of this line segment. | |
| WireSpacingInfo [0..1] | [WireSpacingInfo](#CIM17v40-WireSpacingInfo) | The wire spacing information that applies to this AC line segment | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| length [0..1] | [Length](#CIM17v40-Length) | see [Conductor](CIM17v40-Conductor) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ACLineSegmentPhase}
### ACLineSegmentPhase

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ACLineSegmentPhase {

+ phase : enum:SinglePhaseKind [0..1]
+ sequenceNumber : Integer [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- ACLineSegmentPhase : inherits from
class ACLineSegment {

}

ACLineSegmentPhase --> "1" ACLineSegment : ACLineSegment
class WireInfo {

}

ACLineSegmentPhase --> "0..1" WireInfo : WireInfo
```

Represents a single wire of an alternating current line segment.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| phase [0..1] | [SinglePhaseKind](#CIM17v40-SinglePhaseKind) | The phase connection of the wire at both ends. | |
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | Number designation for this line segment phase. Each line segment phase within a line segment should have a unique sequence number. This is useful for unbalanced modelling to bind the mathematical model (PhaseImpedanceData of PerLengthPhaseImpedance) with the connectivity model (this class) and the physical model (WirePosition) without tight coupling. | |
| ACLineSegment [1] | [ACLineSegment](#CIM17v40-ACLineSegment) | The line segment to which the phase belongs. | |
| WireInfo [0..1] | [WireInfo](#CIM17v40-WireInfo) | Wire information contributing to this AC line segment phase information. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ASRequirements}
### ASRequirements


```mermaid
classDiagram
direction TB

class ASRequirements {

+ intervalStartTime : DateTime [0..1]
}

```

Models Ancillary Service Requirements. Describes interval for which the requirement is applicable.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | The start of the time interval for which requirement is defined. | |

{#CIM17v40-AccessPermit}
### AccessPermit

Inheritance path = [WorkDocument](#CIM17v40-WorkDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AccessPermit {

+ applicationNumber : String [0..1]
+ effectiveDate : Date [0..1]
+ expirationDate : Date [0..1]
+ payment : Money [0..1]
+ permitID : String [0..1]
}

class WorkDocument {

}

WorkDocument <|-- AccessPermit : inherits from
```

A permit is sometimes needed to provide legal access to land or equipment. For example, local authority permission for road works.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| applicationNumber [0..1] | [String](#CIM17v40-String) | Permit application number that is used by municipality, state, province, etc. | |
| effectiveDate [0..1] | [Date](#CIM17v40-Date) | Date that permit became official. | |
| expirationDate [0..1] | [Date](#CIM17v40-Date) | Permit expiration date. | |
| payment [0..1] | [Money](#CIM17v40-Money) | Total cost of permit. | |
| permitID [0..1] | [String](#CIM17v40-String) | Permit identifier. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AccountNotification}
### AccountNotification


```mermaid
classDiagram
direction TB

class AccountNotification {

+ customerNotificationType : String [0..1]
+ methodType : String [0..1]
+ note : String [0..1]
+ time : DateTime [0..1]
}

class CustomerAccount {

}

AccountNotification --> "1" CustomerAccount : CustomerAccount
```

Notifications for move-in, move-out, delinquencies, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| customerNotificationType [0..1] | [String](#CIM17v40-String) | Notifications for move-in, move-out, delinquencies, planned outage, demand response programs, time of use, etc. | |
| methodType [0..1] | [String](#CIM17v40-String) | method of notification such as phone call, email, letter, door hanger, text message, etc. | |
| note [0..1] | [String](#CIM17v40-String) | Free form text characterizing the notification. | |
| time [0..1] | [DateTime](#CIM17v40-DateTime) | Time of notification - this is the time the notification was sent. | |
| CustomerAccount [1] | [CustomerAccount](#CIM17v40-CustomerAccount) | The customer account for which a notification is made | |

{#CIM17v40-Accumulator}
### Accumulator

Inheritance path = [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Accumulator {

+ maxValue : Integer [0..1]
}

class Measurement {

}

Measurement <|-- Accumulator : inherits from
```

Accumulator represents an accumulated (counted) Measurement, e.g. an energy value.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maxValue [0..1] | [Integer](#CIM17v40-Integer) | Normal value range maximum for any of the MeasurementValue.values. Used for scaling, e.g. in bar graphs or of telemetered raw values. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AccumulatorLimit}
### AccumulatorLimit

Inheritance path = [Limit](#CIM17v40-Limit) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AccumulatorLimit {

+ value : Integer [0..1]
}

class Limit {

}

Limit <|-- AccumulatorLimit : inherits from
class AccumulatorLimitSet {

}

AccumulatorLimit --> "1" AccumulatorLimitSet : LimitSet
```

Limit values for Accumulator measurements.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| value [0..1] | [Integer](#CIM17v40-Integer) | The value to supervise against. The value is positive. | |
| `LimitSet [1]` (OfAggregate) | [AccumulatorLimitSet](#CIM17v40-AccumulatorLimitSet) | The set of limits. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AccumulatorLimitSet}
### AccumulatorLimitSet

Inheritance path = [LimitSet](#CIM17v40-LimitSet) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AccumulatorLimitSet {

}

class LimitSet {

}

LimitSet <|-- AccumulatorLimitSet : inherits from
```

An AccumulatorLimitSet specifies a set of Limits that are associated with an Accumulator measurement.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| isPercentageLimits [0..1] | [Boolean](#CIM17v40-Boolean) | see [LimitSet](#CIM17v40-LimitSet) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AccumulatorReset}
### AccumulatorReset

Inheritance path = [Control](#CIM17v40-Control) => [IOPoint](#CIM17v40-IOPoint) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AccumulatorReset {

}

class Control {

}

Control <|-- AccumulatorReset : inherits from
class AccumulatorValue {

}

AccumulatorReset --> "1" AccumulatorValue : AccumulatorValue
```

This command resets the counter value to zero.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AccumulatorValue [1] | [AccumulatorValue](#CIM17v40-AccumulatorValue) | The accumulator value that is reset by the command. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| controlType [0..1] | [String](#CIM17v40-String) | see [Control](#CIM17v40-Control) | |
| operationInProgress [0..1] | [Boolean](#CIM17v40-Boolean) | see [Control](#CIM17v40-Control) | |
| timeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | see [Control](#CIM17v40-Control) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Control](CIM17v40-Control) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Control](CIM17v40-Control) | |
| ControlAction [0..1] | [ControlAction](#CIM17v40-ControlAction) | see [Control](CIM17v40-Control) | |
| PowerSystemResource [0..1] | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Control](CIM17v40-Control) | |
| RemoteControl [0..1] | [RemoteControl](#CIM17v40-RemoteControl) | see [Control](CIM17v40-Control) | |
| IOPointSource [0..1] | [IOPointSource](#CIM17v40-IOPointSource) | see [IOPoint](CIM17v40-IOPoint) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AccumulatorValue}
### AccumulatorValue

Inheritance path = [MeasurementValue](#CIM17v40-MeasurementValue) => [IOPoint](#CIM17v40-IOPoint) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AccumulatorValue {

+ value : Integer [0..1]
}

class MeasurementValue {

}

MeasurementValue <|-- AccumulatorValue : inherits from
class Accumulator {

}

AccumulatorValue --> "1" Accumulator : Accumulator
class AccumulatorReset {

}

AccumulatorValue --> "0..1" AccumulatorReset : AccumulatorReset
```

AccumulatorValue represents an accumulated (counted) MeasurementValue.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| value [0..1] | [Integer](#CIM17v40-Integer) | The value to supervise. The value is positive. | |
| Accumulator [1] | [Accumulator](#CIM17v40-Accumulator) | Measurement to which this value is connected. | |
| AccumulatorReset [0..1] | [AccumulatorReset](#CIM17v40-AccumulatorReset) | The command that resets the accumulator value. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| sensorAccuracy [0..1] | [PerCent](#CIM17v40-PerCent) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| timeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | see [MeasurementValue](#CIM17v40-MeasurementValue) | |
| `CalculationMethodHierarchy [0..1]` (harmonization) | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| `ErpPerson [0..1]` (informative) | [OldPerson](#CIM17v40-OldPerson) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| `MeasurementValueQuality [0..1]` (AggregateOf) | [MeasurementValueQuality](#CIM17v40-MeasurementValueQuality) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| MeasurementValueSource [1] | [MeasurementValueSource](#CIM17v40-MeasurementValueSource) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| RemoteSource [0..1] | [RemoteSource](#CIM17v40-RemoteSource) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| IOPointSource [0..1] | [IOPointSource](#CIM17v40-IOPointSource) | see [IOPoint](CIM17v40-IOPoint) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AceTariffType}
### AceTariffType


```mermaid
classDiagram
direction TB

class AceTariffType {

+ type : String [0..1]
}

```

The Area Control Error tariff type that is applied or used.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| type [0..1] | [String](#CIM17v40-String) | The coded type of an ACE tariff. | |

{#CIM17v40-ActionRequest}
### ActionRequest


```mermaid
classDiagram
direction TB

class ActionRequest {

+ actionName : enum:ActionType [0..1]
}

```

Action request against an existing Trade.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| actionName [0..1] | [ActionType](#CIM17v40-ActionType) | Action name type for the action request. | |

{#CIM17v40-ActivePowerLimit}
### ActivePowerLimit

Inheritance path = [OperationalLimit](#CIM17v40-OperationalLimit) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ActivePowerLimit {

+ normalValue : ActivePower [0..1]
+ value : ActivePower [0..1]
}

class OperationalLimit {

}

OperationalLimit <|-- ActivePowerLimit : inherits from
```

Limit on active power flow.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| normalValue [0..1] | [ActivePower](#CIM17v40-ActivePower) | The normal value of active power limit. The attribute shall be a positive value or zero. | |
| value [0..1] | [ActivePower](#CIM17v40-ActivePower) | Value of active power limit. The attribute shall be a positive value or zero. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `OperationalLimitSet [1]` (OfAggregate) | [OperationalLimitSet](#CIM17v40-OperationalLimitSet) | see [OperationalLimit](CIM17v40-OperationalLimit) | |
| OperationalLimitType [0..1] | [OperationalLimitType](#CIM17v40-OperationalLimitType) | see [OperationalLimit](CIM17v40-OperationalLimit) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ActivityRecord}
### ActivityRecord

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ActivityRecord {

+ createdDateTime : DateTime [0..1]
+ reason : String [0..1]
+ severity : String [0..1]
+ type : String [0..1]
+ status : Status [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ActivityRecord : inherits from
class Author {

}

ActivityRecord --> "0..1" Author : Author
class Document {

}

ActivityRecord --> "0..1" Document : Document
```

Records activity for an entity at a point in time; activity may be for an event that has already occurred or for a planned activity.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time this activity record has been created (different from the 'status.dateTime', which is the time of a status change of the associated object, if applicable). | |
| reason [0..1] | [String](#CIM17v40-String) | Reason for event resulting in this activity record, typically supplied when user initiated. | |
| severity [0..1] | [String](#CIM17v40-String) | Severity level of event resulting in this activity record. | |
| type [0..1] | [String](#CIM17v40-String) | Type of event resulting in this activity record. | |
| Author [0..1] | [Author](#CIM17v40-Author) | Author of this activity record. | |
| Document [0..1] | [Document](#CIM17v40-Document) | The document having associated activity records | |
| status [0..1] | [Status](#CIM17v40-Status) | Information on consequence of event resulting in this activity record. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AdjacentCASet}
### AdjacentCASet

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AdjacentCASet {

+ lossPercentage : Float [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- AdjacentCASet : inherits from
class HostControlArea {

}

AdjacentCASet --> "0..1" HostControlArea : HostControlArea
class RTO {

}

AdjacentCASet --> "1" RTO : RTO
```

Groups Adjacent Control Areas.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| lossPercentage [0..1] | [Float](#CIM17v40-Float) | Loss percentage | |
| HostControlArea [0..1] | [HostControlArea](#CIM17v40-HostControlArea) | | |
| RTO [1] | [RTO](#CIM17v40-RTO) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AggregateNode}
### AggregateNode

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AggregateNode {

+ anodeType : enum:AnodeType [0..1]
+ qualifASOrder : Integer [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- AggregateNode : inherits from
class RTO {

}

AggregateNode --> "1" RTO : RTO
```

An aggregated node can define a typed grouping further defined by the AnodeType enumeratuion. Types range from System Zone/Regions to Market Energy Regions to Aggregated Loads and Aggregated Generators.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| anodeType [0..1] | [AnodeType](#CIM17v40-AnodeType) | Type of aggregated node | |
| qualifASOrder [0..1] | [Integer](#CIM17v40-Integer) | Processing Order for AS self-provisions for this region. The priority of this attribute directs the awards of any resource that resides in overlapping regions. The regions are processed in priority manner. | |
| RTO [1] | [RTO](#CIM17v40-RTO) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AggregateScore}
### AggregateScore

Inheritance path = [AnalyticScore](#CIM17v40-AnalyticScore) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AggregateScore {

}

class AnalyticScore {

}

AnalyticScore <|-- AggregateScore : inherits from
```

An aggregated indicative scoring by an analytic, which is based on other analytic scores, that can be used to characterize the health of or the risk associated with one or more assets.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| calculationDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [AnalyticScore](#CIM17v40-AnalyticScore) | |
| effectiveDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [AnalyticScore](#CIM17v40-AnalyticScore) | |
| value [0..1] | [Float](#CIM17v40-Float) | see [AnalyticScore](#CIM17v40-AnalyticScore) | |
| Analytic [0..1] | [Analytic](#CIM17v40-Analytic) | see [AnalyticScore](CIM17v40-AnalyticScore) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [AnalyticScore](CIM17v40-AnalyticScore) | |
| AssetAggregateScore [0..1] | [AggregateScore](#CIM17v40-AggregateScore) | see [AnalyticScore](CIM17v40-AnalyticScore) | |
| AssetGroup [0..1] | [AssetGroup](#CIM17v40-AssetGroup) | see [AnalyticScore](CIM17v40-AnalyticScore) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AggregatedPnode}
### AggregatedPnode

Inheritance path = [Pnode](#CIM17v40-Pnode) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AggregatedPnode {

+ apnodeType : enum:ApnodeType [0..1]
+ participationCategory : enum:ParticipationCategoryMPM [0..1]
}

class Pnode {

}

Pnode <|-- AggregatedPnode : inherits from
```

An aggregated pricing node is a specialized type of pricing node used to model items such as System Zone, Default Price Zone, Custom Price Zone, Control Area, Aggregated Generation, Aggregated Particpating Load, Aggregated Non-Participating Load, Trading Hub, Designated Control Area(DCA) Zone.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| apnodeType [0..1] | [ApnodeType](#CIM17v40-ApnodeType) | Aggregate Price Node Types | |
| participationCategory [0..1] | [ParticipationCategoryMPM](#CIM17v40-ParticipationCategoryMPM) | Designated Control Area participation in LMP price measurement'Y' - Participates in both Local Market Power Mitigation (LMPM) and System Market Power Mitigation (SMPM)'N' - Not included in LMP price measures'S' - Participatesin SMPM price measures'L' - Participatesin LMPM price measures | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| isPublic [0..1] | [Boolean](#CIM17v40-Boolean) | see [Pnode](#CIM17v40-Pnode) | |
| RTO [0..1] | [RTO](#CIM17v40-RTO) | see [Pnode](CIM17v40-Pnode) | |
| SubControlArea [0..1] | [SubControlArea](#CIM17v40-SubControlArea) | see [Pnode](CIM17v40-Pnode) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Agreement}
### Agreement

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Agreement {

+ signDate : Date [0..1]
+ validityInterval : DateTimeInterval [0..1]
}

class Document {

}

Document <|-- Agreement : inherits from
```

Formal agreement between two parties defining the terms and conditions for a set of services. The specifics of the services are, in turn, defined via one or more service agreements.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| signDate [0..1] | [Date](#CIM17v40-Date) | Date this agreement was consummated among associated persons and/or organisations. | |
| validityInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Date and time interval this agreement is valid (from going into effect to termination). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AirCompressor}
### AirCompressor

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AirCompressor {

+ airCompressorRating : Float [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- AirCompressor : inherits from
class CAESPlant {

}

AirCompressor --> "1" CAESPlant : CAESPlant
class CombustionTurbine {

}

AirCompressor --> "1" CombustionTurbine : CombustionTurbine
```

Combustion turbine air compressor which is an integral part of a compressed air energy storage (CAES) plant.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| airCompressorRating [0..1] | [Float](#CIM17v40-Float) | Rating of the CAES air compressor. | |
| `CAESPlant [1]` (OfAggregate) | [CAESPlant](#CIM17v40-CAESPlant) | An air compressor may be a member of a compressed air energy storage plant. | |
| CombustionTurbine [1] | [CombustionTurbine](#CIM17v40-CombustionTurbine) | A CAES air compressor is driven by combustion turbine. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AlertTypeList}
### AlertTypeList

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AlertTypeList {

+ version : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- AlertTypeList : inherits from
class EnvironmentalDataAuthority {

}

AlertTypeList --> "0..1" EnvironmentalDataAuthority : EnvironmentalDataAuthority
```

A named list of alert types.

Note: the name of the list is reflected in the .name attribute (inherited from IdentifiedObject).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| version [0..1] | [String](#CIM17v40-String) | The version of the named list of alert types. | |
| EnvironmentalDataAuthority [0..1] | [EnvironmentalDataAuthority](#CIM17v40-EnvironmentalDataAuthority) | The environmental data authority responsible for publishing this list of alert types. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AllocationResult}
### AllocationResult


```mermaid
classDiagram
direction TB

class AllocationResult {

+ intervalStartTime : DateTime [0..1]
+ updateTimeStamp : DateTime [0..1]
+ updateUser : String [0..1]
}

```

Models Market clearing results. Indicates market horizon, interval based. Used by a market quality system for billing and settlement purposes.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| updateTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| updateUser [0..1] | [String](#CIM17v40-String) | | |

{#CIM17v40-AllocationResultValues}
### AllocationResultValues


```mermaid
classDiagram
direction TB

class AllocationResultValues {

+ aggregateType : String [0..1]
+ allocationMwHour : Float [0..1]
+ allocationPrice : Float [0..1]
+ energyTypeCode : String [0..1]
+ marketServiceType : String [0..1]
}

class AllocationResult {

}

AllocationResultValues --> "1" AllocationResult : AllocationResult
class RegisteredResource {

}

AllocationResultValues --> "0..1" RegisteredResource : RegisteredResource
```

Models Market clearing results in terms of price and MW values.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aggregateType [0..1] | [String](#CIM17v40-String) | "1" -- "Detail","2" -- "Aggregate by Market service type", in which case, the "AllocationEnergyType" field will not be filled;"3" -- "Aggregate by "AllocationEnergyType", in which case "MarketServiceType" will not be filled. | |
| allocationMwHour [0..1] | [Float](#CIM17v40-Float) | | |
| allocationPrice [0..1] | [Float](#CIM17v40-Float) | | |
| energyTypeCode [0..1] | [String](#CIM17v40-String) | | |
| marketServiceType [0..1] | [String](#CIM17v40-String) | Choices are:ME - Market Energy Capacity;SR - Spinning Reserve Capacity;NR - Non-Spinning Reserve Capacity;DAC - Day Ahead Capacity;DEC - Derate Capacity | |
| `AllocationResult [1]` (OfAggregate) | [AllocationResult](#CIM17v40-AllocationResult) | | |
| RegisteredResource [0..1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |

{#CIM17v40-AltGeneratingUnitMeas}
### AltGeneratingUnitMeas

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AltGeneratingUnitMeas {

+ priority : Integer [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- AltGeneratingUnitMeas : inherits from
class AnalogValue {

}

AltGeneratingUnitMeas --> "1" AnalogValue : AnalogValue
class ControlAreaGeneratingUnit {

}

AltGeneratingUnitMeas --> "1" ControlAreaGeneratingUnit : ControlAreaGeneratingUnit
```

A prioritized measurement to be used for the generating unit in the control area specification.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| priority [0..1] | [Integer](#CIM17v40-Integer) | Priority of a measurement usage. Lower numbers have first priority. | |
| AnalogValue [1] | [AnalogValue](#CIM17v40-AnalogValue) | The specific analog value used as a source. | |
| `ControlAreaGeneratingUnit [1]` (OfAggregate) | [ControlAreaGeneratingUnit](#CIM17v40-ControlAreaGeneratingUnit) | The control area generating unit to which the prioritized measurement assignment is applied. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AltTieMeas}
### AltTieMeas

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AltTieMeas {

+ priority : Integer [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- AltTieMeas : inherits from
class AnalogValue {

}

AltTieMeas --> "1" AnalogValue : AnalogValue
class TieFlow {

}

AltTieMeas --> "1" TieFlow : TieFlow
```

A prioritized measurement to be used for the tie flow as part of the control area specification.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| priority [0..1] | [Integer](#CIM17v40-Integer) | Priority of a measurement usage. Lower numbers have first priority. | |
| AnalogValue [1] | [AnalogValue](#CIM17v40-AnalogValue) | The specific analog value used as a source. | |
| `TieFlow [1]` (OfAggregate) | [TieFlow](#CIM17v40-TieFlow) | The tie flow of the alternate measurements. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AlternateModel}
### (informative) AlternateModel

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AlternateModel {

}

class IdentifiedObject {

}

IdentifiedObject <|-- AlternateModel : inherits from
class AlternateModelGroup {

}

AlternateModel --> "1" AlternateModelGroup : AlternateModelGroup
class DataSet {

}

AlternateModel --> "1" DataSet : Dataset
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `AlternateModelGroup [1]` (informative) | [AlternateModelGroup](#CIM17v40-AlternateModelGroup) | The group of alternate models for which one alternate is used. | |
| `Dataset [1]` (informative) | [DataSet](#CIM17v40-DataSet) | The data belonging to the alternate model. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AlternateModelGroup}
### (informative) AlternateModelGroup

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AlternateModelGroup {

}

class IdentifiedObject {

}

IdentifiedObject <|-- AlternateModelGroup : inherits from
```


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Analog}
### Analog

Inheritance path = [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Analog {

+ maxValue : Float [0..1]
+ minValue : Float [0..1]
+ normalValue : Float [0..1]
+ positiveFlowIn : Boolean [0..1]
}

class Measurement {

}

Measurement <|-- Analog : inherits from
```

Analog represents an analog Measurement.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maxValue [0..1] | [Float](#CIM17v40-Float) | Normal value range maximum for any of the MeasurementValue.values. Used for scaling, e.g. in bar graphs or of telemetered raw values. | |
| minValue [0..1] | [Float](#CIM17v40-Float) | Normal value range minimum for any of the MeasurementValue.values. Used for scaling, e.g. in bar graphs or of telemetered raw values. | |
| normalValue [0..1] | [Float](#CIM17v40-Float) | Normal measurement value, e.g., used for percentage calculations. | |
| positiveFlowIn [0..1] | [Boolean](#CIM17v40-Boolean) | If true then this measurement is an active power, reactive power or current with the convention that a positive value measured at the Terminal means power is flowing into the related PowerSystemResource. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AnalogControl}
### AnalogControl

Inheritance path = [Control](#CIM17v40-Control) => [IOPoint](#CIM17v40-IOPoint) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AnalogControl {

+ maxValue : Float [0..1]
+ minValue : Float [0..1]
}

class Control {

}

Control <|-- AnalogControl : inherits from
class AnalogValue {

}

AnalogControl --> "1" AnalogValue : AnalogValue
```

An analog control used for supervisory control.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maxValue [0..1] | [Float](#CIM17v40-Float) | Normal value range maximum for any of the Control.value. Used for scaling, e.g. in bar graphs. | |
| minValue [0..1] | [Float](#CIM17v40-Float) | Normal value range minimum for any of the Control.value. Used for scaling, e.g. in bar graphs. | |
| AnalogValue [1] | [AnalogValue](#CIM17v40-AnalogValue) | The MeasurementValue that is controlled. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| controlType [0..1] | [String](#CIM17v40-String) | see [Control](#CIM17v40-Control) | |
| operationInProgress [0..1] | [Boolean](#CIM17v40-Boolean) | see [Control](#CIM17v40-Control) | |
| timeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | see [Control](#CIM17v40-Control) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Control](CIM17v40-Control) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Control](CIM17v40-Control) | |
| ControlAction [0..1] | [ControlAction](#CIM17v40-ControlAction) | see [Control](CIM17v40-Control) | |
| PowerSystemResource [0..1] | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Control](CIM17v40-Control) | |
| RemoteControl [0..1] | [RemoteControl](#CIM17v40-RemoteControl) | see [Control](CIM17v40-Control) | |
| IOPointSource [0..1] | [IOPointSource](#CIM17v40-IOPointSource) | see [IOPoint](CIM17v40-IOPoint) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AnalogLimit}
### AnalogLimit

Inheritance path = [Limit](#CIM17v40-Limit) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AnalogLimit {

+ value : Float [0..1]
}

class Limit {

}

Limit <|-- AnalogLimit : inherits from
class AnalogLimitSet {

}

AnalogLimit --> "1" AnalogLimitSet : LimitSet
```

Limit values for Analog measurements.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| value [0..1] | [Float](#CIM17v40-Float) | The value to supervise against. | |
| `LimitSet [1]` (OfAggregate) | [AnalogLimitSet](#CIM17v40-AnalogLimitSet) | The set of limits. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AnalogLimitSet}
### AnalogLimitSet

Inheritance path = [LimitSet](#CIM17v40-LimitSet) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AnalogLimitSet {

}

class LimitSet {

}

LimitSet <|-- AnalogLimitSet : inherits from
```

An AnalogLimitSet specifies a set of Limits that are associated with an Analog measurement.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| isPercentageLimits [0..1] | [Boolean](#CIM17v40-Boolean) | see [LimitSet](#CIM17v40-LimitSet) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AnalogMeasurementValueQuality}
### AnalogMeasurementValueQuality

Inheritance path = [MeasurementValueQuality](#CIM17v40-MeasurementValueQuality) => [Quality61850](#CIM17v40-Quality61850)

```mermaid
classDiagram
direction TB

class AnalogMeasurementValueQuality {

+ scadaQualityCode : String [0..1]
}

class MeasurementValueQuality {

}

MeasurementValueQuality <|-- AnalogMeasurementValueQuality : inherits from
```

Measurement quality flags for Analog Values.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| scadaQualityCode [0..1] | [String](#CIM17v40-String) | The quality code for the given Analog Value. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `MeasurementValue [1]` (OfAggregate) | [MeasurementValue](#CIM17v40-MeasurementValue) | see [MeasurementValueQuality](CIM17v40-MeasurementValueQuality) | |
| badReference [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| estimatorReplaced [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| failure [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| oldData [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| operatorBlocked [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| oscillatory [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| outOfRange [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| overFlow [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| source [0..1] | [Source](#CIM17v40-Source) | see [Quality61850](CIM17v40-Quality61850) | |
| suspect [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| test [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| validity [0..1] | [Validity](#CIM17v40-Validity) | see [Quality61850](CIM17v40-Quality61850) | |

{#CIM17v40-AnalogValue}
### AnalogValue

Inheritance path = [MeasurementValue](#CIM17v40-MeasurementValue) => [IOPoint](#CIM17v40-IOPoint) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AnalogValue {

+ value : Float [0..1]
}

class MeasurementValue {

}

MeasurementValue <|-- AnalogValue : inherits from
class Analog {

}

AnalogValue --> "1" Analog : Analog
class AnalogControl {

}

AnalogValue --> "0..1" AnalogControl : AnalogControl
```

AnalogValue represents an analog MeasurementValue.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| value [0..1] | [Float](#CIM17v40-Float) | The value to supervise. | |
| Analog [1] | [Analog](#CIM17v40-Analog) | Measurement to which this value is connected. | |
| AnalogControl [0..1] | [AnalogControl](#CIM17v40-AnalogControl) | The Control variable associated with the MeasurementValue. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| sensorAccuracy [0..1] | [PerCent](#CIM17v40-PerCent) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| timeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | see [MeasurementValue](#CIM17v40-MeasurementValue) | |
| `CalculationMethodHierarchy [0..1]` (harmonization) | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| `ErpPerson [0..1]` (informative) | [OldPerson](#CIM17v40-OldPerson) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| `MeasurementValueQuality [0..1]` (AggregateOf) | [MeasurementValueQuality](#CIM17v40-MeasurementValueQuality) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| MeasurementValueSource [1] | [MeasurementValueSource](#CIM17v40-MeasurementValueSource) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| RemoteSource [0..1] | [RemoteSource](#CIM17v40-RemoteSource) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| IOPointSource [0..1] | [IOPointSource](#CIM17v40-IOPointSource) | see [IOPoint](CIM17v40-IOPoint) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Analytic}
### Analytic

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Analytic {

+ bestValue : Float [0..1]
+ kind : enum:AnalyticKind [1]
+ scaleKind : enum:ScaleKind [0..1]
+ worstValue : Float [0..1]
}

class Document {

}

Document <|-- Analytic : inherits from
```

An algorithm or calculation for making an assessment about an asset or asset grouping for lifecycle decision making.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| bestValue [0..1] | [Float](#CIM17v40-Float) | Value that indicates best possible numeric value. | |
| kind [1] | [AnalyticKind](#CIM17v40-AnalyticKind) | Kind of analytic this analytic is. | |
| scaleKind [0..1] | [ScaleKind](#CIM17v40-ScaleKind) | The scoring scale kind. | |
| worstValue [0..1] | [Float](#CIM17v40-Float) | Value that indicates worst possible numeric value. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AnalyticScore}
### AnalyticScore

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AnalyticScore {

+ calculationDateTime : DateTime [0..1]
+ effectiveDateTime : DateTime [0..1]
+ value : Float [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- AnalyticScore : inherits from
class Analytic {

}

AnalyticScore --> "0..1" Analytic : Analytic
class Asset {

}

AnalyticScore --> "0..1" Asset : Asset
class AggregateScore {

}

AnalyticScore --> "0..1" AggregateScore : AssetAggregateScore
class AssetGroup {

}

AnalyticScore --> "0..1" AssetGroup : AssetGroup
```

An indicative scoring by an analytic that can be used to characterize the health of or the risk associated with one or more assets. The analytic score reflects the results of an execution of an analytic against an asset or group of assets.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| calculationDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Timestamp of when the score was calculated. | |
| effectiveDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date-time for when the score applies. | |
| value [0..1] | [Float](#CIM17v40-Float) | Asset health score value. | |
| Analytic [0..1] | [Analytic](#CIM17v40-Analytic) | Analytic which was executed to arrive at this analytic score.. | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | Asset to which this analytic score applies. | |
| AssetAggregateScore [0..1] | [AggregateScore](#CIM17v40-AggregateScore) | Aggregate score to which this analytic score contributed. | |
| AssetGroup [0..1] | [AssetGroup](#CIM17v40-AssetGroup) | Asset group to which this analytic score applies.. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AncillaryServiceClearing}
### AncillaryServiceClearing

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AncillaryServiceClearing {

}

class MarketFactors {

}

MarketFactors <|-- AncillaryServiceClearing : inherits from
class MarketCaseClearing {

}

AncillaryServiceClearing --> "0..1" MarketCaseClearing : MarketCaseClearing
```

Model of results of market clearing with respect to Ancillary Service products.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `MarketCaseClearing [0..1]` (informative) | [MarketCaseClearing](#CIM17v40-MarketCaseClearing) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AnnotatedProjectDependency}
### (informative) AnnotatedProjectDependency

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AnnotatedProjectDependency {

+ dependencyType : enum:DependencyKind [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- AnnotatedProjectDependency : inherits from
class NetworkModelProjectStage {

}

AnnotatedProjectDependency --> "1" NetworkModelProjectStage : DependentOnStage
class NetworkModelProjectStage {

}

AnnotatedProjectDependency --> "1" NetworkModelProjectStage : DependingStage
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dependencyType [0..1] | [DependencyKind](#CIM17v40-DependencyKind) | | |
| `DependentOnStage [1]` (informative) | [NetworkModelProjectStage](#CIM17v40-NetworkModelProjectStage) | | |
| `DependingStage [1]` (informative) | [NetworkModelProjectStage](#CIM17v40-NetworkModelProjectStage) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ApparentPowerLimit}
### ApparentPowerLimit

Inheritance path = [OperationalLimit](#CIM17v40-OperationalLimit) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ApparentPowerLimit {

+ normalValue : ApparentPower [0..1]
+ value : ApparentPower [0..1]
}

class OperationalLimit {

}

OperationalLimit <|-- ApparentPowerLimit : inherits from
```

Apparent power limit.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| normalValue [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | The normal apparent power limit. The attribute shall be a positive value or zero. | |
| value [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | The apparent power limit. The attribute shall be a positive value or zero. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `OperationalLimitSet [1]` (OfAggregate) | [OperationalLimitSet](#CIM17v40-OperationalLimitSet) | see [OperationalLimit](CIM17v40-OperationalLimit) | |
| OperationalLimitType [0..1] | [OperationalLimitType](#CIM17v40-OperationalLimitType) | see [OperationalLimit](CIM17v40-OperationalLimit) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Appointment}
### Appointment

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Appointment {

+ callAhead : Boolean [0..1]
+ meetingInterval : DateTimeInterval [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Appointment : inherits from
```

Meeting time and location.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| callAhead [0..1] | [Boolean](#CIM17v40-Boolean) | True if requested to call customer when someone is about to arrive at their premises. | |
| meetingInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Date and time reserved for appointment. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Approver}
### Approver

Inheritance path = [DocumentPersonRole](#CIM17v40-DocumentPersonRole) => [PersonRole](#CIM17v40-PersonRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Approver {

}

class DocumentPersonRole {

}

DocumentPersonRole <|-- Approver : inherits from
```

Person who accepted/signed or rejected the document.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Person [0..1] | [Person](#CIM17v40-Person) | see [PersonRole](CIM17v40-PersonRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AreaLoadBid}
### AreaLoadBid

Inheritance path = [Bid](#CIM17v40-Bid) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AreaLoadBid {

+ demandBidMW : Float [0..1]
}

class Bid {

}

Bid <|-- AreaLoadBid : inherits from
```

AreaLoadBid is not submitted by a market participant into the Markets. Instead, it is simply an aggregation of all LoadBids contained wtihin a specific SubControlArea. This entity should inherit from Bid for representation of the timeframe (startTime, stopTime) and the market type.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| demandBidMW [0..1] | [Float](#CIM17v40-Float) | The Demand Bid Megawatt for the area case.Attribute Usage: This is Scheduled demand MW in Day Ahead | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| marketType [0..1] | [MarketType](#CIM17v40-MarketType) | see [Bid](CIM17v40-Bid) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Bid](#CIM17v40-Bid) | |
| stopTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Bid](#CIM17v40-Bid) | |
| ActionRequest [1] | [ActionRequest](#CIM17v40-ActionRequest) | see [Bid](CIM17v40-Bid) | |
| EnergyMarket [1] | [EnergyMarket](#CIM17v40-EnergyMarket) | see [Bid](CIM17v40-Bid) | |
| MarketParticipant [0..1] | [MarketParticipant](#CIM17v40-MarketParticipant) | see [Bid](CIM17v40-Bid) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AreaLoadCurve}
### AreaLoadCurve

Inheritance path = [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) => [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AreaLoadCurve {

+ forecastType : enum:LoadForecastType [0..1]
}

class RegularIntervalSchedule {

}

RegularIntervalSchedule <|-- AreaLoadCurve : inherits from
class AggregateNode {

}

AreaLoadCurve --> "0..1" AggregateNode : AggregateNode
class TACArea {

}

AreaLoadCurve --> "0..1" TACArea : TACArea
```

Area load curve definition.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| forecastType [0..1] | [LoadForecastType](#CIM17v40-LoadForecastType) | Load forecast area type. | |
| AggregateNode [0..1] | [AggregateNode](#CIM17v40-AggregateNode) | | |
| TACArea [0..1] | [TACArea](#CIM17v40-TACArea) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | see [RegularIntervalSchedule](CIM17v40-RegularIntervalSchedule) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AreaReserveSpec}
### (informative) AreaReserveSpec


```mermaid
classDiagram
direction TB

class AreaReserveSpec {

+ Description : String [0..1]
+ lowerRegMarginReqt : ActivePower [0..1]
+ opReserveReqt : ActivePower [0..1]
+ primaryReserveReqt : ActivePower [0..1]
+ raiseRegMarginReqt : ActivePower [0..1]
+ spinningReserveReqt : ActivePower [0..1]
}

```

The control area's reserve specification.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Description [0..1] | [String](#CIM17v40-String) | Description of the object or instance. | |
| lowerRegMarginReqt [0..1] | [ActivePower](#CIM17v40-ActivePower) | Lower regulating margin requirement in MW, the amount of generation that can be dropped by control in 10 minutes | |
| opReserveReqt [0..1] | [ActivePower](#CIM17v40-ActivePower) | Operating reserve requirement in MW, where operating reserve is the generating capability that is fully available within 30 minutes. Operating reserve is composed of primary reserve (t less than 10 min) and secondary reserve (10 less than t less than 30 min). | |
| primaryReserveReqt [0..1] | [ActivePower](#CIM17v40-ActivePower) | Primary reserve requirement in MW, where primary reserve is generating capability that is fully available within 10 minutes. Primary reserve is composed of spinning reserve and quick-start reserve. | |
| raiseRegMarginReqt [0..1] | [ActivePower](#CIM17v40-ActivePower) | Raise regulating margin requirement in MW, the amount of generation that can be picked up by control in 10 minutes | |
| spinningReserveReqt [0..1] | [ActivePower](#CIM17v40-ActivePower) | Spinning reserve requirement in MW, spinning reserve is generating capability that is presently synchronized to the network and is fully available within 10 minutes | |

{#CIM17v40-AssemblyDescription}
### AssemblyDescription

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AssemblyDescription {

}

class IdentifiedObject {

}

IdentifiedObject <|-- AssemblyDescription : inherits from
```

A description for how to assemble model parts for a specific purpose.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AssemblyManifest}
### AssemblyManifest

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AssemblyManifest {

}

class IdentifiedObject {

}

IdentifiedObject <|-- AssemblyManifest : inherits from
```

A collection of model parts when combined form a case or part of a case.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Asset}
### (informative) Asset

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Asset {

+ critical : Boolean [0..1]
+ initialCondition : String [0..1]
+ initialLossOfLife : PerCent [0..1]
+ inUseState : enum:InUseStateKind [0..1]
+ kind : enum:AssetKind [0..1]
+ lifecycleState : enum:AssetLifecycleStateKind [0..1]
+ lotNumber : String [0..1]
+ position : String [0..1]
+ purchasePrice : Money [0..1]
+ retiredReason : enum:RetiredReasonKind [0..1]
+ serialNumber : String [0..1]
+ type : String [0..1]
+ utcNumber : String [0..1]
+ acceptanceTest : AcceptanceTest [0..1]
+ electronicAddress : ElectronicAddress [0..1]
+ inUseDate : InUseDate [0..1]
+ lifecycleDate : LifecycleDate [0..1]
+ status : Status [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Asset : inherits from
class AssetContainer {

}

Asset --> "0..1" AssetContainer : AssetContainer
class AssetDeployment {

}

Asset --> "0..1" AssetDeployment : AssetDeployment
class AssetInfo {

}

Asset --> "0..1" AssetInfo : AssetInfo
class SwitchOperationSummary {

}

Asset --> "0..1" SwitchOperationSummary : BreakerOperation
class ErpInventory {

}

Asset --> "0..1" ErpInventory : ErpInventory
class ErpItemMaster {

}

Asset --> "0..1" ErpItemMaster : ErpItemMaster
class FinancialInfo {

}

Asset --> "0..1" FinancialInfo : FinancialInfo
class Location {

}

Asset --> "0..1" Location : Location
class ProductAssetModel {

}

Asset --> "0..1" ProductAssetModel : ProductAssetModel
class ServiceLocation {

}

Asset --> "0..1" ServiceLocation : ServiceLocation
```

Tangible resource of the utility, including power system equipment, various end devices, cabinets, buildings, etc. For electrical network equipment, the role of the asset is defined through PowerSystemResource and its subclasses, defined mainly in the Wires model (refer to IEC61970-301 and model package IEC61970::Wires). Asset description places emphasis on the physical characteristics of the equipment fulfilling that role.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | True if asset is considered critical for some reason (for example, a pole with critical attachments). | |
| initialCondition [0..1] | [String](#CIM17v40-String) | Condition of asset at last baseline. Examples include new, rebuilt, overhaul required, other. Refer to inspection data for information on the most current condition of the asset. | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | Percentage of initial life expectancy that has been lost as of the last life expectancy baseline. Represents(initial life expectancy - current life expectancy) / initial life expectancy. | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | Indication of whether asset is currently deployed (in use), ready to be put into use or not available for use. | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | Kind of asset. Used in description of asset components in asset instance templates. | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | Current lifecycle state of asset. | |
| lotNumber [0..1] | [String](#CIM17v40-String) | Lot number for this asset. Even for the same model and version number, many assets are manufactured in lots. | |
| position [0..1] | [String](#CIM17v40-String) | Position of asset or asset component. May often be in relation to other assets or components. | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | Purchase price of asset. | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | Reason asset retired. | |
| serialNumber [0..1] | [String](#CIM17v40-String) | Serial number of this asset. | |
| type [0..1] | [String](#CIM17v40-String) | Utility-specific classification of Asset and its subtypes, according to their corporate standards, practices, and existing IT systems (e.g., for management of assets, maintenance, work, outage, customers, etc.). | |
| utcNumber [0..1] | [String](#CIM17v40-String) | Uniquely tracked commodity (UTC) number. | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | Information on acceptance test. | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | Container of this asset. | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | This asset's deployment. | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | Data applicable to this asset. | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | Breaker operation information for this breaker. | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | Electronic address. | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | Financial information related to this asset. | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | In use dates for this asset. | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | <was lifecycle>Lifecycle dates for this asset. | |
| Location [0..1] | [Location](#CIM17v40-Location) | Location of this asset. | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | The model of this asset. | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | The sevice location at which the assets exist | |
| status [0..1] | [Status](#CIM17v40-Status) | Status of this asset. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AssetAnalog}
### AssetAnalog

Inheritance path = [Analog](#CIM17v40-Analog) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AssetAnalog {

+ detectionLimit : Float [0..1]
+ precision : Float [0..1]
+ reportingTemperature : Temperature [0..1]
}

class Analog {

}

Analog <|-- AssetAnalog : inherits from
class TestStandard {

}

AssetAnalog --> "0..1" TestStandard : TestStandard
```

Definition of type of analog useful in asset domain.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| detectionLimit [0..1] | [Float](#CIM17v40-Float) | Detection limit of related analog value if different from detection limit of test standard or if there is no test standard. The detection limit (also known as lower limit of detection or limit of detection (LOD), is the lowest quantity of a substance that can be distinguished from the absence of that substance (a blank value) within a stated confidence limit (generally 1%). | |
| precision [0..1] | [Float](#CIM17v40-Float) | Precision of related analog value if different from precision of test standard or if there is no test standard. Precision is a measure of how closely individual measurements agree with one another. Expressed as 'plus or minus' the value of this attribute. | |
| reportingTemperature [0..1] | [Temperature](#CIM17v40-Temperature) | Reporting temperature of related analog value if different from reporting temperature of test standard or if there is no test standard. Reporting temperature is what gas volumes are normalized to. Different reporting temperatures are used by different sources. For example, ASTM specifies 0�C, whereas IEC specifies 20�C. Online monitors often have their own unique reporting temperatures. | |
| TestStandard [0..1] | [TestStandard](#CIM17v40-TestStandard) | The lab test standard to which this asset health analog is related. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maxValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| minValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| normalValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| positiveFlowIn [0..1] | [Boolean](#CIM17v40-Boolean) | see [Analog](#CIM17v40-Analog) | |
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AssetContainer}
### AssetContainer

Inheritance path = [Asset](#CIM17v40-Asset) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AssetContainer {

}

class Asset {

}

Asset <|-- AssetContainer : inherits from
```

Asset that is aggregation of other assets such as conductors, transformers, switchgear, land, fences, buildings, equipment, vehicles, etc.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | see [Asset](#CIM17v40-Asset) | |
| initialCondition [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | see [Asset](CIM17v40-Asset) | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | see [Asset](CIM17v40-Asset) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [Asset](CIM17v40-Asset) | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | see [Asset](CIM17v40-Asset) | |
| lotNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| position [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | see [Asset](CIM17v40-Asset) | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | see [Asset](CIM17v40-Asset) | |
| serialNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| type [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| utcNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | see [Asset](CIM17v40-Asset) | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | see [Asset](CIM17v40-Asset) | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | see [Asset](CIM17v40-Asset) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [Asset](CIM17v40-Asset) | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | see [Asset](CIM17v40-Asset) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Asset](CIM17v40-Asset) | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | see [Asset](CIM17v40-Asset) | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | see [Asset](CIM17v40-Asset) | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | see [Asset](CIM17v40-Asset) | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | see [Asset](CIM17v40-Asset) | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | see [Asset](CIM17v40-Asset) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Asset](CIM17v40-Asset) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [Asset](CIM17v40-Asset) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [Asset](CIM17v40-Asset) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Asset](CIM17v40-Asset) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AssetDeployment}
### AssetDeployment

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AssetDeployment {

+ breakerApplication : enum:BreakerApplicationKind [0..1]
+ deploymentState : enum:DeploymentStateKind [0..1]
+ facilityKind : enum:FacilityKind [0..1]
+ likelihoodOfFailure : Integer [0..1]
+ transformerApplication : enum:TransformerApplicationKind [0..1]
+ deploymentDate : DeploymentDate [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- AssetDeployment : inherits from
class Asset {

}

AssetDeployment --> "0..1" Asset : Asset
class BaseVoltage {

}

AssetDeployment --> "1" BaseVoltage : BaseVoltage
```

Deployment of asset deployment in a power system resource role.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| breakerApplication [0..1] | [BreakerApplicationKind](#CIM17v40-BreakerApplicationKind) | Type of network role breaker is playing in this deployment (applies to breaker assets only). | |
| deploymentState [0..1] | [DeploymentStateKind](#CIM17v40-DeploymentStateKind) | Current deployment state of asset. | |
| facilityKind [0..1] | [FacilityKind](#CIM17v40-FacilityKind) | Kind of facility (like substation or pole or building or plant or service center) at which asset deployed. | |
| likelihoodOfFailure [0..1] | [Integer](#CIM17v40-Integer) | Likelihood of asset failure on a scale of 1(low) to 100 (high). | |
| transformerApplication [0..1] | [TransformerApplicationKind](#CIM17v40-TransformerApplicationKind) | Type of network role transformer is playing in this deployment (applies to transformer assets only). | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | Asset in this deployment. | |
| BaseVoltage [1] | [BaseVoltage](#CIM17v40-BaseVoltage) | Base voltage of this network asset deployment. | |
| deploymentDate [0..1] | [DeploymentDate](#CIM17v40-DeploymentDate) | Dates of asset deployment. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AssetDiscrete}
### AssetDiscrete

Inheritance path = [Discrete](#CIM17v40-Discrete) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AssetDiscrete {

}

class Discrete {

}

Discrete <|-- AssetDiscrete : inherits from
class TestStandard {

}

AssetDiscrete --> "0..1" TestStandard : TestStandard
```

Definition of type of discrete useful in asset domain.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| TestStandard [0..1] | [TestStandard](#CIM17v40-TestStandard) | The lab test standard to which this asset health discrete is related. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maxValue [0..1] | [Integer](#CIM17v40-Integer) | see [Discrete](#CIM17v40-Discrete) | |
| minValue [0..1] | [Integer](#CIM17v40-Integer) | see [Discrete](#CIM17v40-Discrete) | |
| normalValue [0..1] | [Integer](#CIM17v40-Integer) | see [Discrete](#CIM17v40-Discrete) | |
| ValueAliasSet [0..1] | [ValueAliasSet](#CIM17v40-ValueAliasSet) | see [Discrete](CIM17v40-Discrete) | |
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AssetFunction}
### AssetFunction

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AssetFunction {

+ configID : String [0..1]
+ firmwareID : String [0..1]
+ hardwareID : String [0..1]
+ password : String [0..1]
+ programID : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- AssetFunction : inherits from
class Asset {

}

AssetFunction --> "0..1" Asset : Asset
```

Function performed by an asset.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| configID [0..1] | [String](#CIM17v40-String) | Configuration specified for this function. | |
| firmwareID [0..1] | [String](#CIM17v40-String) | Firmware version. | |
| hardwareID [0..1] | [String](#CIM17v40-String) | Hardware version. | |
| password [0..1] | [String](#CIM17v40-String) | Password needed to access this function. | |
| programID [0..1] | [String](#CIM17v40-String) | Name of program. | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | Asset on which this function can be performed. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AssetGroup}
### AssetGroup

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AssetGroup {

+ kind : enum:AssetGroupKind [1]
}

class Document {

}

Document <|-- AssetGroup : inherits from
```

A grouping of assets created for a purpose such as fleet analytics, inventory or compliance management.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [1] | [AssetGroupKind](#CIM17v40-AssetGroupKind) | Kind of asset group this asset group is. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AssetHealthEvent}
### AssetHealthEvent

Inheritance path = [ActivityRecord](#CIM17v40-ActivityRecord) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AssetHealthEvent {

+ actionRecommendation : String [0..1]
+ actionTimeline : Duration [0..1]
+ effectiveDateTime : DateTime [0..1]
}

class ActivityRecord {

}

ActivityRecord <|-- AssetHealthEvent : inherits from
class Analytic {

}

AssetHealthEvent --> "1" Analytic : Analytic
```

An asset health-related event that is created by an analytic. The event is a record of a change in asset health.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| actionRecommendation [0..1] | [String](#CIM17v40-String) | Recommendation for action. | |
| actionTimeline [0..1] | [Duration](#CIM17v40-Duration) | Time horizon for action. | |
| effectiveDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | The date and time when the event is effective. | |
| Analytic [1] | [Analytic](#CIM17v40-Analytic) | Analytic that initiated this asset health event. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| reason [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| severity [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| type [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| Document [0..1] | [Document](#CIM17v40-Document) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AssetInfo}
### AssetInfo

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AssetInfo {

}

class IdentifiedObject {

}

IdentifiedObject <|-- AssetInfo : inherits from
class CatalogAssetType {

}

AssetInfo --> "0..1" CatalogAssetType : CatalogAssetType
class ProductAssetModel {

}

AssetInfo --> "0..1" ProductAssetModel : ProductAssetModel
```

Set of attributes of an asset, representing typical datasheet information of a physical device that can be instantiated and shared in different data exchange contexts:

- as attributes of an asset instance (installed or in stock)

- as attributes of an asset model (product by a manufacturer)

- as attributes of a type asset (generic type of an asset as used in designs/extension planning).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | Asset information (nameplate) for this catalog asset type. | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | Product asset model which conforms to this catalog asset type. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AssetLocationHazard}
### AssetLocationHazard

Inheritance path = [Hazard](#CIM17v40-Hazard) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AssetLocationHazard {

+ kind : enum:AssetHazardKind [0..1]
}

class Hazard {

}

Hazard <|-- AssetLocationHazard : inherits from
```

Potential hazard related to the location of an asset. Examples are trees growing under overhead power lines, a park being located by a substation (i.e., children climb fence to recover a ball), a lake near an overhead distribution line (fishing pole/line contacting power lines), dangerous neighbour, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [AssetHazardKind](#CIM17v40-AssetHazardKind) | Kind of hazard. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| type [0..1] | [String](#CIM17v40-String) | see [Hazard](#CIM17v40-Hazard) | |
| Incident [0..1] | [Incident](#CIM17v40-Incident) | see [Hazard](CIM17v40-Hazard) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Hazard](CIM17v40-Hazard) | |
| TroubleTicket [0..1] | [TroubleTicket](#CIM17v40-TroubleTicket) | see [Hazard](CIM17v40-Hazard) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AssetModelCatalogue}
### (informative) AssetModelCatalogue

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AssetModelCatalogue {

+ status : Status [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- AssetModelCatalogue : inherits from
```

Catalogue of available types of products and materials that are used to build or install, maintain or operate an Asset. Each catalogue item is for a specific product (AssetModel) available from a specific supplier.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AssetModelCatalogueItem}
### (informative) AssetModelCatalogueItem

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AssetModelCatalogueItem {

+ unitCost : Money [0..1]
}

class Document {

}

Document <|-- AssetModelCatalogueItem : inherits from
class ProductAssetModel {

}

AssetModelCatalogueItem --> "0..1" ProductAssetModel : AssetModel
class AssetModelCatalogue {

}

AssetModelCatalogueItem --> "1" AssetModelCatalogue : AssetModelCatalogue
```

Provides pricing and other relevant information about a specific manufacturer's product (i.e., AssetModel), and its price from a given supplier. A single AssetModel may be availble from multiple suppliers. Note that manufacturer and supplier are both types of organisation, which the association is inherited from Document.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| unitCost [0..1] | [Money](#CIM17v40-Money) | Unit cost for an asset model from a specific supplier, either for a unit cost or cost per unit length. Cost is for material or asset only and does not include labor to install/construct or configure it. | |
| `AssetModel [0..1]` (informative) | [ProductAssetModel](#CIM17v40-ProductAssetModel) | | |
| `AssetModelCatalogue [1]` (informative) | [AssetModelCatalogue](#CIM17v40-AssetModelCatalogue) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AssetOrganisationRole}
### AssetOrganisationRole

Inheritance path = [OrganisationRole](#CIM17v40-OrganisationRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AssetOrganisationRole {

}

class OrganisationRole {

}

OrganisationRole <|-- AssetOrganisationRole : inherits from
```

Role an organisation plays with respect to asset.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Organisation [0..1] | [Organisation](#CIM17v40-Organisation) | see [OrganisationRole](CIM17v40-OrganisationRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AssetOwner}
### AssetOwner

Inheritance path = [AssetOrganisationRole](#CIM17v40-AssetOrganisationRole) => [OrganisationRole](#CIM17v40-OrganisationRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AssetOwner {

}

class AssetOrganisationRole {

}

AssetOrganisationRole <|-- AssetOwner : inherits from
```

Owner of the asset.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Organisation [0..1] | [Organisation](#CIM17v40-Organisation) | see [OrganisationRole](CIM17v40-OrganisationRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AssetPropertyCurve}
### AssetPropertyCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AssetPropertyCurve {

}

class Curve {

}

Curve <|-- AssetPropertyCurve : inherits from
class Specification {

}

AssetPropertyCurve --> "0..1" Specification : Specification
```

An Asset Property that is described through curves rather than as a data point. The relationship is to be defined between an independent variable (X-axis) and one or two dependent variables (Y1-axis and Y2-axis).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Specification [0..1]` (informative) | [Specification](#CIM17v40-Specification) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AssetStringMeasurement}
### AssetStringMeasurement

Inheritance path = [StringMeasurement](#CIM17v40-StringMeasurement) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AssetStringMeasurement {

+ kind : enum:AssetStringKind [0..1]
}

class StringMeasurement {

}

StringMeasurement <|-- AssetStringMeasurement : inherits from
class TestStandard {

}

AssetStringMeasurement --> "0..1" TestStandard : TestStandard
```

Definition of type of string measurement useful in asset domain.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [AssetStringKind](#CIM17v40-AssetStringKind) | Kind of string useful in asset domain. | |
| TestStandard [0..1] | [TestStandard](#CIM17v40-TestStandard) | Test standard which describes this asset string measurement. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AssetTemperaturePressureAnalog}
### AssetTemperaturePressureAnalog

Inheritance path = [AssetAnalog](#CIM17v40-AssetAnalog) => [Analog](#CIM17v40-Analog) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AssetTemperaturePressureAnalog {

+ kind : enum:AssetTemperaturePressureAnalogKind [0..1]
}

class AssetAnalog {

}

AssetAnalog <|-- AssetTemperaturePressureAnalog : inherits from
```

Temperature or pressure type of asset analog.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [AssetTemperaturePressureAnalogKind](#CIM17v40-AssetTemperaturePressureAnalogKind) | Kind of analog representing temperature or pressure related to an asset. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| detectionLimit [0..1] | [Float](#CIM17v40-Float) | see [AssetAnalog](#CIM17v40-AssetAnalog) | |
| precision [0..1] | [Float](#CIM17v40-Float) | see [AssetAnalog](#CIM17v40-AssetAnalog) | |
| reportingTemperature [0..1] | [Temperature](#CIM17v40-Temperature) | see [AssetAnalog](CIM17v40-AssetAnalog) | |
| TestStandard [0..1] | [TestStandard](#CIM17v40-TestStandard) | see [AssetAnalog](CIM17v40-AssetAnalog) | |
| maxValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| minValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| normalValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| positiveFlowIn [0..1] | [Boolean](#CIM17v40-Boolean) | see [Analog](#CIM17v40-Analog) | |
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AssetTestLab}
### AssetTestLab

Inheritance path = [AssetOrganisationRole](#CIM17v40-AssetOrganisationRole) => [OrganisationRole](#CIM17v40-OrganisationRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AssetTestLab {

}

class AssetOrganisationRole {

}

AssetOrganisationRole <|-- AssetTestLab : inherits from
```

Test lab that performs various types of testing related to assets.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Organisation [0..1] | [Organisation](#CIM17v40-Organisation) | see [OrganisationRole](CIM17v40-OrganisationRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AssetTestSampleTaker}
### AssetTestSampleTaker

Inheritance path = [AssetOrganisationRole](#CIM17v40-AssetOrganisationRole) => [OrganisationRole](#CIM17v40-OrganisationRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AssetTestSampleTaker {

}

class AssetOrganisationRole {

}

AssetOrganisationRole <|-- AssetTestSampleTaker : inherits from
```

Identity of person/organization that took sample.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Organisation [0..1] | [Organisation](#CIM17v40-Organisation) | see [OrganisationRole](CIM17v40-OrganisationRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AssetUser}
### AssetUser

Inheritance path = [AssetOrganisationRole](#CIM17v40-AssetOrganisationRole) => [OrganisationRole](#CIM17v40-OrganisationRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AssetUser {

}

class AssetOrganisationRole {

}

AssetOrganisationRole <|-- AssetUser : inherits from
```

Organisation that is a user of the asset.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Organisation [0..1] | [Organisation](#CIM17v40-Organisation) | see [OrganisationRole](CIM17v40-OrganisationRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Assignment}
### Assignment

Inheritance path = [WorkDocument](#CIM17v40-WorkDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Assignment {

+ effectivePeriod : DateTimeInterval [0..1]
}

class WorkDocument {

}

WorkDocument <|-- Assignment : inherits from
```

An assignment is given to an ErpPerson, Crew, Organisation, Equipment Item, Tool, etc. and may be used to perform Work, WorkTasks, Procedures, etc. TimeSchedules may be set up directly for Assignments or indirectly via the associated WorkTask. Note that these associations are all inherited through the recursive relationship on Document.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| effectivePeriod [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Period between the assignment becoming effective and its expiration. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AsynchronousMachine}
### AsynchronousMachine

Inheritance path = [RotatingMachine](#CIM17v40-RotatingMachine) => [RegulatingCondEq](#CIM17v40-RegulatingCondEq) => [EnergyConnection](#CIM17v40-EnergyConnection) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AsynchronousMachine {

+ asynchronousMachineType : enum:AsynchronousMachineKind [0..1]
+ converterFedDrive : Boolean [0..1]
+ efficiency : PerCent [0..1]
+ iaIrRatio : Float [0..1]
+ nominalFrequency : Frequency [0..1]
+ nominalSpeed : RotationSpeed [0..1]
+ polePairNumber : Integer [0..1]
+ ratedMechanicalPower : ActivePower [0..1]
+ reversible : Boolean [0..1]
+ rr1 : Resistance [0..1]
+ rr2 : Resistance [0..1]
+ rxLockedRotorRatio : Float [0..1]
+ tpo : Seconds [0..1]
+ tppo : Seconds [0..1]
+ xlr1 : Reactance [0..1]
+ xlr2 : Reactance [0..1]
+ xm : Reactance [0..1]
+ xp : Reactance [0..1]
+ xpp : Reactance [0..1]
+ xs : Reactance [0..1]
}

class RotatingMachine {

}

RotatingMachine <|-- AsynchronousMachine : inherits from
class AsynchronousMachineDynamics {

}

AsynchronousMachine --> "0..1" AsynchronousMachineDynamics : AsynchronousMachineDynamics
```

A rotating machine whose shaft rotates asynchronously with the electrical field. Also known as an induction machine with no external connection to the rotor windings, e.g. squirrel-cage induction machine.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| asynchronousMachineType [0..1] | [AsynchronousMachineKind](#CIM17v40-AsynchronousMachineKind) | Indicates the type of Asynchronous Machine (motor or generator). | |
| converterFedDrive [0..1] | [Boolean](#CIM17v40-Boolean) | Indicates whether the machine is a converter fed drive. Used for short circuit data exchange according to IEC 60909. | |
| efficiency [0..1] | [PerCent](#CIM17v40-PerCent) | Efficiency of the asynchronous machine at nominal operation as a percentage. Indicator for converter drive motors. Used for short circuit data exchange according to IEC 60909. | |
| iaIrRatio [0..1] | [Float](#CIM17v40-Float) | Ratio of locked-rotor current to the rated current of the motor (Ia/Ir). Used for short circuit data exchange according to IEC 60909. | |
| nominalFrequency [0..1] | [Frequency](#CIM17v40-Frequency) | Nameplate data indicates if the machine is 50 Hz or 60 Hz. | |
| nominalSpeed [0..1] | [RotationSpeed](#CIM17v40-RotationSpeed) | Nameplate data. Depends on the slip and number of pole pairs. | |
| polePairNumber [0..1] | [Integer](#CIM17v40-Integer) | Number of pole pairs of stator. Used for short circuit data exchange according to IEC 60909. | |
| ratedMechanicalPower [0..1] | [ActivePower](#CIM17v40-ActivePower) | Rated mechanical power (Pr in IEC 60909-0). Used for short circuit data exchange according to IEC 60909. | |
| reversible [0..1] | [Boolean](#CIM17v40-Boolean) | Indicates for converter drive motors if the power can be reversible. Used for short circuit data exchange according to IEC 60909. | |
| rr1 [0..1] | [Resistance](#CIM17v40-Resistance) | Damper 1 winding resistance. | |
| rr2 [0..1] | [Resistance](#CIM17v40-Resistance) | Damper 2 winding resistance. | |
| rxLockedRotorRatio [0..1] | [Float](#CIM17v40-Float) | Locked rotor ratio (R/X). Used for short circuit data exchange according to IEC 60909. | |
| tpo [0..1] | [Seconds](#CIM17v40-Seconds) | Transient rotor time constant (greater than tppo). | |
| tppo [0..1] | [Seconds](#CIM17v40-Seconds) | Sub-transient rotor time constant (greater than 0). | |
| xlr1 [0..1] | [Reactance](#CIM17v40-Reactance) | Damper 1 winding leakage reactance. | |
| xlr2 [0..1] | [Reactance](#CIM17v40-Reactance) | Damper 2 winding leakage reactance. | |
| xm [0..1] | [Reactance](#CIM17v40-Reactance) | Magnetizing reactance. | |
| xp [0..1] | [Reactance](#CIM17v40-Reactance) | Transient reactance (unsaturated) (greater than or equal to xpp). | |
| xpp [0..1] | [Reactance](#CIM17v40-Reactance) | Sub-transient reactance (unsaturated). | |
| xs [0..1] | [Reactance](#CIM17v40-Reactance) | Synchronous reactance (greater than xp). | |
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | Asynchronous machine dynamics model used to describe dynamic behaviour of this asynchronous machine. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| p [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [RotatingMachine](CIM17v40-RotatingMachine) | |
| q [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | see [RotatingMachine](CIM17v40-RotatingMachine) | |
| ratedPowerFactor [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachine](#CIM17v40-RotatingMachine) | |
| ratedS [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | see [RotatingMachine](CIM17v40-RotatingMachine) | |
| ratedU [0..1] | [Voltage](#CIM17v40-Voltage) | see [RotatingMachine](CIM17v40-RotatingMachine) | |
| GeneratingUnit [0..1] | [GeneratingUnit](#CIM17v40-GeneratingUnit) | see [RotatingMachine](CIM17v40-RotatingMachine) | |
| HydroPump [0..1] | [HydroPump](#CIM17v40-HydroPump) | see [RotatingMachine](CIM17v40-RotatingMachine) | |
| controlEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [RegulatingCondEq](#CIM17v40-RegulatingCondEq) | |
| RegulatingControl [0..1] | [RegulatingControl](#CIM17v40-RegulatingControl) | see [RegulatingCondEq](CIM17v40-RegulatingCondEq) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AsynchronousMachineDynamics}
### AsynchronousMachineDynamics

Inheritance path = [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AsynchronousMachineDynamics {

}

class RotatingMachineDynamics {

}

RotatingMachineDynamics <|-- AsynchronousMachineDynamics : inherits from
class AsynchronousMachine {

}

AsynchronousMachineDynamics --> "1" AsynchronousMachine : AsynchronousMachine
class MechanicalLoadDynamics {

}

AsynchronousMachineDynamics --> "0..1" MechanicalLoadDynamics : MechanicalLoadDynamics
class TurbineGovernorDynamics {

}

AsynchronousMachineDynamics --> "0..1" TurbineGovernorDynamics : TurbineGovernorDynamics
class WindTurbineType1or2Dynamics {

}

AsynchronousMachineDynamics --> "0..1" WindTurbineType1or2Dynamics : WindTurbineType1or2Dynamics
```

Asynchronous machine whose behaviour is described by reference to a standard model expressed in either time constant reactance form or equivalent circuit form <font color="#0f0f0f">or by definition of a user-defined model.</font>

Parameter details:

<ol>

<li>Asynchronous machine parameters such as <i>Xl, Xs,</i> etc. are actually used as inductances in the model, but are commonly referred to as reactances since, at nominal frequency, the PU values are the same. However, some references use the symbol <i>L</i> instead of <i>X</i>.</li>

</ol>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachine [1] | [AsynchronousMachine](#CIM17v40-AsynchronousMachine) | Asynchronous machine to which this asynchronous machine dynamics model applies. | |
| MechanicalLoadDynamics [0..1] | [MechanicalLoadDynamics](#CIM17v40-MechanicalLoadDynamics) | Mechanical load model associated with this asynchronous machine model. | |
| TurbineGovernorDynamics [0..1] | [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) | Turbine-governor model associated with this asynchronous machine model. | |
| WindTurbineType1or2Dynamics [0..1] | [WindTurbineType1or2Dynamics](#CIM17v40-WindTurbineType1or2Dynamics) | Wind generator type 1 or type 2 model associated with this asynchronous machine model. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| damping [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| inertia [0..1] | [Seconds](#CIM17v40-Seconds) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| saturationFactor [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| saturationFactor120 [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| statorLeakageReactance [0..1] | [PU](#CIM17v40-PU) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| statorResistance [0..1] | [PU](#CIM17v40-PU) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AsynchronousMachineEquivalentCircuit}
### AsynchronousMachineEquivalentCircuit

Inheritance path = [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) => [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AsynchronousMachineEquivalentCircuit {

+ rr1 : PU [0..1]
+ rr2 : PU [0..1]
+ xlr1 : PU [0..1]
+ xlr2 : PU [0..1]
+ xm : PU [0..1]
}

class AsynchronousMachineDynamics {

}

AsynchronousMachineDynamics <|-- AsynchronousMachineEquivalentCircuit : inherits from
```

The electrical equations of all variations of the asynchronous model are based on the AsynchronousEquivalentCircuit diagram for the direct- and quadrature- axes, with two equivalent rotor windings in each axis.

Equations for conversion between equivalent circuit and time constant reactance forms:

<i>Xs</i> = <i>Xm</i> + <i>Xl</i>

<i>X'</i> = <i>Xl</i> + <i>Xm</i> x <i>Xlr1 </i>/ (<i>Xm </i>+ <i>Xlr1</i>)

<i>X''</i> = <i>Xl</i> + <i>Xm</i> x <i>Xlr1</i> x <i>Xlr2</i> / (<i>Xm</i> x <i>Xlr1</i> + <i>Xm</i> x <i>Xlr2</i> + <i>Xlr1</i> x <i>Xlr2</i>)

<i>T'o</i> = (<i>Xm</i> + <i>Xlr1</i>) / (<i>omega</i><i><sub>0</sub></i> x <i>Rr1</i>)

<i>T''o</i> = (<i>Xm</i> x <i>Xlr1</i> + <i>Xm</i> x <i>Xlr2</i> + <i>Xlr1</i> x <i>Xlr2</i>) / (<i>omega</i><i><sub>0</sub></i> x <i>Rr2</i> x (<i>Xm</i> + <i>Xlr1</i>)

Same equations using CIM attributes from AsynchronousMachineTimeConstantReactance class on left of "=" and AsynchronousMachineEquivalentCircuit class on right (except as noted):

xs = xm + RotatingMachineDynamics.statorLeakageReactance

xp = RotatingMachineDynamics.statorLeakageReactance + xm x xlr1 / (xm + xlr1)

xpp = RotatingMachineDynamics.statorLeakageReactance + xm x xlr1 x xlr2 / (xm x xlr1 + xm x xlr2 + xlr1 x xlr2)

tpo = (xm + xlr1) / (2 x pi x nominal frequency x rr1)

tppo = (xm x xlr1 + xm x xlr2 + xlr1 x xlr2) / (2 x pi x nominal frequency x rr2 x (xm + xlr1).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| rr1 [0..1] | [PU](#CIM17v40-PU) | Damper 1 winding resistance. | |
| rr2 [0..1] | [PU](#CIM17v40-PU) | Damper 2 winding resistance. | |
| xlr1 [0..1] | [PU](#CIM17v40-PU) | Damper 1 winding leakage reactance. | |
| xlr2 [0..1] | [PU](#CIM17v40-PU) | Damper 2 winding leakage reactance. | |
| xm [0..1] | [PU](#CIM17v40-PU) | Magnetizing reactance. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachine [1] | [AsynchronousMachine](#CIM17v40-AsynchronousMachine) | see [AsynchronousMachineDynamics](CIM17v40-AsynchronousMachineDynamics) | |
| MechanicalLoadDynamics [0..1] | [MechanicalLoadDynamics](#CIM17v40-MechanicalLoadDynamics) | see [AsynchronousMachineDynamics](CIM17v40-AsynchronousMachineDynamics) | |
| TurbineGovernorDynamics [0..1] | [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) | see [AsynchronousMachineDynamics](CIM17v40-AsynchronousMachineDynamics) | |
| WindTurbineType1or2Dynamics [0..1] | [WindTurbineType1or2Dynamics](#CIM17v40-WindTurbineType1or2Dynamics) | see [AsynchronousMachineDynamics](CIM17v40-AsynchronousMachineDynamics) | |
| damping [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| inertia [0..1] | [Seconds](#CIM17v40-Seconds) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| saturationFactor [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| saturationFactor120 [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| statorLeakageReactance [0..1] | [PU](#CIM17v40-PU) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| statorResistance [0..1] | [PU](#CIM17v40-PU) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AsynchronousMachineTimeConstantReactance}
### AsynchronousMachineTimeConstantReactance

Inheritance path = [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) => [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AsynchronousMachineTimeConstantReactance {

+ tpo : Seconds [0..1]
+ tppo : Seconds [0..1]
+ xp : PU [0..1]
+ xpp : PU [0..1]
+ xs : PU [0..1]
}

class AsynchronousMachineDynamics {

}

AsynchronousMachineDynamics <|-- AsynchronousMachineTimeConstantReactance : inherits from
```

Parameter details:

<ol>

<li>If <i>X'' </i>=<i> X'</i>, a single cage (one equivalent rotor winding per axis) is modelled.</li>

<li>The �<i>p</i>� in the attribute names is a substitution for a �prime� in the usual parameter notation, e.g. <i>tpo</i> refers to <i>T'o</i>.</li>

</ol>

The parameters used for models expressed in time constant reactance form include:

- RotatingMachine.ratedS (<i>MVAbase</i>);

- RotatingMachineDynamics.damping (<i>D</i>);

- RotatingMachineDynamics.inertia (<i>H</i>);

- RotatingMachineDynamics.saturationFactor (<i>S1</i>);

- RotatingMachineDynamics.saturationFactor120 (<i>S12</i>);

- RotatingMachineDynamics.statorLeakageReactance (<i>Xl</i>);

- RotatingMachineDynamics.statorResistance (<i>Rs</i>);

- .xs (<i>Xs</i>);

- .xp (<i>X'</i>);

- .xpp (<i>X''</i>);

- .tpo (<i>T'o</i>);

- .tppo (<i>T''o</i>).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| tpo [0..1] | [Seconds](#CIM17v40-Seconds) | Transient rotor time constant (<i>T'o</i>) (&gt; AsynchronousMachineTimeConstantReactance.tppo). Typical value = 5. | |
| tppo [0..1] | [Seconds](#CIM17v40-Seconds) | Subtransient rotor time constant (<i>T''o</i>) (&gt; 0). Typical value = 0,03. | |
| xp [0..1] | [PU](#CIM17v40-PU) | Transient reactance (unsaturated) (<i>X'</i>) (&gt;= AsynchronousMachineTimeConstantReactance.xpp). Typical value = 0,5. | |
| xpp [0..1] | [PU](#CIM17v40-PU) | Subtransient reactance (unsaturated) (<i>X''</i>) (&gt; RotatingMachineDynamics.statorLeakageReactance). Typical value = 0,2. | |
| xs [0..1] | [PU](#CIM17v40-PU) | Synchronous reactance (<i>Xs</i>) (&gt;= AsynchronousMachineTimeConstantReactance.xp). Typical value = 1,8. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachine [1] | [AsynchronousMachine](#CIM17v40-AsynchronousMachine) | see [AsynchronousMachineDynamics](CIM17v40-AsynchronousMachineDynamics) | |
| MechanicalLoadDynamics [0..1] | [MechanicalLoadDynamics](#CIM17v40-MechanicalLoadDynamics) | see [AsynchronousMachineDynamics](CIM17v40-AsynchronousMachineDynamics) | |
| TurbineGovernorDynamics [0..1] | [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) | see [AsynchronousMachineDynamics](CIM17v40-AsynchronousMachineDynamics) | |
| WindTurbineType1or2Dynamics [0..1] | [WindTurbineType1or2Dynamics](#CIM17v40-WindTurbineType1or2Dynamics) | see [AsynchronousMachineDynamics](CIM17v40-AsynchronousMachineDynamics) | |
| damping [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| inertia [0..1] | [Seconds](#CIM17v40-Seconds) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| saturationFactor [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| saturationFactor120 [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| statorLeakageReactance [0..1] | [PU](#CIM17v40-PU) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| statorResistance [0..1] | [PU](#CIM17v40-PU) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AsynchronousMachineUserDefined}
### AsynchronousMachineUserDefined

Inheritance path = [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) => [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AsynchronousMachineUserDefined {

+ proprietary : Boolean [0..1]
}

class AsynchronousMachineDynamics {

}

AsynchronousMachineDynamics <|-- AsynchronousMachineUserDefined : inherits from
```

Asynchronous machine whose dynamic behaviour is described by a user-defined model.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| proprietary [0..1] | [Boolean](#CIM17v40-Boolean) | Behaviour is based on a proprietary model as opposed to a detailed model.true = user-defined model is proprietary with behaviour mutually understood by sending and receiving applications and parameters passed as general attributesfalse = user-defined model is explicitly defined in terms of control blocks and their input and output signals. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachine [1] | [AsynchronousMachine](#CIM17v40-AsynchronousMachine) | see [AsynchronousMachineDynamics](CIM17v40-AsynchronousMachineDynamics) | |
| MechanicalLoadDynamics [0..1] | [MechanicalLoadDynamics](#CIM17v40-MechanicalLoadDynamics) | see [AsynchronousMachineDynamics](CIM17v40-AsynchronousMachineDynamics) | |
| TurbineGovernorDynamics [0..1] | [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) | see [AsynchronousMachineDynamics](CIM17v40-AsynchronousMachineDynamics) | |
| WindTurbineType1or2Dynamics [0..1] | [WindTurbineType1or2Dynamics](#CIM17v40-WindTurbineType1or2Dynamics) | see [AsynchronousMachineDynamics](CIM17v40-AsynchronousMachineDynamics) | |
| damping [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| inertia [0..1] | [Seconds](#CIM17v40-Seconds) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| saturationFactor [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| saturationFactor120 [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| statorLeakageReactance [0..1] | [PU](#CIM17v40-PU) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| statorResistance [0..1] | [PU](#CIM17v40-PU) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AtmosphericAnalog}
### AtmosphericAnalog

Inheritance path = [EnvironmentalAnalog](#CIM17v40-EnvironmentalAnalog) => [Analog](#CIM17v40-Analog) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AtmosphericAnalog {

+ kind : enum:AtmosphericAnalogKind [0..1]
}

class EnvironmentalAnalog {

}

EnvironmentalAnalog <|-- AtmosphericAnalog : inherits from
```

Analog (float) measuring an atmospheric condition.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [AtmosphericAnalogKind](#CIM17v40-AtmosphericAnalogKind) | Kind of atmospheric analog. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ClassificationCondition [0..1] | [ClassificationCondition](#CIM17v40-ClassificationCondition) | see [EnvironmentalAnalog](CIM17v40-EnvironmentalAnalog) | |
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | see [EnvironmentalAnalog](CIM17v40-EnvironmentalAnalog) | |
| EnvironmentalMonitoringStation [0..1] | [EnvironmentalMonitoringStation](#CIM17v40-EnvironmentalMonitoringStation) | see [EnvironmentalAnalog](CIM17v40-EnvironmentalAnalog) | |
| ReportingCapability [0..1] | [ReportingCapability](#CIM17v40-ReportingCapability) | see [EnvironmentalAnalog](CIM17v40-EnvironmentalAnalog) | |
| maxValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| minValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| normalValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| positiveFlowIn [0..1] | [Boolean](#CIM17v40-Boolean) | see [Analog](#CIM17v40-Analog) | |
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AtmosphericPhenomenon}
### AtmosphericPhenomenon

Inheritance path = [EnvironmentalPhenomenon](#CIM17v40-EnvironmentalPhenomenon)

```mermaid
classDiagram
direction TB

class AtmosphericPhenomenon {

+ direction : Bearing [0..1]
+ maxCoverage : PerCent [0..1]
+ minCoverage : PerCent [0..1]
+ speed : Speed [0..1]
+ altitude : RelativeDisplacement [0..1]
+ base : RelativeDisplacement [0..1]
}

class EnvironmentalPhenomenon {

}

EnvironmentalPhenomenon <|-- AtmosphericPhenomenon : inherits from
```

An atmospheric phenomenon with a base and altitude providing the vertical coverage (combined with the Location to provide three dimensional space).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| direction [0..1] | [Bearing](#CIM17v40-Bearing) | The direction the phenomenon is moving. | |
| maxCoverage [0..1] | [PerCent](#CIM17v40-PerCent) | The maximum percentage coverage | |
| minCoverage [0..1] | [PerCent](#CIM17v40-PerCent) | The minimum percentage coverage | |
| speed [0..1] | [Speed](#CIM17v40-Speed) | The speed of the phenomenon | |
| altitude [0..1] | [RelativeDisplacement](#CIM17v40-RelativeDisplacement) | The maximum altitude of the phenomenon. | |
| base [0..1] | [RelativeDisplacement](#CIM17v40-RelativeDisplacement) | The base altitude of the phenomenon. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| PhenomenonClassification [0..1] | [PhenomenonClassification](#CIM17v40-PhenomenonClassification) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| timeInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |

{#CIM17v40-AttributeInstanceComponent}
### AttributeInstanceComponent


```mermaid
classDiagram
direction TB

class AttributeInstanceComponent {

+ attribute : String [0..1]
+ attributeValue : String [0..1]
+ position : Integer [0..1]
}

```

A class used to provide information about an attribute.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| attribute [0..1] | [String](#CIM17v40-String) | The identification of the formal name of an attribute. | |
| attributeValue [0..1] | [String](#CIM17v40-String) | The instance value of the attribute. | |
| position [0..1] | [Integer](#CIM17v40-Integer) | A sequential value representing a relative sequence number. | |

{#CIM17v40-AttributeProperty}
### AttributeProperty


```mermaid
classDiagram
direction TB

class AttributeProperty {

+ propertyName : String [0..1]
+ propertyValue : String [0..1]
+ sequence : String [0..1]
}

class MktUserAttribute {

}

AttributeProperty --> "1" MktUserAttribute : MktUserAttribute
```

Property for a particular attribute that contains name and value.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| propertyName [0..1] | [String](#CIM17v40-String) | | |
| propertyValue [0..1] | [String](#CIM17v40-String) | | |
| sequence [0..1] | [String](#CIM17v40-String) | | |
| MktUserAttribute [1] | [MktUserAttribute](#CIM17v40-MktUserAttribute) | | |

{#CIM17v40-Auction}
### Auction

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Auction {

+ allocationMode : String [0..1]
+ cancelled : String [0..1]
+ category : String [0..1]
+ paymentTerms : String [0..1]
+ rights : String [0..1]
+ type : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Auction : inherits from
```

A class providing the identification and type of an auction.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| allocationMode [0..1] | [String](#CIM17v40-String) | Identification of the method of allocation in an auction. | |
| cancelled [0..1] | [String](#CIM17v40-String) | An indicator that signifies that the auction has been cancelled. | |
| category [0..1] | [String](#CIM17v40-String) | The product category of an auction. | |
| paymentTerms [0..1] | [String](#CIM17v40-String) | The terms which dictate the determination of the bid payment price. | |
| rights [0..1] | [String](#CIM17v40-String) | The rights of use the transmission capacity acquired in an auction. | |
| type [0..1] | [String](#CIM17v40-String) | The kind of the Auction (e.g. implicit, explicit ...). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Author}
### Author

Inheritance path = [DocumentPersonRole](#CIM17v40-DocumentPersonRole) => [PersonRole](#CIM17v40-PersonRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Author {

}

class DocumentPersonRole {

}

DocumentPersonRole <|-- Author : inherits from
```

Person who created document or activity record.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Person [0..1] | [Person](#CIM17v40-Person) | see [PersonRole](CIM17v40-PersonRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AuxiliaryAccount}
### AuxiliaryAccount

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AuxiliaryAccount {

+ balance : Money [0..1]
+ principleAmount : Money [0..1]
+ due : Due [0..1]
+ lastCredit : AccountMovement [0..1]
+ lastDebit : AccountMovement [0..1]
}

class Document {

}

Document <|-- AuxiliaryAccount : inherits from
class AuxiliaryAgreement {

}

AuxiliaryAccount --> "0..1" AuxiliaryAgreement : AuxiliaryAgreement
```

Variable and dynamic part of auxiliary agreement, generally representing the current state of the account related to the outstanding balance defined in auxiliary agreement.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| balance [0..1] | [Money](#CIM17v40-Money) | The total amount currently remaining on this account that is required to be paid in order to settle the account to zero. This excludes any due amounts not yet paid. | |
| principleAmount [0..1] | [Money](#CIM17v40-Money) | The initial principle amount, with which this account was instantiated. | |
| AuxiliaryAgreement [0..1] | [AuxiliaryAgreement](#CIM17v40-AuxiliaryAgreement) | Auxiliary agreement regulating this account. | |
| due [0..1] | [Due](#CIM17v40-Due) | Current amounts now due for payment on this account. | |
| lastCredit [0..1] | [AccountMovement](#CIM17v40-AccountMovement) | Details of the last credit transaction performed on this account. | |
| lastDebit [0..1] | [AccountMovement](#CIM17v40-AccountMovement) | Details of the last debit transaction performed on this account. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AuxiliaryAgreement}
### AuxiliaryAgreement

Inheritance path = [Agreement](#CIM17v40-Agreement) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AuxiliaryAgreement {

+ arrearsInterest : PerCent [0..1]
+ auxCycle : String [0..1]
+ auxPriorityCode : String [0..1]
+ fixedAmount : Money [0..1]
+ minAmount : Money [0..1]
+ payCycle : String [0..1]
+ subType : String [0..1]
+ vendPortion : PerCent [0..1]
+ vendPortionArrear : PerCent [0..1]
}

class Agreement {

}

Agreement <|-- AuxiliaryAgreement : inherits from
class CustomerAgreement {

}

AuxiliaryAgreement --> "0..1" CustomerAgreement : CustomerAgreement
```

An ad-hoc auxiliary account agreement associated with a customer agreement, not part of the customer's account, but typically subject to formal agreement between customer and supplier (utility). Typically this is used to collect revenue owed by the customer for other services or arrears accrued with the utility for other services. It is typically linked to a prepaid token purchase transaction, thus forcing the customer to make a payment towards settlement of the auxiliary account balance whenever the customer needs to purchase a prepaid token for electricity.

The present status of the auxiliary agreement can be defined in the context of the utility's business rules, for example: enabled, disabled, pending, over recovered, under recovered, written off, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| arrearsInterest [0..1] | [PerCent](#CIM17v40-PerCent) | The interest per annum to be charged prorata on 'AuxiliaryAccount.dueArrears' at the end of each 'payCycle'. | |
| auxCycle [0..1] | [String](#CIM17v40-String) | The frequency for automatically recurring auxiliary charges, where 'AuxiliaryAccount.initialCharge' is recursively added to 'AuxiliaryAccount.dueCurrent' at the start of each 'auxCycle'. For example: on a specified date and time; hourly; daily; weekly; monthly; 3-monthly; 6-monthly; 12-monthly; etc. | |
| auxPriorityCode [0..1] | [String](#CIM17v40-String) | The coded priority indicating the priority that this auxiliary agreement has above other auxiliary agreements (associated with the same customer agreement) when it comes to competing for settlement from a payment transaction or token purchase. | |
| fixedAmount [0..1] | [Money](#CIM17v40-Money) | The fixed amount that has to be collected from each vending transaction towards settlement of this auxiliary agreement. Note that there may be multiple tokens vended per vending transaction, but this is not relevant. | |
| minAmount [0..1] | [Money](#CIM17v40-Money) | The minimum amount that has to be paid at any transaction towards settling this auxiliary agreement or reducing the balance. | |
| payCycle [0..1] | [String](#CIM17v40-String) | The contractually expected payment frequency (by the customer). Examples are: ad-hoc; on specified date; hourly, daily, weekly, monthly. etc. | |
| subType [0..1] | [String](#CIM17v40-String) | Sub-classification of the inherited 'type' for this AuxiliaryAgreement. | |
| vendPortion [0..1] | [PerCent](#CIM17v40-PerCent) | The percentage of the transaction amount that has to be collected from each vending transaction towards settlement of this auxiliary agreement when payments are not in arrears. Note that there may be multiple tokens vended per vending transaction, but this is not relevant. | |
| vendPortionArrear [0..1] | [PerCent](#CIM17v40-PerCent) | The percentage of the transaction amount that has to be collected from each vending transaction towards settlement of this auxiliary agreement when payments are in arrears. Note that there may be multiple tokens vended per vending transaction, but this is not relevant. | |
| CustomerAgreement [0..1] | [CustomerAgreement](#CIM17v40-CustomerAgreement) | Customer agreement this (non-service related) auxiliary agreement refers to. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| signDate [0..1] | [Date](#CIM17v40-Date) | see [Agreement](#CIM17v40-Agreement) | |
| validityInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [Agreement](CIM17v40-Agreement) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AuxiliaryCost}
### AuxiliaryCost


```mermaid
classDiagram
direction TB

class AuxiliaryCost {

+ intervalStartTime : DateTime [0..1]
+ marketType : enum:MarketType [0..1]
+ updateTimeStamp : DateTime [0..1]
+ updateUser : String [0..1]
}

```

Models Market clearing results for Auxiliary costs.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| marketType [0..1] | [MarketType](#CIM17v40-MarketType) | | |
| updateTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| updateUser [0..1] | [String](#CIM17v40-String) | | |

{#CIM17v40-AuxiliaryEquipment}
### AuxiliaryEquipment

Inheritance path = [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AuxiliaryEquipment {

}

class Equipment {

}

Equipment <|-- AuxiliaryEquipment : inherits from
class Terminal {

}

AuxiliaryEquipment --> "1" Terminal : Terminal
```

AuxiliaryEquipment describe equipment that is not performing any primary functions but support for the equipment performing the primary function.

AuxiliaryEquipment is attached to primary equipment via an association with Terminal.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Terminal [1] | [Terminal](#CIM17v40-Terminal) | The Terminal at the equipment where the AuxiliaryEquipment is attached. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-AuxiliaryObject}
### AuxiliaryObject


```mermaid
classDiagram
direction TB

class AuxiliaryObject {

}

class RegisteredGenerator {

}

AuxiliaryObject --> "0..1" RegisteredGenerator : RegisteredGenerator
class RegisteredLoad {

}

AuxiliaryObject --> "0..1" RegisteredLoad : RegisteredLoad
```

Models Auxiliary Values.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| RegisteredGenerator [0..1] | [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | | |
| RegisteredLoad [0..1] | [RegisteredLoad](#CIM17v40-RegisteredLoad) | | |

{#CIM17v40-AuxiliaryValues}
### AuxiliaryValues

Inheritance path = [AuxiliaryObject](#CIM17v40-AuxiliaryObject)

```mermaid
classDiagram
direction TB

class AuxiliaryValues {

+ availUndispatchedQ : Float [0..1]
+ incrementalORAvail : Float [0..1]
+ maxExpostCapacity : Float [0..1]
+ minExpostCapacity : Float [0..1]
+ noLoadCost : Float [0..1]
+ noLoadCostEligibilityFlag : enum:YesNo [0..1]
+ startUpCost : Float [0..1]
+ startUpCostEligibilityFlag : enum:YesNo [0..1]
}

class AuxiliaryObject {

}

AuxiliaryObject <|-- AuxiliaryValues : inherits from
class AuxiliaryCost {

}

AuxiliaryValues --> "1" AuxiliaryCost : AuxillaryCost
class FiveMinAuxiliaryData {

}

AuxiliaryValues --> "1" FiveMinAuxiliaryData : FiveMinAuxillaryData
class TenMinAuxiliaryData {

}

AuxiliaryValues --> "1" TenMinAuxiliaryData : TenMinAuxillaryData
```

Models Auxiliary Values.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| availUndispatchedQ [0..1] | [Float](#CIM17v40-Float) | | |
| incrementalORAvail [0..1] | [Float](#CIM17v40-Float) | | |
| maxExpostCapacity [0..1] | [Float](#CIM17v40-Float) | | |
| minExpostCapacity [0..1] | [Float](#CIM17v40-Float) | | |
| noLoadCost [0..1] | [Float](#CIM17v40-Float) | | |
| noLoadCostEligibilityFlag [0..1] | [YesNo](#CIM17v40-YesNo) | | |
| startUpCost [0..1] | [Float](#CIM17v40-Float) | | |
| startUpCostEligibilityFlag [0..1] | [YesNo](#CIM17v40-YesNo) | | |
| `AuxillaryCost [1]` (OfAggregate) | [AuxiliaryCost](#CIM17v40-AuxiliaryCost) | | |
| `FiveMinAuxillaryData [1]` (OfAggregate) | [FiveMinAuxiliaryData](#CIM17v40-FiveMinAuxiliaryData) | | |
| `TenMinAuxillaryData [1]` (OfAggregate) | [TenMinAuxiliaryData](#CIM17v40-TenMinAuxiliaryData) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| RegisteredGenerator [0..1] | [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | see [AuxiliaryObject](CIM17v40-AuxiliaryObject) | |
| RegisteredLoad [0..1] | [RegisteredLoad](#CIM17v40-RegisteredLoad) | see [AuxiliaryObject](CIM17v40-AuxiliaryObject) | |

{#CIM17v40-AvailablityPlan}
### AvailablityPlan

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class AvailablityPlan {

+ validPeriod : DateTimeInterval [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- AvailablityPlan : inherits from
```

The collection of all the availability schedules for a given time range. Only one availability plan shall be valid for the same period.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| validPeriod [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | The period of time for which the plan is valid. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BWRSteamSupply}
### BWRSteamSupply

Inheritance path = [SteamSupply](#CIM17v40-SteamSupply) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BWRSteamSupply {

+ highPowerLimit : PU [0..1]
+ inCoreThermalTC : Seconds [0..1]
+ integralGain : Float [0..1]
+ lowerLimit : PU [0..1]
+ lowPowerLimit : PU [0..1]
+ pressureLimit : PU [0..1]
+ pressureSetpointGA : Float [0..1]
+ pressureSetpointTC1 : Seconds [0..1]
+ pressureSetpointTC2 : Seconds [0..1]
+ proportionalGain : Float [0..1]
+ rfAux1 : PU [0..1]
+ rfAux2 : PU [0..1]
+ rfAux3 : PU [0..1]
+ rfAux4 : PU [0..1]
+ rfAux5 : PU [0..1]
+ rfAux6 : PU [0..1]
+ rfAux7 : PU [0..1]
+ rfAux8 : PU [0..1]
+ rodPattern : PU [0..1]
+ rodPatternConstant : Float [0..1]
+ upperLimit : PU [0..1]
}

class SteamSupply {

}

SteamSupply <|-- BWRSteamSupply : inherits from
```

Boiling water reactor used as a steam supply to a steam turbine.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| highPowerLimit [0..1] | [PU](#CIM17v40-PU) | High power limit. | |
| inCoreThermalTC [0..1] | [Seconds](#CIM17v40-Seconds) | In-core thermal time constant. | |
| integralGain [0..1] | [Float](#CIM17v40-Float) | Integral gain. | |
| lowerLimit [0..1] | [PU](#CIM17v40-PU) | Initial lower limit. | |
| lowPowerLimit [0..1] | [PU](#CIM17v40-PU) | Low power limit. | |
| pressureLimit [0..1] | [PU](#CIM17v40-PU) | Pressure limit. | |
| pressureSetpointGA [0..1] | [Float](#CIM17v40-Float) | Pressure setpoint gain adjuster. | |
| pressureSetpointTC1 [0..1] | [Seconds](#CIM17v40-Seconds) | Pressure setpoint time constant. | |
| pressureSetpointTC2 [0..1] | [Seconds](#CIM17v40-Seconds) | Pressure setpoint time constant. | |
| proportionalGain [0..1] | [Float](#CIM17v40-Float) | Proportional gain. | |
| rfAux1 [0..1] | [PU](#CIM17v40-PU) | Coefficient for modelling the effect of off-nominal frequency and voltage on recirculation and core flow, which affects the BWR power output. | |
| rfAux2 [0..1] | [PU](#CIM17v40-PU) | Coefficient for modelling the effect of off-nominal frequency and voltage on recirculation and core flow, which affects the BWR power output. | |
| rfAux3 [0..1] | [PU](#CIM17v40-PU) | Coefficient for modelling the effect of off-nominal frequency and voltage on recirculation and core flow, which affects the BWR power output. | |
| rfAux4 [0..1] | [PU](#CIM17v40-PU) | Coefficient for modelling the effect of off-nominal frequency and voltage on recirculation and core flow, which affects the BWR power output. | |
| rfAux5 [0..1] | [PU](#CIM17v40-PU) | Coefficient for modelling the effect of off-nominal frequency and voltage on recirculation and core flow, which affects the BWR power output. | |
| rfAux6 [0..1] | [PU](#CIM17v40-PU) | Coefficient for modelling the effect of off-nominal frequency and voltage on recirculation and core flow, which affects the BWR power output. | |
| rfAux7 [0..1] | [PU](#CIM17v40-PU) | Coefficient for modelling the effect of off-nominal frequency and voltage on recirculation and core flow, which affects the BWR power output. | |
| rfAux8 [0..1] | [PU](#CIM17v40-PU) | Coefficient for modelling the effect of off-nominal frequency and voltage on recirculation and core flow, which affects the BWR power output. | |
| rodPattern [0..1] | [PU](#CIM17v40-PU) | Rod pattern. | |
| rodPatternConstant [0..1] | [Float](#CIM17v40-Float) | Constant associated with rod pattern. | |
| upperLimit [0..1] | [PU](#CIM17v40-PU) | Initial upper limit. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| steamSupplyRating [0..1] | [Float](#CIM17v40-Float) | see [SteamSupply](#CIM17v40-SteamSupply) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Bank}
### (informative) Bank

Inheritance path = [OrganisationRole](#CIM17v40-OrganisationRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Bank {

+ bic : String [0..1]
+ iban : String [0..1]
}

class OrganisationRole {

}

OrganisationRole <|-- Bank : inherits from
```

Organisation that is a commercial bank, agency, or other institution that offers a similar service.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| bic [0..1] | [String](#CIM17v40-String) | Bank identifier code as defined in ISO 9362; for use in countries wher IBAN is not yet in operation. | |
| iban [0..1] | [String](#CIM17v40-String) | International bank account number defined in ISO 13616; for countries where IBAN is not in operation, the existing BIC or SWIFT codes may be used instead (see ISO 9362). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Organisation [0..1] | [Organisation](#CIM17v40-Organisation) | see [OrganisationRole](CIM17v40-OrganisationRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BankAccount}
### BankAccount

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BankAccount {

+ accountNumber : String [0..1]
}

class Document {

}

Document <|-- BankAccount : inherits from
class Bank {

}

BankAccount --> "0..1" Bank : Bank
class ServiceSupplier {

}

BankAccount --> "0..1" ServiceSupplier : ServiceSupplier
```

Bank account.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| accountNumber [0..1] | [String](#CIM17v40-String) | Account reference number. | |
| `Bank [0..1]` (informative) | [Bank](#CIM17v40-Bank) | Bank that provides this BankAccount. | |
| `ServiceSupplier [0..1]` (informative) | [ServiceSupplier](#CIM17v40-ServiceSupplier) | ServiceSupplier that is owner of this BankAccount. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BaseCaseConstraintLimit}
### BaseCaseConstraintLimit

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BaseCaseConstraintLimit {

}

class Curve {

}

Curve <|-- BaseCaseConstraintLimit : inherits from
class SecurityConstraintSum {

}

BaseCaseConstraintLimit --> "1" SecurityConstraintSum : SecurityConstraintSum
```

Possibly time-varying max MW or MVA and optionally Min MW limit or MVA limit (Y1 and Y2, respectively) assigned to a contingency analysis base case. Use CurveSchedule XAxisUnits to specify MW or MVA. To be used only if the BaseCaseConstraintLimit differs from the DefaultConstraintLimit.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| SecurityConstraintSum [1] | [SecurityConstraintSum](#CIM17v40-SecurityConstraintSum) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BaseFrequency}
### BaseFrequency

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BaseFrequency {

+ frequency : Frequency [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- BaseFrequency : inherits from
```

The BaseFrequency class describes a base frequency for a power system network. In case of multiple power networks with different frequencies, e.g. 50 Hz or 60 Hz each network will have its own base frequency class. Hence it is assumed that power system objects having different base frequencies appear in separate documents where each document has a single base frequency instance.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| frequency [0..1] | [Frequency](#CIM17v40-Frequency) | The base frequency. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BasePower}
### BasePower

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BasePower {

+ basePower : ApparentPower [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- BasePower : inherits from
```

The BasePower class defines the base power used in the per unit calculations.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| basePower [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | Value used as base power. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BaseReading}
### BaseReading

Inheritance path = [MeasurementValue](#CIM17v40-MeasurementValue) => [IOPoint](#CIM17v40-IOPoint) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BaseReading {

+ reportedDateTime : DateTime [0..1]
+ source : String [0..1]
+ value : String [0..1]
+ timePeriod : DateTimeInterval [0..1]
}

class MeasurementValue {

}

MeasurementValue <|-- BaseReading : inherits from
```

Common representation for reading values. Note that a reading value may have multiple qualities, as produced by various systems ('ReadingQuality.source').


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| reportedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | (used only when there are detailed auditing requirements) Date and time at which the reading was first delivered to the metering system. | |
| source [0..1] | [String](#CIM17v40-String) | System that originally supplied the reading (e.g., customer, AMI system, handheld reading system, another enterprise system, etc.). | |
| value [0..1] | [String](#CIM17v40-String) | Value of this reading. | |
| timePeriod [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Start and end of the period for those readings whose type has a time attribute such as 'billing', seasonal' or 'forTheSpecifiedPeriod'. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| sensorAccuracy [0..1] | [PerCent](#CIM17v40-PerCent) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| timeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | see [MeasurementValue](#CIM17v40-MeasurementValue) | |
| `CalculationMethodHierarchy [0..1]` (harmonization) | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| `ErpPerson [0..1]` (informative) | [OldPerson](#CIM17v40-OldPerson) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| `MeasurementValueQuality [0..1]` (AggregateOf) | [MeasurementValueQuality](#CIM17v40-MeasurementValueQuality) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| MeasurementValueSource [1] | [MeasurementValueSource](#CIM17v40-MeasurementValueSource) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| RemoteSource [0..1] | [RemoteSource](#CIM17v40-RemoteSource) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| IOPointSource [0..1] | [IOPointSource](#CIM17v40-IOPointSource) | see [IOPoint](CIM17v40-IOPoint) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BaseVoltage}
### BaseVoltage

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BaseVoltage {

+ nominalVoltage : Voltage [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- BaseVoltage : inherits from
```

Defines a system base voltage which is referenced.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| nominalVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | The power system resource's base voltage. Shall be a positive value and not zero. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BaseWork}
### BaseWork

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BaseWork {

+ kind : enum:ServiceRequestKind [0..1]
+ statusKind : enum:WorkStatusKind [0..1]
+ priority : Priority [0..1]
}

class Document {

}

Document <|-- BaseWork : inherits from
class WorkLocation {

}

BaseWork --> "0..1" WorkLocation : WorkLocation
```

Common representation for work and work tasks.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [ServiceRequestKind](#CIM17v40-ServiceRequestKind) | Kind of work. | |
| statusKind [0..1] | [WorkStatusKind](#CIM17v40-WorkStatusKind) | Kind of work status. | |
| priority [0..1] | [Priority](#CIM17v40-Priority) | Priority of work. | |
| WorkLocation [0..1] | [WorkLocation](#CIM17v40-WorkLocation) | Location for this work/task. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BasicIntervalSchedule}
### BasicIntervalSchedule

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BasicIntervalSchedule {

+ startTime : DateTime [0..1]
+ value1Multiplier : enum:UnitMultiplier [0..1]
+ value1Unit : enum:UnitSymbol [0..1]
+ value2Multiplier : enum:UnitMultiplier [0..1]
+ value2Unit : enum:UnitSymbol [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- BasicIntervalSchedule : inherits from
```

Schedule of values at points in time.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | The time for the first time point. The value can be a time of day, not a specific date. | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | Multiplier for value1. | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | Value1 units of measure. | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | Multiplier for value2. | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | Value2 units of measure. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BatteryUnit}
### BatteryUnit

Inheritance path = [PowerElectronicsUnit](#CIM17v40-PowerElectronicsUnit) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BatteryUnit {

+ batteryState : enum:BatteryStateKind [0..1]
+ ratedE : RealEnergy [0..1]
+ storedE : RealEnergy [0..1]
}

class PowerElectronicsUnit {

}

PowerElectronicsUnit <|-- BatteryUnit : inherits from
```

An electrochemical energy storage device.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| batteryState [0..1] | [BatteryStateKind](#CIM17v40-BatteryStateKind) | The current state of the battery (charging, full, etc.). | |
| ratedE [0..1] | [RealEnergy](#CIM17v40-RealEnergy) | Full energy storage capacity of the battery. The attribute shall be a positive value. | |
| storedE [0..1] | [RealEnergy](#CIM17v40-RealEnergy) | Amount of energy currently stored. The attribute shall be a positive value or zero and lower than BatteryUnit.ratedE. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [PowerElectronicsUnit](CIM17v40-PowerElectronicsUnit) | |
| minP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [PowerElectronicsUnit](CIM17v40-PowerElectronicsUnit) | |
| PowerElectronicsConnection [1] | [PowerElectronicsConnection](#CIM17v40-PowerElectronicsConnection) | see [PowerElectronicsUnit](CIM17v40-PowerElectronicsUnit) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Bay}
### Bay

Inheritance path = [EquipmentContainer](#CIM17v40-EquipmentContainer) => [ConnectivityNodeContainer](#CIM17v40-ConnectivityNodeContainer) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Bay {

+ bayEnergyMeasFlag : Boolean [0..1]
+ bayPowerMeasFlag : Boolean [0..1]
+ breakerConfiguration : enum:BreakerConfiguration [0..1]
+ busBarConfiguration : enum:BusbarConfiguration [0..1]
}

class EquipmentContainer {

}

EquipmentContainer <|-- Bay : inherits from
class Circuit {

}

Bay --> "0..1" Circuit : Circuit
class Substation {

}

Bay --> "0..1" Substation : Substation
class VoltageLevel {

}

Bay --> "0..1" VoltageLevel : VoltageLevel
```

A collection of power system resources (within a given substation) including conducting equipment, protection relays, measurements, and telemetry. A bay typically represents a physical grouping related to modularization of equipment.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| bayEnergyMeasFlag [0..1] | [Boolean](#CIM17v40-Boolean) | Indicates the presence/absence of energy measurements. | |
| bayPowerMeasFlag [0..1] | [Boolean](#CIM17v40-Boolean) | Indicates the presence/absence of active/reactive power measurements. | |
| breakerConfiguration [0..1] | [BreakerConfiguration](#CIM17v40-BreakerConfiguration) | Breaker configuration. | |
| busBarConfiguration [0..1] | [BusbarConfiguration](#CIM17v40-BusbarConfiguration) | Busbar configuration. | |
| `Circuit [0..1]` (informative) | [Circuit](#CIM17v40-Circuit) | | |
| `Substation [0..1]` (OfAggregate) | [Substation](#CIM17v40-Substation) | Substation containing the bay. | |
| `VoltageLevel [0..1]` (OfAggregate) | [VoltageLevel](#CIM17v40-VoltageLevel) | The voltage level containing this bay. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Bid}
### Bid

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Bid {

+ marketType : enum:MarketType [0..1]
+ startTime : DateTime [0..1]
+ stopTime : DateTime [0..1]
}

class Document {

}

Document <|-- Bid : inherits from
class ActionRequest {

}

Bid --> "1" ActionRequest : ActionRequest
class EnergyMarket {

}

Bid --> "1" EnergyMarket : EnergyMarket
class MarketParticipant {

}

Bid --> "0..1" MarketParticipant : MarketParticipant
```

Represents both bids to purchase and offers to sell energy or ancillary services in an RTO-sponsored market.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| marketType [0..1] | [MarketType](#CIM17v40-MarketType) | The market type, DAM or RTM. | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | Start time and date for which bid applies. | |
| stopTime [0..1] | [DateTime](#CIM17v40-DateTime) | Stop time and date for which bid is applicable. | |
| ActionRequest [1] | [ActionRequest](#CIM17v40-ActionRequest) | | |
| EnergyMarket [1] | [EnergyMarket](#CIM17v40-EnergyMarket) | | |
| MarketParticipant [0..1] | [MarketParticipant](#CIM17v40-MarketParticipant) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BidDistributionFactor}
### BidDistributionFactor


```mermaid
classDiagram
direction TB

class BidDistributionFactor {

+ timeIntervalEnd : DateTime [0..1]
+ timeIntervalStart : DateTime [0..1]
}

class ProductBid {

}

BidDistributionFactor --> "1" ProductBid : ProductBid
```

This class allows SC to input different time intervals for distribution factors.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| timeIntervalEnd [0..1] | [DateTime](#CIM17v40-DateTime) | End of the time interval n which bid is valid (yyyy-mm-dd hh24: mi: ss) | |
| timeIntervalStart [0..1] | [DateTime](#CIM17v40-DateTime) | Start of the time interval in which bid is valid (yyyy-mm-dd hh24: mi: ss). | |
| ProductBid [1] | [ProductBid](#CIM17v40-ProductBid) | | |

{#CIM17v40-BidError}
### BidError

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BidError {

+ componentType : String [0..1]
+ endTime : DateTime [0..1]
+ errMessage : String [0..1]
+ errPriority : Integer [0..1]
+ logTimeStamp : DateTime [0..1]
+ msgLevel : Integer [0..1]
+ ruleID : Integer [0..1]
+ startTime : DateTime [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- BidError : inherits from
class MarketProduct {

}

BidError --> "0..1" MarketProduct : MarketProduct
```

This class represent the error information for a bid that is detected during bid validation.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| componentType [0..1] | [String](#CIM17v40-String) | | |
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | hour wihthin the bid for which the error applies | |
| errMessage [0..1] | [String](#CIM17v40-String) | error message | |
| errPriority [0..1] | [Integer](#CIM17v40-Integer) | Priority number for the error message | |
| logTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| msgLevel [0..1] | [Integer](#CIM17v40-Integer) | | |
| ruleID [0..1] | [Integer](#CIM17v40-Integer) | | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | hour wihthin the bid for which the error applies | |
| MarketProduct [0..1] | [MarketProduct](#CIM17v40-MarketProduct) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BidHourlyProductSchedule}
### BidHourlyProductSchedule

Inheritance path = [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) => [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BidHourlyProductSchedule {

}

class RegularIntervalSchedule {

}

RegularIntervalSchedule <|-- BidHourlyProductSchedule : inherits from
class ProductBid {

}

BidHourlyProductSchedule --> "1" ProductBid : ProductBid
```

Containment for bid parameters that are dependent on a market product type.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ProductBid [1] | [ProductBid](#CIM17v40-ProductBid) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | see [RegularIntervalSchedule](CIM17v40-RegularIntervalSchedule) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BidHourlySchedule}
### BidHourlySchedule

Inheritance path = [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) => [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BidHourlySchedule {

}

class RegularIntervalSchedule {

}

RegularIntervalSchedule <|-- BidHourlySchedule : inherits from
class Bid {

}

BidHourlySchedule --> "1" Bid : Bid
```

Containment for bid hourly parameters that are not product dependent.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Bid [1] | [Bid](#CIM17v40-Bid) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | see [RegularIntervalSchedule](CIM17v40-RegularIntervalSchedule) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BidPriceCap}
### BidPriceCap


```mermaid
classDiagram
direction TB

class BidPriceCap {

+ bidCeiling : CostPerEnergyUnit [0..1]
+ bidCeilingAS : CostPerEnergyUnit [0..1]
+ bidFloor : CostPerEnergyUnit [0..1]
+ bidFloorAS : CostPerEnergyUnit [0..1]
+ defaultPrice : CostPerEnergyUnit [0..1]
+ marketType : enum:MarketType [0..1]
}

class MarketProduct {

}

BidPriceCap --> "0..1" MarketProduct : MarketProduct
```

This class represent the bid price cap.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| bidCeiling [0..1] | [CostPerEnergyUnit](#CIM17v40-CostPerEnergyUnit) | Bid Ceiling ($/MWH) | |
| bidCeilingAS [0..1] | [CostPerEnergyUnit](#CIM17v40-CostPerEnergyUnit) | Bid Ceiling ($/MWH) for generic AS versus a specific market product | |
| bidFloor [0..1] | [CostPerEnergyUnit](#CIM17v40-CostPerEnergyUnit) | Bid Floor, ($/MWH) | |
| bidFloorAS [0..1] | [CostPerEnergyUnit](#CIM17v40-CostPerEnergyUnit) | Bid Floor ($/MWH) for generic AS versus a specific market product | |
| defaultPrice [0..1] | [CostPerEnergyUnit](#CIM17v40-CostPerEnergyUnit) | Bid Default Price($/MWH) | |
| marketType [0..1] | [MarketType](#CIM17v40-MarketType) | Market Type of the cap (DAM or RTM) | |
| MarketProduct [0..1] | [MarketProduct](#CIM17v40-MarketProduct) | | |

{#CIM17v40-BidPriceCurve}
### BidPriceCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BidPriceCurve {

}

class Curve {

}

Curve <|-- BidPriceCurve : inherits from
```

Relationship between unit operating price in $/hour (Y-axis) and unit output in MW (X-axis).


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BidPriceSchedule}
### BidPriceSchedule

Inheritance path = [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) => [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BidPriceSchedule {

+ bidType : enum:BidMitigationType [0..1]
+ mitigationStatus : enum:BidMitigationStatus [0..1]
}

class RegularIntervalSchedule {

}

RegularIntervalSchedule <|-- BidPriceSchedule : inherits from
class BidPriceCurve {

}

BidPriceSchedule --> "1" BidPriceCurve : BidPriceCurve
class ProductBid {

}

BidPriceSchedule --> "1" ProductBid : ProductBid
```

Defines bid schedules to allow a product bid to use specified bid price curves for different time intervals.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| bidType [0..1] | [BidMitigationType](#CIM17v40-BidMitigationType) | BID Type:I - Initial Bid;F - Final Bid | |
| mitigationStatus [0..1] | [BidMitigationStatus](#CIM17v40-BidMitigationStatus) | Mitigation Status:'S' - Mitigated by SMPM because of "misconduct"'L; - Mitigated by LMPM because of "misconduct"'R' - Modified by LMPM because of RMR rules'M' - Mitigated because of "misconduct" both by SMPM and LMPM'B' - Mitigated because of "misconduct" both by SMPM and modified by LMLM because of RMR rules'O' - original | |
| BidPriceCurve [1] | [BidPriceCurve](#CIM17v40-BidPriceCurve) | | |
| ProductBid [1] | [ProductBid](#CIM17v40-ProductBid) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | see [RegularIntervalSchedule](CIM17v40-RegularIntervalSchedule) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BidSelfSched}
### BidSelfSched

Inheritance path = [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) => [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BidSelfSched {

+ balancingFlag : enum:YesNo [0..1]
+ bidType : enum:BidTypeRMR [0..1]
+ priorityFlag : enum:YesNo [0..1]
+ pumpSelfSchedMw : Float [0..1]
+ referenceType : enum:SelfSchedReferenceType [0..1]
+ selfSchedMw : Float [0..1]
+ selfSchedSptResource : String [0..1]
+ selfSchedType : enum:MarketProductSelfSchedType [0..1]
+ updateType : enum:MQSCHGType [0..1]
+ wheelingTransactionReference : String [0..1]
}

class RegularIntervalSchedule {

}

RegularIntervalSchedule <|-- BidSelfSched : inherits from
class AdjacentCASet {

}

BidSelfSched --> "0..1" AdjacentCASet : AdjacentCASet
class HostControlArea {

}

BidSelfSched --> "0..1" HostControlArea : HostControlArea
class ProductBid {

}

BidSelfSched --> "1" ProductBid : ProductBid
class SubControlArea {

}

BidSelfSched --> "0..1" SubControlArea : SubControlArea
class ContractRight {

}

BidSelfSched --> "0..1" ContractRight : TransmissionContractRight
```

Defines self schedule values to be used for specified time intervals.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| balancingFlag [0..1] | [YesNo](#CIM17v40-YesNo) | This is a Y/N flag for a self-schedule of a resource per market per date and hour, using a specific TR ID. It indicates whether a self-schedule using a TR is balanced with another self-schedule using the same TR ID. | |
| bidType [0..1] | [BidTypeRMR](#CIM17v40-BidTypeRMR) | bidType has two types as the required output of requirements and qualified pre-dispatch. | |
| priorityFlag [0..1] | [YesNo](#CIM17v40-YesNo) | This is a Y/N flag for a self-schedule of a resource per market per date and hour, using a specific TR ID. It indicates whether a self-schedule using a TR has scheduling priority in DAM/RTM. | |
| pumpSelfSchedMw [0..1] | [Float](#CIM17v40-Float) | Contains the PriceTaker, ExistingTransmissionContract, TransmissionOwnershipRights pumping self schedule quantity. If this value is not null, then the unit is in pumping mode. | |
| referenceType [0..1] | [SelfSchedReferenceType](#CIM17v40-SelfSchedReferenceType) | Indication of which type of self schedule is being referenced. | |
| selfSchedMw [0..1] | [Float](#CIM17v40-Float) | Self scheduled value | |
| selfSchedSptResource [0..1] | [String](#CIM17v40-String) | Price Taker Export Self Sched Support Resource | |
| selfSchedType [0..1] | [MarketProductSelfSchedType](#CIM17v40-MarketProductSelfSchedType) | This attribute is used to specify if a bid includes a self sched bid. If so what self sched type is it. The possible values are shown as follow but not limited to:'ETC' - Existing transmission contract'TOR' - Transmission ownership right'RMR' - Reliability must run'RGMR' - Regulatory must run"RMT" - Relaiability must take"PT" - Price taker"LPT" - Low price taker"SP" - Self provision"RA" - Resource adequacyThis attribute is originally defined in the BidSelfSched class | |
| updateType [0..1] | [MQSCHGType](#CIM17v40-MQSCHGType) | | |
| wheelingTransactionReference [0..1] | [String](#CIM17v40-String) | A unique identifier of a wheeling transaction. A wheeling transaction is a balanced Energy exchange among Supply and Demand Resources. | |
| AdjacentCASet [0..1] | [AdjacentCASet](#CIM17v40-AdjacentCASet) | | |
| HostControlArea [0..1] | [HostControlArea](#CIM17v40-HostControlArea) | | |
| ProductBid [1] | [ProductBid](#CIM17v40-ProductBid) | | |
| SubControlArea [0..1] | [SubControlArea](#CIM17v40-SubControlArea) | | |
| TransmissionContractRight [0..1] | [ContractRight](#CIM17v40-ContractRight) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | see [RegularIntervalSchedule](CIM17v40-RegularIntervalSchedule) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BidSet}
### BidSet

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BidSet {

}

class IdentifiedObject {

}

IdentifiedObject <|-- BidSet : inherits from
```

As set of mutually exclusive bids for which a maximum of one may be scheduled.

Of these generating bids, only one generating bid can be scheduled at a time.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BidTimeSeries}
### BidTimeSeries

Inheritance path = [TimeSeries](#CIM17v40-TimeSeries) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BidTimeSeries {

+ blockBid : String [0..1]
+ direction : String [0..1]
+ divisible : String [0..1]
+ exclusiveBidsIdentification : String [0..1]
+ linkedBidsIdentification : String [0..1]
+ minimumActivationQuantity : Decimal [0..1]
+ priority : Integer [0..1]
+ status : String [0..1]
+ stepIncrementQuantity : Decimal [0..1]
}

class TimeSeries {

}

TimeSeries <|-- BidTimeSeries : inherits from
```

The formal specification of specific characteristics related to a bid.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| blockBid [0..1] | [String](#CIM17v40-String) | Indication that the values in the period are considered as a whole. They cannot be changed or subdivided. | |
| direction [0..1] | [String](#CIM17v40-String) | The coded identification of the energy flow. | |
| divisible [0..1] | [String](#CIM17v40-String) | An indication whether or not each element of the bid may be partially accepted or not. | |
| exclusiveBidsIdentification [0..1] | [String](#CIM17v40-String) | Unique identification associated with all linked tenders.The identification of a set of tenders that are linked together signifying that only one can be accepted.This identification is defined by the tenderer and must be unique for a given auction. | |
| linkedBidsIdentification [0..1] | [String](#CIM17v40-String) | Unique identification associated with all linked bids. | |
| minimumActivationQuantity [0..1] | [Decimal](#CIM17v40-Decimal) | The minimum quantity of energy that can be activated at a given time interval. | |
| priority [0..1] | [Integer](#CIM17v40-Integer) | The numeric local priority given to a bid. Lower numeric values will have higher priority. | |
| status [0..1] | [String](#CIM17v40-String) | The information about the status of the bid, such as "shared", "restricted", ... | |
| stepIncrementQuantity [0..1] | [Decimal](#CIM17v40-Decimal) | The minimum increment that can be applied for an increase in an activation request. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| businessType [0..1] | [String](#CIM17v40-String) | see [TimeSeries](#CIM17v40-TimeSeries) | |
| cancelledTS [0..1] | [String](#CIM17v40-String) | see [TimeSeries](#CIM17v40-TimeSeries) | |
| curveType [0..1] | [String](#CIM17v40-String) | see [TimeSeries](#CIM17v40-TimeSeries) | |
| objectAggregation [0..1] | [String](#CIM17v40-String) | see [TimeSeries](#CIM17v40-TimeSeries) | |
| product [0..1] | [String](#CIM17v40-String) | see [TimeSeries](#CIM17v40-TimeSeries) | |
| version [0..1] | [String](#CIM17v40-String) | see [TimeSeries](#CIM17v40-TimeSeries) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BilateralExchangeActor}
### BilateralExchangeActor

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BilateralExchangeActor {

}

class IdentifiedObject {

}

IdentifiedObject <|-- BilateralExchangeActor : inherits from
```

BilateralExchangeActor describes an actor that provides ICCP data, consumes ICCP data or both. The ICCP data provider lists the data it makes available to an ICCP data consumer. This data is described by ProvidedBilateralPoints. The relation between an ICCP data provider and a consumer is established by a BilateralExchangeAgreement. It is up to the ICCP data consumer to select what ProvidedBilateralPoints to use. The selection made is not described in this information model.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BilateralExchangeAgreement}
### BilateralExchangeAgreement

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BilateralExchangeAgreement {

}

class IdentifiedObject {

}

IdentifiedObject <|-- BilateralExchangeAgreement : inherits from
class BilateralExchangeActor {

}

BilateralExchangeAgreement --> "0..1" BilateralExchangeActor : Consumer
class BilateralExchangeActor {

}

BilateralExchangeAgreement --> "1" BilateralExchangeActor : Provider
```

This is the representation of the information exchange agreement between peers.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Consumer [0..1] | [BilateralExchangeActor](#CIM17v40-BilateralExchangeActor) | Subscriber of information from a remote peer. | |
| Provider [1] | [BilateralExchangeActor](#CIM17v40-BilateralExchangeActor) | Provider of information to a remote peer. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BilateralTransaction}
### BilateralTransaction


```mermaid
classDiagram
direction TB

class BilateralTransaction {

+ curtailTimeMax : Integer [0..1]
+ curtailTimeMin : Integer [0..1]
+ marketType : String [0..1]
+ purchaseTimeMax : Integer [0..1]
+ purchaseTimeMin : Integer [0..1]
+ scope : String [0..1]
+ totalTranChargeMax : Money [0..1]
+ transactionType : String [0..1]
}

```

Bilateral transaction


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curtailTimeMax [0..1] | [Integer](#CIM17v40-Integer) | Maximum curtailment time in number of trading intervals | |
| curtailTimeMin [0..1] | [Integer](#CIM17v40-Integer) | Minimum curtailment time in number of trading intervals | |
| marketType [0..1] | [String](#CIM17v40-String) | Market type (default=DA)DA - Day AheadRT - Real TimeHA - Hour Ahead | |
| purchaseTimeMax [0..1] | [Integer](#CIM17v40-Integer) | Maximum purchase time in number of trading intervals | |
| purchaseTimeMin [0..1] | [Integer](#CIM17v40-Integer) | Minimum purchase time in number of trading intervals | |
| scope [0..1] | [String](#CIM17v40-String) | Transaction scope:'Internal' (default)'External' | |
| totalTranChargeMax [0..1] | [Money](#CIM17v40-Money) | Maximum total transmission (congestion) charges in monetary units | |
| transactionType [0..1] | [String](#CIM17v40-String) | Transaction type (default 1)1 - Fixed2 - Dispatchable continuous3 - Dispatchable block-loading | |

{#CIM17v40-BillDeterminant}
### BillDeterminant

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BillDeterminant {

+ calculationLevel : String [0..1]
+ configVersion : String [0..1]
+ deleteStatus : String [0..1]
+ effectiveDate : DateTime [0..1]
+ exception : String [0..1]
+ factor : String [0..1]
+ frequency : String [0..1]
+ numberInterval : Integer [0..1]
+ offset : String [0..1]
+ precisionLevel : String [0..1]
+ primaryYN : String [0..1]
+ referenceFlag : String [0..1]
+ reportable : String [0..1]
+ roundOff : String [0..1]
+ source : String [0..1]
+ terminationDate : DateTime [0..1]
+ unitOfMeasure : String [0..1]
}

class Document {

}

Document <|-- BillDeterminant : inherits from
class ChargeProfile {

}

BillDeterminant --> "0..1" ChargeProfile : ChargeProfile
```

Models various charges to support billing and settlement.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| calculationLevel [0..1] | [String](#CIM17v40-String) | Level in charge calculation order. | |
| configVersion [0..1] | [String](#CIM17v40-String) | The version of configuration of calculation logic in the settlement. | |
| deleteStatus [0..1] | [String](#CIM17v40-String) | | |
| effectiveDate [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| exception [0..1] | [String](#CIM17v40-String) | | |
| factor [0..1] | [String](#CIM17v40-String) | | |
| frequency [0..1] | [String](#CIM17v40-String) | | |
| numberInterval [0..1] | [Integer](#CIM17v40-Integer) | Number of intervals of bill determiant in trade day, e.g. 300 for five minute intervals. | |
| offset [0..1] | [String](#CIM17v40-String) | | |
| precisionLevel [0..1] | [String](#CIM17v40-String) | The level of precision in the current value. | |
| primaryYN [0..1] | [String](#CIM17v40-String) | | |
| referenceFlag [0..1] | [String](#CIM17v40-String) | | |
| reportable [0..1] | [String](#CIM17v40-String) | | |
| roundOff [0..1] | [String](#CIM17v40-String) | | |
| source [0..1] | [String](#CIM17v40-String) | | |
| terminationDate [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| unitOfMeasure [0..1] | [String](#CIM17v40-String) | The UOM for the current value of the Bill Determinant. | |
| ChargeProfile [0..1] | [ChargeProfile](#CIM17v40-ChargeProfile) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BlockDispatchComponent}
### BlockDispatchComponent

Inheritance path = [EnergyComponent](#CIM17v40-EnergyComponent) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BlockDispatchComponent {

}

class EnergyComponent {

}

EnergyComponent <|-- BlockDispatchComponent : inherits from
```


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BlockDispatchInstruction}
### BlockDispatchInstruction

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BlockDispatchInstruction {

}

class IdentifiedObject {

}

IdentifiedObject <|-- BlockDispatchInstruction : inherits from
```


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BlockDispatchOrder}
### BlockDispatchOrder

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BlockDispatchOrder {

+ p : ActivePower [0..1]
+ sequence : Integer [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- BlockDispatchOrder : inherits from
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| p [0..1] | [ActivePower](#CIM17v40-ActivePower) | | |
| sequence [0..1] | [Integer](#CIM17v40-Integer) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BlockingFunction}
### (informative) BlockingFunction


```mermaid
classDiagram
direction TB

class BlockingFunction {

}

class Delay {

}

BlockingFunction --> "1" Delay : Delay
class VSCtype1 {

}

BlockingFunction --> "0..1" VSCtype1 : VSCtype1
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Delay [1]` (informative) | [Delay](#CIM17v40-Delay) | | |
| `VSCtype1 [0..1]` (informative) | [VSCtype1](#CIM17v40-VSCtype1) | | |

{#CIM17v40-BranchEndFlow}
### BranchEndFlow


```mermaid
classDiagram
direction TB

class BranchEndFlow {

+ loadDumpRating : Float [0..1]
+ longTermRating : Float [0..1]
+ mVARFlow : Float [0..1]
+ mwFlow : Float [0..1]
+ normalRating : Float [0..1]
+ shortTermRating : Float [0..1]
}

```

Dynamic flows and ratings associated with a branch end.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| loadDumpRating [0..1] | [Float](#CIM17v40-Float) | The Load Dump Rating for the branch | |
| longTermRating [0..1] | [Float](#CIM17v40-Float) | The Long Term Rating for the branch | |
| mVARFlow [0..1] | [Float](#CIM17v40-Float) | The MVAR flow on the branchAttribute Usage: Reactive power flow at the series device, transformer, phase shifter, or line end | |
| mwFlow [0..1] | [Float](#CIM17v40-Float) | The MW flow on the branchAttribute Usage: Active power flow at the series device, transformer, phase shifter, or line end | |
| normalRating [0..1] | [Float](#CIM17v40-Float) | The Normal Rating for the branch | |
| shortTermRating [0..1] | [Float](#CIM17v40-Float) | The Short Term Rating for the branch | |

{#CIM17v40-BranchGroup}
### (informative) BranchGroup

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BranchGroup {

+ maximumActivePower : ActivePower [0..1]
+ maximumReactivePower : ReactivePower [0..1]
+ minimumActivePower : ActivePower [0..1]
+ minimumReactivePower : ReactivePower [0..1]
+ monitorActivePower : Boolean [0..1]
+ monitorReactivePower : Boolean [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- BranchGroup : inherits from
```

A group of branch terminals whose directed flow summation is to be monitored. A branch group need not form a cutset of the network.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maximumActivePower [0..1] | [ActivePower](#CIM17v40-ActivePower) | The maximum active power flow. | |
| maximumReactivePower [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | The maximum reactive power flow. | |
| minimumActivePower [0..1] | [ActivePower](#CIM17v40-ActivePower) | The minimum active power flow. | |
| minimumReactivePower [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | The minimum reactive power flow. | |
| monitorActivePower [0..1] | [Boolean](#CIM17v40-Boolean) | Monitor the active power flow. | |
| monitorReactivePower [0..1] | [Boolean](#CIM17v40-Boolean) | Monitor the reactive power flow. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BranchGroupTerminal}
### BranchGroupTerminal


```mermaid
classDiagram
direction TB

class BranchGroupTerminal {

+ positiveFlowIn : Boolean [0..1]
}

class BranchGroup {

}

BranchGroupTerminal --> "1" BranchGroup : BranchGroup
class Terminal {

}

BranchGroupTerminal --> "1" Terminal : Terminal
```

A specific directed terminal flow for a branch group.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| positiveFlowIn [0..1] | [Boolean](#CIM17v40-Boolean) | The flow into the terminal is summed if set true. The flow out of the terminal is summed if set false. | |
| `BranchGroup [1]` (OfAggregate) | [BranchGroup](#CIM17v40-BranchGroup) | The branch group to which the directed branch group terminals belong. | |
| Terminal [1] | [Terminal](#CIM17v40-Terminal) | The terminal to be summed. | |

{#CIM17v40-Breaker}
### Breaker

Inheritance path = [ProtectedSwitch](#CIM17v40-ProtectedSwitch) => [Switch](#CIM17v40-Switch) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Breaker {

+ inTransitTime : Seconds [0..1]
}

class ProtectedSwitch {

}

ProtectedSwitch <|-- Breaker : inherits from
```

A mechanical switching device capable of making, carrying, and breaking currents under normal circuit conditions and also making, carrying for a specified time, and breaking currents under specified abnormal circuit conditions e.g. those of short circuit.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| inTransitTime [0..1] | [Seconds](#CIM17v40-Seconds) | The transition time from open to close. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| breakingCapacity [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [ProtectedSwitch](CIM17v40-ProtectedSwitch) | |
| locked [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| normalOpen [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| open [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [Switch](CIM17v40-Switch) | |
| retained [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| `switchOnCount [0..1]` (deprecated) | [Integer](#CIM17v40-Integer) | see [Switch](#CIM17v40-Switch) | |
| `switchOnDate [0..1]` (deprecated) | [DateTime](#CIM17v40-DateTime) | see [Switch](#CIM17v40-Switch) | |
| `CompositeSwitch [0..1]` (OfAggregate) | [CompositeSwitch](#CIM17v40-CompositeSwitch) | see [Switch](CIM17v40-Switch) | |
| SwitchAction [0..1] | [SwitchAction](#CIM17v40-SwitchAction) | see [Switch](CIM17v40-Switch) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BreakerInfo}
### BreakerInfo

Inheritance path = [OldSwitchInfo](#CIM17v40-OldSwitchInfo) => [SwitchInfo](#CIM17v40-SwitchInfo) => [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BreakerInfo {

+ phaseTrip : CurrentFlow [0..1]
}

class OldSwitchInfo {

}

OldSwitchInfo <|-- BreakerInfo : inherits from
```

Properties of breaker assets.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| phaseTrip [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Phase trip rating. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dielectricStrength [0..1] | [Voltage](#CIM17v40-Voltage) | see [OldSwitchInfo](CIM17v40-OldSwitchInfo) | |
| loadBreak [0..1] | [Boolean](#CIM17v40-Boolean) | see [OldSwitchInfo](#CIM17v40-OldSwitchInfo) | |
| makingCapacity [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [OldSwitchInfo](CIM17v40-OldSwitchInfo) | |
| minimumCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [OldSwitchInfo](CIM17v40-OldSwitchInfo) | |
| poleCount [0..1] | [Integer](#CIM17v40-Integer) | see [OldSwitchInfo](#CIM17v40-OldSwitchInfo) | |
| remote [0..1] | [Boolean](#CIM17v40-Boolean) | see [OldSwitchInfo](#CIM17v40-OldSwitchInfo) | |
| withstandCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [OldSwitchInfo](CIM17v40-OldSwitchInfo) | |
| breakingCapacity [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| gasWeightPerTank [0..1] | [Mass](#CIM17v40-Mass) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| isSinglePhase [0..1] | [Boolean](#CIM17v40-Boolean) | see [SwitchInfo](#CIM17v40-SwitchInfo) | |
| isUnganged [0..1] | [Boolean](#CIM17v40-Boolean) | see [SwitchInfo](#CIM17v40-SwitchInfo) | |
| lowPressureAlarm [0..1] | [Pressure](#CIM17v40-Pressure) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| lowPressureLockOut [0..1] | [Pressure](#CIM17v40-Pressure) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| oilVolumePerTank [0..1] | [Volume](#CIM17v40-Volume) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| ratedFrequency [0..1] | [Frequency](#CIM17v40-Frequency) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| ratedImpulseWithstandVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| ratedInterruptingTime [0..1] | [Seconds](#CIM17v40-Seconds) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| ratedVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BusNameMarker}
### BusNameMarker

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BusNameMarker {

+ priority : Integer [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- BusNameMarker : inherits from
class ReportingGroup {

}

BusNameMarker --> "0..1" ReportingGroup : ReportingGroup
class TopologicalNode {

}

BusNameMarker --> "0..1" TopologicalNode : TopologicalNode
```

Used to apply user standard names to TopologicalNodes. Associated with one or more terminals that are normally connected with the bus name. The associated terminals are normally connected by non-retained switches. For a ring bus station configuration, all BusbarSection terminals in the ring are typically associated. For a breaker and a half scheme, both BusbarSections would normally be associated. For a ring bus, all BusbarSections would normally be associated. For a "straight" busbar configuration, normally only the main terminal at the BusbarSection would be associated.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| priority [0..1] | [Integer](#CIM17v40-Integer) | Priority of bus name marker for use as topology bus name. Use 0 for do not care. Use 1 for highest priority. Use 2 as priority is less than 1 and so on. | |
| ReportingGroup [0..1] | [ReportingGroup](#CIM17v40-ReportingGroup) | The reporting group to which this bus name marker belongs. | |
| TopologicalNode [0..1] | [TopologicalNode](#CIM17v40-TopologicalNode) | A user defined topological node that was originally defined in a planning model not yet having topology described by ConnectivityNodes. Once ConnectivityNodes has been created they may linked to user defined ToplogicalNdes using BusNameMarkers. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BusbarSection}
### BusbarSection

Inheritance path = [Connector](#CIM17v40-Connector) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BusbarSection {

+ ipMax : CurrentFlow [0..1]
}

class Connector {

}

Connector <|-- BusbarSection : inherits from
class VoltageControlZone {

}

BusbarSection --> "0..1" VoltageControlZone : VoltageControlZone
```

A conductor, or group of conductors, with negligible impedance, that serve to connect other conducting equipment within a single substation.

Voltage measurements are typically obtained from voltage transformers that are connected to busbar sections. A bus bar section may have many physical terminals but for analysis is modelled with exactly one logical terminal.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ipMax [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Maximum allowable peak short-circuit current of busbar (Ipmax in IEC 60909-0).Mechanical limit of the busbar in the substation itself. Used for short circuit data exchange according to IEC 60909. | |
| VoltageControlZone [0..1] | [VoltageControlZone](#CIM17v40-VoltageControlZone) | A VoltageControlZone is controlled by a designated BusbarSection. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BusbarSectionInfo}
### BusbarSectionInfo

Inheritance path = [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BusbarSectionInfo {

+ ratedCurrent : CurrentFlow [0..1]
+ ratedVoltage : Voltage [0..1]
}

class AssetInfo {

}

AssetInfo <|-- BusbarSectionInfo : inherits from
```

Busbar section data.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Rated current. | |
| ratedVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Rated voltage. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Bushing}
### (informative) Bushing

Inheritance path = [Asset](#CIM17v40-Asset) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Bushing {

}

class Asset {

}

Asset <|-- Bushing : inherits from
class InterrupterUnit {

}

Bushing --> "0..1" InterrupterUnit : FixedContact
class InterrupterUnit {

}

Bushing --> "0..1" InterrupterUnit : MovingContact
class Terminal {

}

Bushing --> "0..1" Terminal : Terminal
```

Bushing asset.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| FixedContact [0..1] | [InterrupterUnit](#CIM17v40-InterrupterUnit) | Fixed contact of interrupter to which this bushing is attached. | |
| MovingContact [0..1] | [InterrupterUnit](#CIM17v40-InterrupterUnit) | Moving contact of interrupter to which this bushing is attached. | |
| Terminal [0..1] | [Terminal](#CIM17v40-Terminal) | Terminal to which this bushing is attached. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | see [Asset](#CIM17v40-Asset) | |
| initialCondition [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | see [Asset](CIM17v40-Asset) | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | see [Asset](CIM17v40-Asset) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [Asset](CIM17v40-Asset) | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | see [Asset](CIM17v40-Asset) | |
| lotNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| position [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | see [Asset](CIM17v40-Asset) | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | see [Asset](CIM17v40-Asset) | |
| serialNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| type [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| utcNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | see [Asset](CIM17v40-Asset) | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | see [Asset](CIM17v40-Asset) | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | see [Asset](CIM17v40-Asset) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [Asset](CIM17v40-Asset) | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | see [Asset](CIM17v40-Asset) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Asset](CIM17v40-Asset) | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | see [Asset](CIM17v40-Asset) | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | see [Asset](CIM17v40-Asset) | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | see [Asset](CIM17v40-Asset) | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | see [Asset](CIM17v40-Asset) | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | see [Asset](CIM17v40-Asset) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Asset](CIM17v40-Asset) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [Asset](CIM17v40-Asset) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [Asset](CIM17v40-Asset) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Asset](CIM17v40-Asset) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BushingInfo}
### BushingInfo

Inheritance path = [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BushingInfo {

+ c1Capacitance : Capacitance [0..1]
+ c1PowerFactor : PerCent [0..1]
+ c2Capacitance : Capacitance [0..1]
+ c2PowerFactor : PerCent [0..1]
+ insulationKind : enum:BushingInsulationKind [0..1]
+ ratedCurrent : CurrentFlow [0..1]
+ ratedImpulseWithstandVoltage : Voltage [0..1]
+ ratedLineToGroundVoltage : Voltage [0..1]
+ ratedVoltage : Voltage [0..1]
}

class AssetInfo {

}

AssetInfo <|-- BushingInfo : inherits from
```

Bushing datasheet information.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| c1Capacitance [0..1] | [Capacitance](#CIM17v40-Capacitance) | Factory measured capacitance, measured between the power factor tap and the bushing conductor. | |
| c1PowerFactor [0..1] | [PerCent](#CIM17v40-PerCent) | Factory measured insulation power factor, measured between the power factor tap and the bushing conductor. | |
| c2Capacitance [0..1] | [Capacitance](#CIM17v40-Capacitance) | Factory measured capacitance measured between the power factor tap and ground. | |
| c2PowerFactor [0..1] | [PerCent](#CIM17v40-PerCent) | Factory measured insulation power factor, measured between the power factor tap and ground. | |
| insulationKind [0..1] | [BushingInsulationKind](#CIM17v40-BushingInsulationKind) | Kind of insulation. | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Rated current for bushing as installed. | |
| ratedImpulseWithstandVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Rated impulse withstand voltage, also known as BIL (Basic Impulse Level). | |
| ratedLineToGroundVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Rated line-to-ground voltage. Also referred to as Uy on bushing nameplate. | |
| ratedVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Rated voltage. Can be referred to as Um, system voltage or class on bushing nameplate. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BushingInsulationPF}
### BushingInsulationPF

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BushingInsulationPF {

+ testKind : enum:BushingInsulationPfTestKind [0..1]
+ status : Status [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- BushingInsulationPF : inherits from
class Bushing {

}

BushingInsulationPF --> "0..1" Bushing : Bushing
class TransformerObservation {

}

BushingInsulationPF --> "0..1" TransformerObservation : TransformerObservation
```

Bushing insulation power factor condition as a result of a test.

Typical status values are: Acceptable, Minor Deterioration or Moisture Absorption, Major Deterioration or Moisture Absorption, Failed.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| testKind [0..1] | [BushingInsulationPfTestKind](#CIM17v40-BushingInsulationPfTestKind) | Kind of test for this bushing. | |
| `Bushing [0..1]` (informative) | [Bushing](#CIM17v40-Bushing) | | |
| status [0..1] | [Status](#CIM17v40-Status) | | |
| `TransformerObservation [0..1]` (informative) | [TransformerObservation](#CIM17v40-TransformerObservation) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BusinessCase}
### (informative) BusinessCase

Inheritance path = [WorkDocument](#CIM17v40-WorkDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BusinessCase {

+ corporateCode : String [0..1]
}

class WorkDocument {

}

WorkDocument <|-- BusinessCase : inherits from
```

Business justification for capital expenditures, usually addressing operations and maintenance costs as well.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| corporateCode [0..1] | [String](#CIM17v40-String) | A codified representation of the business case (i.e., codes for highway relocation, replace substation transformers, etc.). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BusinessPlan}
### BusinessPlan

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BusinessPlan {

}

class Document {

}

Document <|-- BusinessPlan : inherits from
```

A BusinessPlan is an organized sequence of predetermined actions required to complete a future organizational objective. It is a type of document that typically references a schedule, physical and/or logical resources (assets and/or PowerSystemResources), locations, etc.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-BusinessRole}
### BusinessRole

Inheritance path = [OrganisationRole](#CIM17v40-OrganisationRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class BusinessRole {

+ type : String [0..1]
+ status : Status [0..1]
}

class OrganisationRole {

}

OrganisationRole <|-- BusinessRole : inherits from
```

A business role that this organisation plays. A single organisation typically performs many functions, each one described as a role.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| type [0..1] | [String](#CIM17v40-String) | Classification by utility's corporate standards and practices. | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Organisation [0..1] | [Organisation](#CIM17v40-Organisation) | see [OrganisationRole](CIM17v40-OrganisationRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CAESPlant}
### CAESPlant

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CAESPlant {

+ energyStorageCapacity : RealEnergy [0..1]
+ ratedCapacityP : ActivePower [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- CAESPlant : inherits from
class AirCompressor {

}

CAESPlant --> "1" AirCompressor : AirCompressor
class ThermalGeneratingUnit {

}

CAESPlant --> "0..1" ThermalGeneratingUnit : ThermalGeneratingUnit
```

Compressed air energy storage plant.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| energyStorageCapacity [0..1] | [RealEnergy](#CIM17v40-RealEnergy) | The rated energy storage capacity. The attribute shall be a positive value. | |
| ratedCapacityP [0..1] | [ActivePower](#CIM17v40-ActivePower) | The CAES plant's gross rated generating capacity. The attribute shall be a positive value. | |
| `AirCompressor [1]` (AggregateOf) | [AirCompressor](#CIM17v40-AirCompressor) | An air compressor may be a member of a compressed air energy storage plant. | |
| ThermalGeneratingUnit [0..1] | [ThermalGeneratingUnit](#CIM17v40-ThermalGeneratingUnit) | A thermal generating unit may be a member of a compressed air energy storage plant. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CCAinverter}
### CCAinverter


```mermaid
classDiagram
direction TB

class CCAinverter {

}

```


{#CIM17v40-CCArectifierControl}
### CCArectifierControl


```mermaid
classDiagram
direction TB

class CCArectifierControl {

}

```


{#CIM17v40-CRRMarket}
### CRRMarket

Inheritance path = [Market](#CIM17v40-Market) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CRRMarket {

+ labelID : String [0..1]
}

class Market {

}

Market <|-- CRRMarket : inherits from
```

Model that describes the Congestion Revenue Rights Auction Market.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| labelID [0..1] | [String](#CIM17v40-String) | labelID - an ID for a set of apnodes/pnodes used in a CRR market | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| actualEnd [0..1] | [DateTime](#CIM17v40-DateTime) | see [Market](#CIM17v40-Market) | |
| actualStart [0..1] | [DateTime](#CIM17v40-DateTime) | see [Market](#CIM17v40-Market) | |
| dst [0..1] | [Boolean](#CIM17v40-Boolean) | see [Market](#CIM17v40-Market) | |
| end [0..1] | [DateTime](#CIM17v40-DateTime) | see [Market](#CIM17v40-Market) | |
| localTimeZone [0..1] | [String](#CIM17v40-String) | see [Market](#CIM17v40-Market) | |
| start [0..1] | [DateTime](#CIM17v40-DateTime) | see [Market](#CIM17v40-Market) | |
| status [0..1] | [String](#CIM17v40-String) | see [Market](#CIM17v40-Market) | |
| timeIntervalLength [0..1] | [Float](#CIM17v40-Float) | see [Market](#CIM17v40-Market) | |
| tradingDay [0..1] | [DateTime](#CIM17v40-DateTime) | see [Market](#CIM17v40-Market) | |
| tradingPeriod [0..1] | [String](#CIM17v40-String) | see [Market](#CIM17v40-Market) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CRROrgRole}
### CRROrgRole

Inheritance path = [OrganisationRole](#CIM17v40-OrganisationRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CRROrgRole {

+ kind : enum:CRRRoleType [0..1]
+ status : Status [0..1]
}

class OrganisationRole {

}

OrganisationRole <|-- CRROrgRole : inherits from
class CongestionRevenueRight {

}

CRROrgRole --> "1" CongestionRevenueRight : CongestionRevenueRight
```

Identifies a way in which an organisation may participate with a defined Congestion Revenue Right (CRR).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [CRRRoleType](#CIM17v40-CRRRoleType) | Kind of role the organisation is with regards to the congestion revenue rights. | |
| CongestionRevenueRight [1] | [CongestionRevenueRight](#CIM17v40-CongestionRevenueRight) | | |
| status [0..1] | [Status](#CIM17v40-Status) | Status of congestion revenue rights organisation role. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Organisation [0..1] | [Organisation](#CIM17v40-Organisation) | see [OrganisationRole](CIM17v40-OrganisationRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CRRSegment}
### CRRSegment

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CRRSegment {

+ amount : Money [0..1]
+ clearingPrice : Money [0..1]
+ endDateTime : DateTime [0..1]
+ quantity : Float [0..1]
+ startDateTime : DateTime [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- CRRSegment : inherits from
class CongestionRevenueRight {

}

CRRSegment --> "1" CongestionRevenueRight : CongestionRevenueRight
```

CRRSegment represents a segment of a CRR in a particular time frame.

The segment class contains amount, clearing price, start date and time, end date and time.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| amount [0..1] | [Money](#CIM17v40-Money) | Dollar amount = quantity x clearingPrice | |
| clearingPrice [0..1] | [Money](#CIM17v40-Money) | Clearing price of a CRR | |
| endDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | segment end date time | |
| quantity [0..1] | [Float](#CIM17v40-Float) | The MW amount associated with the CRR | |
| startDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | segment start date time | |
| CongestionRevenueRight [1] | [CongestionRevenueRight](#CIM17v40-CongestionRevenueRight) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CSCDynamics}
### CSCDynamics

Inheritance path = [HVDCDynamics](#CIM17v40-HVDCDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CSCDynamics {

}

class HVDCDynamics {

}

HVDCDynamics <|-- CSCDynamics : inherits from
class CsConverter {

}

CSCDynamics --> "1" CsConverter : CSConverter
```

CSC function block whose behaviour is described by reference to a standard model <font color="#0f0f0f">or by definition of a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CSConverter [1] | [CsConverter](#CIM17v40-CsConverter) | Current source converter to which current source converter dynamics model applies. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CSCUserDefined}
### CSCUserDefined

Inheritance path = [CSCDynamics](#CIM17v40-CSCDynamics) => [HVDCDynamics](#CIM17v40-HVDCDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CSCUserDefined {

+ proprietary : Boolean [0..1]
}

class CSCDynamics {

}

CSCDynamics <|-- CSCUserDefined : inherits from
```

Current source converter (CSC) function block whose dynamic behaviour is described by <font color="#0f0f0f">a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| proprietary [0..1] | [Boolean](#CIM17v40-Boolean) | Behaviour is based on a proprietary model as opposed to a detailed model.true = user-defined model is proprietary with behaviour mutually understood by sending and receiving applications and parameters passed as general attributesfalse = user-defined model is explicitly defined in terms of control blocks and their input and output signals. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CSConverter [1] | [CsConverter](#CIM17v40-CsConverter) | see [CSCDynamics](CIM17v40-CSCDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CSCtype1}
### CSCtype1

Inheritance path = [CSCDynamics](#CIM17v40-CSCDynamics) => [HVDCDynamics](#CIM17v40-HVDCDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CSCtype1 {

}

class CSCDynamics {

}

CSCDynamics <|-- CSCtype1 : inherits from
```


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CSConverter [1] | [CsConverter](#CIM17v40-CsConverter) | see [CSCDynamics](CIM17v40-CSCDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CTTempActivePowerCurve}
### CTTempActivePowerCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CTTempActivePowerCurve {

}

class Curve {

}

Curve <|-- CTTempActivePowerCurve : inherits from
class CombustionTurbine {

}

CTTempActivePowerCurve --> "1" CombustionTurbine : CombustionTurbine
```

Relationship between the combustion turbine's power output rating in gross active power (X-axis) and the ambient air temperature (Y-axis).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `CombustionTurbine [1]` (OfAggregate) | [CombustionTurbine](#CIM17v40-CombustionTurbine) | A combustion turbine may have an active power versus ambient temperature relationship. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CUAllowableAction}
### (informative) CUAllowableAction

Inheritance path = [WorkIdentifiedObject](#CIM17v40-WorkIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CUAllowableAction {

+ status : Status [0..1]
}

class WorkIdentifiedObject {

}

WorkIdentifiedObject <|-- CUAllowableAction : inherits from
```

Allowed actions: Install, Remove, Transfer, Abandon, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CUContractorItem}
### CUContractorItem

Inheritance path = [WorkIdentifiedObject](#CIM17v40-WorkIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CUContractorItem {

+ activityCode : String [0..1]
+ bidAmount : Money [0..1]
+ status : Status [0..1]
}

class WorkIdentifiedObject {

}

WorkIdentifiedObject <|-- CUContractorItem : inherits from
```

Compatible unit contractor item.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| activityCode [0..1] | [String](#CIM17v40-String) | Activity code identifies a specific and distinguishable unit of work. | |
| bidAmount [0..1] | [Money](#CIM17v40-Money) | The amount that a given contractor will charge for performing this unit of work. | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CUGroup}
### (informative) CUGroup

Inheritance path = [WorkIdentifiedObject](#CIM17v40-WorkIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CUGroup {

+ status : Status [0..1]
}

class WorkIdentifiedObject {

}

WorkIdentifiedObject <|-- CUGroup : inherits from
```

A Compatible Unit Group identifies a set of compatible units which may be jointly utilized for estimating and designating jobs.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CULaborCode}
### (informative) CULaborCode

Inheritance path = [WorkIdentifiedObject](#CIM17v40-WorkIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CULaborCode {

+ code : String [0..1]
+ status : Status [0..1]
}

class WorkIdentifiedObject {

}

WorkIdentifiedObject <|-- CULaborCode : inherits from
```

Labor code associated with various compatible unit labor items.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| code [0..1] | [String](#CIM17v40-String) | Labor code. | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CULaborItem}
### CULaborItem

Inheritance path = [WorkIdentifiedObject](#CIM17v40-WorkIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CULaborItem {

+ activityCode : String [0..1]
+ laborDuration : Hours [0..1]
+ laborRate : CostRate [0..1]
+ status : Status [0..1]
}

class WorkIdentifiedObject {

}

WorkIdentifiedObject <|-- CULaborItem : inherits from
class CULaborCode {

}

CULaborItem --> "0..1" CULaborCode : CULaborCode
```

Compatible unit labor item.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| activityCode [0..1] | [String](#CIM17v40-String) | Activity code identifies a specific and distinguishable unit of work. | |
| laborDuration [0..1] | [Hours](#CIM17v40-Hours) | Estimated time to perform work. | |
| laborRate [0..1] | [CostRate](#CIM17v40-CostRate) | The labor rate applied for work. | |
| `CULaborCode [0..1]` (informative) | [CULaborCode](#CIM17v40-CULaborCode) | | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CUMaterialItem}
### CUMaterialItem

Inheritance path = [WorkIdentifiedObject](#CIM17v40-WorkIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CUMaterialItem {

+ corporateCode : String [0..1]
+ quantity : IntegerQuantity [0..1]
+ status : Status [0..1]
}

class WorkIdentifiedObject {

}

WorkIdentifiedObject <|-- CUMaterialItem : inherits from
class TypeMaterial {

}

CUMaterialItem --> "0..1" TypeMaterial : TypeMaterial
```

Compatible unit of a consumable supply item. For example, nuts, bolts, brackets, glue, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| corporateCode [0..1] | [String](#CIM17v40-String) | Code for material. | |
| quantity [0..1] | [IntegerQuantity](#CIM17v40-IntegerQuantity) | Quantity of the TypeMaterial for this CU, used to determine estimated costs based on a per unit cost or a cost per unit length specified in the TypeMaterial. | |
| status [0..1] | [Status](#CIM17v40-Status) | | |
| `TypeMaterial [0..1]` (informative) | [TypeMaterial](#CIM17v40-TypeMaterial) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CUWorkEquipmentItem}
### (informative) CUWorkEquipmentItem

Inheritance path = [WorkIdentifiedObject](#CIM17v40-WorkIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CUWorkEquipmentItem {

+ equipCode : String [0..1]
+ rate : CostRate [0..1]
+ status : Status [0..1]
}

class WorkIdentifiedObject {

}

WorkIdentifiedObject <|-- CUWorkEquipmentItem : inherits from
class WorkAsset {

}

CUWorkEquipmentItem --> "0..1" WorkAsset : TypeAsset
```

Compatible unit for various types of WorkEquipmentAssets, including vehicles.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| equipCode [0..1] | [String](#CIM17v40-String) | The equipment type code. | |
| rate [0..1] | [CostRate](#CIM17v40-CostRate) | Standard usage rate for the type of vehicle. | |
| status [0..1] | [Status](#CIM17v40-Status) | | |
| `TypeAsset [0..1]` (informative) | [WorkAsset](#CIM17v40-WorkAsset) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Cabinet}
### Cabinet

Inheritance path = [AssetContainer](#CIM17v40-AssetContainer) => [Asset](#CIM17v40-Asset) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Cabinet {

}

class AssetContainer {

}

AssetContainer <|-- Cabinet : inherits from
```

Enclosure that offers protection to the equipment it contains and/or safety to people/animals outside it.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | see [Asset](#CIM17v40-Asset) | |
| initialCondition [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | see [Asset](CIM17v40-Asset) | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | see [Asset](CIM17v40-Asset) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [Asset](CIM17v40-Asset) | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | see [Asset](CIM17v40-Asset) | |
| lotNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| position [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | see [Asset](CIM17v40-Asset) | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | see [Asset](CIM17v40-Asset) | |
| serialNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| type [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| utcNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | see [Asset](CIM17v40-Asset) | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | see [Asset](CIM17v40-Asset) | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | see [Asset](CIM17v40-Asset) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [Asset](CIM17v40-Asset) | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | see [Asset](CIM17v40-Asset) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Asset](CIM17v40-Asset) | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | see [Asset](CIM17v40-Asset) | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | see [Asset](CIM17v40-Asset) | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | see [Asset](CIM17v40-Asset) | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | see [Asset](CIM17v40-Asset) | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | see [Asset](CIM17v40-Asset) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Asset](CIM17v40-Asset) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [Asset](CIM17v40-Asset) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [Asset](CIM17v40-Asset) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Asset](CIM17v40-Asset) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CableInfo}
### CableInfo

Inheritance path = [WireInfo](#CIM17v40-WireInfo) => [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CableInfo {

+ constructionKind : enum:CableConstructionKind [0..1]
+ diameterOverCore : Length [0..1]
+ diameterOverInsulation : Length [0..1]
+ diameterOverJacket : Length [0..1]
+ diameterOverScreen : Length [0..1]
+ isStrandFill : Boolean [0..1]
+ nominalTemperature : Temperature [0..1]
+ outerJacketKind : enum:CableOuterJacketKind [0..1]
+ sheathAsNeutral : Boolean [0..1]
+ shieldMaterial : enum:CableShieldMaterialKind [0..1]
}

class WireInfo {

}

WireInfo <|-- CableInfo : inherits from
```

Cable data.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| constructionKind [0..1] | [CableConstructionKind](#CIM17v40-CableConstructionKind) | Kind of construction of this cable. | |
| diameterOverCore [0..1] | [Length](#CIM17v40-Length) | Diameter over the core, including any semi-con screen; should be the insulating layer's inside diameter. | |
| diameterOverInsulation [0..1] | [Length](#CIM17v40-Length) | Diameter over the insulating layer, excluding outer screen. | |
| diameterOverJacket [0..1] | [Length](#CIM17v40-Length) | Diameter over the outermost jacketing layer. | |
| diameterOverScreen [0..1] | [Length](#CIM17v40-Length) | Diameter over the outer screen; should be the shield's inside diameter. | |
| isStrandFill [0..1] | [Boolean](#CIM17v40-Boolean) | True if wire strands are extruded in a way to fill the voids in the cable. | |
| nominalTemperature [0..1] | [Temperature](#CIM17v40-Temperature) | Maximum nominal design operating temperature. | |
| outerJacketKind [0..1] | [CableOuterJacketKind](#CIM17v40-CableOuterJacketKind) | Kind of outer jacket of this cable. | |
| sheathAsNeutral [0..1] | [Boolean](#CIM17v40-Boolean) | True if sheath / shield is used as a neutral (i.e., bonded). | |
| shieldMaterial [0..1] | [CableShieldMaterialKind](#CIM17v40-CableShieldMaterialKind) | Material of the shield. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| coreRadius [0..1] | [Length](#CIM17v40-Length) | see [WireInfo](CIM17v40-WireInfo) | |
| coreStrandCount [0..1] | [Integer](#CIM17v40-Integer) | see [WireInfo](#CIM17v40-WireInfo) | |
| gmr [0..1] | [Length](#CIM17v40-Length) | see [WireInfo](CIM17v40-WireInfo) | |
| insulated [0..1] | [Boolean](#CIM17v40-Boolean) | see [WireInfo](#CIM17v40-WireInfo) | |
| insulationMaterial [0..1] | [WireInsulationKind](#CIM17v40-WireInsulationKind) | see [WireInfo](CIM17v40-WireInfo) | |
| insulationThickness [0..1] | [Length](#CIM17v40-Length) | see [WireInfo](CIM17v40-WireInfo) | |
| material [0..1] | [WireMaterialKind](#CIM17v40-WireMaterialKind) | see [WireInfo](CIM17v40-WireInfo) | |
| rAC25 [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | see [WireInfo](CIM17v40-WireInfo) | |
| rAC50 [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | see [WireInfo](CIM17v40-WireInfo) | |
| rAC75 [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | see [WireInfo](CIM17v40-WireInfo) | |
| radius [0..1] | [Length](#CIM17v40-Length) | see [WireInfo](CIM17v40-WireInfo) | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [WireInfo](CIM17v40-WireInfo) | |
| rDC20 [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | see [WireInfo](CIM17v40-WireInfo) | |
| sizeDescription [0..1] | [String](#CIM17v40-String) | see [WireInfo](#CIM17v40-WireInfo) | |
| strandCount [0..1] | [Integer](#CIM17v40-Integer) | see [WireInfo](#CIM17v40-WireInfo) | |
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CalculationMethodHierarchy}
### (harmonization) CalculationMethodHierarchy

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CalculationMethodHierarchy {

}

class IdentifiedObject {

}

IdentifiedObject <|-- CalculationMethodHierarchy : inherits from
class MeasurementValue {

}

CalculationMethodHierarchy --> "0..1" MeasurementValue : MeasurementValue
```

The hierarchy of calculation methods used to derive this measurement.

.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `MeasurementValue [0..1]` (harmonization) | [MeasurementValue](#CIM17v40-MeasurementValue) | Measurement value to which this calculation method hierarchy applies. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CalculationMethodOrder}
### CalculationMethodOrder


```mermaid
classDiagram
direction TB

class CalculationMethodOrder {

+ order : Integer [0..1]
}

class CalculationMethodHierarchy {

}

CalculationMethodOrder --> "1" CalculationMethodHierarchy : CalculationMethodHierarchy
class StatisticalCalculation {

}

CalculationMethodOrder --> "1" StatisticalCalculation : StatisicalCalculation
```

The order of this calculation method in a hierarchy of calculation methods.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| order [0..1] | [Integer](#CIM17v40-Integer) | Order of the statistical calculation method within the calculation method hierarchy. | |
| CalculationMethodHierarchy [1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | The calculation method hierarchy of which this order of statistical calculation is a member. | |
| StatisicalCalculation [1] | [StatisticalCalculation](#CIM17v40-StatisticalCalculation) | The statistical calculation done at this order. | |

{#CIM17v40-Capability}
### Capability

Inheritance path = [WorkIdentifiedObject](#CIM17v40-WorkIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Capability {

+ performanceFactor : String [0..1]
+ type : String [0..1]
+ status : Status [0..1]
+ validityInterval : DateTimeInterval [0..1]
}

class WorkIdentifiedObject {

}

WorkIdentifiedObject <|-- Capability : inherits from
class OldCrew {

}

Capability --> "0..1" OldCrew : Crew
```

Capabilities of a crew.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| performanceFactor [0..1] | [String](#CIM17v40-String) | Capability performance factor. | |
| type [0..1] | [String](#CIM17v40-String) | Classification by utility's work management standards and practices. | |
| `Crew [0..1]` (informative) | [OldCrew](#CIM17v40-OldCrew) | | |
| status [0..1] | [Status](#CIM17v40-Status) | | |
| validityInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Date and time interval for which this capability is valid (when it became effective and when it expires). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Card}
### Card


```mermaid
classDiagram
direction TB

class Card {

+ accountHolderName : String [0..1]
+ cvNumber : String [0..1]
+ expiryDate : Date [0..1]
+ pan : String [0..1]
}

class Tender {

}

Card --> "1" Tender : Tender
```

Documentation of the tender when it is a type of card (credit, debit, etc).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| accountHolderName [0..1] | [String](#CIM17v40-String) | Name of account holder. | |
| cvNumber [0..1] | [String](#CIM17v40-String) | The card verification number. | |
| expiryDate [0..1] | [Date](#CIM17v40-Date) | The date when this card expires. | |
| pan [0..1] | [String](#CIM17v40-String) | The primary account number. | |
| Tender [1] | [Tender](#CIM17v40-Tender) | Payment tender this card is being used for. | |

{#CIM17v40-Cashier}
### Cashier

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Cashier {

+ electronicAddress : ElectronicAddress [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Cashier : inherits from
```

The operator of the point of sale for the duration of CashierShift. Cashier is under the exclusive management control of Vendor.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | Electronic address. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CashierShift}
### CashierShift

Inheritance path = [Shift](#CIM17v40-Shift) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CashierShift {

+ cashFloat : Money [0..1]
}

class Shift {

}

Shift <|-- CashierShift : inherits from
class Cashier {

}

CashierShift --> "0..1" Cashier : Cashier
class PointOfSale {

}

CashierShift --> "0..1" PointOfSale : PointOfSale
```

The operating shift for a cashier, during which the cashier may transact against the cashier shift, subject to vendor shift being open.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| cashFloat [0..1] | [Money](#CIM17v40-Money) | The amount of cash that the cashier brings to start the shift and that will be taken away at the end of the shift; i.e. the cash float does not get banked. | |
| Cashier [0..1] | [Cashier](#CIM17v40-Cashier) | Cashier operating this shift. | |
| PointOfSale [0..1] | [PointOfSale](#CIM17v40-PointOfSale) | Point of sale that is in operation during this shift. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| receiptsGrandTotalBankable [0..1] | [Money](#CIM17v40-Money) | see [Shift](CIM17v40-Shift) | |
| receiptsGrandTotalNonBankable [0..1] | [Money](#CIM17v40-Money) | see [Shift](CIM17v40-Shift) | |
| receiptsGrandTotalRounding [0..1] | [Money](#CIM17v40-Money) | see [Shift](CIM17v40-Shift) | |
| transactionsGrandTotal [0..1] | [Money](#CIM17v40-Money) | see [Shift](CIM17v40-Shift) | |
| transactionsGrandTotalRounding [0..1] | [Money](#CIM17v40-Money) | see [Shift](CIM17v40-Shift) | |
| activityInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [Shift](CIM17v40-Shift) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CatalogAssetType}
### (informative) CatalogAssetType

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CatalogAssetType {

+ estimatedUnitCost : Money [0..1]
+ kind : enum:AssetKind [0..1]
+ stockItem : Boolean [0..1]
+ type : String [0..1]
+ quantity : StringQuantity [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- CatalogAssetType : inherits from
class AssetInfo {

}

CatalogAssetType --> "0..1" AssetInfo : AssetInfo
class TypeAssetCatalogue {

}

CatalogAssetType --> "0..1" TypeAssetCatalogue : TypeAssetCatalogue
```

a Assets that may be used for planning, work or design purposes.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| estimatedUnitCost [0..1] | [Money](#CIM17v40-Money) | Estimated unit cost (or cost per unit length) of this type of asset. It does not include labor to install, construct or configure it. | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | Kind of asset (from enumerated list). | |
| stockItem [0..1] | [Boolean](#CIM17v40-Boolean) | True if item is a stock item (default). | |
| type [0..1] | [String](#CIM17v40-String) | Description of type of asset. | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | Generic nameplate information associated with this catalog asset type. | |
| quantity [0..1] | [StringQuantity](#CIM17v40-StringQuantity) | The value, unit of measure, and multiplier for the quantity. | |
| `TypeAssetCatalogue [0..1]` (informative) | [TypeAssetCatalogue](#CIM17v40-TypeAssetCatalogue) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ChangeSet}
### (informative) ChangeSet

Inheritance path = [DataSet](#CIM17v40-DataSet)

```mermaid
classDiagram
direction TB

class ChangeSet {

}

class DataSet {

}

DataSet <|-- ChangeSet : inherits from
class NetworkModelProjectStage {

}

ChangeSet --> "0..1" NetworkModelProjectStage : NMProjectStage
```

Describes a set of changes that can be applied in different situations. A given registered target object MRID may only be referenced once by the contained change set members.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `NMProjectStage [0..1]` (informative) | [NetworkModelProjectStage](#CIM17v40-NetworkModelProjectStage) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [DataSet](#CIM17v40-DataSet) | |
| description [0..1] | [String](#CIM17v40-String) | see [DataSet](#CIM17v40-DataSet) | |
| name [0..1] | [String](#CIM17v40-String) | see [DataSet](#CIM17v40-DataSet) | |
| `AlternateModel [0..1]` (informative) | [AlternateModel](#CIM17v40-AlternateModel) | see [DataSet](CIM17v40-DataSet) | |

{#CIM17v40-ChangeSetMember}
### ChangeSetMember


```mermaid
classDiagram
direction TB

class ChangeSetMember {

}

class ChangeSet {

}

ChangeSetMember --> "0..1" ChangeSet : Changeset
class IdentifiedObject {

}

ChangeSetMember --> "0..1" IdentifiedObject : PropertiesObject
class IdentifiedObject {

}

ChangeSetMember --> "1" IdentifiedObject : TargetObject
```

A CRUD-style data object.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Changeset [0..1] | [ChangeSet](#CIM17v40-ChangeSet) | Dataset containing the data objects. | |
| PropertiesObject [0..1] | [IdentifiedObject](#CIM17v40-IdentifiedObject) | The CIM object holding the properties of this dataset context. Sometimes properties are not required and only the reference to the registered object is required. | |
| TargetObject [1] | [IdentifiedObject](#CIM17v40-IdentifiedObject) | The registered CIM object. | |

{#CIM17v40-Channel}
### Channel

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Channel {

+ isVirtual : Boolean [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Channel : inherits from
class ReadingType {

}

Channel --> "0..1" ReadingType : ReadingType
class Register {

}

Channel --> "0..1" Register : Register
```

A single path for the collection or reporting of register values over a period of time. For example, a register which measures forward energy can have two channels, one providing bulk quantity readings and the other providing interval readings of a fixed interval size.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| isVirtual [0..1] | [Boolean](#CIM17v40-Boolean) | If true, the data is being calculated by an enterprise system rather than metered directly. | |
| ReadingType [0..1] | [ReadingType](#CIM17v40-ReadingType) | Reading type for register values reported/collected by this channel. | |
| Register [0..1] | [Register](#CIM17v40-Register) | Register whose values are collected/reported by this channel. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Charge}
### Charge

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Charge {

+ kind : enum:ChargeKind [0..1]
+ variablePortion : PerCent [0..1]
+ fixedPortion : AccountingUnit [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Charge : inherits from
class Charge {

}

Charge --> "0..1" Charge : ParentCharge
```

A charge element associated with other entities such as tariff structures, auxiliary agreements or other charge elements. The total charge amount applicable to this instance of charge is the sum of fixed and variable portion.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [ChargeKind](#CIM17v40-ChargeKind) | The kind of charge to be applied. | |
| variablePortion [0..1] | [PerCent](#CIM17v40-PerCent) | The variable portion of this charge element, calculated as a percentage of the total amount of a parent charge. | |
| fixedPortion [0..1] | [AccountingUnit](#CIM17v40-AccountingUnit) | The fixed portion of this charge element. | |
| ParentCharge [0..1] | [Charge](#CIM17v40-Charge) | Parent of this charge sub-component. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ChargeComponent}
### ChargeComponent

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ChargeComponent {

+ deleteStatus : String [0..1]
+ effectiveDate : DateTime [0..1]
+ equation : String [0..1]
+ message : String [0..1]
+ roundOff : String [0..1]
+ sum : String [0..1]
+ terminationDate : DateTime [0..1]
+ type : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ChargeComponent : inherits from
```

A Charge Component is a list of configurable charge quality items to feed into settlement calculation and/or bill determinants.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| deleteStatus [0..1] | [String](#CIM17v40-String) | | |
| effectiveDate [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| equation [0..1] | [String](#CIM17v40-String) | | |
| message [0..1] | [String](#CIM17v40-String) | | |
| roundOff [0..1] | [String](#CIM17v40-String) | | |
| sum [0..1] | [String](#CIM17v40-String) | | |
| terminationDate [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| type [0..1] | [String](#CIM17v40-String) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ChargeGroup}
### ChargeGroup

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ChargeGroup {

+ effectiveDate : DateTime [0..1]
+ marketCode : String [0..1]
+ terminationDate : DateTime [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ChargeGroup : inherits from
class ChargeGroup {

}

ChargeGroup --> "0..1" ChargeGroup : ChargeGroupParent
```

Charge Group is the grouping of Charge Types for settlement invoicing purpose. Examples such as Ancillary Services, Interests, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| effectiveDate [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| marketCode [0..1] | [String](#CIM17v40-String) | | |
| terminationDate [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| ChargeGroupParent [0..1] | [ChargeGroup](#CIM17v40-ChargeGroup) | A ChargeGroup instance can have relationships with other ChargeGroup instances. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ChargeProfile}
### ChargeProfile

Inheritance path = [Profile](#CIM17v40-Profile) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ChargeProfile {

+ frequency : String [0..1]
+ numberInterval : Integer [0..1]
+ type : String [0..1]
+ unitOfMeasure : String [0..1]
}

class Profile {

}

Profile <|-- ChargeProfile : inherits from
class Bid {

}

ChargeProfile --> "0..1" Bid : Bid
class BillDeterminant {

}

ChargeProfile --> "0..1" BillDeterminant : BillDeterminant
class PassThroughBill {

}

ChargeProfile --> "0..1" PassThroughBill : PassTroughBill
```

A type of profile for financial charges.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| frequency [0..1] | [String](#CIM17v40-String) | The calculation frequency, daily or monthly. | |
| numberInterval [0..1] | [Integer](#CIM17v40-Integer) | The number of intervals in the profile data. | |
| type [0..1] | [String](#CIM17v40-String) | The type of profile. It could be amount, price, or quantity. | |
| unitOfMeasure [0..1] | [String](#CIM17v40-String) | The unit of measure applied to the value attribute of the profile data. | |
| Bid [0..1] | [Bid](#CIM17v40-Bid) | | |
| BillDeterminant [0..1] | [BillDeterminant](#CIM17v40-BillDeterminant) | | |
| PassTroughBill [0..1] | [PassThroughBill](#CIM17v40-PassThroughBill) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ChargeProfileData}
### ChargeProfileData


```mermaid
classDiagram
direction TB

class ChargeProfileData {

+ sequence : Integer [0..1]
+ timeStamp : DateTime [0..1]
+ value : Float [0..1]
}

class BillDeterminant {

}

ChargeProfileData --> "0..1" BillDeterminant : BillDeterminant
class ChargeProfile {

}

ChargeProfileData --> "0..1" ChargeProfile : ChargeProfile
```

Model of various charges associated with an energy profile to support billing and settlement.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| sequence [0..1] | [Integer](#CIM17v40-Integer) | The sequence number of the profile. | |
| timeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | The date and time of an interval. | |
| value [0..1] | [Float](#CIM17v40-Float) | The value of an interval given a profile type (amount, price, or quantity), subject to the UOM. | |
| `BillDeterminant [0..1]` (OfAggregate) | [BillDeterminant](#CIM17v40-BillDeterminant) | | |
| `ChargeProfile [0..1]` (OfAggregate) | [ChargeProfile](#CIM17v40-ChargeProfile) | | |

{#CIM17v40-ChargeType}
### ChargeType

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ChargeType {

+ chargeOrder : String [0..1]
+ chargeVersion : String [0..1]
+ effectiveDate : DateTime [0..1]
+ factor : String [0..1]
+ frequencyType : String [0..1]
+ terminationDate : DateTime [0..1]
+ totalInterval : String [0..1]
}

class Document {

}

Document <|-- ChargeType : inherits from
```

Charge Type is the basic level configuration for settlement to process specific charges for invoicing purpose. Examples such as: Day Ahead Spinning Reserve Default Invoice Interest Charge, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| chargeOrder [0..1] | [String](#CIM17v40-String) | | |
| chargeVersion [0..1] | [String](#CIM17v40-String) | | |
| effectiveDate [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| factor [0..1] | [String](#CIM17v40-String) | | |
| frequencyType [0..1] | [String](#CIM17v40-String) | | |
| terminationDate [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| totalInterval [0..1] | [String](#CIM17v40-String) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Cheque}
### Cheque


```mermaid
classDiagram
direction TB

class Cheque {

+ chequeNumber : String [0..1]
+ date : Date [0..1]
+ kind : enum:ChequeKind [0..1]
+ micrNumber : String [0..1]
+ bankAccountDetail : BankAccountDetail [0..1]
}

class Tender {

}

Cheque --> "1" Tender : Tender
```

The actual tender when it is a type of cheque.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| chequeNumber [0..1] | [String](#CIM17v40-String) | Cheque reference number as printed on the cheque. | |
| date [0..1] | [Date](#CIM17v40-Date) | Date when cheque becomes valid. | |
| kind [0..1] | [ChequeKind](#CIM17v40-ChequeKind) | Kind of cheque. | |
| micrNumber [0..1] | [String](#CIM17v40-String) | The magnetic ink character recognition number printed on the cheque. | |
| bankAccountDetail [0..1] | [BankAccountDetail](#CIM17v40-BankAccountDetail) | Details of the account holder and bank. | |
| Tender [1] | [Tender](#CIM17v40-Tender) | Payment tender the cheque is being used for. | |

{#CIM17v40-Circuit}
### (informative) Circuit

Inheritance path = [Line](#CIM17v40-Line) => [EquipmentContainer](#CIM17v40-EquipmentContainer) => [ConnectivityNodeContainer](#CIM17v40-ConnectivityNodeContainer) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Circuit {

}

class Line {

}

Line <|-- Circuit : inherits from
```


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Region [0..1]` (OfAggregate) | [SubGeographicalRegion](#CIM17v40-SubGeographicalRegion) | see [Line](CIM17v40-Line) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Clamp}
### Clamp

Inheritance path = [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Clamp {

+ lengthFromTerminal1 : Length [0..1]
}

class ConductingEquipment {

}

ConductingEquipment <|-- Clamp : inherits from
class ACLineSegment {

}

Clamp --> "1" ACLineSegment : ACLineSegment
class ClampAction {

}

Clamp --> "0..1" ClampAction : ClampAction
class JumperAction {

}

Clamp --> "0..1" JumperAction : JumperAction
```

A Clamp is a galvanic connection at a line segment where other equipment is connected. A Clamp does not cut the line segment.

A Clamp is ConductingEquipment and has one Terminal with an associated ConnectivityNode. Any other ConductingEquipment can be connected to the Clamp ConnectivityNode.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| lengthFromTerminal1 [0..1] | [Length](#CIM17v40-Length) | The length to the place where the clamp is located starting from side one of the line segment, i.e. the line segment terminal with sequence number equal to 1. | |
| ACLineSegment [1] | [ACLineSegment](#CIM17v40-ACLineSegment) | The line segment to which the clamp is connected. | |
| ClampAction [0..1] | [ClampAction](#CIM17v40-ClampAction) | The clamp action that is performed on the clamp | |
| JumperAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | Action taken with this jumper. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ClampAction}
### ClampAction

Inheritance path = [SwitchingAction](#CIM17v40-SwitchingAction) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ClampAction {

+ kind : enum:TempEquipActionKind [0..1]
}

class SwitchingAction {

}

SwitchingAction <|-- ClampAction : inherits from
class Clamp {

}

ClampAction --> "0..1" Clamp : Clamp
```

Action on Clamp as a switching step


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [TempEquipActionKind](#CIM17v40-TempEquipActionKind) | Switching action to perform | |
| Clamp [0..1] | [Clamp](#CIM17v40-Clamp) | The clamp that the clamp action is performed on | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| executedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| issuedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| plannedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| Operator [0..1] | [Operator](#CIM17v40-Operator) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingEvent [0..1] | [SwitchingEvent](#CIM17v40-SwitchingEvent) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingStep [0..1] | [SwitchingStep](#CIM17v40-SwitchingStep) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ClassificationCondition}
### ClassificationCondition

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ClassificationCondition {

+ duration : Seconds [0..1]
+ test : enum:TestKind [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ClassificationCondition : inherits from
class PhenomenonClassification {

}

ClassificationCondition --> "0..1" PhenomenonClassification : PhenomenonClassification
```

A classification condition used to define preconditions that must be met by a phenomena classification.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| duration [0..1] | [Seconds](#CIM17v40-Seconds) | The duration of the of the condition in seconds | |
| test [0..1] | [TestKind](#CIM17v40-TestKind) | The test applied to the value. | |
| PhenomenonClassification [0..1] | [PhenomenonClassification](#CIM17v40-PhenomenonClassification) | Phenomenon classification to which this condition relates. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ClearanceAction}
### ClearanceAction

Inheritance path = [SwitchingAction](#CIM17v40-SwitchingAction) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ClearanceAction {

+ kind : enum:ClearanceActionKind [0..1]
}

class SwitchingAction {

}

SwitchingAction <|-- ClearanceAction : inherits from
class ClearanceDocument {

}

ClearanceAction --> "0..1" ClearanceDocument : Clearance
```

Action on clearance document as a switching step.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [ClearanceActionKind](#CIM17v40-ClearanceActionKind) | Clearance action to perform. | |
| Clearance [0..1] | [ClearanceDocument](#CIM17v40-ClearanceDocument) | Clearance associated with this clearance action. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| executedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| issuedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| plannedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| Operator [0..1] | [Operator](#CIM17v40-Operator) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingEvent [0..1] | [SwitchingEvent](#CIM17v40-SwitchingEvent) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingStep [0..1] | [SwitchingStep](#CIM17v40-SwitchingStep) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ClearanceDocument}
### ClearanceDocument

Inheritance path = [SafetyDocument](#CIM17v40-SafetyDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ClearanceDocument {

+ mustBeDeenergised : Boolean [0..1]
+ mustBeGrounded : Boolean [0..1]
}

class SafetyDocument {

}

SafetyDocument <|-- ClearanceDocument : inherits from
class ClearanceAction {

}

ClearanceDocument --> "0..1" ClearanceAction : ClearanceAction
```

Safety document used to authorise work on conducting equipment in the field. Tagged equipment is not allowed to be operated.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mustBeDeenergised [0..1] | [Boolean](#CIM17v40-Boolean) | If true, the equipment must be deenergised. | |
| mustBeGrounded [0..1] | [Boolean](#CIM17v40-Boolean) | If true, the equipment must be grounded. | |
| ClearanceAction [0..1] | [ClearanceAction](#CIM17v40-ClearanceAction) | Clearance action associated with this clearance. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| issuedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SafetyDocument](#CIM17v40-SafetyDocument) | |
| releasedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SafetyDocument](#CIM17v40-SafetyDocument) | |
| IssuedBySupervisor [0..1] | [OperationsSafetySupervisor](#CIM17v40-OperationsSafetySupervisor) | see [SafetyDocument](CIM17v40-SafetyDocument) | |
| IssuedToSupervisor [0..1] | [FieldSafetySupervisor](#CIM17v40-FieldSafetySupervisor) | see [SafetyDocument](CIM17v40-SafetyDocument) | |
| ReleasedBySupervisor [0..1] | [FieldSafetySupervisor](#CIM17v40-FieldSafetySupervisor) | see [SafetyDocument](CIM17v40-SafetyDocument) | |
| ReleasedToSupervisor [0..1] | [OperationsSafetySupervisor](#CIM17v40-OperationsSafetySupervisor) | see [SafetyDocument](CIM17v40-SafetyDocument) | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | see [SafetyDocument](CIM17v40-SafetyDocument) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CloudCondition}
### CloudCondition

Inheritance path = [AtmosphericPhenomenon](#CIM17v40-AtmosphericPhenomenon) => [EnvironmentalPhenomenon](#CIM17v40-EnvironmentalPhenomenon)

```mermaid
classDiagram
direction TB

class CloudCondition {

+ kind : enum:CloudKind [0..1]
}

class AtmosphericPhenomenon {

}

AtmosphericPhenomenon <|-- CloudCondition : inherits from
```

A classified cloud phenomenon with a type.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [CloudKind](#CIM17v40-CloudKind) | The type of the cloud as defined by the CloudKind enumeration. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| direction [0..1] | [Bearing](#CIM17v40-Bearing) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| maxCoverage [0..1] | [PerCent](#CIM17v40-PerCent) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| minCoverage [0..1] | [PerCent](#CIM17v40-PerCent) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| speed [0..1] | [Speed](#CIM17v40-Speed) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| altitude [0..1] | [RelativeDisplacement](#CIM17v40-RelativeDisplacement) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| base [0..1] | [RelativeDisplacement](#CIM17v40-RelativeDisplacement) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| PhenomenonClassification [0..1] | [PhenomenonClassification](#CIM17v40-PhenomenonClassification) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| timeInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |

{#CIM17v40-CnodeDistributionFactor}
### CnodeDistributionFactor

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CnodeDistributionFactor {

+ factor : Float [0..1]
+ podLossFactor : Float [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- CnodeDistributionFactor : inherits from
class AggregateNode {

}

CnodeDistributionFactor --> "0..1" AggregateNode : AggregateNode
class HostControlArea {

}

CnodeDistributionFactor --> "0..1" HostControlArea : HostControlArea
class MktConnectivityNode {

}

CnodeDistributionFactor --> "1" MktConnectivityNode : MktConnectivityNode
class SubControlArea {

}

CnodeDistributionFactor --> "0..1" SubControlArea : SubControlArea
```

Participation factors per Cnode. Used to calculate "participation" of Cnode in an AggregateNode. Each Cnode associated to an AggregateNode would be assigned a participation factor for its participation within the AggregateNode.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| factor [0..1] | [Float](#CIM17v40-Float) | Used to calculate "participation" of Cnode in an AggregateNode | |
| podLossFactor [0..1] | [Float](#CIM17v40-Float) | Point of delivery loss factor | |
| AggregateNode [0..1] | [AggregateNode](#CIM17v40-AggregateNode) | | |
| HostControlArea [0..1] | [HostControlArea](#CIM17v40-HostControlArea) | | |
| MktConnectivityNode [1] | [MktConnectivityNode](#CIM17v40-MktConnectivityNode) | | |
| SubControlArea [0..1] | [SubControlArea](#CIM17v40-SubControlArea) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CogenerationPlant}
### CogenerationPlant

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CogenerationPlant {

+ cogenHPSendoutRating : Float [0..1]
+ cogenHPSteamRating : Float [0..1]
+ cogenLPSendoutRating : Float [0..1]
+ cogenLPSteamRating : Float [0..1]
+ ratedP : ActivePower [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- CogenerationPlant : inherits from
class SteamSendoutSchedule {

}

CogenerationPlant --> "1" SteamSendoutSchedule : SteamSendoutSchedule
```

A set of thermal generating units for the production of electrical energy and process steam (usually from the output of the steam turbines). The steam sendout is typically used for industrial purposes or for municipal heating and cooling.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| cogenHPSendoutRating [0..1] | [Float](#CIM17v40-Float) | The high pressure steam sendout. | |
| cogenHPSteamRating [0..1] | [Float](#CIM17v40-Float) | The high pressure steam rating. | |
| cogenLPSendoutRating [0..1] | [Float](#CIM17v40-Float) | The low pressure steam sendout. | |
| cogenLPSteamRating [0..1] | [Float](#CIM17v40-Float) | The low pressure steam rating. | |
| ratedP [0..1] | [ActivePower](#CIM17v40-ActivePower) | The rated output active power of the cogeneration plant.The attribute shall be a positive value. | |
| `SteamSendoutSchedule [1]` (AggregateOf) | [SteamSendoutSchedule](#CIM17v40-SteamSendoutSchedule) | A cogeneration plant has a steam sendout schedule. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ComFunction}
### ComFunction

Inheritance path = [EndDeviceFunction](#CIM17v40-EndDeviceFunction) => [AssetFunction](#CIM17v40-AssetFunction) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ComFunction {

+ amrAddress : String [0..1]
+ amrRouter : String [0..1]
+ direction : enum:ComDirectionKind [0..1]
+ technology : enum:ComTechnologyKind [0..1]
}

class EndDeviceFunction {

}

EndDeviceFunction <|-- ComFunction : inherits from
class ComModule {

}

ComFunction --> "0..1" ComModule : ComModule
```

Communication function of communication equipment or a device such as a meter.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| amrAddress [0..1] | [String](#CIM17v40-String) | Communication ID number (e.g. serial number, IP address, telephone number, etc.) of the AMR module which serves this meter. | |
| amrRouter [0..1] | [String](#CIM17v40-String) | Communication ID number (e.g. port number, serial number, data collector ID, etc.) of the parent device associated to this AMR module. | |
| direction [0..1] | [ComDirectionKind](#CIM17v40-ComDirectionKind) | Kind of communication direction. | |
| technology [0..1] | [ComTechnologyKind](#CIM17v40-ComTechnologyKind) | Kind of communication technology. | |
| ComModule [0..1] | [ComModule](#CIM17v40-ComModule) | Module performing this communication function. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [EndDeviceFunction](#CIM17v40-EndDeviceFunction) | |
| EndDevice [0..1] | [EndDevice](#CIM17v40-EndDevice) | see [EndDeviceFunction](CIM17v40-EndDeviceFunction) | |
| configID [0..1] | [String](#CIM17v40-String) | see [AssetFunction](#CIM17v40-AssetFunction) | |
| firmwareID [0..1] | [String](#CIM17v40-String) | see [AssetFunction](#CIM17v40-AssetFunction) | |
| hardwareID [0..1] | [String](#CIM17v40-String) | see [AssetFunction](#CIM17v40-AssetFunction) | |
| password [0..1] | [String](#CIM17v40-String) | see [AssetFunction](#CIM17v40-AssetFunction) | |
| programID [0..1] | [String](#CIM17v40-String) | see [AssetFunction](#CIM17v40-AssetFunction) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [AssetFunction](CIM17v40-AssetFunction) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ComMedia}
### ComMedia

Inheritance path = [Asset](#CIM17v40-Asset) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ComMedia {

}

class Asset {

}

Asset <|-- ComMedia : inherits from
```

Communication media such as fibre optic cable, power-line, telephone, etc.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | see [Asset](#CIM17v40-Asset) | |
| initialCondition [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | see [Asset](CIM17v40-Asset) | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | see [Asset](CIM17v40-Asset) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [Asset](CIM17v40-Asset) | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | see [Asset](CIM17v40-Asset) | |
| lotNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| position [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | see [Asset](CIM17v40-Asset) | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | see [Asset](CIM17v40-Asset) | |
| serialNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| type [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| utcNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | see [Asset](CIM17v40-Asset) | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | see [Asset](CIM17v40-Asset) | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | see [Asset](CIM17v40-Asset) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [Asset](CIM17v40-Asset) | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | see [Asset](CIM17v40-Asset) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Asset](CIM17v40-Asset) | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | see [Asset](CIM17v40-Asset) | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | see [Asset](CIM17v40-Asset) | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | see [Asset](CIM17v40-Asset) | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | see [Asset](CIM17v40-Asset) | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | see [Asset](CIM17v40-Asset) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Asset](CIM17v40-Asset) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [Asset](CIM17v40-Asset) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [Asset](CIM17v40-Asset) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Asset](CIM17v40-Asset) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ComModule}
### ComModule

Inheritance path = [Asset](#CIM17v40-Asset) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ComModule {

+ amrSystem : String [0..1]
+ supportsAutonomousDst : Boolean [0..1]
+ timeZoneOffset : Minutes [0..1]
}

class Asset {

}

Asset <|-- ComModule : inherits from
```

An asset having communications capabilities that can be paired with a meter or other end device to provide the device with communication ability, through associated communication function. An end device that has communications capabilities through embedded hardware can use that function directly (without the communication module), or combine embedded communication function with additional communication functions provided through an external communication module (e.g. zigbee).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| amrSystem [0..1] | [String](#CIM17v40-String) | Automated meter reading (AMR) system communicating with this com module. | |
| supportsAutonomousDst [0..1] | [Boolean](#CIM17v40-Boolean) | If true, autonomous daylight saving time (DST) function is supported. | |
| timeZoneOffset [0..1] | [Minutes](#CIM17v40-Minutes) | Time zone offset relative to GMT for the location of this com module. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | see [Asset](#CIM17v40-Asset) | |
| initialCondition [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | see [Asset](CIM17v40-Asset) | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | see [Asset](CIM17v40-Asset) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [Asset](CIM17v40-Asset) | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | see [Asset](CIM17v40-Asset) | |
| lotNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| position [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | see [Asset](CIM17v40-Asset) | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | see [Asset](CIM17v40-Asset) | |
| serialNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| type [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| utcNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | see [Asset](CIM17v40-Asset) | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | see [Asset](CIM17v40-Asset) | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | see [Asset](CIM17v40-Asset) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [Asset](CIM17v40-Asset) | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | see [Asset](CIM17v40-Asset) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Asset](CIM17v40-Asset) | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | see [Asset](CIM17v40-Asset) | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | see [Asset](CIM17v40-Asset) | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | see [Asset](CIM17v40-Asset) | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | see [Asset](CIM17v40-Asset) | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | see [Asset](CIM17v40-Asset) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Asset](CIM17v40-Asset) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [Asset](CIM17v40-Asset) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [Asset](CIM17v40-Asset) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Asset](CIM17v40-Asset) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CombinedCycleConfiguration}
### CombinedCycleConfiguration

Inheritance path = [RegisteredGenerator](#CIM17v40-RegisteredGenerator) => [RegisteredResource](#CIM17v40-RegisteredResource) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CombinedCycleConfiguration {

+ primaryConfiguration : Boolean [0..1]
+ ShutdownFlag : Boolean [0..1]
+ StartupFlag : Boolean [0..1]
}

class RegisteredGenerator {

}

RegisteredGenerator <|-- CombinedCycleConfiguration : inherits from
class CombinedCycleLogicalConfiguration {

}

CombinedCycleConfiguration --> "0..1" CombinedCycleLogicalConfiguration : CombinedCycleLogicalConfiguration
```

Configuration options for combined cycle units.

For example, a Combined Cycle with (CT1, CT2, ST1) will have (CT1, ST1) and (CT2, ST1) configurations as part of(1CT + 1STlogicalconfiguration).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| primaryConfiguration [0..1] | [Boolean](#CIM17v40-Boolean) | Whether this CombinedCycleConfiguration is the primary configuration in the associated Logical configuration? | |
| ShutdownFlag [0..1] | [Boolean](#CIM17v40-Boolean) | Whether Combined Cycle Plant can be shut-down in this Configuration? | |
| StartupFlag [0..1] | [Boolean](#CIM17v40-Boolean) | Whether Combined Cycle Plant can be started in this Logical Configuration? | |
| CombinedCycleLogicalConfiguration [0..1] | [CombinedCycleLogicalConfiguration](#CIM17v40-CombinedCycleLogicalConfiguration) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| capacityFactor [0..1] | [PerCent](#CIM17v40-PerCent) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| coldStartTime [0..1] | [Float](#CIM17v40-Float) | see [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | |
| combinedCycleOperatingMode [0..1] | [String](#CIM17v40-String) | see [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | |
| commericialOperationDate [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | |
| constrainedOutputFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| energyDownRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| energyUpRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| extremeLongStart [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| fuelSource [0..1] | [FuelSource](#CIM17v40-FuelSource) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| highControlLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| hotIntTime [0..1] | [Float](#CIM17v40-Float) | see [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | |
| hotStartTime [0..1] | [Float](#CIM17v40-Float) | see [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | |
| intColdTime [0..1] | [Float](#CIM17v40-Float) | see [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | |
| intStartTime [0..1] | [Float](#CIM17v40-Float) | see [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | |
| loadFollowingDownMSS [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| loadFollowingUpMSS [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| lowControlLImit [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| maxDependableCap [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| maximumAllowableSpinningReserve [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| maximumOperatingLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| maxMinLoadCost [0..1] | [CostRate](#CIM17v40-CostRate) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| maxPumpingLevel [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| maxShutdownTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | |
| maxStartUpsPerDay [0..1] | [Integer](#CIM17v40-Integer) | see [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | |
| maxWeeklyEnergy [0..1] | [Float](#CIM17v40-Float) | see [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | |
| maxWeeklyStarts [0..1] | [Integer](#CIM17v40-Integer) | see [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | |
| minimumLoadCostBasis [0..1] | [CostBasis](#CIM17v40-CostBasis) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| minimumLoadFuelCost [0..1] | [CostPerHeatUnit](#CIM17v40-CostPerHeatUnit) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| minimumOperatingLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| minLoadCost [0..1] | [CostRate](#CIM17v40-CostRate) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| mustOfferRA [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| nameplateCapacity [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| operatingMaintenanceCost [0..1] | [CostPerEnergyUnit](#CIM17v40-CostPerEnergyUnit) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| pumpingCost [0..1] | [CostRate](#CIM17v40-CostRate) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| pumpingFactor [0..1] | [Float](#CIM17v40-Float) | see [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | |
| pumpMinDownTime [0..1] | [Float](#CIM17v40-Float) | see [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | |
| pumpMinUpTime [0..1] | [Float](#CIM17v40-Float) | see [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | |
| pumpShutdownCost [0..1] | [Float](#CIM17v40-Float) | see [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | |
| pumpShutdownTime [0..1] | [Integer](#CIM17v40-Integer) | see [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | |
| quickStartFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| rampCurveType [0..1] | [RampCurveType](#CIM17v40-RampCurveType) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| regulationDownRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| regulationFlag [0..1] | [UnitRegulationKind](#CIM17v40-UnitRegulationKind) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| regulationUpRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| resourceSubType [0..1] | [String](#CIM17v40-String) | see [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | |
| riverSystem [0..1] | [String](#CIM17v40-String) | see [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | |
| RMNRFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| RMRFlag [0..1] | [FlagTypeRMR](#CIM17v40-FlagTypeRMR) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| RMRManualIndicator [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| RMTFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| spinRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| startUpCostBasis [0..1] | [CostBasis](#CIM17v40-CostBasis) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| syncCondCapable [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| unitType [0..1] | [UnitType](#CIM17v40-UnitType) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| useLimitFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| variableEnergyResource [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| EnergyPriceIndex [1] | [EnergyPriceIndex](#CIM17v40-EnergyPriceIndex) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| FuelCostCurve [0..1] | [FuelCostCurve](#CIM17v40-FuelCostCurve) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| FuelRegion [0..1] | [FuelRegion](#CIM17v40-FuelRegion) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| LocalReliabilityArea [0..1] | [LocalReliabilityArea](#CIM17v40-LocalReliabilityArea) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| MktHeatRateCurve [0..1] | [MktHeatRateCurve](#CIM17v40-MktHeatRateCurve) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| RegulatingLimit [0..1] | [RegulatingLimit](#CIM17v40-RegulatingLimit) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| RMRHeatRateCurve [0..1] | [RMRHeatRateCurve](#CIM17v40-RMRHeatRateCurve) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| RMRStartUpCostCurve [0..1] | [RMRStartUpCostCurve](#CIM17v40-RMRStartUpCostCurve) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| RMRStartUpEnergyCurve [0..1] | [RMRStartUpEnergyCurve](#CIM17v40-RMRStartUpEnergyCurve) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| RMRStartUpFuelCurve [0..1] | [RMRStartUpFuelCurve](#CIM17v40-RMRStartUpFuelCurve) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| RMRStartUpTimeCurve [0..1] | [RMRStartUpTimeCurve](#CIM17v40-RMRStartUpTimeCurve) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| StartUpEnergyCurve [0..1] | [StartUpEnergyCurve](#CIM17v40-StartUpEnergyCurve) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| StartUpFuelCurve [0..1] | [StartUpFuelCurve](#CIM17v40-StartUpFuelCurve) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| StartUpTimeCurve [0..1] | [StartUpTimeCurve](#CIM17v40-StartUpTimeCurve) | see [RegisteredGenerator](CIM17v40-RegisteredGenerator) | |
| ACAFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| ASSPOptimizationFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| commercialOpDate [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| contingencyAvailFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| dispatchable [0..1] | [Boolean](#CIM17v40-Boolean) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| ECAFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| flexibleOfferFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| hourlyPredispatch [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| isAggregatedRes [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| lastModified [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| LMPMFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| marketParticipationFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| maxBaseSelfSchedQty [0..1] | [Float](#CIM17v40-Float) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| maxOnTime [0..1] | [Float](#CIM17v40-Float) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| minDispatchTime [0..1] | [Hours](#CIM17v40-Hours) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| minOffTime [0..1] | [Float](#CIM17v40-Float) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| minOnTime [0..1] | [Float](#CIM17v40-Float) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| mustOfferFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| nonMarket [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| pointOfDeliveryFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| priceSetFlagDA [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| priceSetFlagRT [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| registrationStatus [0..1] | [ResourceRegistrationStatus](#CIM17v40-ResourceRegistrationStatus) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| resourceAdequacyFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| SMPMFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| AdjacentCASet [0..1] | [AdjacentCASet](#CIM17v40-AdjacentCASet) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| AggregateNode [0..1] | [AggregateNode](#CIM17v40-AggregateNode) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| DefaultBid [0..1] | [DefaultBid](#CIM17v40-DefaultBid) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| HostControlArea [0..1] | [HostControlArea](#CIM17v40-HostControlArea) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| MarketParticipant [0..1] | [MarketParticipant](#CIM17v40-MarketParticipant) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| MktConnectivityNode [0..1] | [MktConnectivityNode](#CIM17v40-MktConnectivityNode) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| Pnode [0..1] | [Pnode](#CIM17v40-Pnode) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| ResourceVerifiableCosts [0..1] | [ResourceVerifiableCosts](#CIM17v40-ResourceVerifiableCosts) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CombinedCycleConfigurationMember}
### CombinedCycleConfigurationMember

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CombinedCycleConfigurationMember {

+ primary : Boolean [0..1]
+ steam : Boolean [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- CombinedCycleConfigurationMember : inherits from
class CombinedCycleConfiguration {

}

CombinedCycleConfigurationMember --> "1" CombinedCycleConfiguration : CombinedCycleConfiguration
class MktThermalGeneratingUnit {

}

CombinedCycleConfigurationMember --> "1" MktThermalGeneratingUnit : MktThermalGeneratingUnit
```

Configuration Member of CCP Configuration.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| primary [0..1] | [Boolean](#CIM17v40-Boolean) | primary configuration. | |
| steam [0..1] | [Boolean](#CIM17v40-Boolean) | Steam plant. | |
| CombinedCycleConfiguration [1] | [CombinedCycleConfiguration](#CIM17v40-CombinedCycleConfiguration) | | |
| MktThermalGeneratingUnit [1] | [MktThermalGeneratingUnit](#CIM17v40-MktThermalGeneratingUnit) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CombinedCycleLogicalConfiguration}
### CombinedCycleLogicalConfiguration

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CombinedCycleLogicalConfiguration {

}

class IdentifiedObject {

}

IdentifiedObject <|-- CombinedCycleLogicalConfiguration : inherits from
class MktCombinedCyclePlant {

}

CombinedCycleLogicalConfiguration --> "0..1" MktCombinedCyclePlant : MktCombinedCyclePlant
```

Logical Configuration of a Combined Cycle plant.

Operating Combined Cycle Plant (CCP) configurations are represented as Logical CCP Resources. Logical representation shall be used for Market applications to optimize and control Market Operations. Logical representation is also necessary for controlling the number of CCP configurations and to temper performance issues that may otherwise occur.

For example,(2CT configuration),(1CT + 1ST configuration) are examples of logical configuration, without specifying the specific CT and ST participating in the configuration.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| MktCombinedCyclePlant [0..1] | [MktCombinedCyclePlant](#CIM17v40-MktCombinedCyclePlant) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CombinedCyclePlant}
### CombinedCyclePlant

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CombinedCyclePlant {

+ combCyclePlantRating : ActivePower [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- CombinedCyclePlant : inherits from
```

A set of combustion turbines and steam turbines where the exhaust heat from the combustion turbines is recovered to make steam for the steam turbines, resulting in greater overall plant efficiency.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| combCyclePlantRating [0..1] | [ActivePower](#CIM17v40-ActivePower) | The combined cycle plant's active power output rating. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CombinedCycleTransitionState}
### CombinedCycleTransitionState


```mermaid
classDiagram
direction TB

class CombinedCycleTransitionState {

+ upTransition : Boolean [0..1]
}

class CombinedCycleConfiguration {

}

CombinedCycleTransitionState --> "1" CombinedCycleConfiguration : FromConfiguration
class CombinedCycleConfiguration {

}

CombinedCycleTransitionState --> "1" CombinedCycleConfiguration : ToConfiguration
```

Defines the available from and to Transition States for the Combine Cycle Configurations.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| upTransition [0..1] | [Boolean](#CIM17v40-Boolean) | Flag indicating whether this is an UP transition.If not, it is a DOWN transition. | |
| FromConfiguration [1] | [CombinedCycleConfiguration](#CIM17v40-CombinedCycleConfiguration) | | |
| ToConfiguration [1] | [CombinedCycleConfiguration](#CIM17v40-CombinedCycleConfiguration) | | |

{#CIM17v40-CombustionTurbine}
### CombustionTurbine

Inheritance path = [PrimeMover](#CIM17v40-PrimeMover) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CombustionTurbine {

+ ambientTemp : Temperature [0..1]
+ auxPowerVersusFrequency : PU [0..1]
+ auxPowerVersusVoltage : PU [0..1]
+ capabilityVersusFrequency : PU [0..1]
+ heatRecoveryFlag : Boolean [0..1]
+ powerVariationByTemp : PU [0..1]
+ referenceTemp : Temperature [0..1]
+ timeConstant : Seconds [0..1]
}

class PrimeMover {

}

PrimeMover <|-- CombustionTurbine : inherits from
class AirCompressor {

}

CombustionTurbine --> "0..1" AirCompressor : AirCompressor
class CTTempActivePowerCurve {

}

CombustionTurbine --> "0..1" CTTempActivePowerCurve : CTTempActivePowerCurve
class HeatRecoveryBoiler {

}

CombustionTurbine --> "0..1" HeatRecoveryBoiler : HeatRecoveryBoiler
```

A prime mover that is typically fuelled by gas or light oil.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ambientTemp [0..1] | [Temperature](#CIM17v40-Temperature) | Default ambient temperature to be used in modelling applications. | |
| auxPowerVersusFrequency [0..1] | [PU](#CIM17v40-PU) | Off-nominal frequency effect on turbine auxiliaries. Per unit reduction in auxiliary active power consumption versus per unit reduction in frequency (from rated frequency). | |
| auxPowerVersusVoltage [0..1] | [PU](#CIM17v40-PU) | Off-nominal voltage effect on turbine auxiliaries. Per unit reduction in auxiliary active power consumption versus per unit reduction in auxiliary bus voltage (from a specified voltage level). | |
| capabilityVersusFrequency [0..1] | [PU](#CIM17v40-PU) | Off-nominal frequency effect on turbine capability. Per unit reduction in unit active power capability versus per unit reduction in frequency (from rated frequency). | |
| heatRecoveryFlag [0..1] | [Boolean](#CIM17v40-Boolean) | Flag that is set to true if the combustion turbine is associated with a heat recovery boiler. | |
| powerVariationByTemp [0..1] | [PU](#CIM17v40-PU) | Per unit change in power per (versus) unit change in ambient temperature. | |
| referenceTemp [0..1] | [Temperature](#CIM17v40-Temperature) | Reference temperature at which the output of the turbine was defined. | |
| timeConstant [0..1] | [Seconds](#CIM17v40-Seconds) | The time constant for the turbine. | |
| AirCompressor [0..1] | [AirCompressor](#CIM17v40-AirCompressor) | A CAES air compressor is driven by combustion turbine. | |
| `CTTempActivePowerCurve [0..1]` (AggregateOf) | [CTTempActivePowerCurve](#CIM17v40-CTTempActivePowerCurve) | A combustion turbine may have an active power versus ambient temperature relationship. | |
| HeatRecoveryBoiler [0..1] | [HeatRecoveryBoiler](#CIM17v40-HeatRecoveryBoiler) | A combustion turbine may have a heat recovery boiler for making steam. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| primeMoverRating [0..1] | [Float](#CIM17v40-Float) | see [PrimeMover](#CIM17v40-PrimeMover) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Command}
### Command

Inheritance path = [Control](#CIM17v40-Control) => [IOPoint](#CIM17v40-IOPoint) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Command {

+ normalValue : Integer [0..1]
+ value : Integer [0..1]
}

class Control {

}

Control <|-- Command : inherits from
class DiscreteValue {

}

Command --> "1" DiscreteValue : DiscreteValue
class ValueAliasSet {

}

Command --> "0..1" ValueAliasSet : ValueAliasSet
```

A Command is a discrete control used for supervisory control.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| normalValue [0..1] | [Integer](#CIM17v40-Integer) | Normal value for Control.value e.g. used for percentage scaling. | |
| value [0..1] | [Integer](#CIM17v40-Integer) | The value representing the actuator output. | |
| DiscreteValue [1] | [DiscreteValue](#CIM17v40-DiscreteValue) | The MeasurementValue that is controlled. | |
| ValueAliasSet [0..1] | [ValueAliasSet](#CIM17v40-ValueAliasSet) | The ValueAliasSet used for translation of a Control value to a name. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| controlType [0..1] | [String](#CIM17v40-String) | see [Control](#CIM17v40-Control) | |
| operationInProgress [0..1] | [Boolean](#CIM17v40-Boolean) | see [Control](#CIM17v40-Control) | |
| timeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | see [Control](#CIM17v40-Control) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Control](CIM17v40-Control) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Control](CIM17v40-Control) | |
| ControlAction [0..1] | [ControlAction](#CIM17v40-ControlAction) | see [Control](CIM17v40-Control) | |
| PowerSystemResource [0..1] | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Control](CIM17v40-Control) | |
| RemoteControl [0..1] | [RemoteControl](#CIM17v40-RemoteControl) | see [Control](CIM17v40-Control) | |
| IOPointSource [0..1] | [IOPointSource](#CIM17v40-IOPointSource) | see [IOPoint](CIM17v40-IOPoint) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CommitmentClearing}
### CommitmentClearing

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CommitmentClearing {

}

class MarketFactors {

}

MarketFactors <|-- CommitmentClearing : inherits from
```

Models results of market clearing which call for commitment of units.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Commitments}
### Commitments


```mermaid
classDiagram
direction TB

class Commitments {

+ commitmentType : enum:CommitmentType [0..1]
+ instructionCost : Float [0..1]
+ instructionType : enum:AutomaticDispInstTypeCommitment [0..1]
+ intervalEndTime : DateTime [0..1]
+ intervalStartTime : DateTime [0..1]
+ minStatusChangeTime : Integer [0..1]
+ noLoadCost : Float [0..1]
+ updateTimeStamp : DateTime [0..1]
+ updateType : enum:MQSCHGType [0..1]
+ updateUser : String [0..1]
}

class RegisteredResource {

}

Commitments --> "1" RegisteredResource : RegisteredResource
```

Provides the necessary information (on a resource basis) to capture the Startup/Shutdown commitment results. This information is relevant to all markets.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| commitmentType [0..1] | [CommitmentType](#CIM17v40-CommitmentType) | the type of UC status (self commitment, ISO commitment, or SCUC commitment) | |
| instructionCost [0..1] | [Float](#CIM17v40-Float) | Total cost associated with changing the status of the resource. | |
| instructionType [0..1] | [AutomaticDispInstTypeCommitment](#CIM17v40-AutomaticDispInstTypeCommitment) | Indicator of either a Start-Up or a Shut-Down. | |
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | End time for the commitment period. This will be on an interval boundary. | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | Start time for the commitment period. This will be on an interval boundary. | |
| minStatusChangeTime [0..1] | [Integer](#CIM17v40-Integer) | SCUC commitment period start-up time. Calculated start up time based on the StartUpTimeCurve provided with the Bid.This is a combination of StartUp time bid and Unit down time.Units is minutes | |
| noLoadCost [0..1] | [Float](#CIM17v40-Float) | Unit no load cost in case of energy commodity | |
| updateTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| updateType [0..1] | [MQSCHGType](#CIM17v40-MQSCHGType) | | |
| updateUser [0..1] | [String](#CIM17v40-String) | | |
| RegisteredResource [1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |

{#CIM17v40-CommodityDefinition}
### CommodityDefinition

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CommodityDefinition {

+ commodityCurrency : enum:Currency [0..1]
+ commodityUnit : enum:UnitSymbol [0..1]
+ commodityUnitMultiplier : enum:UnitMultiplier [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- CommodityDefinition : inherits from
class MarketProduct {

}

CommodityDefinition --> "1" MarketProduct : MarketProduct
class Pnode {

}

CommodityDefinition --> "1" Pnode : Pnode
class RTO {

}

CommodityDefinition --> "1" RTO : RTO
```

Commodities in the context of IEC 62325 are MarketProducts (energy, regulation, reserve, etc) traded at a specific location, which in this case is a Pnode (either a specific pricing node or a pricing area or zone defined as a collection of pricing nodes). The CommodityDefinition is a container for these two parameters, plus the unit of measure and the currency in which the Commodity is traded. Each CommodityDefinition should be relatively static; defined once and rarely changed.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| commodityCurrency [0..1] | [Currency](#CIM17v40-Currency) | The currency in which the Commodity is traded, using the standard conventions associated with the Currency enumeration. | |
| commodityUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | The unit of measure in which the Commodity is traded, using the standard conventions associated with the UnitSymbol enumeration. | |
| commodityUnitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | The unit multiplier, e.g. "k" to convert the unit "W-h" to "kW-h", using the standard conventions associated with the UnitMultiplier enumeration. | |
| MarketProduct [1] | [MarketProduct](#CIM17v40-MarketProduct) | | |
| Pnode [1] | [Pnode](#CIM17v40-Pnode) | | |
| RTO [1] | [RTO](#CIM17v40-RTO) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CommodityPrice}
### CommodityPrice


```mermaid
classDiagram
direction TB

class CommodityPrice {

+ value : Float [0..1]
+ timeIntervalPeriod : DateTimeInterval [0..1]
}

class CommodityDefinition {

}

CommodityPrice --> "1" CommodityDefinition : CommodityDefinition
class PnodeClearing {

}

CommodityPrice --> "0..1" PnodeClearing : PnodeClearing
class PriceDescriptor {

}

CommodityPrice --> "1" PriceDescriptor : PriceDescriptor
```

The CommodityPrice class is used to define the price of a commodity during a given time interval. The interval may be long, e.g. a year, or very short, e.g. 5 minutes. There will be many instances of the CommodityPrice class for each instance of the CommodityDefinition to which it is associated. Note that there may be more than once price associated with a given interval and these variances are described by the association (or associations) with the PriceDescriptor class.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| value [0..1] | [Float](#CIM17v40-Float) | The price of the Commodity, expressed as a floating point value with the currency and unit of measure defined in the associated CommodityDefinition class. | |
| CommodityDefinition [1] | [CommodityDefinition](#CIM17v40-CommodityDefinition) | | |
| PnodeClearing [0..1] | [PnodeClearing](#CIM17v40-PnodeClearing) | | |
| PriceDescriptor [1] | [PriceDescriptor](#CIM17v40-PriceDescriptor) | | |
| timeIntervalPeriod [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | The time interval over which the CommodityPrice is valid, using the standard conventions associated with the DateTimeInterval class. | |

{#CIM17v40-CommunicationLink}
### CommunicationLink

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CommunicationLink {

}

class PowerSystemResource {

}

PowerSystemResource <|-- CommunicationLink : inherits from
class BilateralExchangeActor {

}

CommunicationLink --> "0..1" BilateralExchangeActor : BilateralExchangeActor
```

The connection to remote units is through one or more communication links. Reduntant links may exist. The CommunicationLink class inherits PowerSystemResource. The intention is to allow CommunicationLinks to have Measurements. These Measurements can be used to model link status as operational, out of service, unit failure etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BilateralExchangeActor [0..1] | [BilateralExchangeActor](#CIM17v40-BilateralExchangeActor) | ICCP data provider or consumer using communication addressing for a Bilateral table. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CompatibleUnit}
### CompatibleUnit

Inheritance path = [WorkDocument](#CIM17v40-WorkDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CompatibleUnit {

+ estCost : Money [0..1]
+ quantity : String [0..1]
}

class WorkDocument {

}

WorkDocument <|-- CompatibleUnit : inherits from
class CostType {

}

CompatibleUnit --> "0..1" CostType : CostType
class CUAllowableAction {

}

CompatibleUnit --> "0..1" CUAllowableAction : CUAllowableAction
class CUGroup {

}

CompatibleUnit --> "0..1" CUGroup : CUGroup
class CatalogAssetType {

}

CompatibleUnit --> "0..1" CatalogAssetType : GenericAssetModel
class PropertyUnit {

}

CompatibleUnit --> "0..1" PropertyUnit : PropertyUnit
```

A pre-planned job model containing labor, material, and accounting requirements for standardized job planning.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| estCost [0..1] | [Money](#CIM17v40-Money) | Estimated total cost for perfoming CU. | |
| quantity [0..1] | [String](#CIM17v40-String) | The quantity, unit of measure, and multiplier at the CU level that applies to the materials. | |
| `CostType [0..1]` (informative) | [CostType](#CIM17v40-CostType) | | |
| `CUAllowableAction [0..1]` (informative) | [CUAllowableAction](#CIM17v40-CUAllowableAction) | | |
| `CUGroup [0..1]` (informative) | [CUGroup](#CIM17v40-CUGroup) | | |
| `GenericAssetModel [0..1]` (informative) | [CatalogAssetType](#CIM17v40-CatalogAssetType) | | |
| `PropertyUnit [0..1]` (informative) | [PropertyUnit](#CIM17v40-PropertyUnit) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CompleteModelToBeDeleted}
### CompleteModelToBeDeleted

Inheritance path = [ModelToBeDeleted](#CIM17v40-ModelToBeDeleted) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CompleteModelToBeDeleted {

}

class ModelToBeDeleted {

}

ModelToBeDeleted <|-- CompleteModelToBeDeleted : inherits from
```

A complete model can be used in applications to perform meaningful calculations, e.g. a study case in offline tools or a real time model in a SCADA/EMS.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ComplianceEvent}
### ComplianceEvent

Inheritance path = [ActivityRecord](#CIM17v40-ActivityRecord) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ComplianceEvent {

+ deadline : DateTime [0..1]
}

class ActivityRecord {

}

ActivityRecord <|-- ComplianceEvent : inherits from
```

Compliance events are used for reporting regulatory or contract compliance issues and/or variances. These might be created as a consequence of local business processes and associated rules. It is anticipated that this class will be customised extensively to meet local implementation needs.

Use inherited 'type' to indicate that, for example, expected performance will not be met or reported as mandated.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| deadline [0..1] | [DateTime](#CIM17v40-DateTime) | The deadline for compliance. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| reason [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| severity [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| type [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| Document [0..1] | [Document](#CIM17v40-Document) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CompositeSwitch}
### CompositeSwitch

Inheritance path = [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CompositeSwitch {

+ compositeSwitchType : String [0..1]
}

class Equipment {

}

Equipment <|-- CompositeSwitch : inherits from
```

A model of a set of individual Switches normally enclosed within the same cabinet and possibly with interlocks that restrict the combination of switch positions. These are typically found in medium voltage distribution networks.

A CompositeSwitch could represent a Ring-Main-Unit (RMU), or pad-mounted switchgear, with primitive internal devices such as an internal bus-bar plus 3 or 4 internal switches each of which may individually be open or closed. A CompositeSwitch and a set of contained Switches can also be used to represent a multi-position switch e.g. a switch that can connect a circuit to Ground, Open or Busbar.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| compositeSwitchType [0..1] | [String](#CIM17v40-String) | An alphanumeric code that can be used as a reference to extra information such as the description of the interlocking scheme if any. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CompositeSwitchInfo}
### CompositeSwitchInfo

Inheritance path = [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CompositeSwitchInfo {

+ ganged : Boolean [0..1]
+ initOpMode : String [0..1]
+ interruptingRating : CurrentFlow [0..1]
+ kind : enum:CompositeSwitchKind [0..1]
+ phaseCode : enum:PhaseCode [0..1]
+ phaseCount : Integer [0..1]
+ ratedVoltage : Voltage [0..1]
+ remote : Boolean [0..1]
+ switchStateCount : Integer [0..1]
}

class AssetInfo {

}

AssetInfo <|-- CompositeSwitchInfo : inherits from
```

Properties of a composite switch.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ganged [0..1] | [Boolean](#CIM17v40-Boolean) | True if multi-phase switch controls all phases concurrently. | |
| initOpMode [0..1] | [String](#CIM17v40-String) | Initial operating mode, with the following values: Automatic, Manual. | |
| interruptingRating [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Breaking capacity, or short circuit rating, is the maximum rated current which the device can safely interrupt at the rated voltage. | |
| kind [0..1] | [CompositeSwitchKind](#CIM17v40-CompositeSwitchKind) | Kind of composite switch. | |
| phaseCode [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | Phases carried, if applicable. | |
| phaseCount [0..1] | [Integer](#CIM17v40-Integer) | Supported number of phases, typically 0, 1 or 3. | |
| ratedVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Rated voltage. | |
| remote [0..1] | [Boolean](#CIM17v40-Boolean) | True if device is capable of being operated by remote control. | |
| switchStateCount [0..1] | [Integer](#CIM17v40-Integer) | Number of switch states represented by the composite switch. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ConcentricNeutralCableInfo}
### ConcentricNeutralCableInfo

Inheritance path = [CableInfo](#CIM17v40-CableInfo) => [WireInfo](#CIM17v40-WireInfo) => [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ConcentricNeutralCableInfo {

+ diameterOverNeutral : Length [0..1]
+ neutralStrandCount : Integer [0..1]
+ neutralStrandGmr : Length [0..1]
+ neutralStrandRadius : Length [0..1]
+ neutralStrandRDC20 : ResistancePerLength [0..1]
}

class CableInfo {

}

CableInfo <|-- ConcentricNeutralCableInfo : inherits from
```

Concentric neutral cable data.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| diameterOverNeutral [0..1] | [Length](#CIM17v40-Length) | Diameter over the concentric neutral strands. | |
| neutralStrandCount [0..1] | [Integer](#CIM17v40-Integer) | Number of concentric neutral strands. | |
| neutralStrandGmr [0..1] | [Length](#CIM17v40-Length) | Geometric mean radius of the neutral strand. | |
| neutralStrandRadius [0..1] | [Length](#CIM17v40-Length) | Outside radius of the neutral strand. | |
| neutralStrandRDC20 [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | DC resistance per unit length of the neutral strand at 20 �C. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| constructionKind [0..1] | [CableConstructionKind](#CIM17v40-CableConstructionKind) | see [CableInfo](CIM17v40-CableInfo) | |
| diameterOverCore [0..1] | [Length](#CIM17v40-Length) | see [CableInfo](CIM17v40-CableInfo) | |
| diameterOverInsulation [0..1] | [Length](#CIM17v40-Length) | see [CableInfo](CIM17v40-CableInfo) | |
| diameterOverJacket [0..1] | [Length](#CIM17v40-Length) | see [CableInfo](CIM17v40-CableInfo) | |
| diameterOverScreen [0..1] | [Length](#CIM17v40-Length) | see [CableInfo](CIM17v40-CableInfo) | |
| isStrandFill [0..1] | [Boolean](#CIM17v40-Boolean) | see [CableInfo](#CIM17v40-CableInfo) | |
| nominalTemperature [0..1] | [Temperature](#CIM17v40-Temperature) | see [CableInfo](CIM17v40-CableInfo) | |
| outerJacketKind [0..1] | [CableOuterJacketKind](#CIM17v40-CableOuterJacketKind) | see [CableInfo](CIM17v40-CableInfo) | |
| sheathAsNeutral [0..1] | [Boolean](#CIM17v40-Boolean) | see [CableInfo](#CIM17v40-CableInfo) | |
| shieldMaterial [0..1] | [CableShieldMaterialKind](#CIM17v40-CableShieldMaterialKind) | see [CableInfo](CIM17v40-CableInfo) | |
| coreRadius [0..1] | [Length](#CIM17v40-Length) | see [WireInfo](CIM17v40-WireInfo) | |
| coreStrandCount [0..1] | [Integer](#CIM17v40-Integer) | see [WireInfo](#CIM17v40-WireInfo) | |
| gmr [0..1] | [Length](#CIM17v40-Length) | see [WireInfo](CIM17v40-WireInfo) | |
| insulated [0..1] | [Boolean](#CIM17v40-Boolean) | see [WireInfo](#CIM17v40-WireInfo) | |
| insulationMaterial [0..1] | [WireInsulationKind](#CIM17v40-WireInsulationKind) | see [WireInfo](CIM17v40-WireInfo) | |
| insulationThickness [0..1] | [Length](#CIM17v40-Length) | see [WireInfo](CIM17v40-WireInfo) | |
| material [0..1] | [WireMaterialKind](#CIM17v40-WireMaterialKind) | see [WireInfo](CIM17v40-WireInfo) | |
| rAC25 [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | see [WireInfo](CIM17v40-WireInfo) | |
| rAC50 [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | see [WireInfo](CIM17v40-WireInfo) | |
| rAC75 [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | see [WireInfo](CIM17v40-WireInfo) | |
| radius [0..1] | [Length](#CIM17v40-Length) | see [WireInfo](CIM17v40-WireInfo) | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [WireInfo](CIM17v40-WireInfo) | |
| rDC20 [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | see [WireInfo](CIM17v40-WireInfo) | |
| sizeDescription [0..1] | [String](#CIM17v40-String) | see [WireInfo](#CIM17v40-WireInfo) | |
| strandCount [0..1] | [Integer](#CIM17v40-Integer) | see [WireInfo](#CIM17v40-WireInfo) | |
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ConditionFactor}
### ConditionFactor

Inheritance path = [WorkIdentifiedObject](#CIM17v40-WorkIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ConditionFactor {

+ cfValue : String [0..1]
+ kind : enum:ConditionFactorKind [0..1]
+ status : Status [0..1]
}

class WorkIdentifiedObject {

}

WorkIdentifiedObject <|-- ConditionFactor : inherits from
```

This is to specify the various condition factors for a design that may alter the cost estimate or the allocation.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| cfValue [0..1] | [String](#CIM17v40-String) | The actual value of the condition factor, such as labor flat fee or percentage. | |
| kind [0..1] | [ConditionFactorKind](#CIM17v40-ConditionFactorKind) | Kind of this condition factor. | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ConductingEquipment}
### (informative) ConductingEquipment

Inheritance path = [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ConductingEquipment {

}

class Equipment {

}

Equipment <|-- ConductingEquipment : inherits from
class BaseVoltage {

}

ConductingEquipment --> "0..1" BaseVoltage : BaseVoltage
class GroundAction {

}

ConductingEquipment --> "0..1" GroundAction : GroundingAction
class JumperAction {

}

ConductingEquipment --> "0..1" JumperAction : JumpingAction
class Outage {

}

ConductingEquipment --> "0..1" Outage : Outage
```

The parts of the AC power system that are designed to carry current or that are conductively connected through terminals.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | Base voltage of this conducting equipment. Use only when there is no voltage level container used and only one base voltage applies. For example, not used for transformers. | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | Action involving grounding operation on this conducting equipment. | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | Jumper action involving jumping operation on this conducting equipment. | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | The outage that is isolated by the outage isolation equipment. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Conductor}
### Conductor

Inheritance path = [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Conductor {

+ length : Length [0..1]
}

class ConductingEquipment {

}

ConductingEquipment <|-- Conductor : inherits from
```

Combination of conducting material with consistent electrical characteristics, building a single electrical system, used to carry current between points in the power system.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| length [0..1] | [Length](#CIM17v40-Length) | Segment length for calculating line section capabilities. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ConfigurationEvent}
### ConfigurationEvent

Inheritance path = [ActivityRecord](#CIM17v40-ActivityRecord) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ConfigurationEvent {

+ effectiveDateTime : DateTime [0..1]
+ modifiedBy : String [0..1]
+ remark : String [0..1]
}

class ActivityRecord {

}

ActivityRecord <|-- ConfigurationEvent : inherits from
class Asset {

}

ConfigurationEvent --> "0..1" Asset : ChangedAsset
class Document {

}

ConfigurationEvent --> "0..1" Document : ChangedDocument
class Location {

}

ConfigurationEvent --> "0..1" Location : ChangedLocation
class OrganisationRole {

}

ConfigurationEvent --> "0..1" OrganisationRole : ChangedOrganisationRole
class PersonRole {

}

ConfigurationEvent --> "0..1" PersonRole : ChangedPersonRole
class ServiceCategory {

}

ConfigurationEvent --> "0..1" ServiceCategory : ChangedServiceCategory
class UsagePoint {

}

ConfigurationEvent --> "0..1" UsagePoint : ChangedUsagePoint
class FaultCauseType {

}

ConfigurationEvent --> "1" FaultCauseType : FaultCauseType
class PowerSystemResource {

}

ConfigurationEvent --> "0..1" PowerSystemResource : PowerSystemResource
```

Used to report details on creation, change or deletion of an entity or its configuration.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| effectiveDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time this event has or will become effective. | |
| modifiedBy [0..1] | [String](#CIM17v40-String) | Source/initiator of modification. | |
| remark [0..1] | [String](#CIM17v40-String) | Free text remarks. | |
| ChangedAsset [0..1] | [Asset](#CIM17v40-Asset) | Asset whose change resulted in this configuration event. | |
| ChangedDocument [0..1] | [Document](#CIM17v40-Document) | Document whose change resulted in this configuration event. | |
| ChangedLocation [0..1] | [Location](#CIM17v40-Location) | Location whose change resulted in this configuration event. | |
| ChangedOrganisationRole [0..1] | [OrganisationRole](#CIM17v40-OrganisationRole) | Organisation role whose change resulted in this configuration event. | |
| ChangedPersonRole [0..1] | [PersonRole](#CIM17v40-PersonRole) | Person role whose change resulted in this configuration event. | |
| ChangedServiceCategory [0..1] | [ServiceCategory](#CIM17v40-ServiceCategory) | Service category whose change resulted in this configuration event. | |
| ChangedUsagePoint [0..1] | [UsagePoint](#CIM17v40-UsagePoint) | Usage point whose change resulted in this configuration event. | |
| FaultCauseType [1] | [FaultCauseType](#CIM17v40-FaultCauseType) | Fault cause type whose change resulted in this configuration event. | |
| PowerSystemResource [0..1] | [PowerSystemResource](#CIM17v40-PowerSystemResource) | Power system resource whose change resulted in this configuration event. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| reason [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| severity [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| type [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| Document [0..1] | [Document](#CIM17v40-Document) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ConformLoad}
### ConformLoad

Inheritance path = [EnergyConsumer](#CIM17v40-EnergyConsumer) => [EnergyConnection](#CIM17v40-EnergyConnection) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ConformLoad {

}

class EnergyConsumer {

}

EnergyConsumer <|-- ConformLoad : inherits from
class ConformLoadGroup {

}

ConformLoad --> "0..1" ConformLoadGroup : LoadGroup
```

ConformLoad represent loads that follow a daily load change pattern where the pattern can be used to scale the load with a system load.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| LoadGroup [0..1] | [ConformLoadGroup](#CIM17v40-ConformLoadGroup) | Group of this ConformLoad. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| customerCount [0..1] | [Integer](#CIM17v40-Integer) | see [EnergyConsumer](#CIM17v40-EnergyConsumer) | |
| grounded [0..1] | [Boolean](#CIM17v40-Boolean) | see [EnergyConsumer](#CIM17v40-EnergyConsumer) | |
| p [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| pfixed [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| pfixedPct [0..1] | [PerCent](#CIM17v40-PerCent) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| phaseConnection [0..1] | [PhaseShuntConnectionKind](#CIM17v40-PhaseShuntConnectionKind) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| q [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| qfixed [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| qfixedPct [0..1] | [PerCent](#CIM17v40-PerCent) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| EnergyConsumerAction [0..1] | [EnergyConsumerAction](#CIM17v40-EnergyConsumerAction) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| LoadDynamics [0..1] | [LoadDynamics](#CIM17v40-LoadDynamics) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| LoadResponse [0..1] | [LoadResponseCharacteristic](#CIM17v40-LoadResponseCharacteristic) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| `PowerCutZone [0..1]` (OfAggregate) | [PowerCutZone](#CIM17v40-PowerCutZone) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ConformLoadGroup}
### ConformLoadGroup

Inheritance path = [LoadGroup](#CIM17v40-LoadGroup) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ConformLoadGroup {

}

class LoadGroup {

}

LoadGroup <|-- ConformLoadGroup : inherits from
```

A group of loads conforming to an allocation pattern.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `SubLoadArea [1]` (OfAggregate) | [SubLoadArea](#CIM17v40-SubLoadArea) | see [LoadGroup](CIM17v40-LoadGroup) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ConformLoadSchedule}
### ConformLoadSchedule

Inheritance path = [SeasonDayTypeSchedule](#CIM17v40-SeasonDayTypeSchedule) => [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) => [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ConformLoadSchedule {

}

class SeasonDayTypeSchedule {

}

SeasonDayTypeSchedule <|-- ConformLoadSchedule : inherits from
class ConformLoadGroup {

}

ConformLoadSchedule --> "1" ConformLoadGroup : ConformLoadGroup
```

A curve of load versus time (X-axis) showing the active power values (Y1-axis) and reactive power (Y2-axis) for each unit of the period covered. This curve represents a typical pattern of load over the time period for a given day type and season.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ConformLoadGroup [1]` (OfAggregate) | [ConformLoadGroup](#CIM17v40-ConformLoadGroup) | The ConformLoadGroup where the ConformLoadSchedule belongs. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DayType [0..1] | [DayType](#CIM17v40-DayType) | see [SeasonDayTypeSchedule](CIM17v40-SeasonDayTypeSchedule) | |
| Season [0..1] | [Season](#CIM17v40-Season) | see [SeasonDayTypeSchedule](CIM17v40-SeasonDayTypeSchedule) | |
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | see [RegularIntervalSchedule](CIM17v40-RegularIntervalSchedule) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CongestionArea}
### CongestionArea

Inheritance path = [AggregatedPnode](#CIM17v40-AggregatedPnode) => [Pnode](#CIM17v40-Pnode) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CongestionArea {

}

class AggregatedPnode {

}

AggregatedPnode <|-- CongestionArea : inherits from
```

Designated Congestion Area Definition (DCA).


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| apnodeType [0..1] | [ApnodeType](#CIM17v40-ApnodeType) | see [AggregatedPnode](CIM17v40-AggregatedPnode) | |
| participationCategory [0..1] | [ParticipationCategoryMPM](#CIM17v40-ParticipationCategoryMPM) | see [AggregatedPnode](CIM17v40-AggregatedPnode) | |
| isPublic [0..1] | [Boolean](#CIM17v40-Boolean) | see [Pnode](#CIM17v40-Pnode) | |
| RTO [0..1] | [RTO](#CIM17v40-RTO) | see [Pnode](CIM17v40-Pnode) | |
| SubControlArea [0..1] | [SubControlArea](#CIM17v40-SubControlArea) | see [Pnode](CIM17v40-Pnode) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CongestionRevenueRight}
### CongestionRevenueRight

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CongestionRevenueRight {

+ cRRcategory : enum:CRRCategoryType [0..1]
+ cRRtype : enum:CRRSegmentType [0..1]
+ hedgeType : enum:CRRHedgeType [0..1]
+ timeOfUse : enum:TimeOfUse [0..1]
+ tradeSliceID : String [0..1]
}

class Document {

}

Document <|-- CongestionRevenueRight : inherits from
class CRRMarket {

}

CongestionRevenueRight --> "1" CRRMarket : CRRMarket
class Flowgate {

}

CongestionRevenueRight --> "0..1" Flowgate : Flowgate
```

Congestion Revenue Rights (CRR) class that is inherited from a Document class.

A CRR is a financial concept that is used to hedge congestion charges.

The CRR is usually settled based on the Locational Marginal Prices (LMPs) that are calculated in the day-ahead market. These LMPs are determined by the Day-ahead resource schedules/bids. CRRs will not hedge against marginal losses. If the congestion component of LMP at the sink is greater than at the source, then the CRR owner is entitled to receive a portion of congestion revenues. If the congestion component at the sink is less than at the source, then an obligation-type CRR owner will be charged, but an option-type CRR owner will not.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| cRRcategory [0..1] | [CRRCategoryType](#CIM17v40-CRRCategoryType) | CRR category represents 'PTP' for a point-to-point CRR, or 'NSR' for a Network Service Right. If CRR category is 'PTP', both Source ID and Sink ID fields are required. If CRR category is 'NSR' only one field, either Source ID or Sink ID, shall be not null and the other shall be null. However, the 'NSR' category will include at least three records. | |
| cRRtype [0..1] | [CRRSegmentType](#CIM17v40-CRRSegmentType) | Type of the CRR, from the possible type definitions in the CRR System (e.g. 'LSE', 'ETC'). | |
| hedgeType [0..1] | [CRRHedgeType](#CIM17v40-CRRHedgeType) | Hedge type Obligation or Option. An obligation type requires the holder to receive or pay the congestion rent. An option type gives the holder the option of receiving or paying the congestion rent. | |
| timeOfUse [0..1] | [TimeOfUse](#CIM17v40-TimeOfUse) | Time of Use flag of the CRR - Peak (ON), Offpeak (OFF) or all 24 hours (24HR). | |
| tradeSliceID [0..1] | [String](#CIM17v40-String) | Segment of the CRR described in the current record. | |
| CRRMarket [1] | [CRRMarket](#CIM17v40-CRRMarket) | | |
| Flowgate [0..1] | [Flowgate](#CIM17v40-Flowgate) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ConnectDisconnectFunction}
### ConnectDisconnectFunction

Inheritance path = [EndDeviceFunction](#CIM17v40-EndDeviceFunction) => [AssetFunction](#CIM17v40-AssetFunction) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ConnectDisconnectFunction {

+ eventCount : Integer [0..1]
+ isConnected : Boolean [0..1]
+ isDelayedDiscon : Boolean [0..1]
+ isLocalAutoDisconOp : Boolean [0..1]
+ isLocalAutoReconOp : Boolean [0..1]
+ isRemoteAutoDisconOp : Boolean [0..1]
+ isRemoteAutoReconOp : Boolean [0..1]
+ rcdInfo : RemoteConnectDisconnectInfo [0..1]
}

class EndDeviceFunction {

}

EndDeviceFunction <|-- ConnectDisconnectFunction : inherits from
```

A function that will disconnect and reconnect the customer's load under defined conditions.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| eventCount [0..1] | [Integer](#CIM17v40-Integer) | Running cumulative count of connect or disconnect events, for the lifetime of this function or until the value is cleared. | |
| isConnected [0..1] | [Boolean](#CIM17v40-Boolean) | True if this function is in the connected state. | |
| isDelayedDiscon [0..1] | [Boolean](#CIM17v40-Boolean) | If set true, the switch may disconnect the service at the end of a specified time delay after the disconnect signal has been given. If set false, the switch may disconnect the service immediately after the disconnect signal has been given. This is typically the case for over current circuit-breakers which are classified as either instantaneous or slow acting. | |
| isLocalAutoDisconOp [0..1] | [Boolean](#CIM17v40-Boolean) | If set true and if disconnection can be operated locally, the operation happens automatically. Otherwise it happens manually. | |
| isLocalAutoReconOp [0..1] | [Boolean](#CIM17v40-Boolean) | If set true and if reconnection can be operated locally, then the operation happens automatically. Otherwise, it happens manually. | |
| isRemoteAutoDisconOp [0..1] | [Boolean](#CIM17v40-Boolean) | If set true and if disconnection can be operated remotely, then the operation happens automatically. If set false and if disconnection can be operated remotely, then the operation happens manually. | |
| isRemoteAutoReconOp [0..1] | [Boolean](#CIM17v40-Boolean) | If set true and if reconnection can be operated remotely, then the operation happens automatically. If set false and if reconnection can be operated remotely, then the operation happens manually. | |
| rcdInfo [0..1] | [RemoteConnectDisconnectInfo](#CIM17v40-RemoteConnectDisconnectInfo) | Information on remote connect disconnect switch. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [EndDeviceFunction](#CIM17v40-EndDeviceFunction) | |
| EndDevice [0..1] | [EndDevice](#CIM17v40-EndDevice) | see [EndDeviceFunction](CIM17v40-EndDeviceFunction) | |
| configID [0..1] | [String](#CIM17v40-String) | see [AssetFunction](#CIM17v40-AssetFunction) | |
| firmwareID [0..1] | [String](#CIM17v40-String) | see [AssetFunction](#CIM17v40-AssetFunction) | |
| hardwareID [0..1] | [String](#CIM17v40-String) | see [AssetFunction](#CIM17v40-AssetFunction) | |
| password [0..1] | [String](#CIM17v40-String) | see [AssetFunction](#CIM17v40-AssetFunction) | |
| programID [0..1] | [String](#CIM17v40-String) | see [AssetFunction](#CIM17v40-AssetFunction) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [AssetFunction](CIM17v40-AssetFunction) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ConnectivityNode}
### ConnectivityNode

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ConnectivityNode {

}

class IdentifiedObject {

}

IdentifiedObject <|-- ConnectivityNode : inherits from
class ConnectivityNodeContainer {

}

ConnectivityNode --> "1" ConnectivityNodeContainer : ConnectivityNodeContainer
class TopologicalNode {

}

ConnectivityNode --> "0..1" TopologicalNode : TopologicalNode
```

Connectivity nodes are points where terminals of AC conducting equipment are connected together with zero impedance.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ConnectivityNodeContainer [1] | [ConnectivityNodeContainer](#CIM17v40-ConnectivityNodeContainer) | Container of this connectivity node. | |
| `TopologicalNode [0..1]` (OfAggregate) | [TopologicalNode](#CIM17v40-TopologicalNode) | The topological node to which this connectivity node is assigned. May depend on the current state of switches in the network. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ConnectivityNodeContainer}
### ConnectivityNodeContainer

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ConnectivityNodeContainer {

}

class PowerSystemResource {

}

PowerSystemResource <|-- ConnectivityNodeContainer : inherits from
```

A base class for all objects that may contain connectivity nodes or topological nodes.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Connector}
### Connector

Inheritance path = [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Connector {

}

class ConductingEquipment {

}

ConductingEquipment <|-- Connector : inherits from
```

A conductor, or group of conductors, with negligible impedance, that serve to connect other conducting equipment within a single substation and are modelled with a single logical terminal.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ConstraintClearing}
### ConstraintClearing

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ConstraintClearing {

}

class MarketFactors {

}

MarketFactors <|-- ConstraintClearing : inherits from
```

Groups all items associated with Binding Constraints and Constraint Violations per interval and market.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ConstraintDuration}
### ConstraintDuration


```mermaid
classDiagram
direction TB

class ConstraintDuration {

+ duration : Duration [0..1]
+ type : String [0..1]
}

```

Duration constraint to activate, to put in operation, to deactivate, ... a given event.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| duration [0..1] | [Duration](#CIM17v40-Duration) | The duration of the constraint. | |
| type [0..1] | [String](#CIM17v40-String) | The type of the constraint. | |

{#CIM17v40-ConstraintResults}
### ConstraintResults

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ConstraintResults {

+ baseFlow : Float [0..1]
+ BGLimit : Float [0..1]
+ BGTRResCap : Float [0..1]
+ bindingLimit : Float [0..1]
+ clearedValue : Float [0..1]
+ competitivePathConstraint : enum:YesNo [0..1]
+ constraintType : enum:ResultsConstraintType [0..1]
+ limitFlag : enum:ConstraintLimitType [0..1]
+ optimizationFlag : enum:YesNo [0..1]
+ overloadMW : Float [0..1]
+ percentMW : Float [0..1]
+ shadowPrice : Float [0..1]
+ updateTimeStamp : DateTime [0..1]
+ updateType : enum:MQSCHGType [0..1]
+ updateUser : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ConstraintResults : inherits from
class ConstraintClearing {

}

ConstraintResults --> "0..1" ConstraintClearing : ConstraintClearing
class Flowgate {

}

ConstraintResults --> "1" Flowgate : Flowgate
class MktContingency {

}

ConstraintResults --> "1" MktContingency : MktContingency
```

Provides the Market results for the constraint processing for either the DAM or RTM. The data includes the constraint type (binding or violated), the solved value for the constraint, and the associated shadow price.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| baseFlow [0..1] | [Float](#CIM17v40-Float) | Branch base Power Flow. | |
| BGLimit [0..1] | [Float](#CIM17v40-Float) | This value is determined in DA and RTM. The SCUC optimization ensures that the MW flow on the Branch Group will not exceed this limit in the relevant direction. | |
| BGTRResCap [0..1] | [Float](#CIM17v40-Float) | Branch Group TR Reservation Capacity - This value is determined in DA and RTM. It is the amount of spare transmission capacity that is left for the TR holder to use. | |
| bindingLimit [0..1] | [Float](#CIM17v40-Float) | MW Limit. | |
| clearedValue [0..1] | [Float](#CIM17v40-Float) | Cleared MW. | |
| competitivePathConstraint [0..1] | [YesNo](#CIM17v40-YesNo) | Non-competitive path constraint Flag"(Y/N) indicating whether the shadow price on a non-competitive path was non-zero. | |
| constraintType [0..1] | [ResultsConstraintType](#CIM17v40-ResultsConstraintType) | Type of constraint. | |
| limitFlag [0..1] | [ConstraintLimitType](#CIM17v40-ConstraintLimitType) | Limit flag ('Maximum', 'Minimum'). | |
| optimizationFlag [0..1] | [YesNo](#CIM17v40-YesNo) | Included in optimization Y/N. | |
| overloadMW [0..1] | [Float](#CIM17v40-Float) | Transmission overload MW. | |
| percentMW [0..1] | [Float](#CIM17v40-Float) | Actual MW flow as percent of limit. | |
| shadowPrice [0..1] | [Float](#CIM17v40-Float) | Shadow Price ($/MW) for the commodity. Shadow price for the corresponding constraint. | |
| updateTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | Update time stamp. | |
| updateType [0..1] | [MQSCHGType](#CIM17v40-MQSCHGType) | MQS change type. | |
| updateUser [0..1] | [String](#CIM17v40-String) | Updated user. | |
| ConstraintClearing [0..1] | [ConstraintClearing](#CIM17v40-ConstraintClearing) | | |
| Flowgate [1] | [Flowgate](#CIM17v40-Flowgate) | | |
| MktContingency [1] | [MktContingency](#CIM17v40-MktContingency) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ConstraintTerm}
### ConstraintTerm

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ConstraintTerm {

+ factor : String [0..1]
+ function : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ConstraintTerm : inherits from
class SecurityConstraintSum {

}

ConstraintTerm --> "1" SecurityConstraintSum : SecurityConstraintSum
```

A constraint term is one element of a linear constraint.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| factor [0..1] | [String](#CIM17v40-String) | | |
| function [0..1] | [String](#CIM17v40-String) | The function is an enumerated value that can be 'active', 'reactive', or 'VA' to indicate the type of flow. | |
| SecurityConstraintSum [1] | [SecurityConstraintSum](#CIM17v40-SecurityConstraintSum) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ConsumptionTariffInterval}
### ConsumptionTariffInterval


```mermaid
classDiagram
direction TB

class ConsumptionTariffInterval {

+ sequenceNumber : Integer [0..1]
+ startValue : Float [0..1]
}

class ReadingType {

}

ConsumptionTariffInterval --> "0..1" ReadingType : ReadingType
```

One of a sequence of intervals defined in terms of consumption quantity of a service such as electricity, water, gas, etc. It is typically used in association with TariffProfile to define the steps or blocks in a step tariff structure, where startValue simultaneously defines the entry value of this step and the closing value of the previous step. Where consumption is >= startValue it falls within this interval and where consumption is < startValue it falls within the previous interval.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | A sequential reference that defines the identity of this interval and its relative position with respect to other intervals in a sequence of intervals. | |
| startValue [0..1] | [Float](#CIM17v40-Float) | The lowest level of consumption that defines the starting point of this interval. The interval extends to the start of the next interval or until it is reset to the start of the first interval by TariffProfile.tariffCycle. | |
| ReadingType [0..1] | [ReadingType](#CIM17v40-ReadingType) | Reading type for 'startValue'. | |

{#CIM17v40-Contingency}
### Contingency

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Contingency {

+ mustStudy : Boolean [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Contingency : inherits from
```

An event threatening system reliability, consisting of one or more contingency elements.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mustStudy [0..1] | [Boolean](#CIM17v40-Boolean) | Set true if must study this contingency. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ContingencyConstraintLimit}
### ContingencyConstraintLimit

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ContingencyConstraintLimit {

}

class Curve {

}

Curve <|-- ContingencyConstraintLimit : inherits from
class MktContingency {

}

ContingencyConstraintLimit --> "1" MktContingency : MktContingency
class MWLimitSchedule {

}

ContingencyConstraintLimit --> "1" MWLimitSchedule : MWLimitSchedules
class SecurityConstraintSum {

}

ContingencyConstraintLimit --> "1" SecurityConstraintSum : SecurityConstraintSum
```

Possibly time-varying max MW or MVA and optionally Min MW limit or MVA limit (Y1 and Y2, respectively) assigned to a constraint for a specific contingency. Use CurveSchedule XAxisUnits to specify MW or MVA.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| MktContingency [1] | [MktContingency](#CIM17v40-MktContingency) | | |
| MWLimitSchedules [1] | [MWLimitSchedule](#CIM17v40-MWLimitSchedule) | | |
| SecurityConstraintSum [1] | [SecurityConstraintSum](#CIM17v40-SecurityConstraintSum) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ContingencyElement}
### ContingencyElement

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ContingencyElement {

}

class IdentifiedObject {

}

IdentifiedObject <|-- ContingencyElement : inherits from
class Contingency {

}

ContingencyElement --> "1" Contingency : Contingency
```

An element of a system event to be studied by contingency analysis, representing a change in status of a single piece of equipment.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Contingency [1]` (OfAggregate) | [Contingency](#CIM17v40-Contingency) | A contingency element belongs to one contingency. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ContingencyEquipment}
### ContingencyEquipment

Inheritance path = [ContingencyElement](#CIM17v40-ContingencyElement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ContingencyEquipment {

+ contingentStatus : enum:ContingencyEquipmentStatusKind [0..1]
}

class ContingencyElement {

}

ContingencyElement <|-- ContingencyEquipment : inherits from
class Equipment {

}

ContingencyEquipment --> "1" Equipment : Equipment
```

Equipment whose in service status is to change, such as a power transformer or AC line segment.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| contingentStatus [0..1] | [ContingencyEquipmentStatusKind](#CIM17v40-ContingencyEquipmentStatusKind) | The status for the associated equipment when in the contingency state. This status is independent of the case to which the contingency is originally applied, but defines the equipment status when the contingency is applied. | |
| Equipment [1] | [Equipment](#CIM17v40-Equipment) | The single piece of equipment to which to apply the contingency. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Contingency [1]` (OfAggregate) | [Contingency](#CIM17v40-Contingency) | see [ContingencyElement](CIM17v40-ContingencyElement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ContractDistributionFactor}
### ContractDistributionFactor


```mermaid
classDiagram
direction TB

class ContractDistributionFactor {

+ factor : Float [0..1]
+ sinkFlag : enum:YesNo [0..1]
+ sourceFlag : enum:YesNo [0..1]
}

class Flowgate {

}

ContractDistributionFactor --> "0..1" Flowgate : Flowgate
class RegisteredResource {

}

ContractDistributionFactor --> "0..1" RegisteredResource : RegisteredResource
class ContractRight {

}

ContractDistributionFactor --> "0..1" ContractRight : TransmissionContractRight
```

Distribution among resources at the sink point or source point.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| factor [0..1] | [Float](#CIM17v40-Float) | MW value that this resource provides to the overall contract. | |
| sinkFlag [0..1] | [YesNo](#CIM17v40-YesNo) | This value will be set to YES if the referenced Cnode is defined as the sink point in the contract. | |
| sourceFlag [0..1] | [YesNo](#CIM17v40-YesNo) | This value will be set to YES if the referenced Cnode is defined as the source point in the contract. | |
| Flowgate [0..1] | [Flowgate](#CIM17v40-Flowgate) | | |
| RegisteredResource [0..1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |
| TransmissionContractRight [0..1] | [ContractRight](#CIM17v40-ContractRight) | | |

{#CIM17v40-ContractRight}
### ContractRight

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ContractRight {

+ chainOrder : Integer [0..1]
+ contractMW : Float [0..1]
+ contractPrice : CostPerEnergyUnit [0..1]
+ contractPriority : Integer [0..1]
+ contractStatus : String [0..1]
+ contractType : enum:ContractType [0..1]
+ financialLocation : enum:YesNo [0..1]
+ financialRightsDAM : enum:YesNo [0..1]
+ financialRightsRTM : enum:YesNo [0..1]
+ fuelAdder : Float [0..1]
+ latestSchedMinutes : Integer [0..1]
+ latestSchedMktType : enum:MarketType [0..1]
+ maximumScheduleQuantity : Float [0..1]
+ maximumServiceHours : Integer [0..1]
+ maximumStartups : Integer [0..1]
+ maxNetDependableCapacity : Float [0..1]
+ minimumLoad : Float [0..1]
+ minimumScheduleQuantity : Float [0..1]
+ physicalRightsDAM : enum:YesNo [0..1]
+ physicalRightsRTM : enum:YesNo [0..1]
+ startupLeadTime : Integer [0..1]
+ TRType : enum:TRType [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ContractRight : inherits from
class TransmissionRightChain {

}

ContractRight --> "0..1" TransmissionRightChain : Chain_TransmissionRightChain
class TransmissionRightChain {

}

ContractRight --> "0..1" TransmissionRightChain : Ind_TransmissionRightChain
class RTO {

}

ContractRight --> "1" RTO : RTO
class SchedulingCoordinator {

}

ContractRight --> "1" SchedulingCoordinator : SchedulingCoordinator
```

Provides definition of Transmission Ownership Right and Existing Transmission Contract identifiers for use by SCUC. RMR contract hosting: Startup lead time, Contract Service Limits, Max Service Hours, Max MWhs, Max Start-ups, Ramp Rate, Max Net Dependable Capacity, Min Capacity and Unit Substitution for DAM/RTM to retrieve.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| chainOrder [0..1] | [Integer](#CIM17v40-Integer) | When used in conjunction with a Transmission Right contract chain, this is the precedence for the contracts. | |
| contractMW [0..1] | [Float](#CIM17v40-Float) | MW value of the contract | |
| contractPrice [0..1] | [CostPerEnergyUnit](#CIM17v40-CostPerEnergyUnit) | Financial value of the contract | |
| contractPriority [0..1] | [Integer](#CIM17v40-Integer) | Priority for the contract. This should be unique amoung all contracts for a specific resource. This value is the directive for the SCUC algorithm on the order to satisfy/cut contracts. | |
| contractStatus [0..1] | [String](#CIM17v40-String) | Contract status | |
| contractType [0..1] | [ContractType](#CIM17v40-ContractType) | type of the contract. Possible values are but not limited by:ETC, TOR or RMR and RMT self schedules | |
| financialLocation [0..1] | [YesNo](#CIM17v40-YesNo) | Indicator if the location associated with this contract is financial (e.g. pricing nodes) or physical (e.g. connectivity nodes). | |
| financialRightsDAM [0..1] | [YesNo](#CIM17v40-YesNo) | Flag to indicate this contract provides financial rights in the DA Market | |
| financialRightsRTM [0..1] | [YesNo](#CIM17v40-YesNo) | Flag to indicate this contract provides financial rights in the RT Market | |
| fuelAdder [0..1] | [Float](#CIM17v40-Float) | Estimated Fuel Adder | |
| latestSchedMinutes [0..1] | [Integer](#CIM17v40-Integer) | This indicates the latest schedule minutes (e.g. t - xx) that this resource can be notified to respond. This attribute is only used if the market type is not supplied. | |
| latestSchedMktType [0..1] | [MarketType](#CIM17v40-MarketType) | This indicates the latest schedule market type a contract can be applied to. This is used in conjunction with the latestSchedMinutes attribute to determine the latest time this contract can be called in. The possible values for this attribute are: DAM, RTM or it can be omitted. If omitted, the latestSchedMinutes attribute defines the value. | |
| maximumScheduleQuantity [0..1] | [Float](#CIM17v40-Float) | Maximum schedule MW quantity | |
| maximumServiceHours [0..1] | [Integer](#CIM17v40-Integer) | Maximum service hours | |
| maximumStartups [0..1] | [Integer](#CIM17v40-Integer) | Maximum startups | |
| maxNetDependableCapacity [0..1] | [Float](#CIM17v40-Float) | Maximum Net Dependable Capacity | |
| minimumLoad [0..1] | [Float](#CIM17v40-Float) | Minimum Load | |
| minimumScheduleQuantity [0..1] | [Float](#CIM17v40-Float) | Minimum schedule quanity | |
| physicalRightsDAM [0..1] | [YesNo](#CIM17v40-YesNo) | Flag to indicate this contract provides physical rights in the DA Market | |
| physicalRightsRTM [0..1] | [YesNo](#CIM17v40-YesNo) | Flag to indicate this contract provides physical rights in the RT Market | |
| startupLeadTime [0..1] | [Integer](#CIM17v40-Integer) | Start up lead time | |
| TRType [0..1] | [TRType](#CIM17v40-TRType) | Transmission Right type - is this an individual contract right or a chain contract right. Types = CHAIN or INDIVIDUAL | |
| Chain_TransmissionRightChain [0..1] | [TransmissionRightChain](#CIM17v40-TransmissionRightChain) | | |
| Ind_TransmissionRightChain [0..1] | [TransmissionRightChain](#CIM17v40-TransmissionRightChain) | | |
| RTO [1] | [RTO](#CIM17v40-RTO) | | |
| SchedulingCoordinator [1] | [SchedulingCoordinator](#CIM17v40-SchedulingCoordinator) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ContractorItem}
### ContractorItem

Inheritance path = [WorkIdentifiedObject](#CIM17v40-WorkIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ContractorItem {

+ activityCode : String [0..1]
+ bidAmount : Money [0..1]
+ cost : Money [0..1]
+ status : Status [0..1]
}

class WorkIdentifiedObject {

}

WorkIdentifiedObject <|-- ContractorItem : inherits from
class WorkCostDetail {

}

ContractorItem --> "1" WorkCostDetail : WorkCostDetail
class OldWorkTask {

}

ContractorItem --> "0..1" OldWorkTask : WorkTask
```

Contractor information for work task.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| activityCode [0..1] | [String](#CIM17v40-String) | Activity code identifies a specific and distinguishable unit of work. | |
| bidAmount [0..1] | [Money](#CIM17v40-Money) | The amount that a given contractor will charge for performing this unit of work. | |
| cost [0..1] | [Money](#CIM17v40-Money) | The total amount charged. | |
| status [0..1] | [Status](#CIM17v40-Status) | | |
| `WorkCostDetail [1]` (informative) | [WorkCostDetail](#CIM17v40-WorkCostDetail) | | |
| `WorkTask [0..1]` (informative) | [OldWorkTask](#CIM17v40-OldWorkTask) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Control}
### Control

Inheritance path = [IOPoint](#CIM17v40-IOPoint) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Control {

+ controlType : String [0..1]
+ operationInProgress : Boolean [0..1]
+ timeStamp : DateTime [0..1]
+ unitMultiplier : enum:UnitMultiplier [0..1]
+ unitSymbol : enum:UnitSymbol [0..1]
}

class IOPoint {

}

IOPoint <|-- Control : inherits from
class ControlAction {

}

Control --> "0..1" ControlAction : ControlAction
class PowerSystemResource {

}

Control --> "0..1" PowerSystemResource : PowerSystemResource
class RemoteControl {

}

Control --> "0..1" RemoteControl : RemoteControl
```

Control is used for supervisory/device control. It represents control outputs that are used to change the state in a process, e.g. close or open breaker, a set point value or a raise lower command.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| controlType [0..1] | [String](#CIM17v40-String) | Specifies the type of Control. For example, this specifies if the Control represents BreakerOpen, BreakerClose, GeneratorVoltageSetPoint, GeneratorRaise, GeneratorLower, etc. | |
| operationInProgress [0..1] | [Boolean](#CIM17v40-Boolean) | Indicates that a client is currently sending control commands that has not completed. | |
| timeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | The last time a control output was sent. | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | The unit multiplier of the controlled quantity. | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | The unit of measure of the controlled quantity. | |
| ControlAction [0..1] | [ControlAction](#CIM17v40-ControlAction) | The control action that is performed on the control | |
| PowerSystemResource [0..1] | [PowerSystemResource](#CIM17v40-PowerSystemResource) | Regulating device governed by this control output. | |
| RemoteControl [0..1] | [RemoteControl](#CIM17v40-RemoteControl) | The remote point controlling the physical actuator. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| IOPointSource [0..1] | [IOPointSource](#CIM17v40-IOPointSource) | see [IOPoint](CIM17v40-IOPoint) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ControlAction}
### ControlAction

Inheritance path = [SwitchingAction](#CIM17v40-SwitchingAction) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ControlAction {

+ analogValue : Float [0..1]
+ discreteValue : Integer [0..1]
}

class SwitchingAction {

}

SwitchingAction <|-- ControlAction : inherits from
class Control {

}

ControlAction --> "0..1" Control : Control
```

Control executed as a switching step.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| analogValue [0..1] | [Float](#CIM17v40-Float) | The analog value used for the analog control, the raise/lower control and the set point control | |
| discreteValue [0..1] | [Integer](#CIM17v40-Integer) | The integer value used for the command or the accumulator reset. | |
| Control [0..1] | [Control](#CIM17v40-Control) | The control that the control action is performed on. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| executedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| issuedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| plannedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| Operator [0..1] | [Operator](#CIM17v40-Operator) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingEvent [0..1] | [SwitchingEvent](#CIM17v40-SwitchingEvent) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingStep [0..1] | [SwitchingStep](#CIM17v40-SwitchingStep) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ControlArea}
### ControlArea

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ControlArea {

+ netInterchange : ActivePower [0..1]
+ pTolerance : ActivePower [0..1]
+ type : enum:ControlAreaTypeKind [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- ControlArea : inherits from
class EnergyArea {

}

ControlArea --> "0..1" EnergyArea : EnergyArea
```

A control area is a grouping of generating units and/or loads and a cutset of tie lines (as terminals) which may be used for a variety of purposes including automatic generation control, power flow solution area interchange control specification, and input to load forecasting. All generation and load within the area defined by the terminals on the border are considered in the area interchange control. Note that any number of overlapping control area specifications can be superimposed on the physical model. The following general principles apply to ControlArea:

1. The control area orientation for net interchange is positive for an import, negative for an export.

2. The control area net interchange is determined by summing flows in Terminals. The Terminals are identified by creating a set of TieFlow objects associated with a ControlArea object. Each TieFlow object identifies one Terminal.

3. In a single network model, a tie between two control areas must be modelled in both control area specifications, such that the two representations of the tie flow sum to zero.

4. The normal orientation of Terminal flow is positive for flow into the conducting equipment that owns the Terminal. (i.e. flow from a bus into a device is positive.) However, the orientation of each flow in the control area specification must align with the control area convention, i.e. import is positive. If the orientation of the Terminal flow referenced by a TieFlow is positive into the control area, then this is confirmed by setting TieFlow.positiveFlowIn flag TRUE. If not, the orientation must be reversed by setting the TieFlow.positiveFlowIn flag FALSE.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| netInterchange [0..1] | [ActivePower](#CIM17v40-ActivePower) | The specified positive net interchange into the control area, i.e. positive sign means flow into the area. | |
| pTolerance [0..1] | [ActivePower](#CIM17v40-ActivePower) | Active power net interchange tolerance. The attribute shall be a positive value or zero. | |
| type [0..1] | [ControlAreaTypeKind](#CIM17v40-ControlAreaTypeKind) | The primary type of control area definition used to determine if this is used for automatic generation control, for planning interchange control, or other purposes. A control area specified with primary type of automatic generation control could still be forecast and used as an interchange area in power flow analysis. | |
| EnergyArea [0..1] | [EnergyArea](#CIM17v40-EnergyArea) | The energy area that is forecast from this control area specification. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ControlAreaDesignation}
### ControlAreaDesignation


```mermaid
classDiagram
direction TB

class ControlAreaDesignation {

+ attained : enum:YesNo [0..1]
+ native : enum:YesNo [0..1]
}

```

Indicates Control Area associated with self-schedule.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| attained [0..1] | [YesNo](#CIM17v40-YesNo) | Attained. | |
| native [0..1] | [YesNo](#CIM17v40-YesNo) | Native. | |

{#CIM17v40-ControlAreaGeneratingUnit}
### ControlAreaGeneratingUnit

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ControlAreaGeneratingUnit {

}

class IdentifiedObject {

}

IdentifiedObject <|-- ControlAreaGeneratingUnit : inherits from
class ControlArea {

}

ControlAreaGeneratingUnit --> "1" ControlArea : ControlArea
class GeneratingUnit {

}

ControlAreaGeneratingUnit --> "1" GeneratingUnit : GeneratingUnit
```

A control area generating unit. This class is needed so that alternate control area definitions may include the same generating unit. It should be noted that only one instance within a control area should reference a specific generating unit.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ControlArea [1]` (OfAggregate) | [ControlArea](#CIM17v40-ControlArea) | The parent control area for the generating unit specifications. | |
| GeneratingUnit [1] | [GeneratingUnit](#CIM17v40-GeneratingUnit) | The generating unit specified for this control area. Note that a control area should include a GeneratingUnit only once. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ControlAreaOperator}
### (informative) ControlAreaOperator

Inheritance path = [Organisation](#CIM17v40-Organisation) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ControlAreaOperator {

}

class Organisation {

}

Organisation <|-- ControlAreaOperator : inherits from
class HostControlArea {

}

ControlAreaOperator --> "1" HostControlArea : ControlledBy
```

Operates the Control Area. Approves and implements energy transactions. Verifies both Inter-Control Area and Intra-Control Area transactions for the power system before granting approval (and implementing) the transactions.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ControlledBy [1]` (informative) | [HostControlArea](#CIM17v40-HostControlArea) | A ControlAreaCompany controls a ControlArea. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Organisation](CIM17v40-Organisation) | |
| ParentOrganisation [0..1] | [ParentOrganization](#CIM17v40-ParentOrganization) | see [Organisation](CIM17v40-Organisation) | |
| phone1 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Organisation](CIM17v40-Organisation) | |
| phone2 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Organisation](CIM17v40-Organisation) | |
| postalAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Organisation](CIM17v40-Organisation) | |
| streetAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Organisation](CIM17v40-Organisation) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ControlAreaSolutionData}
### ControlAreaSolutionData


```mermaid
classDiagram
direction TB

class ControlAreaSolutionData {

+ solvedInterchange : Float [0..1]
+ solvedLosses : Float [0..1]
}

class MktControlArea {

}

ControlAreaSolutionData --> "0..1" MktControlArea : MktControlArea
```

State Estimator Solution Pool Interchange and Losses.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| solvedInterchange [0..1] | [Float](#CIM17v40-Float) | Pool MW InterchangeAttribute Usage: The active power interchange of the pool | |
| solvedLosses [0..1] | [Float](#CIM17v40-Float) | Pool Losses MWAttribute Usage: The active power losses of the pool in MW | |
| MktControlArea [0..1] | [MktControlArea](#CIM17v40-MktControlArea) | | |

{#CIM17v40-CoolingPowerRating}
### CoolingPowerRating

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CoolingPowerRating {

+ coolingKind : enum:CoolingKind [0..1]
+ powerRating : ApparentPower [0..1]
+ stage : Integer [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- CoolingPowerRating : inherits from
```

There are often stages of power which are associated with stages of cooling. For instance, a transformer may be rated 121kV on the primary, 15kV on the secondary and 4kV on the tertiary winding. These are voltage ratings and the power ratings are generally the same for all three windings and independent of the voltage ratings, there are instances where the tertiary may have a lower power rating.

For example, for three stages, the power rating may be 15/20/25 MVA and the cooling is OA/FA/FOA. The 15 MVA rating goes with the OA cooling (Oil and Air cooling). This is called the self cooled rating as there are no external cooling enhancements. The 20 MVA rating goes with the FA cooling (Forced Air cooling), this means that when the fans are running and thus enhancing the cooling characteristics, the transformer can operate at a power level of 20 MVA. The 25 MVA rating goes with the FOA cooling (Forced Oil and Air cooling), this means that when the fans and pumps are running and thus enhancing the cooling characteristics even more than before, the transformer can operate at a power level of 25 MVA. This 15/20/25 MVA does not state how the power is split between the various windings. It may be 25 MVA input on the primary, 25 MVA output on the secondary and 0 MVA output on the tertiary. It may also operate at 25 MVA input on the primary, 17 MVA output on the secondary and 8 MVA output on the tertiary.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| coolingKind [0..1] | [CoolingKind](#CIM17v40-CoolingKind) | Kind of cooling system. | |
| powerRating [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | The power rating associated with type of cooling specified for this stage. | |
| stage [0..1] | [Integer](#CIM17v40-Integer) | Stage of cooling and associated power rating. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CoordinateSystem}
### CoordinateSystem

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CoordinateSystem {

+ crsUrn : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- CoordinateSystem : inherits from
```

Coordinate reference system.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| crsUrn [0..1] | [String](#CIM17v40-String) | A Uniform Resource Name (URN) for the coordinate reference system (crs) used to define 'Location.PositionPoints'.An example would be the European Petroleum Survey Group (EPSG) code for a coordinate reference system, defined in URN under the Open Geospatial Consortium (OGC) namespace as: urn:ogc:def:crs:EPSG::XXXX, where XXXX is an EPSG code (a full list of codes can be found at the EPSG Registry web site http://www.epsg-registry.org/). To define the coordinate system as being WGS84 (latitude, longitude) using an EPSG OGC, this attribute would be urn:ogc:def:crs:EPSG::4.3.2.6A profile should limit this code to a set of allowed URNs agreed to by all sending and receiving parties. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CostType}
### (informative) CostType

Inheritance path = [WorkIdentifiedObject](#CIM17v40-WorkIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CostType {

+ amountAssignable : Boolean [0..1]
+ code : String [0..1]
+ level : String [0..1]
+ stage : String [0..1]
+ status : Status [0..1]
}

class WorkIdentifiedObject {

}

WorkIdentifiedObject <|-- CostType : inherits from
class CostType {

}

CostType --> "0..1" CostType : ParentCostType
```

A categorization for resources, often costs, in accounting transactions. Examples include: material components, building in service, coal sales, overhead, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| amountAssignable [0..1] | [Boolean](#CIM17v40-Boolean) | True if an amount can be assigned to the resource element (e.g., building in service, transmission plant, software development capital); false otherwise (e.g., internal labor, material components). | |
| code [0..1] | [String](#CIM17v40-String) | A codified representation of the resource element. | |
| level [0..1] | [String](#CIM17v40-String) | The level of the resource element in the hierarchy of resource elements (recursive relationship). | |
| stage [0..1] | [String](#CIM17v40-String) | The stage for which this costType applies: estimated design, estimated actual or actual actual. | |
| `ParentCostType [0..1]` (informative) | [CostType](#CIM17v40-CostType) | | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Craft}
### Craft

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Craft {

+ type : String [0..1]
+ status : Status [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Craft : inherits from
```

Craft of a person or a crew. Examples include overhead electric, underground electric, high pressure gas, etc. This ensures necessary knowledge and skills before being allowed to perform certain types of work.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| type [0..1] | [String](#CIM17v40-String) | Classification by utility's work mangement standards and practices. | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Crew}
### Crew

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Crew {

+ status : Status [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Crew : inherits from
class CrewType {

}

Crew --> "0..1" CrewType : CrewType
class Location {

}

Crew --> "0..1" Location : Location
class SwitchingAction {

}

Crew --> "1" SwitchingAction : SwitchingAction
```

Group of people with specific skills, tools, and vehicles.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CrewType [0..1] | [CrewType](#CIM17v40-CrewType) | Type of this crew. | |
| Location [0..1] | [Location](#CIM17v40-Location) | The location this crew is assigned to. | |
| status [0..1] | [Status](#CIM17v40-Status) | Status of this crew. | |
| SwitchingAction [1] | [SwitchingAction](#CIM17v40-SwitchingAction) | The switching action that is assigned to this crew. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CrewMember}
### CrewMember

Inheritance path = [OperationPersonRole](#CIM17v40-OperationPersonRole) => [PersonRole](#CIM17v40-PersonRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CrewMember {

}

class OperationPersonRole {

}

OperationPersonRole <|-- CrewMember : inherits from
class Crew {

}

CrewMember --> "0..1" Crew : Crew
```

Member of a crew.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Crew [0..1] | [Crew](#CIM17v40-Crew) | Crew to which this crew member belongs. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Person [0..1] | [Person](#CIM17v40-Person) | see [PersonRole](CIM17v40-PersonRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CrewType}
### CrewType

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CrewType {

}

class IdentifiedObject {

}

IdentifiedObject <|-- CrewType : inherits from
```

Custom description of the type of crew. This may be used to determine the type of work the crew can be assigned to. Examples include repair, tree trimming, switching, etc.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CrossCompoundTurbineGovernorDynamics}
### CrossCompoundTurbineGovernorDynamics

Inheritance path = [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CrossCompoundTurbineGovernorDynamics {

}

class DynamicsFunctionBlock {

}

DynamicsFunctionBlock <|-- CrossCompoundTurbineGovernorDynamics : inherits from
class SynchronousMachineDynamics {

}

CrossCompoundTurbineGovernorDynamics --> "1" SynchronousMachineDynamics : HighPressureSynchronousMachineDynamics
class SynchronousMachineDynamics {

}

CrossCompoundTurbineGovernorDynamics --> "1" SynchronousMachineDynamics : LowPressureSynchronousMachineDynamics
```

Turbine-governor cross-compound function block whose behaviour is described by reference to a standard model <font color="#0f0f0f">or by definition of a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| HighPressureSynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | High-pressure synchronous machine with which this cross-compound turbine governor is associated. | |
| LowPressureSynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | Low-pressure synchronous machine with which this cross-compound turbine governor is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CsConverter}
### CsConverter

Inheritance path = [ACDCConverter](#CIM17v40-ACDCConverter) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CsConverter {

+ alpha : AngleDegrees [0..1]
+ gamma : AngleDegrees [0..1]
+ maxAlpha : AngleDegrees [0..1]
+ maxGamma : AngleDegrees [0..1]
+ maxIdc : CurrentFlow [0..1]
+ minAlpha : AngleDegrees [0..1]
+ minGamma : AngleDegrees [0..1]
+ minIdc : CurrentFlow [0..1]
+ operatingMode : enum:CsOperatingModeKind [0..1]
+ pPccControl : enum:CsPpccControlKind [0..1]
+ ratedIdc : CurrentFlow [0..1]
+ targetAlpha : AngleDegrees [0..1]
+ targetGamma : AngleDegrees [0..1]
+ targetIdc : CurrentFlow [0..1]
}

class ACDCConverter {

}

ACDCConverter <|-- CsConverter : inherits from
class CSCDynamics {

}

CsConverter --> "0..1" CSCDynamics : CSCDynamics
```

DC side of the current source converter (CSC).

The firing angle controls the dc voltage at the converter, both for rectifier and inverter. The difference between the dc voltages of the rectifier and inverter determines the dc current. The extinction angle is used to limit the dc voltage at the inverter, if needed, and is not used in active power control. The firing angle, transformer tap position and number of connected filters are the primary means to control a current source dc line. Higher level controls are built on top, e.g. dc voltage, dc current and active power. From a steady state perspective it is sufficient to specify the wanted active power transfer (ACDCConverter.targetPpcc) and the control functions will set the dc voltage, dc current, firing angle, transformer tap position and number of connected filters to meet this. Therefore attributes targetAlpha and targetGamma are not applicable in this case.

The reactive power consumed by the converter is a function of the firing angle, transformer tap position and number of connected filter, which can be approximated with half of the active power. The losses is a function of the dc voltage and dc current.

The attributes minAlpha and maxAlpha define the range of firing angles for rectifier operation between which no discrete tap changer action takes place. The range is typically 10-18 degrees.

The attributes minGamma and maxGamma define the range of extinction angles for inverter operation between which no discrete tap changer action takes place. The range is typically 17-20 degrees.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| alpha [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Firing angle that determines the dc voltage at the converter dc terminal. Typical value between 10 degrees and 18 degrees for a rectifier. It is converter�s state variable, result from power flow. The attribute shall be a positive value. | |
| gamma [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Extinction angle. It is used to limit the dc voltage at the inverter if needed. Typical value between 17 degrees and 20 degrees for an inverter. It is converter�s state variable, result from power flow. The attribute shall be a positive value. | |
| maxAlpha [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Maximum firing angle. It is converter�s configuration data used in power flow. The attribute shall be a positive value. | |
| maxGamma [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Maximum extinction angle. It is converter�s configuration data used in power flow. The attribute shall be a positive value. | |
| maxIdc [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | The maximum direct current (Id) on the DC side at which the converter should operate. It is converter�s configuration data use in power flow. The attribute shall be a positive value. | |
| minAlpha [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Minimum firing angle. It is converter�s configuration data used in power flow. The attribute shall be a positive value. | |
| minGamma [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Minimum extinction angle. It is converter�s configuration data used in power flow. The attribute shall be a positive value. | |
| minIdc [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | The minimum direct current (Id) on the DC side at which the converter should operate. It is converter�s configuration data used in power flow. The attribute shall be a positive value. | |
| operatingMode [0..1] | [CsOperatingModeKind](#CIM17v40-CsOperatingModeKind) | Indicates whether the DC pole is operating as an inverter or as a rectifier. It is converter�s control variable used in power flow. | |
| pPccControl [0..1] | [CsPpccControlKind](#CIM17v40-CsPpccControlKind) | Kind of active power control. | |
| ratedIdc [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Rated converter DC current, also called IdN. The attribute shall be a positive value. It is converter�s configuration data used in power flow. | |
| targetAlpha [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Target firing angle. It is converter�s control variable used in power flow. It is only applicable for rectifier if continuous tap changer control is used. Allowed values are within the range minAlpha&lt;=targetAlpha&lt;=maxAlpha. The attribute shall be a positive value. | |
| targetGamma [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Target extinction angle. It is converter�s control variable used in power flow. It is only applicable for inverter if continuous tap changer control is used. Allowed values are within the range minGamma&lt;=targetGamma&lt;=maxGamma. The attribute shall be a positive value. | |
| targetIdc [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | DC current target value. It is converter�s control variable used in power flow. The attribute shall be a positive value. | |
| CSCDynamics [0..1] | [CSCDynamics](#CIM17v40-CSCDynamics) | Current source converter dynamics model used to describe dynamic behaviour of this converter. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| baseS [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| idc [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| idleLoss [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| maxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| maxUdc [0..1] | [Voltage](#CIM17v40-Voltage) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| minP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| minUdc [0..1] | [Voltage](#CIM17v40-Voltage) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| numberOfValves [0..1] | [Integer](#CIM17v40-Integer) | see [ACDCConverter](#CIM17v40-ACDCConverter) | |
| p [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| poleLossP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| q [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| ratedUdc [0..1] | [Voltage](#CIM17v40-Voltage) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| resistiveLoss [0..1] | [Resistance](#CIM17v40-Resistance) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| switchingLoss [0..1] | [ActivePowerPerCurrentFlow](#CIM17v40-ActivePowerPerCurrentFlow) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| targetPpcc [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| targetUdc [0..1] | [Voltage](#CIM17v40-Voltage) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| uc [0..1] | [Voltage](#CIM17v40-Voltage) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| udc [0..1] | [Voltage](#CIM17v40-Voltage) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| valveU0 [0..1] | [Voltage](#CIM17v40-Voltage) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| PccTerminal [0..1] | [Terminal](#CIM17v40-Terminal) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CurrentEmergencyScheduledInterchange}
### CurrentEmergencyScheduledInterchange

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CurrentEmergencyScheduledInterchange {

+ emergencyScheduleMW : Float [0..1]
+ emergencyScheduleRampTime : Integer [0..1]
+ emergencyScheduleStartTime : DateTime [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- CurrentEmergencyScheduledInterchange : inherits from
class InternalControlArea {

}

CurrentEmergencyScheduledInterchange --> "1" InternalControlArea : InternalControlArea
```

Control area emergency schedules


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| emergencyScheduleMW [0..1] | [Float](#CIM17v40-Float) | Net tie MW. These are three entries, the current emergency schedule interchange and the two future schedules if they exist. | |
| emergencyScheduleRampTime [0..1] | [Integer](#CIM17v40-Integer) | Ramp time, the ramping time for a schedule. This is calculated as the remaining time to ramp if a schedule is ramping. Measured in seconds, but can be negattive. | |
| emergencyScheduleStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | Net tie time, the start time for a schedule. This is calculated as the current time if a schedule is ramping. | |
| `InternalControlArea [1]` (informative) | [InternalControlArea](#CIM17v40-InternalControlArea) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CurrentLimit}
### CurrentLimit

Inheritance path = [OperationalLimit](#CIM17v40-OperationalLimit) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CurrentLimit {

+ normalValue : CurrentFlow [0..1]
+ value : CurrentFlow [0..1]
}

class OperationalLimit {

}

OperationalLimit <|-- CurrentLimit : inherits from
```

Operational limit on current.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| normalValue [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | The normal value for limit on current flow. The attribute shall be a positive value or zero. | |
| value [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Limit on current flow. The attribute shall be a positive value or zero. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `OperationalLimitSet [1]` (OfAggregate) | [OperationalLimitSet](#CIM17v40-OperationalLimitSet) | see [OperationalLimit](CIM17v40-OperationalLimit) | |
| OperationalLimitType [0..1] | [OperationalLimitType](#CIM17v40-OperationalLimitType) | see [OperationalLimit](CIM17v40-OperationalLimit) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CurrentRelay}
### CurrentRelay

Inheritance path = [ProtectionEquipment](#CIM17v40-ProtectionEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CurrentRelay {

+ currentLimit1 : CurrentFlow [0..1]
+ currentLimit2 : CurrentFlow [0..1]
+ currentLimit3 : CurrentFlow [0..1]
+ inverseTimeFlag : Boolean [0..1]
+ timeDelay1 : Seconds [0..1]
+ timeDelay2 : Seconds [0..1]
+ timeDelay3 : Seconds [0..1]
}

class ProtectionEquipment {

}

ProtectionEquipment <|-- CurrentRelay : inherits from
```

A device that checks current flow values in any direction or designated direction.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| currentLimit1 [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Current limit number one 1 for inverse time pickup. | |
| currentLimit2 [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Current limit number 2 for inverse time pickup. | |
| currentLimit3 [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Current limit number 3 for inverse time pickup. | |
| inverseTimeFlag [0..1] | [Boolean](#CIM17v40-Boolean) | Set true if the current relay has inverse time characteristic. | |
| timeDelay1 [0..1] | [Seconds](#CIM17v40-Seconds) | Inverse time delay number 1 for current limit number 1. | |
| timeDelay2 [0..1] | [Seconds](#CIM17v40-Seconds) | Inverse time delay number 2 for current limit number 2. | |
| timeDelay3 [0..1] | [Seconds](#CIM17v40-Seconds) | Inverse time delay number 3 for current limit number 3. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| highLimit [0..1] | [Float](#CIM17v40-Float) | see [ProtectionEquipment](#CIM17v40-ProtectionEquipment) | |
| lowLimit [0..1] | [Float](#CIM17v40-Float) | see [ProtectionEquipment](#CIM17v40-ProtectionEquipment) | |
| powerDirectionFlag [0..1] | [Boolean](#CIM17v40-Boolean) | see [ProtectionEquipment](#CIM17v40-ProtectionEquipment) | |
| relayDelayTime [0..1] | [Seconds](#CIM17v40-Seconds) | see [ProtectionEquipment](CIM17v40-ProtectionEquipment) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [ProtectionEquipment](CIM17v40-ProtectionEquipment) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [ProtectionEquipment](CIM17v40-ProtectionEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CurrentScheduledInterchange}
### (informative) CurrentScheduledInterchange


```mermaid
classDiagram
direction TB

class CurrentScheduledInterchange {

+ currentNetTieMW : Float [0..1]
+ useEmergencySchedule : Boolean [0..1]
}

class InternalControlArea {

}

CurrentScheduledInterchange --> "1" InternalControlArea : InternalControlArea
```

Control area current net tie (scheduled interchange) sent to real time dispatch.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| currentNetTieMW [0..1] | [Float](#CIM17v40-Float) | Current control area net tie MW (the sum of the tie line flows, i.e the sum of flows into and out of the control area), the current instantaneous scheduled interchange. | |
| useEmergencySchedule [0..1] | [Boolean](#CIM17v40-Boolean) | Use Emergency ScheduleAttribute Usage: Emergency use indicator, false = Emergency Schedular OFF, true = Emergency Schedular ON. | |
| `InternalControlArea [1]` (informative) | [InternalControlArea](#CIM17v40-InternalControlArea) | | |

{#CIM17v40-CurrentState}
### CurrentState

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CurrentState {

}

class IdentifiedObject {

}

IdentifiedObject <|-- CurrentState : inherits from
```


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CurrentTransformer}
### CurrentTransformer

Inheritance path = [Sensor](#CIM17v40-Sensor) => [AuxiliaryEquipment](#CIM17v40-AuxiliaryEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CurrentTransformer {

+ accuracyClass : String [0..1]
+ accuracyLimit : PerCent [0..1]
+ coreBurden : ActivePower [0..1]
+ ctClass : String [0..1]
+ usage : String [0..1]
}

class Sensor {

}

Sensor <|-- CurrentTransformer : inherits from
```

Instrument transformer used to measure electrical qualities of the circuit that is being protected and/or monitored. Typically used as current transducer for the purpose of metering or protection. A typical secondary current rating would be 5A.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| accuracyClass [0..1] | [String](#CIM17v40-String) | CT accuracy classification. | |
| accuracyLimit [0..1] | [PerCent](#CIM17v40-PerCent) | Percent of rated current for which the CT remains accurate within specified limits. | |
| coreBurden [0..1] | [ActivePower](#CIM17v40-ActivePower) | Power burden of the CT core. | |
| ctClass [0..1] | [String](#CIM17v40-String) | CT classification; i.e. class 10P. | |
| usage [0..1] | [String](#CIM17v40-String) | Intended usage of the CT; i.e. metering, protection. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Terminal [1] | [Terminal](#CIM17v40-Terminal) | see [AuxiliaryEquipment](CIM17v40-AuxiliaryEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CurrentTransformerInfo}
### CurrentTransformerInfo

Inheritance path = [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CurrentTransformerInfo {

+ accuracyClass : String [0..1]
+ accuracyLimit : CurrentFlow [0..1]
+ coreCount : Integer [0..1]
+ ctClass : String [0..1]
+ kneePointCurrent : CurrentFlow [0..1]
+ kneePointVoltage : Voltage [0..1]
+ primaryFlsRating : CurrentFlow [0..1]
+ ratedCurrent : CurrentFlow [0..1]
+ secondaryFlsRating : CurrentFlow [0..1]
+ tertiaryFlsRating : CurrentFlow [0..1]
+ usage : String [0..1]
+ maxRatio : Ratio [0..1]
+ nominalRatio : Ratio [0..1]
+ primaryRatio : Ratio [0..1]
+ secondaryRatio : Ratio [0..1]
+ tertiaryRatio : Ratio [0..1]
}

class AssetInfo {

}

AssetInfo <|-- CurrentTransformerInfo : inherits from
```

Properties of current transformer asset.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| accuracyClass [0..1] | [String](#CIM17v40-String) | CT accuracy classification. | |
| accuracyLimit [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Accuracy limit. | |
| coreCount [0..1] | [Integer](#CIM17v40-Integer) | Number of cores. | |
| ctClass [0..1] | [String](#CIM17v40-String) | | |
| kneePointCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Maximum primary current where the CT still displays linear characteristicts. | |
| kneePointVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Maximum voltage across the secondary terminals where the CT still displays linear characteristicts. | |
| primaryFlsRating [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Full load secondary (FLS) rating for primary winding. | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Rated current on the primary side. | |
| secondaryFlsRating [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Full load secondary (FLS) rating for secondary winding. | |
| tertiaryFlsRating [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Full load secondary (FLS) rating for tertiary winding. | |
| usage [0..1] | [String](#CIM17v40-String) | Usage: eg. metering, protection, etc. | |
| maxRatio [0..1] | [Ratio](#CIM17v40-Ratio) | Maximum ratio between the primary and secondary current. | |
| nominalRatio [0..1] | [Ratio](#CIM17v40-Ratio) | Nominal ratio between the primary and secondary current; i.e. 100:5. | |
| primaryRatio [0..1] | [Ratio](#CIM17v40-Ratio) | Ratio for the primary winding tap changer. | |
| secondaryRatio [0..1] | [Ratio](#CIM17v40-Ratio) | Ratio for the secondary winding tap changer. | |
| tertiaryRatio [0..1] | [Ratio](#CIM17v40-Ratio) | Ratio for the tertiary winding tap changer. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CurtailmentProfile}
### CurtailmentProfile

Inheritance path = [Profile](#CIM17v40-Profile) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CurtailmentProfile {

}

class Profile {

}

Profile <|-- CurtailmentProfile : inherits from
class EnergyTransaction {

}

CurtailmentProfile --> "1" EnergyTransaction : EnergyTransaction
```

Curtailing entity must be providing at least one service to the EnergyTransaction. The CurtailmentProfile must be completely contained within the EnergyProfile timeframe for this EnergyTransaction.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `EnergyTransaction [1]` (OfAggregate, informative) | [EnergyTransaction](#CIM17v40-EnergyTransaction) | An EnergyTransaction may be curtailed by any of the participating entities. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Curve}
### Curve

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Curve {

+ curveStyle : enum:CurveStyle [0..1]
+ xMultiplier : enum:UnitMultiplier [0..1]
+ xUnit : enum:UnitSymbol [0..1]
+ y1Multiplier : enum:UnitMultiplier [0..1]
+ y1Unit : enum:UnitSymbol [0..1]
+ y2Multiplier : enum:UnitMultiplier [0..1]
+ y2Unit : enum:UnitSymbol [0..1]
+ y3Multiplier : enum:UnitMultiplier [0..1]
+ y3Unit : enum:UnitSymbol [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Curve : inherits from
```

A multi-purpose curve or functional relationship between an independent variable (X-axis) and dependent (Y-axis) variables.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | The style or shape of the curve. | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | Multiplier for X-axis. | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | The X-axis units of measure. | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | Multiplier for Y1-axis. | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | The Y1-axis units of measure. | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | Multiplier for Y2-axis. | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | The Y2-axis units of measure. | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | Multiplier for Y3-axis. | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | The Y3-axis units of measure. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CurveData}
### CurveData


```mermaid
classDiagram
direction TB

class CurveData {

+ xvalue : Float [0..1]
+ y1value : Float [0..1]
+ y2value : Float [0..1]
+ y3value : Float [0..1]
}

class Curve {

}

CurveData --> "1" Curve : Curve
```

Multi-purpose data points for defining a curve. The use of this generic class is discouraged if a more specific class can be used to specify the X and Y axis values along with their specific data types.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| xvalue [0..1] | [Float](#CIM17v40-Float) | The data value of the X-axis variable, depending on the X-axis units. | |
| y1value [0..1] | [Float](#CIM17v40-Float) | The data value of the first Y-axis variable, depending on the Y-axis units. | |
| y2value [0..1] | [Float](#CIM17v40-Float) | The data value of the second Y-axis variable (if present), depending on the Y-axis units. | |
| y3value [0..1] | [Float](#CIM17v40-Float) | The data value of the third Y-axis variable (if present), depending on the Y-axis units. | |
| `Curve [1]` (OfAggregate) | [Curve](#CIM17v40-Curve) | The curve of this curve data point. | |

{#CIM17v40-Customer}
### (informative) Customer

Inheritance path = [OrganisationRole](#CIM17v40-OrganisationRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Customer {

+ kind : enum:CustomerKind [0..1]
+ locale : String [0..1]
+ pucNumber : String [0..1]
+ specialNeed : String [0..1]
+ vip : Boolean [0..1]
+ priority : Priority [0..1]
+ status : Status [0..1]
}

class OrganisationRole {

}

OrganisationRole <|-- Customer : inherits from
class Customer {

}

Customer --> "0..1" Customer : Customer
class OutagePlan {

}

Customer --> "0..1" OutagePlan : OutagePlan
```

Organisation receiving services from service supplier.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [CustomerKind](#CIM17v40-CustomerKind) | Kind of customer. | |
| locale [0..1] | [String](#CIM17v40-String) | Locale designating language to use in communications with this customer. | |
| pucNumber [0..1] | [String](#CIM17v40-String) | (if applicable) Public utilities commission (PUC) identification number. | |
| specialNeed [0..1] | [String](#CIM17v40-String) | True if customer organisation has special service needs such as life support, hospitals, etc. | |
| `vip [0..1]` (deprecated) | [Boolean](#CIM17v40-Boolean) | (deprecated) (use 'priority' instead) True if this is an important customer. Importance is for matters different than those in 'specialNeed' attribute. | |
| Customer [0..1] | [Customer](#CIM17v40-Customer) | All customers related to the primary customer. This may support customer hierarchies. (this can be used to support some form of customer containment) | |
| OutagePlan [0..1] | [OutagePlan](#CIM17v40-OutagePlan) | The outage plan that identifies the customers that are affected. | |
| priority [0..1] | [Priority](#CIM17v40-Priority) | Priority of the customer. | |
| status [0..1] | [Status](#CIM17v40-Status) | Status of this customer. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Organisation [0..1] | [Organisation](#CIM17v40-Organisation) | see [OrganisationRole](CIM17v40-OrganisationRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CustomerAccount}
### (informative) CustomerAccount

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CustomerAccount {

+ billingCycle : String [0..1]
+ budgetBill : String [0..1]
+ lastBillAmount : Money [0..1]
}

class Document {

}

Document <|-- CustomerAccount : inherits from
class Customer {

}

CustomerAccount --> "1" Customer : Customer
class MeterReadSchedule {

}

CustomerAccount --> "0..1" MeterReadSchedule : MeterReadSchedule
```

Assignment of a group of products and services purchased by the customer through a customer agreement, used as a mechanism for customer billing and payment. It contains common information from the various types of customer agreements to create billings (invoices) for a customer and receive payment.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| billingCycle [0..1] | [String](#CIM17v40-String) | Cycle day on which the associated customer account will normally be billed, used to determine when to produce the billing. | |
| budgetBill [0..1] | [String](#CIM17v40-String) | Budget bill code. | |
| lastBillAmount [0..1] | [Money](#CIM17v40-Money) | The last amount that will be billed to the customer prior to shut off of the account. | |
| Customer [1] | [Customer](#CIM17v40-Customer) | Customer owning this account. | |
| MeterReadSchedule [0..1] | [MeterReadSchedule](#CIM17v40-MeterReadSchedule) | Meter read schedule that applies to the customer account | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CustomerAgreement}
### CustomerAgreement

Inheritance path = [Agreement](#CIM17v40-Agreement) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CustomerAgreement {

+ isPrePay : Boolean [0..1]
+ loadMgmt : String [0..1]
+ shutOffDateTime : DateTime [0..1]
}

class Agreement {

}

Agreement <|-- CustomerAgreement : inherits from
class Customer {

}

CustomerAgreement --> "1" Customer : Customer
class CustomerAccount {

}

CustomerAgreement --> "1" CustomerAccount : CustomerAccount
class MeterReadSchedule {

}

CustomerAgreement --> "0..1" MeterReadSchedule : MeterReadSchedule
class ServiceCategory {

}

CustomerAgreement --> "0..1" ServiceCategory : ServiceCategory
class ServiceSupplier {

}

CustomerAgreement --> "1" ServiceSupplier : ServiceSupplier
class StandardIndustryCode {

}

CustomerAgreement --> "0..1" StandardIndustryCode : StandardIndustryCode
```

Agreement between the customer and the service supplier to pay for service at a specific service location. It records certain billing information about the type of service provided at the service location and is used during charge creation to determine the type of service.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| isPrePay [0..1] | [Boolean](#CIM17v40-Boolean) | If true, the customer is a pre-pay customer for the specified service. | |
| loadMgmt [0..1] | [String](#CIM17v40-String) | Load management code. | |
| shutOffDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Final date and time the service will be billed to the previous customer. | |
| Customer [1] | [Customer](#CIM17v40-Customer) | Customer for this agreement. | |
| CustomerAccount [1] | [CustomerAccount](#CIM17v40-CustomerAccount) | Customer account owning this agreement. | |
| MeterReadSchedule [0..1] | [MeterReadSchedule](#CIM17v40-MeterReadSchedule) | Meter read schedule that applies to the customer agreement | |
| ServiceCategory [0..1] | [ServiceCategory](#CIM17v40-ServiceCategory) | Service category for this agreement. | |
| ServiceSupplier [1] | [ServiceSupplier](#CIM17v40-ServiceSupplier) | Service supplier for this customer agreement. | |
| `StandardIndustryCode [0..1]` (informative) | [StandardIndustryCode](#CIM17v40-StandardIndustryCode) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| signDate [0..1] | [Date](#CIM17v40-Date) | see [Agreement](#CIM17v40-Agreement) | |
| validityInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [Agreement](CIM17v40-Agreement) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CustomerBillingInfo}
### CustomerBillingInfo

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CustomerBillingInfo {

+ billingDate : Date [0..1]
+ dueDate : Date [0..1]
+ kind : enum:CustomerBillingKind [0..1]
+ lastPaymentAmt : Money [0..1]
+ lastPaymentDate : Date [0..1]
+ outBalance : Money [0..1]
+ pymtPlanAmt : Money [0..1]
+ pymtPlanType : String [0..1]
}

class Document {

}

Document <|-- CustomerBillingInfo : inherits from
class CustomerAccount {

}

CustomerBillingInfo --> "0..1" CustomerAccount : CustomerAccount
```

The creation of the monthly customer billing statements is the method employed to notify Customers of charges, adjustments and credits applied to their account for Services and Products. The actuall billing occurs through an ErpInvoice. The CustomerBillingInfo includes information from the payment, collection, meter reading, installed meter, service, site, customer, customer account, customer agreement, services and pricing subject areas. Each component price shows up as a separate line item on the ErpInvoice.

The Customer Billing Statement may include collection and account messages, marketing/civic event messages and bill inserts.

One Customer Billing Statement is produced for all Agreements under a CustomerAccount per billing cycle date defined in 'CustomerAccount.billingCycle'.

The history of CustomerBillingInfo, Invoices and Payments is to be maintained in associated ActivityRecords.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| billingDate [0..1] | [Date](#CIM17v40-Date) | Business date designated for the billing run which produced this CustomerBillingInfo. | |
| dueDate [0..1] | [Date](#CIM17v40-Date) | Calculated date upon which a customer billing amount is due, used in the invoicing process to determine when a Customer's Payment is delinquent. It takes into consideration the regulatory criteria and the Customer's requested due date. In the absence of a Customer requested due date, the due date is typically calculated from the regulated number of days and the 'billingDate'. | |
| kind [0..1] | [CustomerBillingKind](#CIM17v40-CustomerBillingKind) | Kind of bill customer receives. | |
| lastPaymentAmt [0..1] | [Money](#CIM17v40-Money) | Amount of the last payment received from the customer. It is retained in the Customer Billing system, although the details of each payment are tracked in the ERP system. | |
| lastPaymentDate [0..1] | [Date](#CIM17v40-Date) | Date of the last payment received from the customer. It is retained in the Customer Billing system, although the details of each payment are tracked in the ERP system. | |
| outBalance [0..1] | [Money](#CIM17v40-Money) | Outstanding balance on the CustomerAccount as of the statement date. | |
| pymtPlanAmt [0..1] | [Money](#CIM17v40-Money) | Monthly amortized amount due during each billing cycle for the CustomerAccount balance for which the Payment Plan is set-up. | |
| pymtPlanType [0..1] | [String](#CIM17v40-String) | Type of payment plan. | |
| `CustomerAccount [0..1]` (informative) | [CustomerAccount](#CIM17v40-CustomerAccount) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CustomerConsumer}
### (informative) CustomerConsumer

Inheritance path = [Organisation](#CIM17v40-Organisation) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CustomerConsumer {

}

class Organisation {

}

Organisation <|-- CustomerConsumer : inherits from
```

The energy buyer in the energy marketplace.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Organisation](CIM17v40-Organisation) | |
| ParentOrganisation [0..1] | [ParentOrganization](#CIM17v40-ParentOrganization) | see [Organisation](CIM17v40-Organisation) | |
| phone1 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Organisation](CIM17v40-Organisation) | |
| phone2 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Organisation](CIM17v40-Organisation) | |
| postalAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Organisation](CIM17v40-Organisation) | |
| streetAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Organisation](CIM17v40-Organisation) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CustomerNotification}
### CustomerNotification


```mermaid
classDiagram
direction TB

class CustomerNotification {

+ contactType : String [0..1]
+ contactValue : String [0..1]
+ earliestDateTimeToCall : DateTime [0..1]
+ latestDateTimeToCall : DateTime [0..1]
+ trigger : enum:NotificationTriggerKind [0..1]
}

class Customer {

}

CustomerNotification --> "0..1" Customer : Customer
class Incident {

}

CustomerNotification --> "0..1" Incident : Incident
```

Conditions for notifying the customer about the changes in the status of their service (e.g., outage restore, estimated restoration time, tariff or service level change, etc.)


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| contactType [0..1] | [String](#CIM17v40-String) | Type of contact (e.g., phone, email, etc.). | |
| contactValue [0..1] | [String](#CIM17v40-String) | Value of contact type (e.g., phone number, email address, etc.). | |
| earliestDateTimeToCall [0..1] | [DateTime](#CIM17v40-DateTime) | Earliest date time to call the customer. | |
| latestDateTimeToCall [0..1] | [DateTime](#CIM17v40-DateTime) | Latest date time to call the customer. | |
| trigger [0..1] | [NotificationTriggerKind](#CIM17v40-NotificationTriggerKind) | Trigger for this notification. | |
| Customer [0..1] | [Customer](#CIM17v40-Customer) | Customer requiring this notification. | |
| Incident [0..1] | [Incident](#CIM17v40-Incident) | Incident as a subject of this customer notification. | |

{#CIM17v40-Cut}
### Cut

Inheritance path = [Switch](#CIM17v40-Switch) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Cut {

+ lengthFromTerminal1 : Length [0..1]
}

class Switch {

}

Switch <|-- Cut : inherits from
class ACLineSegment {

}

Cut --> "1" ACLineSegment : ACLineSegment
class CutAction {

}

Cut --> "0..1" CutAction : CutAction
```

A cut separates a line segment into two parts. The cut appears as a switch inserted between these two parts and connects them together. As the cut is normally open there is no galvanic connection between the two line segment parts. But it is possible to close the cut to get galvanic connection.

The cut terminals are oriented towards the line segment terminals with the same sequence number. Hence the cut terminal with sequence number equal to 1 is oriented to the line segment's terminal with sequence number equal to 1.

The cut terminals also act as connection points for jumpers and other equipment, e.g. a mobile generator. To enable this, connectivity nodes are placed at the cut terminals. Once the connectivity nodes are in place any conducting equipment can be connected at them.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| lengthFromTerminal1 [0..1] | [Length](#CIM17v40-Length) | The length to the place where the cut is located starting from side one of the cut line segment, i.e. the line segment Terminal with sequenceNumber equal to 1. | |
| ACLineSegment [1] | [ACLineSegment](#CIM17v40-ACLineSegment) | The line segment to which the cut is applied. | |
| CutAction [0..1] | [CutAction](#CIM17v40-CutAction) | Action taken with this cut. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| locked [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| normalOpen [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| open [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [Switch](CIM17v40-Switch) | |
| retained [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| `switchOnCount [0..1]` (deprecated) | [Integer](#CIM17v40-Integer) | see [Switch](#CIM17v40-Switch) | |
| `switchOnDate [0..1]` (deprecated) | [DateTime](#CIM17v40-DateTime) | see [Switch](#CIM17v40-Switch) | |
| `CompositeSwitch [0..1]` (OfAggregate) | [CompositeSwitch](#CIM17v40-CompositeSwitch) | see [Switch](CIM17v40-Switch) | |
| SwitchAction [0..1] | [SwitchAction](#CIM17v40-SwitchAction) | see [Switch](CIM17v40-Switch) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-CutAction}
### CutAction

Inheritance path = [SwitchingAction](#CIM17v40-SwitchingAction) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class CutAction {

+ kind : enum:TempEquipActionKind [0..1]
}

class SwitchingAction {

}

SwitchingAction <|-- CutAction : inherits from
class Cut {

}

CutAction --> "0..1" Cut : Cut
```

Action on cut as a switching step.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [TempEquipActionKind](#CIM17v40-TempEquipActionKind) | Switching action to perform. | |
| Cut [0..1] | [Cut](#CIM17v40-Cut) | Cut on which this action is taken. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| executedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| issuedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| plannedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| Operator [0..1] | [Operator](#CIM17v40-Operator) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingEvent [0..1] | [SwitchingEvent](#CIM17v40-SwitchingEvent) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingStep [0..1] | [SwitchingStep](#CIM17v40-SwitchingStep) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Cyclone}
### Cyclone

Inheritance path = [AtmosphericPhenomenon](#CIM17v40-AtmosphericPhenomenon) => [EnvironmentalPhenomenon](#CIM17v40-EnvironmentalPhenomenon)

```mermaid
classDiagram
direction TB

class Cyclone {

+ centralPressure : Pressure [0..1]
+ maxSurfaceWindSpeed : Speed [0..1]
+ windForce : Integer [0..1]
}

class AtmosphericPhenomenon {

}

AtmosphericPhenomenon <|-- Cyclone : inherits from
```

A cyclone (or tropical cyclone), a rapidly-rotating storm system characterized by a low-pressure center, strong winds, and a spiral arrangement of thunderstorms that produce heavy rain.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| centralPressure [0..1] | [Pressure](#CIM17v40-Pressure) | The central pressure of the cyclone during the time interval. | |
| maxSurfaceWindSpeed [0..1] | [Speed](#CIM17v40-Speed) | The maximum surface wind speed of the cyclone during the time interval. | |
| windForce [0..1] | [Integer](#CIM17v40-Integer) | Wind Force as classified on the Beaufort Scale (0-12) during the time interval. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| direction [0..1] | [Bearing](#CIM17v40-Bearing) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| maxCoverage [0..1] | [PerCent](#CIM17v40-PerCent) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| minCoverage [0..1] | [PerCent](#CIM17v40-PerCent) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| speed [0..1] | [Speed](#CIM17v40-Speed) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| altitude [0..1] | [RelativeDisplacement](#CIM17v40-RelativeDisplacement) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| base [0..1] | [RelativeDisplacement](#CIM17v40-RelativeDisplacement) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| PhenomenonClassification [0..1] | [PhenomenonClassification](#CIM17v40-PhenomenonClassification) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| timeInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |

{#CIM17v40-DCBaseTerminal}
### DCBaseTerminal

Inheritance path = [ACDCTerminal](#CIM17v40-ACDCTerminal) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DCBaseTerminal {

}

class ACDCTerminal {

}

ACDCTerminal <|-- DCBaseTerminal : inherits from
class DCNode {

}

DCBaseTerminal --> "0..1" DCNode : DCNode
class DCTopologicalNode {

}

DCBaseTerminal --> "0..1" DCTopologicalNode : DCTopologicalNode
```

An electrical connection point at a piece of DC conducting equipment. DC terminals are connected at one physical DC node that may have multiple DC terminals connected. A DC node is similar to an AC connectivity node. The model requires that DC connections are distinct from AC connections.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DCNode [0..1] | [DCNode](#CIM17v40-DCNode) | The DC connectivity node to which this DC base terminal connects with zero impedance. | |
| DCTopologicalNode [0..1] | [DCTopologicalNode](#CIM17v40-DCTopologicalNode) | See association end Terminal.TopologicalNode. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| connected [0..1] | [Boolean](#CIM17v40-Boolean) | see [ACDCTerminal](#CIM17v40-ACDCTerminal) | |
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | see [ACDCTerminal](#CIM17v40-ACDCTerminal) | |
| BusNameMarker [0..1] | [BusNameMarker](#CIM17v40-BusNameMarker) | see [ACDCTerminal](CIM17v40-ACDCTerminal) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DCBreaker}
### DCBreaker

Inheritance path = [DCSwitch](#CIM17v40-DCSwitch) => [DCConductingEquipment](#CIM17v40-DCConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DCBreaker {

}

class DCSwitch {

}

DCSwitch <|-- DCBreaker : inherits from
```

A breaker within a DC system.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ratedUdc [0..1] | [Voltage](#CIM17v40-Voltage) | see [DCConductingEquipment](CIM17v40-DCConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DCBusbar}
### DCBusbar

Inheritance path = [DCConductingEquipment](#CIM17v40-DCConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DCBusbar {

}

class DCConductingEquipment {

}

DCConductingEquipment <|-- DCBusbar : inherits from
```

A busbar within a DC system.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ratedUdc [0..1] | [Voltage](#CIM17v40-Voltage) | see [DCConductingEquipment](CIM17v40-DCConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DCChopper}
### DCChopper

Inheritance path = [DCConductingEquipment](#CIM17v40-DCConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DCChopper {

}

class DCConductingEquipment {

}

DCConductingEquipment <|-- DCChopper : inherits from
```

Low resistance equipment used in the internal DC circuit to balance voltages. It has typically positive and negative pole terminals and a ground.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ratedUdc [0..1] | [Voltage](#CIM17v40-Voltage) | see [DCConductingEquipment](CIM17v40-DCConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DCConductingEquipment}
### (informative) DCConductingEquipment

Inheritance path = [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DCConductingEquipment {

+ ratedUdc : Voltage [0..1]
}

class Equipment {

}

Equipment <|-- DCConductingEquipment : inherits from
```

The parts of the DC power system that are designed to carry current or that are conductively connected through DC terminals.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ratedUdc [0..1] | [Voltage](#CIM17v40-Voltage) | Rated DC device voltage. The attribute shall be a positive value. It is configuration data used in power flow. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DCConverterUnit}
### DCConverterUnit

Inheritance path = [DCEquipmentContainer](#CIM17v40-DCEquipmentContainer) => [EquipmentContainer](#CIM17v40-EquipmentContainer) => [ConnectivityNodeContainer](#CIM17v40-ConnectivityNodeContainer) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DCConverterUnit {

+ operationMode : enum:DCConverterOperatingModeKind [0..1]
}

class DCEquipmentContainer {

}

DCEquipmentContainer <|-- DCConverterUnit : inherits from
class Substation {

}

DCConverterUnit --> "0..1" Substation : Substation
```

Indivisible operative unit comprising all equipment between the point of common coupling on the AC side and the point of common coupling � DC side, essentially one or more converters, together with one or more converter transformers, converter control equipment, essential protective and switching devices and auxiliaries, if any, used for conversion.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| operationMode [0..1] | [DCConverterOperatingModeKind](#CIM17v40-DCConverterOperatingModeKind) | The operating mode of an HVDC bipole (bipolar, monopolar metallic return, etc). | |
| `Substation [0..1]` (OfAggregate) | [Substation](#CIM17v40-Substation) | The containing substation of the DC converter unit. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DCDisconnector}
### DCDisconnector

Inheritance path = [DCSwitch](#CIM17v40-DCSwitch) => [DCConductingEquipment](#CIM17v40-DCConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DCDisconnector {

}

class DCSwitch {

}

DCSwitch <|-- DCDisconnector : inherits from
```

A disconnector within a DC system.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ratedUdc [0..1] | [Voltage](#CIM17v40-Voltage) | see [DCConductingEquipment](CIM17v40-DCConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DCEquipmentContainer}
### DCEquipmentContainer

Inheritance path = [EquipmentContainer](#CIM17v40-EquipmentContainer) => [ConnectivityNodeContainer](#CIM17v40-ConnectivityNodeContainer) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DCEquipmentContainer {

}

class EquipmentContainer {

}

EquipmentContainer <|-- DCEquipmentContainer : inherits from
```

A modelling construct to provide a root class for containment of DC as well as AC equipment. The class differ from the EquipmentContaner for AC in that it may also contain DCNode-s. Hence it can contain both AC and DC equipment.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DCGround}
### DCGround

Inheritance path = [DCConductingEquipment](#CIM17v40-DCConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DCGround {

+ inductance : Inductance [0..1]
+ r : Resistance [0..1]
}

class DCConductingEquipment {

}

DCConductingEquipment <|-- DCGround : inherits from
```

A ground within a DC system.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| inductance [0..1] | [Inductance](#CIM17v40-Inductance) | Inductance to ground. | |
| r [0..1] | [Resistance](#CIM17v40-Resistance) | Resistance to ground. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ratedUdc [0..1] | [Voltage](#CIM17v40-Voltage) | see [DCConductingEquipment](CIM17v40-DCConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DCLine}
### DCLine

Inheritance path = [DCEquipmentContainer](#CIM17v40-DCEquipmentContainer) => [EquipmentContainer](#CIM17v40-EquipmentContainer) => [ConnectivityNodeContainer](#CIM17v40-ConnectivityNodeContainer) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DCLine {

}

class DCEquipmentContainer {

}

DCEquipmentContainer <|-- DCLine : inherits from
class SubGeographicalRegion {

}

DCLine --> "0..1" SubGeographicalRegion : Region
```

Overhead lines and/or cables connecting two or more HVDC substations.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Region [0..1] | [SubGeographicalRegion](#CIM17v40-SubGeographicalRegion) | The SubGeographicalRegion containing the DC line. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DCLineSegment}
### DCLineSegment

Inheritance path = [DCConductingEquipment](#CIM17v40-DCConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DCLineSegment {

+ capacitance : Capacitance [0..1]
+ inductance : Inductance [0..1]
+ length : Length [0..1]
+ resistance : Resistance [0..1]
}

class DCConductingEquipment {

}

DCConductingEquipment <|-- DCLineSegment : inherits from
class PerLengthDCLineParameter {

}

DCLineSegment --> "0..1" PerLengthDCLineParameter : PerLengthParameter
```

A wire or combination of wires not insulated from one another, with consistent electrical characteristics, used to carry direct current between points in the DC region of the power system.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| capacitance [0..1] | [Capacitance](#CIM17v40-Capacitance) | Capacitance of the DC line segment. Significant for cables only. | |
| inductance [0..1] | [Inductance](#CIM17v40-Inductance) | Inductance of the DC line segment. Negligible compared with DCSeriesDevice used for smoothing. | |
| length [0..1] | [Length](#CIM17v40-Length) | Segment length for calculating line section capabilities. | |
| resistance [0..1] | [Resistance](#CIM17v40-Resistance) | Resistance of the DC line segment. | |
| PerLengthParameter [0..1] | [PerLengthDCLineParameter](#CIM17v40-PerLengthDCLineParameter) | Set of per-length parameters for this line segment. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ratedUdc [0..1] | [Voltage](#CIM17v40-Voltage) | see [DCConductingEquipment](CIM17v40-DCConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DCNode}
### DCNode

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DCNode {

}

class IdentifiedObject {

}

IdentifiedObject <|-- DCNode : inherits from
class DCEquipmentContainer {

}

DCNode --> "1" DCEquipmentContainer : DCEquipmentContainer
class DCTopologicalNode {

}

DCNode --> "0..1" DCTopologicalNode : DCTopologicalNode
```

DC nodes are points where terminals of DC conducting equipment are connected together with zero impedance.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DCEquipmentContainer [1] | [DCEquipmentContainer](#CIM17v40-DCEquipmentContainer) | The DC container for the DC nodes. | |
| DCTopologicalNode [0..1] | [DCTopologicalNode](#CIM17v40-DCTopologicalNode) | The DC topological node to which this DC connectivity node is assigned. May depend on the current state of switches in the network. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DCSeriesDevice}
### DCSeriesDevice

Inheritance path = [DCConductingEquipment](#CIM17v40-DCConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DCSeriesDevice {

+ inductance : Inductance [0..1]
+ resistance : Resistance [0..1]
}

class DCConductingEquipment {

}

DCConductingEquipment <|-- DCSeriesDevice : inherits from
```

A series device within the DC system, typically a reactor used for filtering or smoothing. Needed for transient and short circuit studies.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| inductance [0..1] | [Inductance](#CIM17v40-Inductance) | Inductance of the device. | |
| resistance [0..1] | [Resistance](#CIM17v40-Resistance) | Resistance of the DC device. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ratedUdc [0..1] | [Voltage](#CIM17v40-Voltage) | see [DCConductingEquipment](CIM17v40-DCConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DCShunt}
### DCShunt

Inheritance path = [DCConductingEquipment](#CIM17v40-DCConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DCShunt {

+ capacitance : Capacitance [0..1]
+ resistance : Resistance [0..1]
}

class DCConductingEquipment {

}

DCConductingEquipment <|-- DCShunt : inherits from
```

A shunt device within the DC system, typically used for filtering. Needed for transient and short circuit studies.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| capacitance [0..1] | [Capacitance](#CIM17v40-Capacitance) | Capacitance of the DC shunt. | |
| resistance [0..1] | [Resistance](#CIM17v40-Resistance) | Resistance of the DC device. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ratedUdc [0..1] | [Voltage](#CIM17v40-Voltage) | see [DCConductingEquipment](CIM17v40-DCConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DCSwitch}
### DCSwitch

Inheritance path = [DCConductingEquipment](#CIM17v40-DCConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DCSwitch {

}

class DCConductingEquipment {

}

DCConductingEquipment <|-- DCSwitch : inherits from
```

A switch within the DC system.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ratedUdc [0..1] | [Voltage](#CIM17v40-Voltage) | see [DCConductingEquipment](CIM17v40-DCConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DCTerminal}
### DCTerminal

Inheritance path = [DCBaseTerminal](#CIM17v40-DCBaseTerminal) => [ACDCTerminal](#CIM17v40-ACDCTerminal) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DCTerminal {

}

class DCBaseTerminal {

}

DCBaseTerminal <|-- DCTerminal : inherits from
class DCConductingEquipment {

}

DCTerminal --> "1" DCConductingEquipment : DCConductingEquipment
```

An electrical connection point to generic DC conducting equipment.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DCConductingEquipment [1] | [DCConductingEquipment](#CIM17v40-DCConductingEquipment) | An DC terminal belong to a DC conducting equipment. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DCNode [0..1] | [DCNode](#CIM17v40-DCNode) | see [DCBaseTerminal](CIM17v40-DCBaseTerminal) | |
| DCTopologicalNode [0..1] | [DCTopologicalNode](#CIM17v40-DCTopologicalNode) | see [DCBaseTerminal](CIM17v40-DCBaseTerminal) | |
| connected [0..1] | [Boolean](#CIM17v40-Boolean) | see [ACDCTerminal](#CIM17v40-ACDCTerminal) | |
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | see [ACDCTerminal](#CIM17v40-ACDCTerminal) | |
| BusNameMarker [0..1] | [BusNameMarker](#CIM17v40-BusNameMarker) | see [ACDCTerminal](CIM17v40-ACDCTerminal) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DCTopologicalIsland}
### DCTopologicalIsland

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DCTopologicalIsland {

}

class IdentifiedObject {

}

IdentifiedObject <|-- DCTopologicalIsland : inherits from
```

An electrically connected subset of the network. DC topological islands can change as the current network state changes, e.g. due to:

- disconnect switches or breakers changing state in a SCADA/EMS.

- manual creation, change or deletion of topological nodes in a planning tool.

Only energised TopologicalNode-s shall be part of the topological island.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DCTopologicalNode}
### DCTopologicalNode

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DCTopologicalNode {

}

class IdentifiedObject {

}

IdentifiedObject <|-- DCTopologicalNode : inherits from
class DCEquipmentContainer {

}

DCTopologicalNode --> "0..1" DCEquipmentContainer : DCEquipmentContainer
class DCTopologicalIsland {

}

DCTopologicalNode --> "0..1" DCTopologicalIsland : DCTopologicalIsland
```

DC bus.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DCEquipmentContainer [0..1] | [DCEquipmentContainer](#CIM17v40-DCEquipmentContainer) | The connectivity node container to which the topological node belongs. | |
| `DCTopologicalIsland [0..1]` (OfAggregate) | [DCTopologicalIsland](#CIM17v40-DCTopologicalIsland) | A DC topological node belongs to a DC topological island. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DCvoltageControl}
### (informative) DCvoltageControl


```mermaid
classDiagram
direction TB

class DCvoltageControl {

+ kivdc : PU [0..1]
+ kpvdc : PU [0..1]
+ vdcmax : PU [0..1]
+ vdcmin : PU [0..1]
}

class Delay {

}

DCvoltageControl --> "1" Delay : Delay
class VSCtype1 {

}

DCvoltageControl --> "0..1" VSCtype1 : VSCtype1
```

DC voltage control used for voltage regulation.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kivdc [0..1] | [PU](#CIM17v40-PU) | Integral gain of the DC voltage regulator (Kivdc). | |
| kpvdc [0..1] | [PU](#CIM17v40-PU) | Proportional gain of the DC voltage regulator (Kpvdc). | |
| vdcmax [0..1] | [PU](#CIM17v40-PU) | Maximum DC voltage (Vdcmax). | |
| vdcmin [0..1] | [PU](#CIM17v40-PU) | Minimum DC voltage (Vdcmin). | |
| `Delay [1]` (informative) | [Delay](#CIM17v40-Delay) | | |
| `VSCtype1 [0..1]` (informative) | [VSCtype1](#CIM17v40-VSCtype1) | | |

{#CIM17v40-DERCurveData}
### DERCurveData


```mermaid
classDiagram
direction TB

class DERCurveData {

+ intervalNumber : Integer [0..1]
+ maxYValue : Float [0..1]
+ minYValue : Float [0..1]
+ nominalYValue : Float [0..1]
+ timeStamp : DateTime [0..1]
}

class DERMonitorableParameter {

}

DERCurveData --> "1" DERMonitorableParameter : DERMonitorableParameter
class DispatchSchedule {

}

DERCurveData --> "0..1" DispatchSchedule : DispatchSchedule
```

The DER curve data class provides the nominal, maximum and minimum values for a DER Monitorable parameter for a series of time intervals defined by the DER DispatchSchedule.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalNumber [0..1] | [Integer](#CIM17v40-Integer) | The sequence number of a time interval defined by the DispatchSchedule. | |
| maxYValue [0..1] | [Float](#CIM17v40-Float) | The maximum value of the DERMonitorableParameter during the time interval. | |
| minYValue [0..1] | [Float](#CIM17v40-Float) | The minimum value of the DERMonitorableParameter during the time interval. | |
| nominalYValue [0..1] | [Float](#CIM17v40-Float) | The nominal value of the DERMonitorableParameter during the time interval. | |
| timeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | The start time of the interval | |
| DERMonitorableParameter [1] | [DERMonitorableParameter](#CIM17v40-DERMonitorableParameter) | The DER monitorable parameter for which a time dependent curve has been created. | |
| DispatchSchedule [0..1] | [DispatchSchedule](#CIM17v40-DispatchSchedule) | The schedule used for dispatching or forecasting the values of DER monitorable parameters over time. | |

{#CIM17v40-DERFunction}
### DERFunction


```mermaid
classDiagram
direction TB

class DERFunction {

+ connectDisconnect : Boolean [0..1]
+ frequencyWattCurveFunction : Boolean [0..1]
+ maxRealPowerLimiting : Boolean [0..1]
+ rampRateControl : Boolean [0..1]
+ reactivePowerDispatch : Boolean [0..1]
+ realPowerDispatch : Boolean [0..1]
+ voltageRegulation : Boolean [0..1]
+ voltVarCurveFunction : Boolean [0..1]
+ voltWattCurveFunction : Boolean [0..1]
}

class EndDeviceGroup {

}

DERFunction --> "0..1" EndDeviceGroup : EndDeviceGroup
```

Specifies the list of functions that are supported.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| connectDisconnect [0..1] | [Boolean](#CIM17v40-Boolean) | If set to TRUE, the connect/disconnect function is supported. | |
| frequencyWattCurveFunction [0..1] | [Boolean](#CIM17v40-Boolean) | | |
| maxRealPowerLimiting [0..1] | [Boolean](#CIM17v40-Boolean) | If set to TRUE, the maxRealPowerLimiting function is supported. | |
| rampRateControl [0..1] | [Boolean](#CIM17v40-Boolean) | If set to TRUE, the rampRateControl function is supported. | |
| reactivePowerDispatch [0..1] | [Boolean](#CIM17v40-Boolean) | If set to TRUE, the reactivePowerDispatch function is supported. | |
| realPowerDispatch [0..1] | [Boolean](#CIM17v40-Boolean) | If set to TRUE, the realPowerDispatch function is supported. | |
| voltageRegulation [0..1] | [Boolean](#CIM17v40-Boolean) | If set to TRUE, the voltageRegulation function is supported. | |
| voltVarCurveFunction [0..1] | [Boolean](#CIM17v40-Boolean) | If set to TRUE, the voltVARCurveFunction is supported. | |
| voltWattCurveFunction [0..1] | [Boolean](#CIM17v40-Boolean) | If set to TRUE, the voltWattCurveFunction is supported. | |
| EndDeviceGroup [0..1] | [EndDeviceGroup](#CIM17v40-EndDeviceGroup) | The DER Group supporting the DER functions. | |

{#CIM17v40-DERGroupDispatch}
### DERGroupDispatch

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DERGroupDispatch {

}

class IdentifiedObject {

}

IdentifiedObject <|-- DERGroupDispatch : inherits from
```

Specifies the capabilities of the DER Group that are to be dispatched according to a schedule. Each dispatch identifies a DER Group and the specific monitorable parameter to be dispatched over a specific time interval.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DERGroupForecast}
### DERGroupForecast

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DERGroupForecast {

+ predictionCreationDate : DateTime [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- DERGroupForecast : inherits from
```

Specifies the forecasted values of the DERMonitorableParameters for a DER Group over a specific time interval.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| predictionCreationDate [0..1] | [DateTime](#CIM17v40-DateTime) | The timestamp for when the DER Group forecast was created | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DERMonitorableParameter}
### DERMonitorableParameter


```mermaid
classDiagram
direction TB

class DERMonitorableParameter {

+ DERParameter : enum:DERParameterKind [0..1]
+ flowDirection : enum:FlowDirectionKind [1]
+ yMultiplier : enum:UnitMultiplier [0..1]
+ yUnit : enum:DERUnitSymbol [0..1]
+ yUnitInstalledMax : Float [0..1]
+ yUnitInstalledMin : Float [0..1]
}

class DERCurveData {

}

DERMonitorableParameter --> "0..1" DERCurveData : DERCurveData
```

To define the DER monitorable parameters that will be forecasted and dispatched for a DER Group. Each parameter is represented as a Y Value at a point in time or on a curve as a function of time, which is represented on the X axis.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DERParameter [0..1] | [DERParameterKind](#CIM17v40-DERParameterKind) | Defines the specific engineering value being forecasted or dispatched. | |
| flowDirection [1] | [FlowDirectionKind](#CIM17v40-FlowDirectionKind) | Kind of flow direction for reading/measured values proper to some commodities such as, for example, energy, power, demand. | |
| yMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | The UnitMultiplier that is applied to the DERMonitorableParameter. | |
| yUnit [0..1] | [DERUnitSymbol](#CIM17v40-DERUnitSymbol) | The DERUnitSymbol that is applied to the DERMonitorableParameter | |
| yUnitInstalledMax [0..1] | [Float](#CIM17v40-Float) | The maximum value of the DERMonitorableParameter based on the installed capacity. | |
| yUnitInstalledMin [0..1] | [Float](#CIM17v40-Float) | The minimum value of the DERMonitorableParameter based on the installed capacity. | |
| DERCurveData [0..1] | [DERCurveData](#CIM17v40-DERCurveData) | Specifies the time dependent curve for a DER monitorable parameter | |

{#CIM17v40-DataSet}
### (informative) DataSet


```mermaid
classDiagram
direction TB

class DataSet {

+ mRID : String [0..1]
+ description : String [0..1]
+ name : String [0..1]
}

class AlternateModel {

}

DataSet --> "0..1" AlternateModel : AlternateModel
```

A generic container of a version of instance data. The MRID can be used in an audit trail, not in reusable script intended to work with new versions of data.

A dataset could be serialized multiple times and in multiple technologies, yet retain the same identity.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | Master resource identifier issued by a model authority. The mRID is unique within an exchange context. Global uniqueness is easily achieved by using a UUID, as specified in RFC 4122, for the mRID. The use of UUID is strongly recommended.For CIMXML data files in RDF syntax conforming to IEC 61970-552 Edition 1, the mRID is mapped to rdf:ID or rdf:about attributes that identify CIM object elements. | |
| description [0..1] | [String](#CIM17v40-String) | The description is a free human readable text describing or naming the object. It may be non unique and may not correlate to a naming hierarchy. | |
| name [0..1] | [String](#CIM17v40-String) | The name is any free human readable and possibly non unique text naming the object. | |
| `AlternateModel [0..1]` (informative) | [AlternateModel](#CIM17v40-AlternateModel) | The alternate model using the data. | |

{#CIM17v40-DatasetArg}
### DatasetArg

Inheritance path = [ModelOperationArg](#CIM17v40-ModelOperationArg) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DatasetArg {

}

class ModelOperationArg {

}

ModelOperationArg <|-- DatasetArg : inherits from
class InstanceSet {

}

DatasetArg --> "1" InstanceSet : Dataset
class DatasetArgDescription {

}

DatasetArg --> "1" DatasetArgDescription : OperationDatasetArgDescription
```

A model operation argument referencing a dataset instance.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Dataset [1]` (informative) | [InstanceSet](#CIM17v40-InstanceSet) | Dataset referenced by this argument of a model operation.. | |
| `OperationDatasetArgDescription [1]` (informative) | [DatasetArgDescription](#CIM17v40-DatasetArgDescription) | The type of role for this dataset role. Should only reference role types that belong to the operation type of the associated operation. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | see [ModelOperationArg](#CIM17v40-ModelOperationArg) | |
| `ModelOperation [1]` (informative) | [ModelOperation](#CIM17v40-ModelOperation) | see [ModelOperationArg](CIM17v40-ModelOperationArg) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DatasetArgDescription}
### (informative) DatasetArgDescription

Inheritance path = [ModelOperationArgDescription](#CIM17v40-ModelOperationArgDescription) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DatasetArgDescription {

}

class ModelOperationArgDescription {

}

ModelOperationArgDescription <|-- DatasetArgDescription : inherits from
```


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| multiplicityMaximum [0..1] | [Integer](#CIM17v40-Integer) | see [ModelOperationArgDescription](#CIM17v40-ModelOperationArgDescription) | |
| multiplicityMinimum [0..1] | [Integer](#CIM17v40-Integer) | see [ModelOperationArgDescription](#CIM17v40-ModelOperationArgDescription) | |
| `ModelOperationDefinition [1]` (informative) | [ModelOperationDescription](#CIM17v40-ModelOperationDescription) | see [ModelOperationArgDescription](CIM17v40-ModelOperationArgDescription) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DateAndOrTime}
### DateAndOrTime


```mermaid
classDiagram
direction TB

class DateAndOrTime {

+ date : Date [0..1]
+ time : Time [0..1]
}

```

The date and/or the time.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| date [0..1] | [Date](#CIM17v40-Date) | Date as "yyyy-mm-dd", which conforms with ISO 8601 | |
| time [0..1] | [Time](#CIM17v40-Time) | Time as "hh:mm:ss.sssZ", which conforms with ISO 8601. | |

{#CIM17v40-DayType}
### DayType

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DayType {

}

class IdentifiedObject {

}

IdentifiedObject <|-- DayType : inherits from
```

Group of similar days. For example it could be used to represent weekdays, weekend, or holidays.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DefaultBid}
### DefaultBid

Inheritance path = [Bid](#CIM17v40-Bid) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DefaultBid {

+ bidType : enum:BidType [0..1]
+ minLoadCost : CostRate [0..1]
+ peakFlag : enum:OnOff [0..1]
}

class Bid {

}

Bid <|-- DefaultBid : inherits from
class DefaultBidCurve {

}

DefaultBid --> "0..1" DefaultBidCurve : DefaultBidCurve
class RegisteredResource {

}

DefaultBid --> "1" RegisteredResource : RegisteredResource
```

DefaultBid is a generic class to hold Default Energy Bid, Default Startup Bid, and Default Minimum Load Bid:

Default Energy Bid

A Default Energy Bid is a monotonically increasing staircase function consisting at maximum 10 economic bid segments, or 10 ($/MW, MW) pairs. There are three methods for determining the Default Energy Bid:

<ul>

<li>Cost Based: derived from the Heat Rate or Average Cost multiplied by the Gas Price Index plus 10%.</li>

<li>LMP Based: a weighted average of LMPs in the preceding 90 days.</li>

<li>Negotiated: an amount negotiated with the designated Independent Entity.</li>

</ul>

Default Startup Bid

A Default Startup Bid (DSUB) shall be calculated for each RMR unit based on the Startup Cost stored in the Master File and the applicable GPI and EPI.

Default Minimum Load Bid

A Default Minimum Load Bid (DMLB) shall be calculated for each RMR unit based on the Minimum Load Cost stored in the Master File and the applicable GPI.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| bidType [0..1] | [BidType](#CIM17v40-BidType) | Default bid type such as Default Energy Bid, Default Minimum Load Bid, and Default Startup Bid | |
| minLoadCost [0..1] | [CostRate](#CIM17v40-CostRate) | Minimum load cost in $/hr | |
| peakFlag [0..1] | [OnOff](#CIM17v40-OnOff) | on-peak, off-peak, or all | |
| DefaultBidCurve [0..1] | [DefaultBidCurve](#CIM17v40-DefaultBidCurve) | | |
| RegisteredResource [1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| marketType [0..1] | [MarketType](#CIM17v40-MarketType) | see [Bid](CIM17v40-Bid) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Bid](#CIM17v40-Bid) | |
| stopTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Bid](#CIM17v40-Bid) | |
| ActionRequest [1] | [ActionRequest](#CIM17v40-ActionRequest) | see [Bid](CIM17v40-Bid) | |
| EnergyMarket [1] | [EnergyMarket](#CIM17v40-EnergyMarket) | see [Bid](CIM17v40-Bid) | |
| MarketParticipant [0..1] | [MarketParticipant](#CIM17v40-MarketParticipant) | see [Bid](CIM17v40-Bid) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DefaultBidCurve}
### DefaultBidCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DefaultBidCurve {

+ curveType : String [0..1]
+ debAdderFlag : enum:YesNo [0..1]
}

class Curve {

}

Curve <|-- DefaultBidCurve : inherits from
class DefaultBid {

}

DefaultBidCurve --> "0..1" DefaultBid : DefaultBid
```

Default bid curve for default energy bid curve and default startup curves (cost and time).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveType [0..1] | [String](#CIM17v40-String) | To indicate a type used for a default energy bid curve, such as LMP, cost or consultative based. | |
| debAdderFlag [0..1] | [YesNo](#CIM17v40-YesNo) | Default energy bid adder flag | |
| DefaultBid [0..1] | [DefaultBid](#CIM17v40-DefaultBid) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DefaultBidCurveData}
### DefaultBidCurveData

Inheritance path = [CurveData](#CIM17v40-CurveData)

```mermaid
classDiagram
direction TB

class DefaultBidCurveData {

+ bidSegmentCalcType : enum:BidCalculationBasis [0..1]
}

class CurveData {

}

CurveData <|-- DefaultBidCurveData : inherits from
```

Curve data for default bid curve and startup cost curve.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| bidSegmentCalcType [0..1] | [BidCalculationBasis](#CIM17v40-BidCalculationBasis) | Type of calculation basis used to define the default bid segment curve. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| xvalue [0..1] | [Float](#CIM17v40-Float) | see [CurveData](#CIM17v40-CurveData) | |
| y1value [0..1] | [Float](#CIM17v40-Float) | see [CurveData](#CIM17v40-CurveData) | |
| y2value [0..1] | [Float](#CIM17v40-Float) | see [CurveData](#CIM17v40-CurveData) | |
| y3value [0..1] | [Float](#CIM17v40-Float) | see [CurveData](#CIM17v40-CurveData) | |
| `Curve [1]` (OfAggregate) | [Curve](#CIM17v40-Curve) | see [CurveData](CIM17v40-CurveData) | |

{#CIM17v40-DefaultConstraintLimit}
### DefaultConstraintLimit

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DefaultConstraintLimit {

}

class Curve {

}

Curve <|-- DefaultConstraintLimit : inherits from
class SecurityConstraintSum {

}

DefaultConstraintLimit --> "1" SecurityConstraintSum : SecurityConstraintSum
```

Possibly time-varying max MW or MVA and optionally Min MW limit or MVA limit (Y1 and Y2, respectively) applied as a default value if no specific constraint limits are specified for a contingency analysis. Use CurveSchedule XAxisUnits to specify MW or MVA.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| SecurityConstraintSum [1] | [SecurityConstraintSum](#CIM17v40-SecurityConstraintSum) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Delay}
### (informative) Delay


```mermaid
classDiagram
direction TB

class Delay {

+ tm : Seconds [0..1]
}

class BlockingFunction {

}

Delay --> "0..1" BlockingFunction : BlockingFunction
class DCvoltageControl {

}

Delay --> "0..1" DCvoltageControl : DCvoltageControl
class Pcontrol {

}

Delay --> "0..1" Pcontrol : Pcontrol
class PFmode {

}

Delay --> "0..1" PFmode : PFmode
class Qlimiter {

}

Delay --> "0..1" Qlimiter : Qlimiter
class Qmode {

}

Delay --> "0..1" Qmode : Qmode
class Qregulator {

}

Delay --> "0..1" Qregulator : Qregulator
class Umode {

}

Delay --> "0..1" Umode : Umode
```

All the measurements are filtered by a first lag element with a time constant TM.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| tm [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant. | |
| `BlockingFunction [0..1]` (informative) | [BlockingFunction](#CIM17v40-BlockingFunction) | | |
| `DCvoltageControl [0..1]` (informative) | [DCvoltageControl](#CIM17v40-DCvoltageControl) | | |
| `Pcontrol [0..1]` (informative) | [Pcontrol](#CIM17v40-Pcontrol) | | |
| `PFmode [0..1]` (informative) | [PFmode](#CIM17v40-PFmode) | | |
| `Qlimiter [0..1]` (informative) | [Qlimiter](#CIM17v40-Qlimiter) | | |
| `Qmode [0..1]` (informative) | [Qmode](#CIM17v40-Qmode) | | |
| `Qregulator [0..1]` (informative) | [Qregulator](#CIM17v40-Qregulator) | | |
| `Umode [0..1]` (informative) | [Umode](#CIM17v40-Umode) | | |

{#CIM17v40-DemandResponseProgram}
### DemandResponseProgram

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DemandResponseProgram {

+ type : String [0..1]
+ validityInterval : DateTimeInterval [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- DemandResponseProgram : inherits from
```

Demand response program.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| type [0..1] | [String](#CIM17v40-String) | Type of demand response program; examples are CPP (critical-peak pricing), RTP (real-time pricing), DLC (direct load control), DBP (demand bidding program), BIP (base interruptible program). Note that possible types change a lot and it would be impossible to enumerate them all. | |
| validityInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Interval within which the program is valid. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Design}
### (informative) Design

Inheritance path = [WorkDocument](#CIM17v40-WorkDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Design {

+ costEstimate : Money [0..1]
+ kind : enum:DesignKind [0..1]
+ price : Money [0..1]
}

class WorkDocument {

}

WorkDocument <|-- Design : inherits from
class ErpQuoteLineItem {

}

Design --> "0..1" ErpQuoteLineItem : ErpQuoteLineItem
class Work {

}

Design --> "0..1" Work : Work
```

A design for consideration by customers, potential customers, or internal work.

Note that the Version of design is the revision attribute that is inherited from Document.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| costEstimate [0..1] | [Money](#CIM17v40-Money) | Estimated cost (not price) of design. | |
| kind [0..1] | [DesignKind](#CIM17v40-DesignKind) | Kind of this design. | |
| price [0..1] | [Money](#CIM17v40-Money) | Price to customer for implementing design. | |
| `ErpQuoteLineItem [0..1]` (informative) | [ErpQuoteLineItem](#CIM17v40-ErpQuoteLineItem) | | |
| `Work [0..1]` (informative) | [Work](#CIM17v40-Work) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DesignLocation}
### (informative) DesignLocation

Inheritance path = [WorkIdentifiedObject](#CIM17v40-WorkIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DesignLocation {

+ spanLength : Length [0..1]
+ status : Status [0..1]
}

class WorkIdentifiedObject {

}

WorkIdentifiedObject <|-- DesignLocation : inherits from
```

A logical part of the design (e.g., pole and all equipment on a pole). This includes points and spans.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| spanLength [0..1] | [Length](#CIM17v40-Length) | The legth of the span from the previous pole to this pole. | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DesignLocationCU}
### DesignLocationCU

Inheritance path = [WorkIdentifiedObject](#CIM17v40-WorkIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DesignLocationCU {

+ cuAccount : String [0..1]
+ cuAction : enum:WorkActionKind [0..1]
+ cuUsage : String [0..1]
+ removalDate : Date [0..1]
+ toBeEnergised : Boolean [0..1]
+ cuQuantity : IntegerQuantity [0..1]
+ status : Status [0..1]
}

class WorkIdentifiedObject {

}

WorkIdentifiedObject <|-- DesignLocationCU : inherits from
class DesignLocation {

}

DesignLocationCU --> "0..1" DesignLocation : DesignLocation
```

Compatible unit at a given design location.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| cuAccount [0..1] | [String](#CIM17v40-String) | A code that helps direct accounting (capital, expense, or accounting treatment). | |
| cuAction [0..1] | [WorkActionKind](#CIM17v40-WorkActionKind) | A code that instructs the crew what action to perform. | |
| cuUsage [0..1] | [String](#CIM17v40-String) | As the same CU can be used for different purposes and accounting purposes, usage must be specified. Examples include: distribution, transmission, substation. | |
| removalDate [0..1] | [Date](#CIM17v40-Date) | Year when a CU that represents an asset is removed. | |
| toBeEnergised [0..1] | [Boolean](#CIM17v40-Boolean) | True if associated electrical equipment is intended to be energized while work is being performed. | |
| cuQuantity [0..1] | [IntegerQuantity](#CIM17v40-IntegerQuantity) | The quantity of the CU being assigned to this location. | |
| `DesignLocation [0..1]` (informative) | [DesignLocation](#CIM17v40-DesignLocation) | | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DiagnosisDataSet}
### DiagnosisDataSet

Inheritance path = [ProcedureDataSet](#CIM17v40-ProcedureDataSet) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DiagnosisDataSet {

+ effect : String [0..1]
+ failureMode : String [0..1]
+ finalCause : String [0..1]
+ finalCode : String [0..1]
+ finalOrigin : String [0..1]
+ finalRemark : String [0..1]
+ phaseCode : enum:PhaseCode [0..1]
+ preliminaryCode : String [0..1]
+ preliminaryDateTime : DateTime [0..1]
+ preliminaryRemark : String [0..1]
+ rootCause : String [0..1]
+ rootOrigin : String [0..1]
+ rootRemark : String [0..1]
}

class ProcedureDataSet {

}

ProcedureDataSet <|-- DiagnosisDataSet : inherits from
```

The result of a problem (typically an asset failure) diagnosis. Contains complete information like what might be received from a lab doing forensic analysis of a failed asset.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| effect [0..1] | [String](#CIM17v40-String) | Effect of problem. | |
| failureMode [0..1] | [String](#CIM17v40-String) | Failuer mode, for example: Failure to Insulate; Failure to conduct; Failure to contain oil; Failure to provide ground plane; Other. | |
| finalCause [0..1] | [String](#CIM17v40-String) | Cause of problem determined during diagnosis. | |
| finalCode [0..1] | [String](#CIM17v40-String) | Code for diagnosed probem type. | |
| finalOrigin [0..1] | [String](#CIM17v40-String) | Origin of problem determined during diagnosis. | |
| finalRemark [0..1] | [String](#CIM17v40-String) | Remarks pertaining to findings during problem diagnosis. | |
| phaseCode [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | Phase(s) diagnosed. | |
| preliminaryCode [0..1] | [String](#CIM17v40-String) | Code for problem type determined during preliminary assessment. | |
| preliminaryDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time preliminary assessment of problem was performed. | |
| preliminaryRemark [0..1] | [String](#CIM17v40-String) | Remarks pertaining to preliminary assessment of problem. | |
| rootCause [0..1] | [String](#CIM17v40-String) | Root cause of problem determined during diagnosis. | |
| rootOrigin [0..1] | [String](#CIM17v40-String) | Root origin of problem determined during diagnosis. | |
| rootRemark [0..1] | [String](#CIM17v40-String) | Remarks pertaining to root cause findings during problem diagnosis. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| completedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [ProcedureDataSet](#CIM17v40-ProcedureDataSet) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [ProcedureDataSet](CIM17v40-ProcedureDataSet) | |
| Procedure [0..1] | [Procedure](#CIM17v40-Procedure) | see [ProcedureDataSet](CIM17v40-ProcedureDataSet) | |
| WorkTask [0..1] | [WorkTask](#CIM17v40-WorkTask) | see [ProcedureDataSet](CIM17v40-ProcedureDataSet) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Diagram}
### Diagram

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Diagram {

+ orientation : enum:OrientationKind [0..1]
+ x1InitialView : Float [0..1]
+ x2InitialView : Float [0..1]
+ y1InitialView : Float [0..1]
+ y2InitialView : Float [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Diagram : inherits from
class DiagramStyle {

}

Diagram --> "0..1" DiagramStyle : DiagramStyle
```

The diagram being exchanged. The coordinate system is a standard Cartesian coordinate system and the orientation attribute defines the orientation. The initial view related attributes can be used to specify an initial view with the x,y coordinates of the diagonal points.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| orientation [0..1] | [OrientationKind](#CIM17v40-OrientationKind) | Coordinate system orientation of the diagram. A positive orientation gives standard �right-hand� orientation, with negative orientation indicating a �left-hand� orientation. For 2D diagrams, a positive orientation will result in X values increasing from left to right and Y values increasing from bottom to top. A negative orientation gives the �left-hand� orientation (favoured by computer graphics displays) with X values increasing from left to right and Y values increasing from top to bottom. | |
| x1InitialView [0..1] | [Float](#CIM17v40-Float) | X coordinate of the first corner of the initial view. | |
| x2InitialView [0..1] | [Float](#CIM17v40-Float) | X coordinate of the second corner of the initial view. | |
| y1InitialView [0..1] | [Float](#CIM17v40-Float) | Y coordinate of the first corner of the initial view. | |
| y2InitialView [0..1] | [Float](#CIM17v40-Float) | Y coordinate of the second corner of the initial view. | |
| DiagramStyle [0..1] | [DiagramStyle](#CIM17v40-DiagramStyle) | A Diagram may have a DiagramStyle. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DiagramObject}
### DiagramObject

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DiagramObject {

+ drawingOrder : Integer [0..1]
+ isPolygon : Boolean [0..1]
+ offsetX : Float [0..1]
+ offsetY : Float [0..1]
+ rotation : AngleDegrees [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- DiagramObject : inherits from
class Diagram {

}

DiagramObject --> "0..1" Diagram : Diagram
class DiagramObjectStyle {

}

DiagramObject --> "0..1" DiagramObjectStyle : DiagramObjectStyle
class IdentifiedObject {

}

DiagramObject --> "0..1" IdentifiedObject : IdentifiedObject
```

An object that defines one or more points in a given space. This object can be associated with anything that specializes IdentifiedObject. For single line diagrams such objects typically include such items as analog values, breakers, disconnectors, power transformers, and transmission lines.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| drawingOrder [0..1] | [Integer](#CIM17v40-Integer) | The drawing order of this element. The higher the number, the later the element is drawn in sequence. This is used to ensure that elements that overlap are rendered in the correct order. | |
| isPolygon [0..1] | [Boolean](#CIM17v40-Boolean) | Defines whether or not the diagram objects points define the boundaries of a polygon or the routing of a polyline. If this value is true then a receiving application should consider the first and last points to be connected. | |
| offsetX [0..1] | [Float](#CIM17v40-Float) | The offset in the X direction. This is used for defining the offset from centre for rendering an icon (the default is that a single point specifies the centre of the icon).The offset is in per-unit with 0 indicating there is no offset from the horizontal centre of the icon. -0.5 indicates it is offset by 50% to the left and 0.5 indicates an offset of 50% to the right. | |
| offsetY [0..1] | [Float](#CIM17v40-Float) | The offset in the Y direction. This is used for defining the offset from centre for rendering an icon (the default is that a single point specifies the centre of the icon).The offset is in per-unit with 0 indicating there is no offset from the vertical centre of the icon. The offset direction is dependent on the orientation of the diagram, with -0.5 and 0.5 indicating an offset of +/- 50% on the vertical axis. | |
| rotation [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Sets the angle of rotation of the diagram object. Zero degrees is pointing to the top of the diagram. Rotation is clockwise. DiagramObject.rotation=0 has the following meaning: The connection point of an element which has one terminal is pointing to the top side of the diagram. The connection point "From side" of an element which has more than one terminal is pointing to the top side of the diagram.DiagramObject.rotation=90 has the following meaning: The connection point of an element which has one terminal is pointing to the right hand side of the diagram. The connection point "From side" of an element which has more than one terminal is pointing to the right hand side of the diagram. | |
| Diagram [0..1] | [Diagram](#CIM17v40-Diagram) | A diagram object is part of a diagram. | |
| DiagramObjectStyle [0..1] | [DiagramObjectStyle](#CIM17v40-DiagramObjectStyle) | A diagram object has a style associated that provides a reference for the style used in the originating system. | |
| IdentifiedObject [0..1] | [IdentifiedObject](#CIM17v40-IdentifiedObject) | The domain object to which this diagram object is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DiagramObjectGluePoint}
### DiagramObjectGluePoint


```mermaid
classDiagram
direction TB

class DiagramObjectGluePoint {

}

```

This is used for grouping diagram object points from different diagram objects that are considered to be glued together in a diagram even if they are not at the exact same coordinates.


{#CIM17v40-DiagramObjectPoint}
### DiagramObjectPoint


```mermaid
classDiagram
direction TB

class DiagramObjectPoint {

+ sequenceNumber : Integer [0..1]
+ xPosition : Float [0..1]
+ yPosition : Float [0..1]
+ zPosition : Float [0..1]
}

class DiagramObject {

}

DiagramObjectPoint --> "1" DiagramObject : DiagramObject
class DiagramObjectGluePoint {

}

DiagramObjectPoint --> "0..1" DiagramObjectGluePoint : DiagramObjectGluePoint
```

A point in a given space defined by 3 coordinates and associated to a diagram object. The coordinates may be positive or negative as the origin does not have to be in the corner of a diagram.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | The sequence position of the point, used for defining the order of points for diagram objects acting as a polyline or polygon with more than one point. The attribute shall be a positive value. | |
| xPosition [0..1] | [Float](#CIM17v40-Float) | The X coordinate of this point. | |
| yPosition [0..1] | [Float](#CIM17v40-Float) | The Y coordinate of this point. | |
| zPosition [0..1] | [Float](#CIM17v40-Float) | The Z coordinate of this point. | |
| DiagramObject [1] | [DiagramObject](#CIM17v40-DiagramObject) | The diagram object with which the points are associated. | |
| DiagramObjectGluePoint [0..1] | [DiagramObjectGluePoint](#CIM17v40-DiagramObjectGluePoint) | The 'glue' point to which this point is associated. | |

{#CIM17v40-DiagramObjectStyle}
### DiagramObjectStyle

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DiagramObjectStyle {

}

class IdentifiedObject {

}

IdentifiedObject <|-- DiagramObjectStyle : inherits from
```

A reference to a style used by the originating system for a diagram object. A diagram object style describes information such as line thickness, shape such as circle or rectangle etc, and colour.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DiagramStyle}
### DiagramStyle

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DiagramStyle {

}

class IdentifiedObject {

}

IdentifiedObject <|-- DiagramStyle : inherits from
```

The diagram style refers to a style used by the originating system for a diagram. A diagram style describes information such as schematic, geographic, etc.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DifferentialModel}
### DifferentialModel


```mermaid
classDiagram
direction TB

class DifferentialModel {

}

```

A set of statements describing the changes in the network model. The statement is defined in the incremental model.


{#CIM17v40-DimensionsInfo}
### DimensionsInfo

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DimensionsInfo {

+ orientation : String [0..1]
+ sizeDepth : Length [0..1]
+ sizeDiameter : Length [0..1]
+ sizeLength : Length [0..1]
+ sizeWidth : Length [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- DimensionsInfo : inherits from
```

As applicable, the basic linear, area, or volume dimensions of an asset, asset type (AssetModel) or other type of object (such as land area). Units and multipliers are specified per dimension.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| orientation [0..1] | [String](#CIM17v40-String) | A description of the orientation of the object relative to the dimensions. As an example, a vault may have north-south orientation for the sizeLength measurement and sizeDepth may be the height of the vault. | |
| sizeDepth [0..1] | [Length](#CIM17v40-Length) | Depth measurement. | |
| sizeDiameter [0..1] | [Length](#CIM17v40-Length) | Diameter measurement. | |
| sizeLength [0..1] | [Length](#CIM17v40-Length) | Length measurement. | |
| sizeWidth [0..1] | [Length](#CIM17v40-Length) | Width measurement. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DiscExcContIEEEDEC1A}
### DiscExcContIEEEDEC1A

Inheritance path = [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DiscExcContIEEEDEC1A {

+ esc : PU [0..1]
+ kan : PU [0..1]
+ ketl : PU [0..1]
+ tan : Seconds [0..1]
+ td : Seconds [0..1]
+ tl1 : Seconds [0..1]
+ tl2 : Seconds [0..1]
+ tw5 : Seconds [0..1]
+ val : PU [0..1]
+ vanmax : PU [0..1]
+ vomax : PU [0..1]
+ vomin : PU [0..1]
+ vsmax : PU [0..1]
+ vsmin : PU [0..1]
+ vtc : PU [0..1]
+ vtlmt : PU [0..1]
+ vtm : PU [0..1]
+ vtn : PU [0..1]
}

class DiscontinuousExcitationControlDynamics {

}

DiscontinuousExcitationControlDynamics <|-- DiscExcContIEEEDEC1A : inherits from
```

IEEE type DEC1A discontinuous excitation control model that boosts generator excitation to a level higher than that demanded by the voltage regulator and stabilizer immediately following a system fault.

Reference: IEEE 421.5-2005, 12.2.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| esc [0..1] | [PU](#CIM17v40-PU) | Speed change reference (<i>E</i><i><sub>SC</sub></i>). Typical value = 0,0015. | |
| kan [0..1] | [PU](#CIM17v40-PU) | Discontinuous controller gain (<i>K</i><i><sub>AN</sub></i>). Typical value = 400. | |
| ketl [0..1] | [PU](#CIM17v40-PU) | Terminal voltage limiter gain (<i>K</i><i><sub>ETL</sub></i>). Typical value = 47. | |
| tan [0..1] | [Seconds](#CIM17v40-Seconds) | Discontinuous controller time constant (<i>T</i><i><sub>AN</sub></i>) (&gt;= 0). Typical value = 0,08. | |
| td [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>D</sub></i>) (&gt;= 0). Typical value = 0,03. | |
| tl1 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>L</sub></i><sub>1</sub>) (&gt;= 0). Typical value = 0,025. | |
| tl2 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>L</sub></i><sub>2</sub>) (&gt;= 0). Typical value = 1,25. | |
| tw5 [0..1] | [Seconds](#CIM17v40-Seconds) | DEC washout time constant (<i>T</i><i><sub>W</sub></i><sub>5</sub>) (&gt;= 0). Typical value = 5. | |
| val [0..1] | [PU](#CIM17v40-PU) | Regulator voltage reference (<i>V</i><i><sub>AL</sub></i>). Typical value = 5,5. | |
| vanmax [0..1] | [PU](#CIM17v40-PU) | Limiter for Van (<i>V</i><i><sub>ANMAX</sub></i>). | |
| vomax [0..1] | [PU](#CIM17v40-PU) | Limiter (<i>V</i><i><sub>OMAX</sub></i>) (&gt; DiscExcContIEEEDEC1A.vomin). Typical value = 0,3. | |
| vomin [0..1] | [PU](#CIM17v40-PU) | Limiter (<i>V</i><i><sub>OMIN</sub></i>) (&lt; DiscExcContIEEEDEC1A.vomax). Typical value = 0,1. | |
| vsmax [0..1] | [PU](#CIM17v40-PU) | Limiter (<i>V</i><i><sub>SMAX</sub></i>)(&gt; DiscExcContIEEEDEC1A.vsmin). Typical value = 0,2. | |
| vsmin [0..1] | [PU](#CIM17v40-PU) | Limiter (<i>V</i><i><sub>SMIN</sub></i>) (&lt; DiscExcContIEEEDEC1A.vsmax). Typical value = -0,066. | |
| vtc [0..1] | [PU](#CIM17v40-PU) | Terminal voltage level reference (<i>V</i><i><sub>TC</sub></i>). Typical value = 0,95. | |
| vtlmt [0..1] | [PU](#CIM17v40-PU) | Voltage reference (<i>V</i><i><sub>TLMT</sub></i>). Typical value = 1,1. | |
| vtm [0..1] | [PU](#CIM17v40-PU) | Voltage limits (<i>V</i><i><sub>TM</sub></i>). Typical value = 1,13. | |
| vtn [0..1] | [PU](#CIM17v40-PU) | Voltage limits (<i>V</i><i><sub>TN</sub></i>). Typical value = 1,12. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [DiscontinuousExcitationControlDynamics](CIM17v40-DiscontinuousExcitationControlDynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [DiscontinuousExcitationControlDynamics](CIM17v40-DiscontinuousExcitationControlDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DiscExcContIEEEDEC2A}
### DiscExcContIEEEDEC2A

Inheritance path = [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DiscExcContIEEEDEC2A {

+ td1 : Seconds [0..1]
+ td2 : Seconds [0..1]
+ vdmax : PU [0..1]
+ vdmin : PU [0..1]
+ vk : PU [0..1]
}

class DiscontinuousExcitationControlDynamics {

}

DiscontinuousExcitationControlDynamics <|-- DiscExcContIEEEDEC2A : inherits from
```

IEEE type DEC2A model for discontinuous excitation control. This system provides transient excitation boosting via an open-loop control as initiated by a trigger signal generated remotely.

Reference: IEEE 421.5-2005 12.3.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| td1 [0..1] | [Seconds](#CIM17v40-Seconds) | Discontinuous controller time constant (<i>T</i><i><sub>D1</sub></i>) (&gt;= 0). | |
| td2 [0..1] | [Seconds](#CIM17v40-Seconds) | Discontinuous controller washout time constant (<i>T</i><i><sub>D2</sub></i>) (&gt;= 0). | |
| vdmax [0..1] | [PU](#CIM17v40-PU) | Limiter (<i>V</i><i><sub>DMAX</sub></i>) (&gt; DiscExcContIEEEDEC2A.vdmin). | |
| vdmin [0..1] | [PU](#CIM17v40-PU) | Limiter (<i>V</i><i><sub>DMIN</sub></i>) (&lt; DiscExcContIEEEDEC2A.vdmax). | |
| vk [0..1] | [PU](#CIM17v40-PU) | Discontinuous controller input reference (<i>V</i><i><sub>K</sub></i>). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [DiscontinuousExcitationControlDynamics](CIM17v40-DiscontinuousExcitationControlDynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [DiscontinuousExcitationControlDynamics](CIM17v40-DiscontinuousExcitationControlDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DiscExcContIEEEDEC3A}
### DiscExcContIEEEDEC3A

Inheritance path = [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DiscExcContIEEEDEC3A {

+ tdr : Seconds [0..1]
+ vtmin : PU [0..1]
}

class DiscontinuousExcitationControlDynamics {

}

DiscontinuousExcitationControlDynamics <|-- DiscExcContIEEEDEC3A : inherits from
```

IEEE type DEC3A model. In some systems, the stabilizer output is disconnected from the regulator immediately following a severe fault to prevent the stabilizer from competing with action of voltage regulator during the first swing.

Reference: IEEE 421.5-2005 12.4.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| tdr [0..1] | [Seconds](#CIM17v40-Seconds) | Reset time delay (<i>T</i><i><sub>DR</sub></i>) (&gt;= 0). | |
| vtmin [0..1] | [PU](#CIM17v40-PU) | Terminal undervoltage comparison level (<i>V</i><i><sub>TMIN</sub></i>). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [DiscontinuousExcitationControlDynamics](CIM17v40-DiscontinuousExcitationControlDynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [DiscontinuousExcitationControlDynamics](CIM17v40-DiscontinuousExcitationControlDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DisconnectingCircuitBreaker}
### DisconnectingCircuitBreaker

Inheritance path = [Breaker](#CIM17v40-Breaker) => [ProtectedSwitch](#CIM17v40-ProtectedSwitch) => [Switch](#CIM17v40-Switch) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DisconnectingCircuitBreaker {

}

class Breaker {

}

Breaker <|-- DisconnectingCircuitBreaker : inherits from
```

A circuit breaking device including disconnecting function, eliminating the need for separate disconnectors.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| inTransitTime [0..1] | [Seconds](#CIM17v40-Seconds) | see [Breaker](CIM17v40-Breaker) | |
| breakingCapacity [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [ProtectedSwitch](CIM17v40-ProtectedSwitch) | |
| locked [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| normalOpen [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| open [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [Switch](CIM17v40-Switch) | |
| retained [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| `switchOnCount [0..1]` (deprecated) | [Integer](#CIM17v40-Integer) | see [Switch](#CIM17v40-Switch) | |
| `switchOnDate [0..1]` (deprecated) | [DateTime](#CIM17v40-DateTime) | see [Switch](#CIM17v40-Switch) | |
| `CompositeSwitch [0..1]` (OfAggregate) | [CompositeSwitch](#CIM17v40-CompositeSwitch) | see [Switch](CIM17v40-Switch) | |
| SwitchAction [0..1] | [SwitchAction](#CIM17v40-SwitchAction) | see [Switch](CIM17v40-Switch) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Disconnector}
### Disconnector

Inheritance path = [Switch](#CIM17v40-Switch) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Disconnector {

}

class Switch {

}

Switch <|-- Disconnector : inherits from
```

A manually operated or motor operated mechanical switching device used for changing the connections in a circuit, or for isolating a circuit or equipment from a source of power. It is required to open or close circuits when negligible current is broken or made.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| locked [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| normalOpen [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| open [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [Switch](CIM17v40-Switch) | |
| retained [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| `switchOnCount [0..1]` (deprecated) | [Integer](#CIM17v40-Integer) | see [Switch](#CIM17v40-Switch) | |
| `switchOnDate [0..1]` (deprecated) | [DateTime](#CIM17v40-DateTime) | see [Switch](#CIM17v40-Switch) | |
| `CompositeSwitch [0..1]` (OfAggregate) | [CompositeSwitch](#CIM17v40-CompositeSwitch) | see [Switch](CIM17v40-Switch) | |
| SwitchAction [0..1] | [SwitchAction](#CIM17v40-SwitchAction) | see [Switch](CIM17v40-Switch) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DiscontinuousExcitationControlDynamics}
### DiscontinuousExcitationControlDynamics

Inheritance path = [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DiscontinuousExcitationControlDynamics {

}

class DynamicsFunctionBlock {

}

DynamicsFunctionBlock <|-- DiscontinuousExcitationControlDynamics : inherits from
class ExcitationSystemDynamics {

}

DiscontinuousExcitationControlDynamics --> "1" ExcitationSystemDynamics : ExcitationSystemDynamics
class RemoteInputSignal {

}

DiscontinuousExcitationControlDynamics --> "0..1" RemoteInputSignal : RemoteInputSignal
```

Discontinuous excitation control function block whose behaviour is described by reference to a standard model <font color="#0f0f0f">or by definition of a user-defined model</font>.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | Excitation system model with which this discontinuous excitation control model is associated. | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | Remote input signal used by this discontinuous excitation control system model. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DiscontinuousExcitationControlUserDefined}
### DiscontinuousExcitationControlUserDefined

Inheritance path = [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DiscontinuousExcitationControlUserDefined {

+ proprietary : Boolean [0..1]
}

class DiscontinuousExcitationControlDynamics {

}

DiscontinuousExcitationControlDynamics <|-- DiscontinuousExcitationControlUserDefined : inherits from
```

Discontinuous excitation control function block whose dynamic behaviour is described by <font color="#0f0f0f">a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| proprietary [0..1] | [Boolean](#CIM17v40-Boolean) | Behaviour is based on a proprietary model as opposed to a detailed model.true = user-defined model is proprietary with behaviour mutually understood by sending and receiving applications and parameters passed as general attributesfalse = user-defined model is explicitly defined in terms of control blocks and their input and output signals. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [DiscontinuousExcitationControlDynamics](CIM17v40-DiscontinuousExcitationControlDynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [DiscontinuousExcitationControlDynamics](CIM17v40-DiscontinuousExcitationControlDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Discrete}
### Discrete

Inheritance path = [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Discrete {

+ maxValue : Integer [0..1]
+ minValue : Integer [0..1]
+ normalValue : Integer [0..1]
}

class Measurement {

}

Measurement <|-- Discrete : inherits from
class ValueAliasSet {

}

Discrete --> "0..1" ValueAliasSet : ValueAliasSet
```

Discrete represents a discrete Measurement, i.e. a Measurement representing discrete values, e.g. a Breaker position.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maxValue [0..1] | [Integer](#CIM17v40-Integer) | Normal value range maximum for any of the MeasurementValue.values. Used for scaling, e.g. in bar graphs or of telemetered raw values. | |
| minValue [0..1] | [Integer](#CIM17v40-Integer) | Normal value range minimum for any of the MeasurementValue.values. Used for scaling, e.g. in bar graphs or of telemetered raw values. | |
| normalValue [0..1] | [Integer](#CIM17v40-Integer) | Normal measurement value, e.g., used for percentage calculations. | |
| ValueAliasSet [0..1] | [ValueAliasSet](#CIM17v40-ValueAliasSet) | The ValueAliasSet used for translation of a MeasurementValue.value to a name. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DiscreteMeasurementValueQuality}
### DiscreteMeasurementValueQuality

Inheritance path = [MeasurementValueQuality](#CIM17v40-MeasurementValueQuality) => [Quality61850](#CIM17v40-Quality61850)

```mermaid
classDiagram
direction TB

class DiscreteMeasurementValueQuality {

+ manualReplaceIndicator : Boolean [0..1]
+ removeFromOperationIndicator : Boolean [0..1]
}

class MeasurementValueQuality {

}

MeasurementValueQuality <|-- DiscreteMeasurementValueQuality : inherits from
```

Measurement quality flags for Discrete Values.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| manualReplaceIndicator [0..1] | [Boolean](#CIM17v40-Boolean) | Switch Manual Replace Indicator. Flag indicating that the switch is manual replace. | |
| removeFromOperationIndicator [0..1] | [Boolean](#CIM17v40-Boolean) | Removed From Operation Indicator. Flag indicating that the switch is removed from operation. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `MeasurementValue [1]` (OfAggregate) | [MeasurementValue](#CIM17v40-MeasurementValue) | see [MeasurementValueQuality](CIM17v40-MeasurementValueQuality) | |
| badReference [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| estimatorReplaced [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| failure [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| oldData [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| operatorBlocked [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| oscillatory [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| outOfRange [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| overFlow [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| source [0..1] | [Source](#CIM17v40-Source) | see [Quality61850](CIM17v40-Quality61850) | |
| suspect [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| test [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| validity [0..1] | [Validity](#CIM17v40-Validity) | see [Quality61850](CIM17v40-Quality61850) | |

{#CIM17v40-DiscreteValue}
### DiscreteValue

Inheritance path = [MeasurementValue](#CIM17v40-MeasurementValue) => [IOPoint](#CIM17v40-IOPoint) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DiscreteValue {

+ value : Integer [0..1]
}

class MeasurementValue {

}

MeasurementValue <|-- DiscreteValue : inherits from
class Command {

}

DiscreteValue --> "0..1" Command : Command
class Discrete {

}

DiscreteValue --> "1" Discrete : Discrete
```

DiscreteValue represents a discrete MeasurementValue.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| value [0..1] | [Integer](#CIM17v40-Integer) | The value to supervise. | |
| Command [0..1] | [Command](#CIM17v40-Command) | The Control variable associated with the MeasurementValue. | |
| Discrete [1] | [Discrete](#CIM17v40-Discrete) | Measurement to which this value is connected. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| sensorAccuracy [0..1] | [PerCent](#CIM17v40-PerCent) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| timeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | see [MeasurementValue](#CIM17v40-MeasurementValue) | |
| `CalculationMethodHierarchy [0..1]` (harmonization) | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| `ErpPerson [0..1]` (informative) | [OldPerson](#CIM17v40-OldPerson) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| `MeasurementValueQuality [0..1]` (AggregateOf) | [MeasurementValueQuality](#CIM17v40-MeasurementValueQuality) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| MeasurementValueSource [1] | [MeasurementValueSource](#CIM17v40-MeasurementValueSource) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| RemoteSource [0..1] | [RemoteSource](#CIM17v40-RemoteSource) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| IOPointSource [0..1] | [IOPointSource](#CIM17v40-IOPointSource) | see [IOPoint](CIM17v40-IOPoint) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DispatchInstReply}
### DispatchInstReply

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DispatchInstReply {

+ acceptMW : ActivePower [0..1]
+ acceptStatus : enum:DispatchResponseType [0..1]
+ certificationName : String [0..1]
+ clearedMW : ActivePower [0..1]
+ instructionTime : DateTime [0..1]
+ instructionType : String [0..1]
+ passIndicator : enum:PassIndicatorType [0..1]
+ receivedTime : DateTime [0..1]
+ startTime : DateTime [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- DispatchInstReply : inherits from
class RegisteredResource {

}

DispatchInstReply --> "1" RegisteredResource : RegisteredResource
```

Response from registered resource acknowledging receipt of dispatch instructions.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| acceptMW [0..1] | [ActivePower](#CIM17v40-ActivePower) | The accepted mw amount by the responder. aka response mw. | |
| acceptStatus [0..1] | [DispatchResponseType](#CIM17v40-DispatchResponseType) | The accept status submitted by the responder. enumeration type needs to be defined | |
| certificationName [0..1] | [String](#CIM17v40-String) | The Subject DN is the X509 Certificate Subject DN. This is the essentially the certificate name presented by the client. In the case of ADS Certificates, this will be the user name. It may be from an API Client or the MP Client (GUI).The Subject ID normally includes more than just the user name (Common Name), it can also contain information such as City, Company ID, etc. | |
| clearedMW [0..1] | [ActivePower](#CIM17v40-ActivePower) | MW amount associated with instruction. For 5 minute binding dispatches, this is the Goto MW or DOT | |
| instructionTime [0..1] | [DateTime](#CIM17v40-DateTime) | The target date/time for the received instruction. | |
| instructionType [0..1] | [String](#CIM17v40-String) | instruction type:commitmentout of sequencedispatch | |
| passIndicator [0..1] | [PassIndicatorType](#CIM17v40-PassIndicatorType) | The type of run for the market clearing. | |
| receivedTime [0..1] | [DateTime](#CIM17v40-DateTime) | Timestamp indicating the time at which the instruction was received. | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | start time | |
| RegisteredResource [1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DispatchSchedule}
### DispatchSchedule


```mermaid
classDiagram
direction TB

class DispatchSchedule {

+ confidence : PerCent [0..1]
+ curveStyleKind : enum:CurveStyle [0..1]
+ numberOfIntervals : Integer [0..1]
+ startTime : DateTime [0..1]
+ timeIntervalDuration : Integer [0..1]
+ timeIntervalUnit : enum:TimeIntervalKind [0..1]
}

class DERMonitorableParameter {

}

DispatchSchedule --> "1" DERMonitorableParameter : DERMonitorableParameter
```

Specifies the characteristics of the time schedule over which DERMonitorableParameters are dispatched.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| confidence [0..1] | [PerCent](#CIM17v40-PerCent) | A value set by the system, function, algorithm or person creating a prediction as to how accurate the prediction is. | |
| curveStyleKind [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | Used to specify whether the values over an interval are constant (constantYValue) or linearly interpolated (straightLineYValues) | |
| numberOfIntervals [0..1] | [Integer](#CIM17v40-Integer) | Used to specify the number of intervals when requesting a forecast or a dispatch. | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | The start time of the first interval in the dispatch schedule | |
| timeIntervalDuration [0..1] | [Integer](#CIM17v40-Integer) | The length of time for each interval in the dispatch schedule. | |
| timeIntervalUnit [0..1] | [TimeIntervalKind](#CIM17v40-TimeIntervalKind) | The unit of measure for the time axis of the dispatch schedule. | |
| DERMonitorableParameter [1] | [DERMonitorableParameter](#CIM17v40-DERMonitorableParameter) | The DER monitorable parameter included in the DER dispatch schedule. | |

{#CIM17v40-DistributedResourceActualEvent}
### (IRC-DR) DistributedResourceActualEvent

Inheritance path = [MarketActualEvent](#CIM17v40-MarketActualEvent) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DistributedResourceActualEvent {

+ totalPowerAdjustment : ActivePower [0..1]
}

class MarketActualEvent {

}

MarketActualEvent <|-- DistributedResourceActualEvent : inherits from
```

A demand response event is created when there is a need to call upon resources to respond to demand adjustment requests. These events are created by ISO/RTO system operations and managed by a demand response management system (DRMS). These events may or may not be coordinated with the Market Events and a defined Energy Market. The event will call for the deployment of a number of registered resources, or for deployment of resources within a zone (an organizational area within the power system that contains a number of resources).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| totalPowerAdjustment [0..1] | [ActivePower](#CIM17v40-ActivePower) | Total active power adjustment (e.g. load reduction) requested for this demand response event. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| eventComments [0..1] | [String](#CIM17v40-String) | see [MarketActualEvent](#CIM17v40-MarketActualEvent) | |
| eventEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketActualEvent](#CIM17v40-MarketActualEvent) | |
| eventStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketActualEvent](#CIM17v40-MarketActualEvent) | |
| eventStatus [1] | [MarketEventStatusKind](#CIM17v40-MarketEventStatusKind) | see [MarketActualEvent](CIM17v40-MarketActualEvent) | |
| eventType [0..1] | [String](#CIM17v40-String) | see [MarketActualEvent](#CIM17v40-MarketActualEvent) | |
| MarketRun [0..1] | [MarketRun](#CIM17v40-MarketRun) | see [MarketActualEvent](CIM17v40-MarketActualEvent) | |
| PlannedMarketEvent [0..1] | [PlannedMarketEvent](#CIM17v40-PlannedMarketEvent) | see [MarketActualEvent](CIM17v40-MarketActualEvent) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DistributionFactorSet}
### DistributionFactorSet


```mermaid
classDiagram
direction TB

class DistributionFactorSet {

+ intervalEndTime : DateTime [0..1]
+ intervalStartTime : DateTime [0..1]
+ marketType : enum:MarketType [0..1]
}

```

A containing class that groups all the distribution factors within a market.

This is calculated daily for DA factors and hourly for RT factors.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | The end of the time interval for which requirement is defined. | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | The start of the time interval for which requirement is defined. | |
| marketType [0..1] | [MarketType](#CIM17v40-MarketType) | Market type. | |

{#CIM17v40-Document}
### Document

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Document {

+ authorName : String [0..1]
+ comment : String [0..1]
+ createdDateTime : DateTime [0..1]
+ lastModifiedDateTime : DateTime [0..1]
+ revisionNumber : String [0..1]
+ subject : String [0..1]
+ title : String [0..1]
+ type : String [0..1]
+ docStatus : Status [0..1]
+ electronicAddress : ElectronicAddress [0..1]
+ status : Status [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Document : inherits from
class Approver {

}

Document --> "0..1" Approver : Approver
class Author {

}

Document --> "0..1" Author : Author
class Editor {

}

Document --> "0..1" Editor : Editor
class Issuer {

}

Document --> "0..1" Issuer : Issuer
```

Parent class for different groupings of information collected and managed as a part of a business process. It will frequently contain references to other objects, such as assets, people and power system resources.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | Name of the author of this document. | |
| comment [0..1] | [String](#CIM17v40-String) | Free text comment. | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time that this document was created. | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time this document was last modified. Documents may potentially be modified many times during their lifetime. | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | Revision number for this document. | |
| subject [0..1] | [String](#CIM17v40-String) | Document subject. | |
| title [0..1] | [String](#CIM17v40-String) | Document title. | |
| type [0..1] | [String](#CIM17v40-String) | Utility-specific classification of this document, according to its corporate standards, practices, and existing IT systems (e.g., for management of assets, maintenance, work, outage, customers, etc.). | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | Approver of this document. | |
| Author [0..1] | [Author](#CIM17v40-Author) | Author of this document. | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | Status of this document. For status of subject matter this document represents (e.g., Agreement, Work), use 'status' attribute.Example values for 'docStatus.status' are draft, approved, cancelled, etc. | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | Editor of this document. | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | Electronic address. | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | Issuer of this document. | |
| status [0..1] | [Status](#CIM17v40-Status) | Status of subject matter (e.g., Agreement, Work) this document represents. For status of the document itself, use 'docStatus' attribute. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DocumentOrganisationRole}
### DocumentOrganisationRole

Inheritance path = [OrganisationRole](#CIM17v40-OrganisationRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DocumentOrganisationRole {

}

class OrganisationRole {

}

OrganisationRole <|-- DocumentOrganisationRole : inherits from
```

Role an organisation plays with respect to documents.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Organisation [0..1] | [Organisation](#CIM17v40-Organisation) | see [OrganisationRole](CIM17v40-OrganisationRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DocumentPersonRole}
### DocumentPersonRole

Inheritance path = [PersonRole](#CIM17v40-PersonRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DocumentPersonRole {

}

class PersonRole {

}

PersonRole <|-- DocumentPersonRole : inherits from
```

Person role with respect to documents.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Person [0..1] | [Person](#CIM17v40-Person) | see [PersonRole](CIM17v40-PersonRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Domain}
### Domain

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Domain {

}

class IdentifiedObject {

}

IdentifiedObject <|-- Domain : inherits from
```

An area of activity defined within the energy market.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DopInstruction}
### DopInstruction


```mermaid
classDiagram
direction TB

class DopInstruction {

+ mwDOP : ActivePower [0..1]
+ plotPriority : Integer [0..1]
+ runIndicatorDOP : enum:YesNo [0..1]
+ timestampDOP : DateTime [0..1]
+ updateTimeStamp : DateTime [0..1]
+ updateType : enum:MQSCHGType [0..1]
+ updateUser : String [0..1]
}

class RegisteredResource {

}

DopInstruction --> "0..1" RegisteredResource : RegisteredResouce
```

Provides the necessary information (on a resource basis) to capture the Dispatch Operating Point (DOP) results on a Dispatch interval. This information is only relevant to the RT interval market.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mwDOP [0..1] | [ActivePower](#CIM17v40-ActivePower) | Dispatched Operating Point (MW) | |
| plotPriority [0..1] | [Integer](#CIM17v40-Integer) | A value used to establish priority of the DOP when plotting. This is only applicable when two DOPs exist for the same time, but with different MW values. E.g. when indicating a step in the curve. Its used to determine if the curve steps up or down. | |
| runIndicatorDOP [0..1] | [YesNo](#CIM17v40-YesNo) | Indication of DOP validity.Shows the DOP is calculated from the latest run (YES). A NO indicator shows that the DOP is copied from a previous execution.Up to 2 intervals can be missed. | |
| timestampDOP [0..1] | [DateTime](#CIM17v40-DateTime) | DOP time stamp | |
| updateTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| updateType [0..1] | [MQSCHGType](#CIM17v40-MQSCHGType) | | |
| updateUser [0..1] | [String](#CIM17v40-String) | | |
| RegisteredResouce [0..1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |

{#CIM17v40-DotInstruction}
### DotInstruction


```mermaid
classDiagram
direction TB

class DotInstruction {

+ actualRampRate : Float [0..1]
+ compliantIndicator : enum:YesNo [0..1]
+ DOT : Float [0..1]
+ economicMaxOverride : Float [0..1]
+ expectedEnergy : Float [0..1]
+ generatorPerformanceDegree : Float [0..1]
+ hourAheadSchedEnergy : Float [0..1]
+ hourlySchedule : Float [0..1]
+ instructionTime : DateTime [0..1]
+ maximumEmergencyInd : Boolean [0..1]
+ meterLoadFollowing : Float [0..1]
+ nonRampRestrictedMW : Float [0..1]
+ nonSpinReserve : Float [0..1]
+ previousDOTTimeStamp : DateTime [0..1]
+ rampRateLimit : Float [0..1]
+ regulationStatus : enum:YesNo [0..1]
+ spinReserve : Float [0..1]
+ standardRampEnergy : Float [0..1]
+ supplementalEnergy : Float [0..1]
+ unitStatus : Integer [0..1]
}

class RegisteredResource {

}

DotInstruction --> "0..1" RegisteredResource : RegisteredResource
```

Provides the necessary information (on a resource basis) to capture the Dispatch Operating Target (DOT) results on a Dispatch interval. This information is only relevant to the RT interval market.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| actualRampRate [0..1] | [Float](#CIM17v40-Float) | Actual ramp rate. | |
| compliantIndicator [0..1] | [YesNo](#CIM17v40-YesNo) | Flag indicating whether or not the resource was in compliance with the instruction (plus/minus 10%).Directs if a unit is allowed to set the price (ex-post pricing). | |
| DOT [0..1] | [Float](#CIM17v40-Float) | Dispatch operating target value. | |
| economicMaxOverride [0..1] | [Float](#CIM17v40-Float) | Economic Max Limit override for unit, this value is null, if it is not, this value overrides the Energy column value.Allows dispatcher to override the unit's energy value. | |
| expectedEnergy [0..1] | [Float](#CIM17v40-Float) | Expected energy. | |
| generatorPerformanceDegree [0..1] | [Float](#CIM17v40-Float) | The Degree of Generator Performance (DGP) used for the unit. Measure of how a generator responds to raise /lower signals. Calculated every five minutes. | |
| hourAheadSchedEnergy [0..1] | [Float](#CIM17v40-Float) | HASP results. | |
| hourlySchedule [0..1] | [Float](#CIM17v40-Float) | Hourly Schedule (DA Energy Schedule). | |
| instructionTime [0..1] | [DateTime](#CIM17v40-DateTime) | The date/time for the instruction. | |
| maximumEmergencyInd [0..1] | [Boolean](#CIM17v40-Boolean) | True if maximum emergency limit activated; false otherwise. If unit is requested to move up to its max emergency limit., this flag is set to true. | |
| meterLoadFollowing [0..1] | [Float](#CIM17v40-Float) | Meter Sub System Load Following. | |
| nonRampRestrictedMW [0..1] | [Float](#CIM17v40-Float) | Desired MW that is not ramp restricted. If no ramp rate limit existed for the unit, this is the MW value tha t the unit was requested to move to. | |
| nonSpinReserve [0..1] | [Float](#CIM17v40-Float) | Non Spin Reserve used to procure energy. | |
| previousDOTTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | Timestamp when the previous DOT value was issued. | |
| rampRateLimit [0..1] | [Float](#CIM17v40-Float) | The ramp rate limit for the unit in MWs per minute. Participant bidding data. | |
| regulationStatus [0..1] | [YesNo](#CIM17v40-YesNo) | Regulation Status (Yes/No). | |
| spinReserve [0..1] | [Float](#CIM17v40-Float) | Spin Reserve used to procure energy. | |
| standardRampEnergy [0..1] | [Float](#CIM17v40-Float) | Standard ramping energy (MWH). | |
| supplementalEnergy [0..1] | [Float](#CIM17v40-Float) | Supplemental Energy procure by Real Time Dispatch. | |
| unitStatus [0..1] | [Integer](#CIM17v40-Integer) | Output results from the case identifying the reason the unit was committed by the software. | |
| RegisteredResource [0..1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |

{#CIM17v40-DrumBoiler}
### DrumBoiler

Inheritance path = [FossilSteamSupply](#CIM17v40-FossilSteamSupply) => [SteamSupply](#CIM17v40-SteamSupply) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DrumBoiler {

+ drumBoilerRating : Float [0..1]
}

class FossilSteamSupply {

}

FossilSteamSupply <|-- DrumBoiler : inherits from
```

Drum boiler.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| drumBoilerRating [0..1] | [Float](#CIM17v40-Float) | Rating of drum boiler in steam units. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| auxPowerVersusFrequency [0..1] | [PU](#CIM17v40-PU) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| auxPowerVersusVoltage [0..1] | [PU](#CIM17v40-PU) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| boilerControlMode [0..1] | [BoilerControlMode](#CIM17v40-BoilerControlMode) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| controlErrorBiasP [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| controlIC [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| controlPC [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| controlPEB [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| controlPED [0..1] | [PU](#CIM17v40-PU) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| controlTC [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| feedWaterIG [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| feedWaterPG [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| feedWaterTC [0..1] | [Seconds](#CIM17v40-Seconds) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| fuelDemandLimit [0..1] | [PU](#CIM17v40-PU) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| fuelSupplyDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| fuelSupplyTC [0..1] | [Seconds](#CIM17v40-Seconds) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| maxErrorRateP [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| mechPowerSensorLag [0..1] | [Seconds](#CIM17v40-Seconds) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| minErrorRateP [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| pressureCtrlDG [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| pressureCtrlIG [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| pressureCtrlPG [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| pressureFeedback [0..1] | [Integer](#CIM17v40-Integer) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| superHeater1Capacity [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| superHeater2Capacity [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| superHeaterPipePD [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| throttlePressureSP [0..1] | [PU](#CIM17v40-PU) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| steamSupplyRating [0..1] | [Float](#CIM17v40-Float) | see [SteamSupply](#CIM17v40-SteamSupply) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DuctBank}
### (informative) DuctBank

Inheritance path = [AssetContainer](#CIM17v40-AssetContainer) => [Asset](#CIM17v40-Asset) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DuctBank {

+ circuitCount : Integer [0..1]
}

class AssetContainer {

}

AssetContainer <|-- DuctBank : inherits from
```

A duct contains individual wires in the layout as specified with associated wire spacing instances; number of them gives the number of conductors in this duct.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| circuitCount [0..1] | [Integer](#CIM17v40-Integer) | Number of circuits in duct bank. Refer to associations between a duct (ConductorAsset) and an ACLineSegment to understand which circuits are in which ducts. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | see [Asset](#CIM17v40-Asset) | |
| initialCondition [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | see [Asset](CIM17v40-Asset) | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | see [Asset](CIM17v40-Asset) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [Asset](CIM17v40-Asset) | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | see [Asset](CIM17v40-Asset) | |
| lotNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| position [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | see [Asset](CIM17v40-Asset) | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | see [Asset](CIM17v40-Asset) | |
| serialNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| type [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| utcNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | see [Asset](CIM17v40-Asset) | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | see [Asset](CIM17v40-Asset) | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | see [Asset](CIM17v40-Asset) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [Asset](CIM17v40-Asset) | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | see [Asset](CIM17v40-Asset) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Asset](CIM17v40-Asset) | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | see [Asset](CIM17v40-Asset) | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | see [Asset](CIM17v40-Asset) | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | see [Asset](CIM17v40-Asset) | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | see [Asset](CIM17v40-Asset) | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | see [Asset](CIM17v40-Asset) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Asset](CIM17v40-Asset) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [Asset](CIM17v40-Asset) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [Asset](CIM17v40-Asset) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Asset](CIM17v40-Asset) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DynamicSchedule}
### DynamicSchedule

Inheritance path = [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DynamicSchedule {

+ dynSchedSignRev : Boolean [0..1]
+ dynSchedStatus : String [0..1]
}

class BasicIntervalSchedule {

}

BasicIntervalSchedule <|-- DynamicSchedule : inherits from
class MktMeasurement {

}

DynamicSchedule --> "1" MktMeasurement : MktMeasurement
class SubControlArea {

}

DynamicSchedule --> "1" SubControlArea : Receive_SubControlArea
class SubControlArea {

}

DynamicSchedule --> "1" SubControlArea : Send_SubControlArea
```

A continuously variable component of a control area's MW net interchange schedule. Dynamic schedules are sent and received by control areas.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dynSchedSignRev [0..1] | [Boolean](#CIM17v40-Boolean) | Dynamic schedule sign reversal required (true/false) | |
| dynSchedStatus [0..1] | [String](#CIM17v40-String) | The "active" or "inactive" status of the dynamic schedule | |
| `MktMeasurement [1]` (informative) | [MktMeasurement](#CIM17v40-MktMeasurement) | | |
| `Receive_SubControlArea [1]` (informative) | [SubControlArea](#CIM17v40-SubControlArea) | A control area can receive dynamic schedules from other control areas | |
| `Send_SubControlArea [1]` (informative) | [SubControlArea](#CIM17v40-SubControlArea) | A control area can send dynamic schedules to other control areas | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-DynamicsFunctionBlock}
### DynamicsFunctionBlock

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class DynamicsFunctionBlock {

+ enabled : Boolean [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- DynamicsFunctionBlock : inherits from
```

Abstract parent class for all Dynamics function blocks.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | Function block used indicator.true = use of function block is enabledfalse = use of function block is disabled. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EarthFaultCompensator}
### EarthFaultCompensator

Inheritance path = [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EarthFaultCompensator {

+ r : Resistance [0..1]
}

class ConductingEquipment {

}

ConductingEquipment <|-- EarthFaultCompensator : inherits from
```

A conducting equipment used to represent a connection to ground which is typically used to compensate earth faults. An earth fault compensator device modelled with a single terminal implies a second terminal solidly connected to ground. If two terminals are modelled, the ground is not assumed and normal connection rules apply.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| r [0..1] | [Resistance](#CIM17v40-Resistance) | Nominal resistance of device. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Earthquake}
### Earthquake

Inheritance path = [GeosphericPhenomenon](#CIM17v40-GeosphericPhenomenon) => [EnvironmentalPhenomenon](#CIM17v40-EnvironmentalPhenomenon)

```mermaid
classDiagram
direction TB

class Earthquake {

+ intensity : Integer [0..1]
+ magnitude : Float [0..1]
+ focalDepth : RelativeDisplacement [0..1]
}

class GeosphericPhenomenon {

}

GeosphericPhenomenon <|-- Earthquake : inherits from
```

An earthquake.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intensity [0..1] | [Integer](#CIM17v40-Integer) | The intensity of the earthquake as defined by the Modified Mercalli Intensity (MMI) scale. Possible values are 1-12, corresponding to I-XII. | |
| magnitude [0..1] | [Float](#CIM17v40-Float) | The magnitude of the earthquake as defined on the Moment Magnitude (M<sub>w</sub>) scale, which measures the size of earthquakes in terms of the energy released. Must be greater than zero. | |
| focalDepth [0..1] | [RelativeDisplacement](#CIM17v40-RelativeDisplacement) | The depth below the earth's surface of the earthquake's focal point. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| PhenomenonClassification [0..1] | [PhenomenonClassification](#CIM17v40-PhenomenonClassification) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| timeInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |

{#CIM17v40-Editor}
### Editor

Inheritance path = [DocumentPersonRole](#CIM17v40-DocumentPersonRole) => [PersonRole](#CIM17v40-PersonRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Editor {

}

class DocumentPersonRole {

}

DocumentPersonRole <|-- Editor : inherits from
```

Person who modified the document.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Person [0..1] | [Person](#CIM17v40-Person) | see [PersonRole](CIM17v40-PersonRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EmissionAccount}
### EmissionAccount

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EmissionAccount {

+ emissionType : enum:EmissionType [0..1]
+ emissionValueSource : enum:EmissionValueSource [0..1]
}

class Curve {

}

Curve <|-- EmissionAccount : inherits from
class ThermalGeneratingUnit {

}

EmissionAccount --> "1" ThermalGeneratingUnit : ThermalGeneratingUnit
```

Accounts for tracking emissions usage and credits for thermal generating units. A unit may have zero or more emission accounts, and will typically have one for tracking usage and one for tracking credits.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| emissionType [0..1] | [EmissionType](#CIM17v40-EmissionType) | The type of emission, for example sulfur dioxide (SO2). The y1AxisUnits of the curve contains the unit of measure (e.g. kg) and the emissionType is the type of emission (e.g. sulfur dioxide). | |
| emissionValueSource [0..1] | [EmissionValueSource](#CIM17v40-EmissionValueSource) | The source of the emission value. | |
| `ThermalGeneratingUnit [1]` (OfAggregate) | [ThermalGeneratingUnit](#CIM17v40-ThermalGeneratingUnit) | A thermal generating unit may have one or more emission allowance accounts. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EmissionCurve}
### EmissionCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EmissionCurve {

+ emissionContent : Emission [0..1]
+ emissionType : enum:EmissionType [0..1]
+ isNetGrossP : Boolean [0..1]
}

class Curve {

}

Curve <|-- EmissionCurve : inherits from
class ThermalGeneratingUnit {

}

EmissionCurve --> "1" ThermalGeneratingUnit : ThermalGeneratingUnit
```

Relationship between the unit's emission rate in units of mass per hour (Y-axis) and output active power (X-axis) for a given type of emission. This curve applies when only one type of fuel is being burned.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| emissionContent [0..1] | [Emission](#CIM17v40-Emission) | The emission content per quantity of fuel burned. | |
| emissionType [0..1] | [EmissionType](#CIM17v40-EmissionType) | The type of emission, which also gives the production rate measurement unit. The y1AxisUnits of the curve contains the unit of measure (e.g. kg) and the emissionType is the type of emission (e.g. sulfur dioxide). | |
| isNetGrossP [0..1] | [Boolean](#CIM17v40-Boolean) | Flag is set to true when output is expressed in net active power. | |
| `ThermalGeneratingUnit [1]` (OfAggregate) | [ThermalGeneratingUnit](#CIM17v40-ThermalGeneratingUnit) | A thermal generating unit may have one or more emission curves. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EndDevice}
### EndDevice

Inheritance path = [AssetContainer](#CIM17v40-AssetContainer) => [Asset](#CIM17v40-Asset) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EndDevice {

+ amrSystem : String [0..1]
+ installCode : String [0..1]
+ isPan : Boolean [0..1]
+ isSmartInverter : Boolean [0..1]
+ isVirtual : Boolean [0..1]
+ timeZoneOffset : Minutes [0..1]
}

class AssetContainer {

}

AssetContainer <|-- EndDevice : inherits from
class Customer {

}

EndDevice --> "0..1" Customer : Customer
class EndDeviceInfo {

}

EndDevice --> "0..1" EndDeviceInfo : EndDeviceInfo
class MeterReadSchedule {

}

EndDevice --> "0..1" MeterReadSchedule : MeterReadSchedule
class ServiceLocation {

}

EndDevice --> "0..1" ServiceLocation : ServiceLocation
class UsagePoint {

}

EndDevice --> "0..1" UsagePoint : UsagePoint
```

Asset container that performs one or more end device functions. One type of end device is a meter which can perform metering, load management, connect/disconnect, accounting functions, etc. Some end devices, such as ones monitoring and controlling air conditioners, refrigerators, pool pumps may be connected to a meter. All end devices may have communication capability defined by the associated communication function(s). An end device may be owned by a consumer, a service provider, utility or otherwise.

There may be a related end device function that identifies a sensor or control point within a metering application or communications systems (e.g., water, gas, electricity).

Some devices may use an optical port that conforms to the ANSI C12.18 standard for communications.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| amrSystem [0..1] | [String](#CIM17v40-String) | Automated meter reading (AMR) or other communication system responsible for communications to this end device. | |
| installCode [0..1] | [String](#CIM17v40-String) | Installation code. | |
| isPan [0..1] | [Boolean](#CIM17v40-Boolean) | If true, this is a premises area network (PAN) device. | |
| isSmartInverter [0..1] | [Boolean](#CIM17v40-Boolean) | If true, there is a communicating inverter present. | |
| isVirtual [0..1] | [Boolean](#CIM17v40-Boolean) | If true, there is no physical device. As an example, a virtual meter can be defined to aggregate the consumption for two or more physical meters. Otherwise, this is a physical hardware device. | |
| timeZoneOffset [0..1] | [Minutes](#CIM17v40-Minutes) | Time zone offset relative to GMT for the location of this end device. | |
| Customer [0..1] | [Customer](#CIM17v40-Customer) | Customer owning this end device. | |
| EndDeviceInfo [0..1] | [EndDeviceInfo](#CIM17v40-EndDeviceInfo) | End device data. | |
| MeterReadSchedule [0..1] | [MeterReadSchedule](#CIM17v40-MeterReadSchedule) | Meter read schedule that applies to the end device | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | Service location whose service delivery is measured by this end device. | |
| UsagePoint [0..1] | [UsagePoint](#CIM17v40-UsagePoint) | Usage point to which this end device belongs. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | see [Asset](#CIM17v40-Asset) | |
| initialCondition [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | see [Asset](CIM17v40-Asset) | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | see [Asset](CIM17v40-Asset) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [Asset](CIM17v40-Asset) | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | see [Asset](CIM17v40-Asset) | |
| lotNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| position [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | see [Asset](CIM17v40-Asset) | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | see [Asset](CIM17v40-Asset) | |
| serialNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| type [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| utcNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | see [Asset](CIM17v40-Asset) | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | see [Asset](CIM17v40-Asset) | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | see [Asset](CIM17v40-Asset) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [Asset](CIM17v40-Asset) | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | see [Asset](CIM17v40-Asset) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Asset](CIM17v40-Asset) | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | see [Asset](CIM17v40-Asset) | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | see [Asset](CIM17v40-Asset) | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | see [Asset](CIM17v40-Asset) | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | see [Asset](CIM17v40-Asset) | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | see [Asset](CIM17v40-Asset) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Asset](CIM17v40-Asset) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [Asset](CIM17v40-Asset) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [Asset](CIM17v40-Asset) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Asset](CIM17v40-Asset) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EndDeviceAction}
### EndDeviceAction


```mermaid
classDiagram
direction TB

class EndDeviceAction {

+ command : String [0..1]
+ duration : Minutes [0..1]
+ durationIndefinite : Boolean [0..1]
+ startDateTime : DateTime [0..1]
}

class EndDeviceControl {

}

EndDeviceAction --> "0..1" EndDeviceControl : EndDeviceControl
```

Action/command performed by an end device on a device other than the end device.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| command [0..1] | [String](#CIM17v40-String) | Command text. | |
| duration [0..1] | [Minutes](#CIM17v40-Minutes) | Amount of time the action of this control is to remain active. | |
| durationIndefinite [0..1] | [Boolean](#CIM17v40-Boolean) | True if the action of this control is indefinite. | |
| startDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Start date and time for action of this control. | |
| EndDeviceControl [0..1] | [EndDeviceControl](#CIM17v40-EndDeviceControl) | End device control issuing this end device action. | |

{#CIM17v40-EndDeviceControl}
### EndDeviceControl

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EndDeviceControl {

+ drProgramLevel : Integer [0..1]
+ drProgramMandatory : Boolean [0..1]
+ issuerID : String [0..1]
+ issuerTrackingID : String [0..1]
+ priceSignal : Float [0..1]
+ reason : String [0..1]
+ primaryDeviceTiming : EndDeviceTiming [0..1]
+ scheduledInterval : DateTimeInterval [0..1]
+ secondaryDeviceTiming : EndDeviceTiming [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- EndDeviceControl : inherits from
class EndDeviceAction {

}

EndDeviceControl --> "0..1" EndDeviceAction : EndDeviceAction
class EndDeviceControlType {

}

EndDeviceControl --> "1" EndDeviceControlType : EndDeviceControlType
```

Instructs an end device (or an end device group) to perform a specified action.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| drProgramLevel [0..1] | [Integer](#CIM17v40-Integer) | Level of a demand response program request, where 0=emergency. Note: Attribute is not defined on DemandResponseProgram as it is not its inherent property (it serves to control it). | |
| drProgramMandatory [0..1] | [Boolean](#CIM17v40-Boolean) | Whether a demand response program request is mandatory. Note: Attribute is not defined on DemandResponseProgram as it is not its inherent property (it serves to control it). | |
| issuerID [0..1] | [String](#CIM17v40-String) | Unique identifier of the business entity originating an end device control. | |
| issuerTrackingID [0..1] | [String](#CIM17v40-String) | Identifier assigned by the initiator (e.g. retail electric provider) of an end device control action to uniquely identify the demand response event, text message, or other subject of the control action. Can be used when cancelling an event or text message request or to identify the originating event or text message in a consequential end device event. | |
| priceSignal [0..1] | [Float](#CIM17v40-Float) | (if applicable) Price signal used as parameter for this end device control. | |
| reason [0..1] | [String](#CIM17v40-String) | Reason for the control action that allows to determine how to continue processing. For example, disconnect meter command may require different processing by the receiving system if it has been issued for a network-related reason (protection) or for a payment-related reason. | |
| EndDeviceAction [0..1] | [EndDeviceAction](#CIM17v40-EndDeviceAction) | End device action issued by this end device control. | |
| EndDeviceControlType [1] | [EndDeviceControlType](#CIM17v40-EndDeviceControlType) | Type of this end device control. | |
| primaryDeviceTiming [0..1] | [EndDeviceTiming](#CIM17v40-EndDeviceTiming) | Timing for the control actions performed on the device identified in the end device control. | |
| scheduledInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | (if control has scheduled duration) Date and time interval the control has been scheduled to execute within. | |
| secondaryDeviceTiming [0..1] | [EndDeviceTiming](#CIM17v40-EndDeviceTiming) | Timing for the control actions performed by devices that are responding to event related information sent to the primary device indicated in the end device control. For example, load control actions performed by a PAN device in response to demand response event information sent to a PAN gateway server. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EndDeviceControlType}
### EndDeviceControlType

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EndDeviceControlType {

+ domain : String [0..1]
+ eventOrAction : String [0..1]
+ subDomain : String [0..1]
+ type : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- EndDeviceControlType : inherits from
```

Detailed description for a control produced by an end device. Values in attributes allow for creation of recommended codes to be used for identifying end device controls as follows: <type>.<domain>.<subDomain>.<eventOrAction>.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| domain [0..1] | [String](#CIM17v40-String) | High-level nature of the control. | |
| eventOrAction [0..1] | [String](#CIM17v40-String) | The most specific part of this control type. It is mainly in the form of a verb that gives action to the control that just occurred. | |
| subDomain [0..1] | [String](#CIM17v40-String) | More specific nature of the control, as a further sub-categorisation of 'domain'. | |
| type [0..1] | [String](#CIM17v40-String) | Type of physical device from which the control was created. A value of zero (0) can be used when the source is unknown. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EndDeviceEvent}
### EndDeviceEvent

Inheritance path = [ActivityRecord](#CIM17v40-ActivityRecord) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EndDeviceEvent {

+ issuerID : String [0..1]
+ issuerTrackingID : String [0..1]
+ userID : String [0..1]
}

class ActivityRecord {

}

ActivityRecord <|-- EndDeviceEvent : inherits from
class EndDevice {

}

EndDeviceEvent --> "0..1" EndDevice : EndDevice
class EndDeviceEventType {

}

EndDeviceEvent --> "1" EndDeviceEventType : EndDeviceEventType
class MeterReading {

}

EndDeviceEvent --> "0..1" MeterReading : MeterReading
class UsagePoint {

}

EndDeviceEvent --> "0..1" UsagePoint : UsagePoint
```

Event detected by a device function associated with the end device.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| issuerID [0..1] | [String](#CIM17v40-String) | Unique identifier of the business entity originating an end device control. | |
| issuerTrackingID [0..1] | [String](#CIM17v40-String) | Identifier assigned by the initiator (e.g. retail electric provider) of an end device control action to uniquely identify the demand response event, text message, or other subject of the control action. Can be used when cancelling an event or text message request or to identify the originating event or text message in a consequential end device event. | |
| userID [0..1] | [String](#CIM17v40-String) | (if user initiated) ID of user who initiated this end device event. | |
| EndDevice [0..1] | [EndDevice](#CIM17v40-EndDevice) | End device that reported this end device event. | |
| EndDeviceEventType [1] | [EndDeviceEventType](#CIM17v40-EndDeviceEventType) | Type of this end device event. | |
| MeterReading [0..1] | [MeterReading](#CIM17v40-MeterReading) | Set of measured values to which this event applies. | |
| UsagePoint [0..1] | [UsagePoint](#CIM17v40-UsagePoint) | Usage point for which this end device event is reported. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| reason [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| severity [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| type [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| Document [0..1] | [Document](#CIM17v40-Document) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EndDeviceEventDetail}
### EndDeviceEventDetail


```mermaid
classDiagram
direction TB

class EndDeviceEventDetail {

+ name : String [0..1]
+ value : StringQuantity [0..1]
}

class EndDeviceEvent {

}

EndDeviceEventDetail --> "0..1" EndDeviceEvent : EndDeviceEvent
```

Name-value pair, specific to end device events.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| name [0..1] | [String](#CIM17v40-String) | Name. | |
| EndDeviceEvent [0..1] | [EndDeviceEvent](#CIM17v40-EndDeviceEvent) | End device owning this detail. | |
| value [0..1] | [StringQuantity](#CIM17v40-StringQuantity) | Value, including unit information. | |

{#CIM17v40-EndDeviceEventType}
### EndDeviceEventType

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EndDeviceEventType {

+ domain : String [0..1]
+ eventOrAction : String [0..1]
+ subDomain : String [0..1]
+ type : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- EndDeviceEventType : inherits from
```

Detailed description for an event produced by an end device. Values in attributes allow for creation of recommended codes to be used for identifying end device events as follows: <type>.<domain>.<subDomain>.<eventOrAction>.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| domain [0..1] | [String](#CIM17v40-String) | High-level nature of the event. By properly classifying events by a small set of domain codes, a system can more easily run reports based on the types of events that have occurred or been received. | |
| eventOrAction [0..1] | [String](#CIM17v40-String) | The most specific part of this event type. It is mainly in the form of a verb that gives action to the event that just occurred. | |
| subDomain [0..1] | [String](#CIM17v40-String) | More specific nature of the event, as a further sub-categorisation of 'domain'. | |
| type [0..1] | [String](#CIM17v40-String) | Type of physical device from which the event was created. A value of zero (0) can be used when the source is unknown. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EndDeviceFunction}
### EndDeviceFunction

Inheritance path = [AssetFunction](#CIM17v40-AssetFunction) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EndDeviceFunction {

+ enabled : Boolean [0..1]
}

class AssetFunction {

}

AssetFunction <|-- EndDeviceFunction : inherits from
class EndDevice {

}

EndDeviceFunction --> "0..1" EndDevice : EndDevice
```

Function performed by an end device such as a meter, communication equipment, controllers, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | True if the function is enabled. | |
| EndDevice [0..1] | [EndDevice](#CIM17v40-EndDevice) | End device that performs this function. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| configID [0..1] | [String](#CIM17v40-String) | see [AssetFunction](#CIM17v40-AssetFunction) | |
| firmwareID [0..1] | [String](#CIM17v40-String) | see [AssetFunction](#CIM17v40-AssetFunction) | |
| hardwareID [0..1] | [String](#CIM17v40-String) | see [AssetFunction](#CIM17v40-AssetFunction) | |
| password [0..1] | [String](#CIM17v40-String) | see [AssetFunction](#CIM17v40-AssetFunction) | |
| programID [0..1] | [String](#CIM17v40-String) | see [AssetFunction](#CIM17v40-AssetFunction) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [AssetFunction](CIM17v40-AssetFunction) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EndDeviceGroup}
### EndDeviceGroup

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EndDeviceGroup {

+ type : String [0..1]
+ status : Status [0..1]
+ version : Version [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- EndDeviceGroup : inherits from
class DERFunction {

}

EndDeviceGroup --> "0..1" DERFunction : DERFunction
class MeterReadSchedule {

}

EndDeviceGroup --> "0..1" MeterReadSchedule : MeterReadSchedule
```

Abstraction for management of group communications within a two-way AMR system or the data for a group of related end devices. Commands can be issued to all of the end devices that belong to the group using a defined group address and the underlying AMR communication infrastructure. A DERGroup and a PANDeviceGroup is an EndDeviceGroup.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| type [0..1] | [String](#CIM17v40-String) | Type of this group. | |
| DERFunction [0..1] | [DERFunction](#CIM17v40-DERFunction) | Functions supported by the DER Group | |
| MeterReadSchedule [0..1] | [MeterReadSchedule](#CIM17v40-MeterReadSchedule) | Meter read schedule that applies to the end device group | |
| status [0..1] | [Status](#CIM17v40-Status) | Current status information relevant to a group. | |
| version [0..1] | [Version](#CIM17v40-Version) | version of this group | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EndDeviceInfo}
### EndDeviceInfo

Inheritance path = [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EndDeviceInfo {

+ isSolidState : Boolean [0..1]
+ phaseCount : Integer [0..1]
+ ratedCurrent : CurrentFlow [0..1]
+ ratedVoltage : Voltage [0..1]
+ capability : EndDeviceCapability [0..1]
}

class AssetInfo {

}

AssetInfo <|-- EndDeviceInfo : inherits from
```

End device data.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| isSolidState [0..1] | [Boolean](#CIM17v40-Boolean) | If true, this is a solid state end device (as opposed to a mechanical or electromechanical device). | |
| phaseCount [0..1] | [Integer](#CIM17v40-Integer) | Number of potential phases the end device supports, typically 0, 1 or 3. | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Rated current. | |
| ratedVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Rated voltage. | |
| capability [0..1] | [EndDeviceCapability](#CIM17v40-EndDeviceCapability) | Inherent capabilities of the device (i.e., the functions it supports). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnergyArea}
### EnergyArea

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnergyArea {

}

class IdentifiedObject {

}

IdentifiedObject <|-- EnergyArea : inherits from
class ControlArea {

}

EnergyArea --> "0..1" ControlArea : ControlArea
```

Describes an area having energy production or consumption. Specializations are intended to support the load allocation function as typically required in energy management systems or planning studies to allocate hypothesized load levels to individual load points for power flow analysis. Often the energy area can be linked to both measured and forecast load levels.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ControlArea [0..1] | [ControlArea](#CIM17v40-ControlArea) | The control area specification that is used for the load forecast. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnergyComponent}
### EnergyComponent

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnergyComponent {

}

class IdentifiedObject {

}

IdentifiedObject <|-- EnergyComponent : inherits from
```


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnergyConnection}
### EnergyConnection

Inheritance path = [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnergyConnection {

}

class ConductingEquipment {

}

ConductingEquipment <|-- EnergyConnection : inherits from
```

A connection of energy generation or consumption on the power system model.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnergyConsumer}
### EnergyConsumer

Inheritance path = [EnergyConnection](#CIM17v40-EnergyConnection) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnergyConsumer {

+ customerCount : Integer [0..1]
+ grounded : Boolean [0..1]
+ p : ActivePower [0..1]
+ pfixed : ActivePower [0..1]
+ pfixedPct : PerCent [0..1]
+ phaseConnection : enum:PhaseShuntConnectionKind [0..1]
+ q : ReactivePower [0..1]
+ qfixed : ReactivePower [0..1]
+ qfixedPct : PerCent [0..1]
}

class EnergyConnection {

}

EnergyConnection <|-- EnergyConsumer : inherits from
class EnergyConsumerAction {

}

EnergyConsumer --> "0..1" EnergyConsumerAction : EnergyConsumerAction
class LoadDynamics {

}

EnergyConsumer --> "0..1" LoadDynamics : LoadDynamics
class LoadResponseCharacteristic {

}

EnergyConsumer --> "0..1" LoadResponseCharacteristic : LoadResponse
class PowerCutZone {

}

EnergyConsumer --> "0..1" PowerCutZone : PowerCutZone
```

Generic user of energy - a point of consumption on the power system model.

EnergyConsumer.pfixed, .qfixed, .pfixedPct and .qfixedPct have meaning only if there is no LoadResponseCharacteristic associated with EnergyConsumer or if LoadResponseCharacteristic.exponentModel is set to False.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| customerCount [0..1] | [Integer](#CIM17v40-Integer) | Number of individual customers represented by this demand. | |
| grounded [0..1] | [Boolean](#CIM17v40-Boolean) | Used for Yn and Zn connections. True if the neutral is solidly grounded. | |
| p [0..1] | [ActivePower](#CIM17v40-ActivePower) | Active power of the load. Load sign convention is used, i.e. positive sign means flow out from a node.For voltage dependent loads the value is at rated voltage.Starting value for a steady state solution. | |
| pfixed [0..1] | [ActivePower](#CIM17v40-ActivePower) | Active power of the load that is a fixed quantity and does not vary as load group value varies. Load sign convention is used, i.e. positive sign means flow out from a node. | |
| pfixedPct [0..1] | [PerCent](#CIM17v40-PerCent) | Fixed active power as a percentage of load group fixed active power. Used to represent the time-varying components. Load sign convention is used, i.e. positive sign means flow out from a node. | |
| phaseConnection [0..1] | [PhaseShuntConnectionKind](#CIM17v40-PhaseShuntConnectionKind) | The type of phase connection, such as wye or delta. | |
| q [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Reactive power of the load. Load sign convention is used, i.e. positive sign means flow out from a node.For voltage dependent loads the value is at rated voltage.Starting value for a steady state solution. | |
| qfixed [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Reactive power of the load that is a fixed quantity and does not vary as load group value varies. Load sign convention is used, i.e. positive sign means flow out from a node. | |
| qfixedPct [0..1] | [PerCent](#CIM17v40-PerCent) | Fixed reactive power as a percentage of load group fixed reactive power. Used to represent the time-varying components. Load sign convention is used, i.e. positive sign means flow out from a node. | |
| EnergyConsumerAction [0..1] | [EnergyConsumerAction](#CIM17v40-EnergyConsumerAction) | The energy consumer action that is performed on the energy consumer | |
| LoadDynamics [0..1] | [LoadDynamics](#CIM17v40-LoadDynamics) | Load dynamics model used to describe dynamic behaviour of this energy consumer. | |
| LoadResponse [0..1] | [LoadResponseCharacteristic](#CIM17v40-LoadResponseCharacteristic) | The load response characteristic of this load. If missing, this load is assumed to be constant power. | |
| `PowerCutZone [0..1]` (OfAggregate) | [PowerCutZone](#CIM17v40-PowerCutZone) | The energy consumer is assigned to this power cut zone. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnergyConsumerAction}
### EnergyConsumerAction

Inheritance path = [SwitchingAction](#CIM17v40-SwitchingAction) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnergyConsumerAction {

+ kind : enum:TempEquipActionKind [0..1]
}

class SwitchingAction {

}

SwitchingAction <|-- EnergyConsumerAction : inherits from
class EnergyConsumer {

}

EnergyConsumerAction --> "0..1" EnergyConsumer : EnergyConsumer
```

Action to connect or disconnect the Energy Consumer from its Terminal


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [TempEquipActionKind](#CIM17v40-TempEquipActionKind) | Switching action to perform | |
| EnergyConsumer [0..1] | [EnergyConsumer](#CIM17v40-EnergyConsumer) | The energy consumer that the energy consumer action is performed on | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| executedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| issuedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| plannedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| Operator [0..1] | [Operator](#CIM17v40-Operator) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingEvent [0..1] | [SwitchingEvent](#CIM17v40-SwitchingEvent) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingStep [0..1] | [SwitchingStep](#CIM17v40-SwitchingStep) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnergyConsumerPhase}
### EnergyConsumerPhase

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnergyConsumerPhase {

+ p : ActivePower [0..1]
+ pfixed : ActivePower [0..1]
+ pfixedPct : PerCent [0..1]
+ phase : enum:SinglePhaseKind [0..1]
+ q : ReactivePower [0..1]
+ qfixed : ReactivePower [0..1]
+ qfixedPct : PerCent [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- EnergyConsumerPhase : inherits from
class EnergyConsumer {

}

EnergyConsumerPhase --> "1" EnergyConsumer : EnergyConsumer
```

A single phase of an energy consumer.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| p [0..1] | [ActivePower](#CIM17v40-ActivePower) | Active power of the load. Load sign convention is used, i.e. positive sign means flow out from a node.For voltage dependent loads the value is at rated voltage.Starting value for a steady state solution. | |
| pfixed [0..1] | [ActivePower](#CIM17v40-ActivePower) | Active power of the load that is a fixed quantity. Load sign convention is used, i.e. positive sign means flow out from a node. | |
| pfixedPct [0..1] | [PerCent](#CIM17v40-PerCent) | Fixed active power as per cent of load group fixed active power. Load sign convention is used, i.e. positive sign means flow out from a node. | |
| phase [0..1] | [SinglePhaseKind](#CIM17v40-SinglePhaseKind) | Phase of this energy consumer component. If the energy consumer is wye connected, the connection is from the indicated phase to the central ground or neutral point. If the energy consumer is delta connected, the phase indicates an energy consumer connected from the indicated phase to the next logical non-neutral phase. | |
| q [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Reactive power of the load. Load sign convention is used, i.e. positive sign means flow out from a node.For voltage dependent loads the value is at rated voltage.Starting value for a steady state solution. | |
| qfixed [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Reactive power of the load that is a fixed quantity. Load sign convention is used, i.e. positive sign means flow out from a node. | |
| qfixedPct [0..1] | [PerCent](#CIM17v40-PerCent) | Fixed reactive power as per cent of load group fixed reactive power. Load sign convention is used, i.e. positive sign means flow out from a node. | |
| EnergyConsumer [1] | [EnergyConsumer](#CIM17v40-EnergyConsumer) | The energy consumer to which this phase belongs. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnergyGroup}
### EnergyGroup

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnergyGroup {

+ isSlack : Boolean [0..1]
+ p : ActivePower [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- EnergyGroup : inherits from
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| isSlack [0..1] | [Boolean](#CIM17v40-Boolean) | | |
| p [0..1] | [ActivePower](#CIM17v40-ActivePower) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnergyMarket}
### EnergyMarket

Inheritance path = [Market](#CIM17v40-Market) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnergyMarket {

}

class Market {

}

Market <|-- EnergyMarket : inherits from
class MarketResults {

}

EnergyMarket --> "0..1" MarketResults : MarketResults
class RTO {

}

EnergyMarket --> "0..1" RTO : RTO
```

Energy and Ancillary Market (e.g. Energy, Spinning Reserve, Non-Spinning Reserve) with a description of the Market operation control parameters.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| MarketResults [0..1] | [MarketResults](#CIM17v40-MarketResults) | | |
| RTO [0..1] | [RTO](#CIM17v40-RTO) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| actualEnd [0..1] | [DateTime](#CIM17v40-DateTime) | see [Market](#CIM17v40-Market) | |
| actualStart [0..1] | [DateTime](#CIM17v40-DateTime) | see [Market](#CIM17v40-Market) | |
| dst [0..1] | [Boolean](#CIM17v40-Boolean) | see [Market](#CIM17v40-Market) | |
| end [0..1] | [DateTime](#CIM17v40-DateTime) | see [Market](#CIM17v40-Market) | |
| localTimeZone [0..1] | [String](#CIM17v40-String) | see [Market](#CIM17v40-Market) | |
| start [0..1] | [DateTime](#CIM17v40-DateTime) | see [Market](#CIM17v40-Market) | |
| status [0..1] | [String](#CIM17v40-String) | see [Market](#CIM17v40-Market) | |
| timeIntervalLength [0..1] | [Float](#CIM17v40-Float) | see [Market](#CIM17v40-Market) | |
| tradingDay [0..1] | [DateTime](#CIM17v40-DateTime) | see [Market](#CIM17v40-Market) | |
| tradingPeriod [0..1] | [String](#CIM17v40-String) | see [Market](#CIM17v40-Market) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnergyPriceCurve}
### (informative) EnergyPriceCurve


```mermaid
classDiagram
direction TB

class EnergyPriceCurve {

}

```

Relationship between a price in $(or other monetary unit) /hour (Y-axis) and a MW value (X-axis).


{#CIM17v40-EnergyPriceIndex}
### EnergyPriceIndex

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnergyPriceIndex {

+ energyPriceIndex : Float [0..1]
+ energyPriceIndexType : enum:EnergyPriceIndexType [0..1]
+ lastModified : DateTime [0..1]
+ validPeriod : DateTimeInterval [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- EnergyPriceIndex : inherits from
class RegisteredGenerator {

}

EnergyPriceIndex --> "1" RegisteredGenerator : RegisteredGenerator
```

An Energy Price Index for each Resource is valid for a period (e.g. daily) that is identified by a Valid Period Start Time and a Valid Period End Time. An Energy Price Index is in $/MWh.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| energyPriceIndex [0..1] | [Float](#CIM17v40-Float) | Energy price index | |
| energyPriceIndexType [0..1] | [EnergyPriceIndexType](#CIM17v40-EnergyPriceIndexType) | EPI type such as wholesale or retail | |
| lastModified [0..1] | [DateTime](#CIM17v40-DateTime) | Time updated | |
| RegisteredGenerator [1] | [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | | |
| validPeriod [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Valid period for which the energy price index is valid. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnergyProduct}
### (informative) EnergyProduct

Inheritance path = [Agreement](#CIM17v40-Agreement) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnergyProduct {

}

class Agreement {

}

Agreement <|-- EnergyProduct : inherits from
class GenerationProvider {

}

EnergyProduct --> "1" GenerationProvider : GenerationProvider
class Marketer {

}

EnergyProduct --> "0..1" Marketer : TitleHeldBy_Marketer
```

An EnergyProduct is offered commercially as a ContractOrTariff.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `GenerationProvider [1]` (informative) | [GenerationProvider](#CIM17v40-GenerationProvider) | | |
| `TitleHeldBy_Marketer [0..1]` (informative) | [Marketer](#CIM17v40-Marketer) | A Marketer holds title to an EnergyProduct. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| signDate [0..1] | [Date](#CIM17v40-Date) | see [Agreement](#CIM17v40-Agreement) | |
| validityInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [Agreement](CIM17v40-Agreement) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnergyProfile}
### EnergyProfile

Inheritance path = [Profile](#CIM17v40-Profile) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnergyProfile {

}

class Profile {

}

Profile <|-- EnergyProfile : inherits from
class EnergyTransaction {

}

EnergyProfile --> "1" EnergyTransaction : EnergyTransaction
class TransactionBid {

}

EnergyProfile --> "1" TransactionBid : TransactionBid
```

Specifies the start time, stop time, level for an EnergyTransaction.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `EnergyTransaction [1]` (OfAggregate) | [EnergyTransaction](#CIM17v40-EnergyTransaction) | An EnergyTransaction shall have at least one EnergyProfile. | |
| `TransactionBid [1]` (OfAggregate) | [TransactionBid](#CIM17v40-TransactionBid) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnergySchedulingType}
### EnergySchedulingType

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnergySchedulingType {

}

class IdentifiedObject {

}

IdentifiedObject <|-- EnergySchedulingType : inherits from
```

Used to define the type of generation for scheduling purposes.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnergySource}
### EnergySource

Inheritance path = [EnergyConnection](#CIM17v40-EnergyConnection) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnergySource {

+ activePower : ActivePower [0..1]
+ nominalVoltage : Voltage [0..1]
+ pMax : ActivePower [0..1]
+ pMin : ActivePower [0..1]
+ r : Resistance [0..1]
+ r0 : Resistance [0..1]
+ reactivePower : ReactivePower [0..1]
+ rn : Resistance [0..1]
+ voltageAngle : AngleRadians [0..1]
+ voltageMagnitude : Voltage [0..1]
+ x : Reactance [0..1]
+ x0 : Reactance [0..1]
+ xn : Reactance [0..1]
}

class EnergyConnection {

}

EnergyConnection <|-- EnergySource : inherits from
class EnergySchedulingType {

}

EnergySource --> "0..1" EnergySchedulingType : EnergySchedulingType
class EnergySourceAction {

}

EnergySource --> "0..1" EnergySourceAction : EnergySourceAction
```

A generic equivalent for an energy supplier on a transmission or distribution voltage level.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| activePower [0..1] | [ActivePower](#CIM17v40-ActivePower) | High voltage source active injection. Load sign convention is used, i.e. positive sign means flow out from a node.Starting value for steady state solutions. | |
| nominalVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Phase-to-phase nominal voltage. | |
| pMax [0..1] | [ActivePower](#CIM17v40-ActivePower) | This is the maximum active power that can be produced by the source. Load sign convention is used, i.e. positive sign means flow out from a TopologicalNode (bus) into the conducting equipment. | |
| pMin [0..1] | [ActivePower](#CIM17v40-ActivePower) | This is the minimum active power that can be produced by the source. Load sign convention is used, i.e. positive sign means flow out from a TopologicalNode (bus) into the conducting equipment. | |
| r [0..1] | [Resistance](#CIM17v40-Resistance) | Positive sequence Thevenin resistance. | |
| r0 [0..1] | [Resistance](#CIM17v40-Resistance) | Zero sequence Thevenin resistance. | |
| reactivePower [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | High voltage source reactive injection. Load sign convention is used, i.e. positive sign means flow out from a node.Starting value for steady state solutions. | |
| rn [0..1] | [Resistance](#CIM17v40-Resistance) | Negative sequence Thevenin resistance. | |
| voltageAngle [0..1] | [AngleRadians](#CIM17v40-AngleRadians) | Phase angle of a-phase open circuit used when voltage characteristics need to be imposed at the node associated with the terminal of the energy source, such as when voltages and angles from the transmission level are used as input to the distribution network. The attribute shall be a positive value or zero. | |
| voltageMagnitude [0..1] | [Voltage](#CIM17v40-Voltage) | Phase-to-phase open circuit voltage magnitude used when voltage characteristics need to be imposed at the node associated with the terminal of the energy source, such as when voltages and angles from the transmission level are used as input to the distribution network. The attribute shall be a positive value or zero. | |
| x [0..1] | [Reactance](#CIM17v40-Reactance) | Positive sequence Thevenin reactance. | |
| x0 [0..1] | [Reactance](#CIM17v40-Reactance) | Zero sequence Thevenin reactance. | |
| xn [0..1] | [Reactance](#CIM17v40-Reactance) | Negative sequence Thevenin reactance. | |
| EnergySchedulingType [0..1] | [EnergySchedulingType](#CIM17v40-EnergySchedulingType) | Energy Scheduling Type of an Energy Source. | |
| EnergySourceAction [0..1] | [EnergySourceAction](#CIM17v40-EnergySourceAction) | Action taken with this energy source. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnergySourceAction}
### EnergySourceAction

Inheritance path = [SwitchingAction](#CIM17v40-SwitchingAction) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnergySourceAction {

+ kind : enum:TempEquipActionKind [0..1]
}

class SwitchingAction {

}

SwitchingAction <|-- EnergySourceAction : inherits from
class EnergySource {

}

EnergySourceAction --> "0..1" EnergySource : EnergySource
```

Action on energy source as a switching step.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [TempEquipActionKind](#CIM17v40-TempEquipActionKind) | Switching action to perform. | |
| EnergySource [0..1] | [EnergySource](#CIM17v40-EnergySource) | Energy source on which this action is taken. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| executedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| issuedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| plannedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| Operator [0..1] | [Operator](#CIM17v40-Operator) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingEvent [0..1] | [SwitchingEvent](#CIM17v40-SwitchingEvent) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingStep [0..1] | [SwitchingStep](#CIM17v40-SwitchingStep) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnergySourcePhase}
### EnergySourcePhase

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnergySourcePhase {

+ phase : enum:SinglePhaseKind [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- EnergySourcePhase : inherits from
class EnergySource {

}

EnergySourcePhase --> "1" EnergySource : EnergySource
```

Represents the single phase information of an unbalanced energy source.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| phase [0..1] | [SinglePhaseKind](#CIM17v40-SinglePhaseKind) | Phase of this energy source component. If the energy source wye connected, the connection is from the indicated phase to the central ground or neutral point. If the energy source is delta connected, the phase indicates an energy source connected from the indicated phase to the next logical non-neutral phase. | |
| EnergySource [1] | [EnergySource](#CIM17v40-EnergySource) | The energy sourceto which the phase belongs. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnergyTransaction}
### (informative) EnergyTransaction

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnergyTransaction {

+ capacityBacked : Boolean [0..1]
+ congestChargeMax : Money [0..1]
+ deliveryPointP : ActivePower [0..1]
+ energyMin : ActivePower [0..1]
+ firmInterchangeFlag : Boolean [0..1]
+ payCongestion : Boolean [0..1]
+ reason : String [0..1]
+ receiptPointP : ActivePower [0..1]
+ state : enum:EnergyTransactionType [0..1]
}

class Document {

}

Document <|-- EnergyTransaction : inherits from
class EnergyProduct {

}

EnergyTransaction --> "1" EnergyProduct : EnergyProduct
class SubControlArea {

}

EnergyTransaction --> "1" SubControlArea : Export_SubControlArea
class SubControlArea {

}

EnergyTransaction --> "1" SubControlArea : Import_SubControlArea
class TransmissionReservation {

}

EnergyTransaction --> "0..1" TransmissionReservation : TransmissionReservation
```

Specifies the schedule for energy transfers between interchange areas that are necessary to satisfy the associated interchange transaction.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| capacityBacked [0..1] | [Boolean](#CIM17v40-Boolean) | Interchange capacity flag. When the flag is set to true, it indicates a transaction is capacity backed. | |
| congestChargeMax [0..1] | [Money](#CIM17v40-Money) | Maximum congestion charges in monetary units. | |
| deliveryPointP [0..1] | [ActivePower](#CIM17v40-ActivePower) | Delivery point active power. | |
| energyMin [0..1] | [ActivePower](#CIM17v40-ActivePower) | Transaction minimum active power if dispatchable. | |
| firmInterchangeFlag [0..1] | [Boolean](#CIM17v40-Boolean) | Firm interchange flag indicates whether or not this energy transaction can be changed without potential financial consequences. | |
| payCongestion [0..1] | [Boolean](#CIM17v40-Boolean) | Willing to Pay congestion flag | |
| reason [0..1] | [String](#CIM17v40-String) | Reason for energy transaction. | |
| receiptPointP [0..1] | [ActivePower](#CIM17v40-ActivePower) | Receipt point active power. | |
| state [0..1] | [EnergyTransactionType](#CIM17v40-EnergyTransactionType) | { Approve {vbar} Deny {vbar} Study } | |
| `EnergyProduct [1]` (informative) | [EnergyProduct](#CIM17v40-EnergyProduct) | The "Source" for an EnergyTransaction is an EnergyProduct which is injected into a ControlArea. Typically this is a ServicePoint. | |
| Export_SubControlArea [1] | [SubControlArea](#CIM17v40-SubControlArea) | Energy is transferred between interchange areas | |
| Import_SubControlArea [1] | [SubControlArea](#CIM17v40-SubControlArea) | Energy is transferred between interchange areas | |
| TransmissionReservation [0..1] | [TransmissionReservation](#CIM17v40-TransmissionReservation) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnergyTypeReference}
### EnergyTypeReference

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnergyTypeReference {

+ kind : enum:EnergyTypeKind [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- EnergyTypeReference : inherits from
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [EnergyTypeKind](#CIM17v40-EnergyTypeKind) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnvironmentalAlert}
### EnvironmentalAlert

Inheritance path = [ActivityRecord](#CIM17v40-ActivityRecord) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnvironmentalAlert {

+ alertType : String [0..1]
+ cancelledDateTime : DateTime [0..1]
+ headline : String [0..1]
+ inEffect : DateTimeInterval [0..1]
}

class ActivityRecord {

}

ActivityRecord <|-- EnvironmentalAlert : inherits from
class AlertTypeList {

}

EnvironmentalAlert --> "1" AlertTypeList : AlertTypeList
class EnvironmentalDataProvider {

}

EnvironmentalAlert --> "0..1" EnvironmentalDataProvider : EnvironmentalDataProvider
```

An environmental alert issued by a provider or system.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| alertType [0..1] | [String](#CIM17v40-String) | The type of the issued alert which is drawn from the specified alert type list. | |
| cancelledDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Time and date alert cancelled. Used only if alert is cancelled before it expires. | |
| headline [0..1] | [String](#CIM17v40-String) | An abbreviated textual description of the alert issued.Note: the full text of the alert appears in the .description attribute (inherited from IdentifiedObject). | |
| AlertTypeList [1] | [AlertTypeList](#CIM17v40-AlertTypeList) | The list of alert types from which the type of this alert is drawn. | |
| EnvironmentalDataProvider [0..1] | [EnvironmentalDataProvider](#CIM17v40-EnvironmentalDataProvider) | Environmental data provider for this alert. | |
| inEffect [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | The interval for which this weather alert is in effect. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| reason [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| severity [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| type [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| Document [0..1] | [Document](#CIM17v40-Document) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnvironmentalAnalog}
### EnvironmentalAnalog

Inheritance path = [Analog](#CIM17v40-Analog) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnvironmentalAnalog {

}

class Analog {

}

Analog <|-- EnvironmentalAnalog : inherits from
class ClassificationCondition {

}

EnvironmentalAnalog --> "0..1" ClassificationCondition : ClassificationCondition
class EnvironmentalInformation {

}

EnvironmentalAnalog --> "0..1" EnvironmentalInformation : EnvironmentalInformation
class EnvironmentalMonitoringStation {

}

EnvironmentalAnalog --> "0..1" EnvironmentalMonitoringStation : EnvironmentalMonitoringStation
class ReportingCapability {

}

EnvironmentalAnalog --> "0..1" ReportingCapability : ReportingCapability
```

Analog (float) measurement of relevance in the environmental domain.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ClassificationCondition [0..1] | [ClassificationCondition](#CIM17v40-ClassificationCondition) | Classification condition which this analog helps define. | |
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | Observation or forecast with which this environmental analog measurement is associated. | |
| EnvironmentalMonitoringStation [0..1] | [EnvironmentalMonitoringStation](#CIM17v40-EnvironmentalMonitoringStation) | Monitoring station which provides this environmental analog measurement. | |
| ReportingCapability [0..1] | [ReportingCapability](#CIM17v40-ReportingCapability) | The reporting capability this environmental value set helps define. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maxValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| minValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| normalValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| positiveFlowIn [0..1] | [Boolean](#CIM17v40-Boolean) | see [Analog](#CIM17v40-Analog) | |
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnvironmentalCodedValue}
### EnvironmentalCodedValue

Inheritance path = [StringMeasurementValue](#CIM17v40-StringMeasurementValue) => [MeasurementValue](#CIM17v40-MeasurementValue) => [IOPoint](#CIM17v40-IOPoint) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnvironmentalCodedValue {

+ coverageKind : enum:CoverageCodeKind [0..1]
+ intensityKind : enum:IntensityCodeKind [0..1]
+ probabilityPercent : PerCent [0..1]
+ weatherKind : enum:WeatherCodeKind [0..1]
}

class StringMeasurementValue {

}

StringMeasurementValue <|-- EnvironmentalCodedValue : inherits from
```

An environmental value described using a coded value. A triplicate of enumerated values representing intensity, coverage, type of weather is used. These may be concatenated into the string value.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| coverageKind [0..1] | [CoverageCodeKind](#CIM17v40-CoverageCodeKind) | Code representing the coverage of the weather condition. | |
| intensityKind [0..1] | [IntensityCodeKind](#CIM17v40-IntensityCodeKind) | Code representing the intensity of the weather condition. | |
| probabilityPercent [0..1] | [PerCent](#CIM17v40-PerCent) | Probability of weather condition occurring during the time interval expressed as a percentage. Applicable only when weather condition is related to a forecast (not an observation). | |
| weatherKind [0..1] | [WeatherCodeKind](#CIM17v40-WeatherCodeKind) | Code representing the type of weather condition. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| value [0..1] | [String](#CIM17v40-String) | see [StringMeasurementValue](#CIM17v40-StringMeasurementValue) | |
| StringMeasurement [1] | [StringMeasurement](#CIM17v40-StringMeasurement) | see [StringMeasurementValue](CIM17v40-StringMeasurementValue) | |
| sensorAccuracy [0..1] | [PerCent](#CIM17v40-PerCent) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| timeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | see [MeasurementValue](#CIM17v40-MeasurementValue) | |
| `CalculationMethodHierarchy [0..1]` (harmonization) | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| `ErpPerson [0..1]` (informative) | [OldPerson](#CIM17v40-OldPerson) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| `MeasurementValueQuality [0..1]` (AggregateOf) | [MeasurementValueQuality](#CIM17v40-MeasurementValueQuality) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| MeasurementValueSource [1] | [MeasurementValueSource](#CIM17v40-MeasurementValueSource) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| RemoteSource [0..1] | [RemoteSource](#CIM17v40-RemoteSource) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| IOPointSource [0..1] | [IOPointSource](#CIM17v40-IOPointSource) | see [IOPoint](CIM17v40-IOPoint) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnvironmentalDataAuthority}
### EnvironmentalDataAuthority

Inheritance path = [OrganisationRole](#CIM17v40-OrganisationRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnvironmentalDataAuthority {

}

class OrganisationRole {

}

OrganisationRole <|-- EnvironmentalDataAuthority : inherits from
```

An entity defining classifications or categories of environmental information, like phenomena or alerts.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Organisation [0..1] | [Organisation](#CIM17v40-Organisation) | see [OrganisationRole](CIM17v40-OrganisationRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnvironmentalDataProvider}
### EnvironmentalDataProvider

Inheritance path = [OrganisationRole](#CIM17v40-OrganisationRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnvironmentalDataProvider {

}

class OrganisationRole {

}

OrganisationRole <|-- EnvironmentalDataProvider : inherits from
```

Entity providing environmental data. Could be an observed weather data provider, an entity providing forecasts, an authority providing alerts, etc.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Organisation [0..1] | [Organisation](#CIM17v40-Organisation) | see [OrganisationRole](CIM17v40-OrganisationRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnvironmentalDependentLimit}
### EnvironmentalDependentLimit

Inheritance path = [LimitDependency](#CIM17v40-LimitDependency) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnvironmentalDependentLimit {

}

class LimitDependency {

}

LimitDependency <|-- EnvironmentalDependentLimit : inherits from
```

This is a environmental based limit dependency model for calculating operational limits.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Equipment [0..1]` (OfAggregate, informative) | [Equipment](#CIM17v40-Equipment) | see [LimitDependency](CIM17v40-LimitDependency) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnvironmentalDiscrete}
### EnvironmentalDiscrete

Inheritance path = [Discrete](#CIM17v40-Discrete) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnvironmentalDiscrete {

+ kind : enum:EnvironmentalDiscreteKind [1]
}

class Discrete {

}

Discrete <|-- EnvironmentalDiscrete : inherits from
class EnvironmentalInformation {

}

EnvironmentalDiscrete --> "0..1" EnvironmentalInformation : EnvironmentalInformation
```

Discrete (integer) measurement of relevance in the environmental domain.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [1] | [EnvironmentalDiscreteKind](#CIM17v40-EnvironmentalDiscreteKind) | Kind of environmental discrete (integer). | |
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | Observation or forecast with which this environmental discrete (integer) is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maxValue [0..1] | [Integer](#CIM17v40-Integer) | see [Discrete](#CIM17v40-Discrete) | |
| minValue [0..1] | [Integer](#CIM17v40-Integer) | see [Discrete](#CIM17v40-Discrete) | |
| normalValue [0..1] | [Integer](#CIM17v40-Integer) | see [Discrete](#CIM17v40-Discrete) | |
| ValueAliasSet [0..1] | [ValueAliasSet](#CIM17v40-ValueAliasSet) | see [Discrete](CIM17v40-Discrete) | |
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnvironmentalEvent}
### EnvironmentalEvent

Inheritance path = [ActivityRecord](#CIM17v40-ActivityRecord) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnvironmentalEvent {

}

class ActivityRecord {

}

ActivityRecord <|-- EnvironmentalEvent : inherits from
```

An environmental event to which one or more forecasts or observations may be tied and which may relate to or affect one or more assets.

This class is intended to be used as a means of grouping forecasts and/or observations and could be used for a variety of purposes, including:

<ul>

<li>to define a 'named' event like Hurricane Katrina and allow the historic (or forecast) values for phenomena and measurements (precipitation, temperature) across time to be associated with it</li>

<li>to identify assets that were (or are forecast to be) affected by a phenomenon or set of measurements</li>

</ul>


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| reason [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| severity [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| type [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| Document [0..1] | [Document](#CIM17v40-Document) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnvironmentalInformation}
### EnvironmentalInformation

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnvironmentalInformation {

+ created : DateTime [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- EnvironmentalInformation : inherits from
class EnvironmentalDataProvider {

}

EnvironmentalInformation --> "0..1" EnvironmentalDataProvider : EnvironmentalDataProvider
```

Abstract class (with concrete child classes of Observation and Forecast) that groups phenomenon and/or environmental value sets.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| created [0..1] | [DateTime](#CIM17v40-DateTime) | The timestamp of when the forecast was created | |
| EnvironmentalDataProvider [0..1] | [EnvironmentalDataProvider](#CIM17v40-EnvironmentalDataProvider) | Environmental data provider supplying this environmental information. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnvironmentalLocationType}
### EnvironmentalLocationType


```mermaid
classDiagram
direction TB

class EnvironmentalLocationType {

+ kind : enum:LocationKind [0..1]
}

class Location {

}

EnvironmentalLocationType --> "0..1" Location : Location
```

Type of environmental location. Used when an environmental alert or phenomenon has multiple locations associated with it.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [LocationKind](#CIM17v40-LocationKind) | The kind of location. Typical values might be center, extent, primary, secondary, etc. | |
| Location [0..1] | [Location](#CIM17v40-Location) | Location of this instance of ths kind of environmental location. | |

{#CIM17v40-EnvironmentalMonitoringStation}
### EnvironmentalMonitoringStation

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnvironmentalMonitoringStation {

+ dstObserved : Boolean [0..1]
+ isNetworked : Boolean [0..1]
+ timeZoneOffset : Minutes [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- EnvironmentalMonitoringStation : inherits from
class Location {

}

EnvironmentalMonitoringStation --> "0..1" Location : Location
```

An environmental monitoring station, examples of which could be a weather station or a seismic monitoring station.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dstObserved [0..1] | [Boolean](#CIM17v40-Boolean) | Whether this station is currently reporting using daylight saving time. Intended to aid a utility Weather Service in interpreting information coming from a station and has no direct relationship to the manner in which time is expressed in EnvironmentalValueSet. | |
| isNetworked [0..1] | [Boolean](#CIM17v40-Boolean) | Indication that station is part of a network of stations used to monitor weather phenomena covering a large geographical area. | |
| timeZoneOffset [0..1] | [Minutes](#CIM17v40-Minutes) | The time offset from UTC (a.k.a. GMT) configured in the station "clock", not (necessarily) the time zone in which the station is physically located.This attribute exists to support management of utility monitoring stations and has no direct relationship to the manner in which time is expressed in EnvironmentalValueSet. | |
| Location [0..1] | [Location](#CIM17v40-Location) | Location of this monitoring station. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EnvironmentalPhenomenon}
### EnvironmentalPhenomenon


```mermaid
classDiagram
direction TB

class EnvironmentalPhenomenon {

+ timeInterval : DateTimeInterval [0..1]
}

class EnvironmentalInformation {

}

EnvironmentalPhenomenon --> "0..1" EnvironmentalInformation : EnvironmentalInformation
class PhenomenonClassification {

}

EnvironmentalPhenomenon --> "0..1" PhenomenonClassification : PhenomenonClassification
```

The actual or forecast characteristics of an environmental phenomenon at a specific point in time (or during a specific time interval) that may have both a center and area/line location.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | The forecast or observation of which this phenomenon description is a part. | |
| PhenomenonClassification [0..1] | [PhenomenonClassification](#CIM17v40-PhenomenonClassification) | The classification of this phenomenon. | |
| timeInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | The timestamp of the phenomenon as a single point or time interval. | |

{#CIM17v40-EnvironmentalStringMeasurement}
### EnvironmentalStringMeasurement

Inheritance path = [StringMeasurement](#CIM17v40-StringMeasurement) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EnvironmentalStringMeasurement {

}

class StringMeasurement {

}

StringMeasurement <|-- EnvironmentalStringMeasurement : inherits from
class ClassificationCondition {

}

EnvironmentalStringMeasurement --> "0..1" ClassificationCondition : ClassificationCondition
class EnvironmentalInformation {

}

EnvironmentalStringMeasurement --> "0..1" EnvironmentalInformation : EnvironmentalInformation
```

String measurement of relevance in the environmental domain.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ClassificationCondition [0..1] | [ClassificationCondition](#CIM17v40-ClassificationCondition) | Classification condition which this string measurement helps define. | |
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | Observation or forecast with which this environmental string is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Equipment}
### (informative) Equipment

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Equipment {

+ aggregate : Boolean [0..1]
+ inService : Boolean [0..1]
+ networkAnalysisEnabled : Boolean [0..1]
+ normallyInService : Boolean [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- Equipment : inherits from
class EquipmentContainer {

}

Equipment --> "0..*" EquipmentContainer : AdditionalEquipmentContainer
class EquipmentContainer {

}

Equipment --> "0..1" EquipmentContainer : EquipmentContainer
```

The parts of a power system that are physical devices, electronic or mechanical.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | The aggregate flag provides an alternative way of representing an aggregated (equivalent) element. It is applicable in cases when the dedicated classes for equivalent equipment do not have all of the attributes necessary to represent the required level of detail. In case the flag is set to �true� the single instance of equipment represents multiple pieces of equipment that have been modelled together as an aggregate equivalent obtained by a network reduction procedure. Examples would be power transformers or synchronous machines operating in parallel modelled as a single aggregate power transformer or aggregate synchronous machine.The attribute is not used for EquivalentBranch, EquivalentShunt and EquivalentInjection. | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | Specifies the availability of the equipment. True means the equipment is available for topology processing, which determines if the equipment is energized or not. False means that the equipment is treated by network applications as if it is not in the model. | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | The equipment is enabled to participate in network analysis. If unspecified, the value is assumed to be true. | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | Specifies the availability of the equipment under normal operating conditions. True means the equipment is available for topology processing, which determines if the equipment is energized or not. False means that the equipment is treated by network applications as if it is not in the model. | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | Additional equipment container beyond the primary equipment container. The equipment is contained in another equipment container, but also grouped with this equipment container. | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | Container of this equipment. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EquipmentContainer}
### EquipmentContainer

Inheritance path = [ConnectivityNodeContainer](#CIM17v40-ConnectivityNodeContainer) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EquipmentContainer {

}

class ConnectivityNodeContainer {

}

ConnectivityNodeContainer <|-- EquipmentContainer : inherits from
```

A modelling construct to provide a root class for containing equipment.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EquipmentFault}
### EquipmentFault

Inheritance path = [Fault](#CIM17v40-Fault) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EquipmentFault {

}

class Fault {

}

Fault <|-- EquipmentFault : inherits from
class Terminal {

}

EquipmentFault --> "0..1" Terminal : Terminal
```

A fault applied at the terminal, external to the equipment. This class is not used to specify faults internal to the equipment.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Terminal [0..1] | [Terminal](#CIM17v40-Terminal) | The terminal connecting to the bus to which the fault is applied. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [PhaseConnectedFaultKind](#CIM17v40-PhaseConnectedFaultKind) | see [Fault](CIM17v40-Fault) | |
| occurredDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Fault](#CIM17v40-Fault) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Fault](CIM17v40-Fault) | |
| FaultyEquipment [0..1] | [Equipment](#CIM17v40-Equipment) | see [Fault](CIM17v40-Fault) | |
| impedance [0..1] | [FaultImpedance](#CIM17v40-FaultImpedance) | see [Fault](CIM17v40-Fault) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Fault](CIM17v40-Fault) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [Fault](CIM17v40-Fault) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EquipmentLimitSeriesComponent}
### EquipmentLimitSeriesComponent

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EquipmentLimitSeriesComponent {

}

class IdentifiedObject {

}

IdentifiedObject <|-- EquipmentLimitSeriesComponent : inherits from
class Equipment {

}

EquipmentLimitSeriesComponent --> "1" Equipment : Equipment
class SeriesEquipmentDependentLimit {

}

EquipmentLimitSeriesComponent --> "1" SeriesEquipmentDependentLimit : SeriesEquipmentDependentLimit
```

This represents one instance of an equipment that contributes to the calculation of an operational limit.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Equipment [1]` (informative) | [Equipment](#CIM17v40-Equipment) | Equipment contributing toward the series limit. The reference here is to Equipment rather than a specific limit on the equipment so the grouiping can be reused for multiple limits of different types on the same instance of equipment. | |
| `SeriesEquipmentDependentLimit [1]` (OfAggregate, informative) | [SeriesEquipmentDependentLimit](#CIM17v40-SeriesEquipmentDependentLimit) | Calculation in which the refernce to equipment applies. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EquipmentUnavailabilitySchedule}
### EquipmentUnavailabilitySchedule

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EquipmentUnavailabilitySchedule {

}

class IdentifiedObject {

}

IdentifiedObject <|-- EquipmentUnavailabilitySchedule : inherits from
```


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EquivalentBranch}
### EquivalentBranch

Inheritance path = [EquivalentEquipment](#CIM17v40-EquivalentEquipment) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EquivalentBranch {

+ negativeR12 : Resistance [0..1]
+ negativeR21 : Resistance [0..1]
+ negativeX12 : Reactance [0..1]
+ negativeX21 : Reactance [0..1]
+ positiveR12 : Resistance [0..1]
+ positiveR21 : Resistance [0..1]
+ positiveX12 : Reactance [0..1]
+ positiveX21 : Reactance [0..1]
+ r : Resistance [0..1]
+ r21 : Resistance [0..1]
+ x : Reactance [0..1]
+ x21 : Reactance [0..1]
+ zeroR12 : Resistance [0..1]
+ zeroR21 : Resistance [0..1]
+ zeroX12 : Reactance [0..1]
+ zeroX21 : Reactance [0..1]
}

class EquivalentEquipment {

}

EquivalentEquipment <|-- EquivalentBranch : inherits from
```

The class represents equivalent branches. In cases where a transformer phase shift is modelled and the EquivalentBranch is spanning the same nodes, the impedance quantities for the EquivalentBranch shall consider the needed phase shift.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| negativeR12 [0..1] | [Resistance](#CIM17v40-Resistance) | Negative sequence series resistance from terminal sequence 1 to terminal sequence 2. Used for short circuit data exchange according to IEC 60909.EquivalentBranch is a result of network reduction prior to the data exchange. | |
| negativeR21 [0..1] | [Resistance](#CIM17v40-Resistance) | Negative sequence series resistance from terminal sequence 2 to terminal sequence 1. Used for short circuit data exchange according to IEC 60909.EquivalentBranch is a result of network reduction prior to the data exchange. | |
| negativeX12 [0..1] | [Reactance](#CIM17v40-Reactance) | Negative sequence series reactance from terminal sequence 1 to terminal sequence 2. Used for short circuit data exchange according to IEC 60909.Usage : EquivalentBranch is a result of network reduction prior to the data exchange. | |
| negativeX21 [0..1] | [Reactance](#CIM17v40-Reactance) | Negative sequence series reactance from terminal sequence 2 to terminal sequence 1. Used for short circuit data exchange according to IEC 60909.Usage: EquivalentBranch is a result of network reduction prior to the data exchange. | |
| positiveR12 [0..1] | [Resistance](#CIM17v40-Resistance) | Positive sequence series resistance from terminal sequence 1 to terminal sequence 2 . Used for short circuit data exchange according to IEC 60909.EquivalentBranch is a result of network reduction prior to the data exchange. | |
| positiveR21 [0..1] | [Resistance](#CIM17v40-Resistance) | Positive sequence series resistance from terminal sequence 2 to terminal sequence 1. Used for short circuit data exchange according to IEC 60909.EquivalentBranch is a result of network reduction prior to the data exchange. | |
| positiveX12 [0..1] | [Reactance](#CIM17v40-Reactance) | Positive sequence series reactance from terminal sequence 1 to terminal sequence 2. Used for short circuit data exchange according to IEC 60909.Usage : EquivalentBranch is a result of network reduction prior to the data exchange. | |
| positiveX21 [0..1] | [Reactance](#CIM17v40-Reactance) | Positive sequence series reactance from terminal sequence 2 to terminal sequence 1. Used for short circuit data exchange according to IEC 60909.Usage : EquivalentBranch is a result of network reduction prior to the data exchange. | |
| r [0..1] | [Resistance](#CIM17v40-Resistance) | Positive sequence series resistance of the reduced branch. | |
| r21 [0..1] | [Resistance](#CIM17v40-Resistance) | Resistance from terminal sequence 2 to terminal sequence 1 .Used for steady state power flow. This attribute is optional and represent unbalanced network such as off-nominal phase shifter. If only EquivalentBranch.r is given, then EquivalentBranch.r21 is assumed equal to EquivalentBranch.r.Usage rule : EquivalentBranch is a result of network reduction prior to the data exchange. | |
| x [0..1] | [Reactance](#CIM17v40-Reactance) | Positive sequence series reactance of the reduced branch. | |
| x21 [0..1] | [Reactance](#CIM17v40-Reactance) | Reactance from terminal sequence 2 to terminal sequence 1. Used for steady state power flow. This attribute is optional and represents an unbalanced network such as off-nominal phase shifter. If only EquivalentBranch.x is given, then EquivalentBranch.x21 is assumed equal to EquivalentBranch.x.Usage rule: EquivalentBranch is a result of network reduction prior to the data exchange. | |
| zeroR12 [0..1] | [Resistance](#CIM17v40-Resistance) | Zero sequence series resistance from terminal sequence 1 to terminal sequence 2. Used for short circuit data exchange according to IEC 60909.EquivalentBranch is a result of network reduction prior to the data exchange. | |
| zeroR21 [0..1] | [Resistance](#CIM17v40-Resistance) | Zero sequence series resistance from terminal sequence 2 to terminal sequence 1. Used for short circuit data exchange according to IEC 60909.Usage : EquivalentBranch is a result of network reduction prior to the data exchange. | |
| zeroX12 [0..1] | [Reactance](#CIM17v40-Reactance) | Zero sequence series reactance from terminal sequence 1 to terminal sequence 2. Used for short circuit data exchange according to IEC 60909.Usage : EquivalentBranch is a result of network reduction prior to the data exchange. | |
| zeroX21 [0..1] | [Reactance](#CIM17v40-Reactance) | Zero sequence series reactance from terminal sequence 2 to terminal sequence 1. Used for short circuit data exchange according to IEC 60909.Usage : EquivalentBranch is a result of network reduction prior to the data exchange. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `EquivalentNetwork [0..1]` (OfAggregate) | [EquivalentNetwork](#CIM17v40-EquivalentNetwork) | see [EquivalentEquipment](CIM17v40-EquivalentEquipment) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EquivalentEquipment}
### EquivalentEquipment

Inheritance path = [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EquivalentEquipment {

}

class ConductingEquipment {

}

ConductingEquipment <|-- EquivalentEquipment : inherits from
class EquivalentNetwork {

}

EquivalentEquipment --> "0..1" EquivalentNetwork : EquivalentNetwork
```

The class represents equivalent objects that are the result of a network reduction. The class is the base for equivalent objects of different types.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `EquivalentNetwork [0..1]` (OfAggregate) | [EquivalentNetwork](#CIM17v40-EquivalentNetwork) | The equivalent where the reduced model belongs. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EquivalentInjection}
### EquivalentInjection

Inheritance path = [EquivalentEquipment](#CIM17v40-EquivalentEquipment) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EquivalentInjection {

+ maxP : ActivePower [0..1]
+ maxQ : ReactivePower [0..1]
+ minP : ActivePower [0..1]
+ minQ : ReactivePower [0..1]
+ p : ActivePower [0..1]
+ q : ReactivePower [0..1]
+ r : Resistance [0..1]
+ r0 : Resistance [0..1]
+ r2 : Resistance [0..1]
+ regulationCapability : Boolean [0..1]
+ regulationStatus : Boolean [0..1]
+ regulationTarget : Voltage [0..1]
+ x : Reactance [0..1]
+ x0 : Reactance [0..1]
+ x2 : Reactance [0..1]
}

class EquivalentEquipment {

}

EquivalentEquipment <|-- EquivalentInjection : inherits from
class ReactiveCapabilityCurve {

}

EquivalentInjection --> "0..1" ReactiveCapabilityCurve : ReactiveCapabilityCurve
```

This class represents equivalent injections (generation or load). Voltage regulation is allowed only at the point of connection.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | Maximum active power of the injection. | |
| maxQ [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Maximum reactive power of the injection. Used for modelling of infeed for load flow exchange. Not used for short circuit modelling. If maxQ and minQ are not used ReactiveCapabilityCurve can be used. | |
| minP [0..1] | [ActivePower](#CIM17v40-ActivePower) | Minimum active power of the injection. | |
| minQ [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Minimum reactive power of the injection. Used for modelling of infeed for load flow exchange. Not used for short circuit modelling. If maxQ and minQ are not used ReactiveCapabilityCurve can be used. | |
| p [0..1] | [ActivePower](#CIM17v40-ActivePower) | Equivalent active power injection. Load sign convention is used, i.e. positive sign means flow out from a node.Starting value for steady state solutions. | |
| q [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Equivalent reactive power injection. Load sign convention is used, i.e. positive sign means flow out from a node.Starting value for steady state solutions. | |
| r [0..1] | [Resistance](#CIM17v40-Resistance) | Positive sequence resistance. Used to represent Extended-Ward (IEC 60909).Usage : Extended-Ward is a result of network reduction prior to the data exchange. | |
| r0 [0..1] | [Resistance](#CIM17v40-Resistance) | Zero sequence resistance. Used to represent Extended-Ward (IEC 60909).Usage : Extended-Ward is a result of network reduction prior to the data exchange. | |
| r2 [0..1] | [Resistance](#CIM17v40-Resistance) | Negative sequence resistance. Used to represent Extended-Ward (IEC 60909).Usage : Extended-Ward is a result of network reduction prior to the data exchange. | |
| regulationCapability [0..1] | [Boolean](#CIM17v40-Boolean) | Specifies whether or not the EquivalentInjection has the capability to regulate the local voltage. If true the EquivalentInjection can regulate. If false the EquivalentInjection cannot regulate. ReactiveCapabilityCurve can only be associated with EquivalentInjection if the flag is true. | |
| regulationStatus [0..1] | [Boolean](#CIM17v40-Boolean) | Specifies the regulation status of the EquivalentInjection. True is regulating. False is not regulating. | |
| regulationTarget [0..1] | [Voltage](#CIM17v40-Voltage) | The target voltage for voltage regulation. The attribute shall be a positive value. | |
| x [0..1] | [Reactance](#CIM17v40-Reactance) | Positive sequence reactance. Used to represent Extended-Ward (IEC 60909).Usage : Extended-Ward is a result of network reduction prior to the data exchange. | |
| x0 [0..1] | [Reactance](#CIM17v40-Reactance) | Zero sequence reactance. Used to represent Extended-Ward (IEC 60909).Usage : Extended-Ward is a result of network reduction prior to the data exchange. | |
| x2 [0..1] | [Reactance](#CIM17v40-Reactance) | Negative sequence reactance. Used to represent Extended-Ward (IEC 60909).Usage : Extended-Ward is a result of network reduction prior to the data exchange. | |
| ReactiveCapabilityCurve [0..1] | [ReactiveCapabilityCurve](#CIM17v40-ReactiveCapabilityCurve) | The reactive capability curve used by this equivalent injection. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `EquivalentNetwork [0..1]` (OfAggregate) | [EquivalentNetwork](#CIM17v40-EquivalentNetwork) | see [EquivalentEquipment](CIM17v40-EquivalentEquipment) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EquivalentNetwork}
### EquivalentNetwork

Inheritance path = [ConnectivityNodeContainer](#CIM17v40-ConnectivityNodeContainer) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EquivalentNetwork {

}

class ConnectivityNodeContainer {

}

ConnectivityNodeContainer <|-- EquivalentNetwork : inherits from
```

A class that groups electrical equivalents, including internal nodes, of a network that has been reduced. The ConnectivityNodes contained in the equivalent are intended to reflect internal nodes of the equivalent. The boundary Connectivity nodes where the equivalent connects outside itself are not contained by the equivalent.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EquivalentShunt}
### EquivalentShunt

Inheritance path = [EquivalentEquipment](#CIM17v40-EquivalentEquipment) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class EquivalentShunt {

+ b : Susceptance [0..1]
+ g : Conductance [0..1]
}

class EquivalentEquipment {

}

EquivalentEquipment <|-- EquivalentShunt : inherits from
```

The class represents equivalent shunts.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| b [0..1] | [Susceptance](#CIM17v40-Susceptance) | Positive sequence shunt susceptance. | |
| g [0..1] | [Conductance](#CIM17v40-Conductance) | Positive sequence shunt conductance. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `EquivalentNetwork [0..1]` (OfAggregate) | [EquivalentNetwork](#CIM17v40-EquivalentNetwork) | see [EquivalentEquipment](CIM17v40-EquivalentEquipment) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpBOM}
### (informative) ErpBOM

Inheritance path = [ErpDocument](#CIM17v40-ErpDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpBOM {

}

class ErpDocument {

}

ErpDocument <|-- ErpBOM : inherits from
class Design {

}

ErpBOM --> "0..1" Design : Design
```

Information that generally describes the Bill of Material Structure and its contents for a utility.

This is used by ERP systems to transfer Bill of Material information between two business applications.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Design [0..1]` (informative) | [Design](#CIM17v40-Design) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpBankAccount}
### ErpBankAccount

Inheritance path = [BankAccount](#CIM17v40-BankAccount) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpBankAccount {

+ bankABA : String [0..1]
}

class BankAccount {

}

BankAccount <|-- ErpBankAccount : inherits from
```

Relationship under a particular name, usually evidenced by a deposit against which withdrawals can be made. Types of bank accounts include: demand, time, custodial, joint, trustee, corporate, special, and regular accounts.

A statement of transactions during a fiscal period and the resulting balance is maintained on each account.

For Payment metering, the account is associated with Bank and Supplier, reflecting details of the bank account used for depositing revenue collected by TokenVendor. The name of the account holder should be specified in 'name' attribute.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| bankABA [0..1] | [String](#CIM17v40-String) | Bank ABA. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| accountNumber [0..1] | [String](#CIM17v40-String) | see [BankAccount](#CIM17v40-BankAccount) | |
| `Bank [0..1]` (informative) | [Bank](#CIM17v40-Bank) | see [BankAccount](CIM17v40-BankAccount) | |
| `ServiceSupplier [0..1]` (informative) | [ServiceSupplier](#CIM17v40-ServiceSupplier) | see [BankAccount](CIM17v40-BankAccount) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpBomItemData}
### ErpBomItemData

Inheritance path = [ErpIdentifiedObject](#CIM17v40-ErpIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpBomItemData {

}

class ErpIdentifiedObject {

}

ErpIdentifiedObject <|-- ErpBomItemData : inherits from
class DesignLocation {

}

ErpBomItemData --> "0..1" DesignLocation : DesignLocation
class ErpBOM {

}

ErpBomItemData --> "1" ErpBOM : ErpBOM
class CatalogAssetType {

}

ErpBomItemData --> "0..1" CatalogAssetType : TypeAsset
```

An individual item on a bill of materials.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `DesignLocation [0..1]` (informative) | [DesignLocation](#CIM17v40-DesignLocation) | | |
| `ErpBOM [1]` (informative) | [ErpBOM](#CIM17v40-ErpBOM) | | |
| `TypeAsset [0..1]` (informative) | [CatalogAssetType](#CIM17v40-CatalogAssetType) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpChartOfAccounts}
### ErpChartOfAccounts

Inheritance path = [ErpDocument](#CIM17v40-ErpDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpChartOfAccounts {

}

class ErpDocument {

}

ErpDocument <|-- ErpChartOfAccounts : inherits from
```

Accounting structure of a business. Each account represents a financial aspect of a business, such as its Accounts Payable, or the value of its inventory, or its office supply expenses.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpCompetency}
### (informative) ErpCompetency

Inheritance path = [ErpIdentifiedObject](#CIM17v40-ErpIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpCompetency {

}

class ErpIdentifiedObject {

}

ErpIdentifiedObject <|-- ErpCompetency : inherits from
```

Information that describes aptitudes of a utility employee. Unlike Skills that an ErpPerson must be certified to perform before undertaking certain type of assignments (to be able to perfrom a Craft), ErpCompetency has more to do with typical Human Resource (HR) matters such as schooling, training, etc.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpDocument}
### ErpDocument

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpDocument {

}

class Document {

}

Document <|-- ErpDocument : inherits from
```

Shadow class for Document, to isolate subclassing from this package. If any subclass gets normative and needs inheritance, it will inherit directly from Document.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpEngChangeOrder}
### ErpEngChangeOrder

Inheritance path = [ErpDocument](#CIM17v40-ErpDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpEngChangeOrder {

}

class ErpDocument {

}

ErpDocument <|-- ErpEngChangeOrder : inherits from
```

General Utility Engineering Change Order information.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpIdentifiedObject}
### ErpIdentifiedObject

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpIdentifiedObject {

}

class IdentifiedObject {

}

IdentifiedObject <|-- ErpIdentifiedObject : inherits from
```

Shadow class for IdentifiedObject, to isolate subclassing from this package. If any subclass gets normative and needs inheritance, it will inherit directly from IdentifiedObject.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpInventory}
### (informative) ErpInventory

Inheritance path = [ErpIdentifiedObject](#CIM17v40-ErpIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpInventory {

+ status : Status [0..1]
}

class ErpIdentifiedObject {

}

ErpIdentifiedObject <|-- ErpInventory : inherits from
class Asset {

}

ErpInventory --> "0..1" Asset : Asset
```

Utility inventory-related information about an item or part (and not for description of the item and its attributes). It is used by ERP applications to enable the synchronization of Inventory data that exists on separate Item Master databases. This data is not the master data that describes the attributes of the item such as dimensions, weight, or unit of measure - it describes the item as it exists at a specific location.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Asset [0..1]` (informative) | [Asset](#CIM17v40-Asset) | | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpInventoryCount}
### ErpInventoryCount

Inheritance path = [ErpIdentifiedObject](#CIM17v40-ErpIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpInventoryCount {

+ status : Status [0..1]
}

class ErpIdentifiedObject {

}

ErpIdentifiedObject <|-- ErpInventoryCount : inherits from
```

This is related to Inventory physical counts organized by AssetModel. Note that a count of a type of asset can be accomplished by the association inherited by AssetModel (from Document) to Asset.

It enables ERP applications to transfer an inventory count between ERP and the actual physical inventory location. This count may be a cycle count or a physical count.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpInvoice}
### (informative) ErpInvoice

Inheritance path = [ErpDocument](#CIM17v40-ErpDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpInvoice {

+ amount : Money [0..1]
+ billMediaKind : enum:BillMediaKind [0..1]
+ dueDate : Date [0..1]
+ kind : enum:ErpInvoiceKind [0..1]
+ mailedDate : Date [0..1]
+ proForma : Boolean [0..1]
+ referenceNumber : String [0..1]
+ transactionDateTime : DateTime [0..1]
+ transferType : String [0..1]
}

class ErpDocument {

}

ErpDocument <|-- ErpInvoice : inherits from
class CustomerAccount {

}

ErpInvoice --> "0..1" CustomerAccount : CustomerAccount
```

A roll up of invoice line items. The whole invoice has a due date and amount to be paid, with information such as customer, banks etc. being obtained through associations. The invoice roll up is based on individual line items that each contain amounts and descriptions for specific services or products.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| amount [0..1] | [Money](#CIM17v40-Money) | Total amount due on this invoice based on line items and applicable adjustments. | |
| billMediaKind [0..1] | [BillMediaKind](#CIM17v40-BillMediaKind) | Kind of media by which the CustomerBillingInfo was delivered. | |
| dueDate [0..1] | [Date](#CIM17v40-Date) | Calculated date upon which the Invoice amount is due. | |
| kind [0..1] | [ErpInvoiceKind](#CIM17v40-ErpInvoiceKind) | Kind of invoice (default is 'sales'). | |
| mailedDate [0..1] | [Date](#CIM17v40-Date) | Date on which the customer billing statement/invoice was printed/mailed. | |
| proForma [0..1] | [Boolean](#CIM17v40-Boolean) | True if payment is to be paid by a Customer to accept a particular ErpQuote (with associated Design) and have work initiated, at which time an associated ErpInvoice should automatically be generated. EprPayment.subjectStatus satisfies terms specificed in the ErpQuote. | |
| referenceNumber [0..1] | [String](#CIM17v40-String) | Number of an invoice to be reference by this invoice. | |
| transactionDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time when the invoice is issued. | |
| transferType [0..1] | [String](#CIM17v40-String) | Type of invoice transfer. | |
| `CustomerAccount [0..1]` (informative) | [CustomerAccount](#CIM17v40-CustomerAccount) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpInvoiceLineItem}
### (informative) ErpInvoiceLineItem

Inheritance path = [ErpDocument](#CIM17v40-ErpDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpInvoiceLineItem {

+ glAccount : String [0..1]
+ glDateTime : DateTime [0..1]
+ kind : enum:ErpInvoiceLineItemKind [0..1]
+ lineAmount : Float [0..1]
+ lineNumber : String [0..1]
+ lineVersion : String [0..1]
+ netAmount : Float [0..1]
+ previousAmount : Float [0..1]
+ billPeriod : DateTimeInterval [0..1]
}

class ErpDocument {

}

ErpDocument <|-- ErpInvoiceLineItem : inherits from
class ErpInvoiceLineItem {

}

ErpInvoiceLineItem --> "0..1" ErpInvoiceLineItem : ContainerErpInvoiceLineItem
class ErpInvoice {

}

ErpInvoiceLineItem --> "1" ErpInvoice : ErpInvoice
class ErpPayableLineItem {

}

ErpInvoiceLineItem --> "0..1" ErpPayableLineItem : ErpPayableLineItem
class ErpQuoteLineItem {

}

ErpInvoiceLineItem --> "0..1" ErpQuoteLineItem : ErpQuoteLineItem
class ErpRecDelvLineItem {

}

ErpInvoiceLineItem --> "0..1" ErpRecDelvLineItem : ErpRecDelvLineItem
class ErpRecLineItem {

}

ErpInvoiceLineItem --> "0..1" ErpRecLineItem : ErpRecLineItem
```

An individual line item on an invoice.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| glAccount [0..1] | [String](#CIM17v40-String) | General Ledger account code, must be a valid combination. | |
| glDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time line item will be posted to the General Ledger. | |
| kind [0..1] | [ErpInvoiceLineItemKind](#CIM17v40-ErpInvoiceLineItemKind) | Kind of line item. | |
| lineAmount [0..1] | [Float](#CIM17v40-Float) | Amount due for this line item. | |
| lineNumber [0..1] | [String](#CIM17v40-String) | Line item number on invoice statement. | |
| lineVersion [0..1] | [String](#CIM17v40-String) | Version number of the bill run. | |
| netAmount [0..1] | [Float](#CIM17v40-Float) | Net line item charge amount. | |
| previousAmount [0..1] | [Float](#CIM17v40-Float) | Previous line item charge amount. | |
| billPeriod [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Bill period for the line item. | |
| `ContainerErpInvoiceLineItem [0..1]` (informative) | [ErpInvoiceLineItem](#CIM17v40-ErpInvoiceLineItem) | | |
| `ErpInvoice [1]` (informative) | [ErpInvoice](#CIM17v40-ErpInvoice) | | |
| `ErpPayableLineItem [0..1]` (informative) | [ErpPayableLineItem](#CIM17v40-ErpPayableLineItem) | | |
| `ErpQuoteLineItem [0..1]` (informative) | [ErpQuoteLineItem](#CIM17v40-ErpQuoteLineItem) | | |
| `ErpRecDelvLineItem [0..1]` (informative) | [ErpRecDelvLineItem](#CIM17v40-ErpRecDelvLineItem) | | |
| `ErpRecLineItem [0..1]` (informative) | [ErpRecLineItem](#CIM17v40-ErpRecLineItem) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpIssueInventory}
### ErpIssueInventory

Inheritance path = [ErpIdentifiedObject](#CIM17v40-ErpIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpIssueInventory {

+ status : Status [0..1]
}

class ErpIdentifiedObject {

}

ErpIdentifiedObject <|-- ErpIssueInventory : inherits from
class CatalogAssetType {

}

ErpIssueInventory --> "0..1" CatalogAssetType : TypeAsset
class TypeMaterial {

}

ErpIssueInventory --> "0..1" TypeMaterial : TypeMaterial
```

Can be used to request an application to process an issue or request information about an issue.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| status [0..1] | [Status](#CIM17v40-Status) | | |
| `TypeAsset [0..1]` (informative) | [CatalogAssetType](#CIM17v40-CatalogAssetType) | | |
| `TypeMaterial [0..1]` (informative) | [TypeMaterial](#CIM17v40-TypeMaterial) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpItemMaster}
### (informative) ErpItemMaster

Inheritance path = [ErpIdentifiedObject](#CIM17v40-ErpIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpItemMaster {

+ status : Status [0..1]
}

class ErpIdentifiedObject {

}

ErpIdentifiedObject <|-- ErpItemMaster : inherits from
class Asset {

}

ErpItemMaster --> "0..1" Asset : Asset
```

Any unique purchased part for manufactured product tracked by ERP systems for a utility.

Item, as used by the OAG, refers to the basic information about an item, including its attributes, cost, and locations. It does not include item quantities. Compare to the Inventory, which includes all quantities and other location-specific information.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Asset [0..1]` (informative) | [Asset](#CIM17v40-Asset) | | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpJournal}
### (informative) ErpJournal

Inheritance path = [ErpDocument](#CIM17v40-ErpDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpJournal {

}

class ErpDocument {

}

ErpDocument <|-- ErpJournal : inherits from
```

Book for recording accounting transactions as they occur. Transactions and adjustments are first recorded in a journal, which is like a diary of instructions, advising which account to be charged and by how much.

A journal represents a change in the balances of a business's financial accounts. Many tasks or transactions throughout an enterprise will result in the creation of a journal. Some examples are creating a customer invoice, paying a vendor, transferring inventory, or paying employees.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpJournalEntry}
### (informative) ErpJournalEntry

Inheritance path = [ErpIdentifiedObject](#CIM17v40-ErpIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpJournalEntry {

+ accountID : String [0..1]
+ amount : Money [0..1]
+ postingDateTime : DateTime [0..1]
+ sourceID : String [0..1]
+ transactionDateTime : DateTime [0..1]
+ status : Status [0..1]
}

class ErpIdentifiedObject {

}

ErpIdentifiedObject <|-- ErpJournalEntry : inherits from
class ErpInvoiceLineItem {

}

ErpJournalEntry --> "0..1" ErpInvoiceLineItem : ErpInvoiceLineItem
class ErpJournal {

}

ErpJournalEntry --> "1" ErpJournal : ErpJournal
class ErpLedgerEntry {

}

ErpJournalEntry --> "0..1" ErpLedgerEntry : ErpLedgerEntry
```

Details of an individual entry in a journal, which is to be posted to a ledger on the posting date.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| accountID [0..1] | [String](#CIM17v40-String) | Account identifier for this entry. | |
| amount [0..1] | [Money](#CIM17v40-Money) | The amount of the debit or credit for this account. | |
| postingDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time this entry is to be posted to the ledger. | |
| sourceID [0..1] | [String](#CIM17v40-String) | The identifer of the source for this entry. | |
| transactionDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time journal entry was recorded. | |
| `ErpInvoiceLineItem [0..1]` (informative) | [ErpInvoiceLineItem](#CIM17v40-ErpInvoiceLineItem) | | |
| `ErpJournal [1]` (informative) | [ErpJournal](#CIM17v40-ErpJournal) | | |
| `ErpLedgerEntry [0..1]` (informative) | [ErpLedgerEntry](#CIM17v40-ErpLedgerEntry) | | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpLedBudLineItem}
### (informative) ErpLedBudLineItem

Inheritance path = [ErpIdentifiedObject](#CIM17v40-ErpIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpLedBudLineItem {

+ status : Status [0..1]
}

class ErpIdentifiedObject {

}

ErpIdentifiedObject <|-- ErpLedBudLineItem : inherits from
class ErpLedgerEntry {

}

ErpLedBudLineItem --> "0..1" ErpLedgerEntry : ErpLedBudLineItem
class ErpLedgerBudget {

}

ErpLedBudLineItem --> "1" ErpLedgerBudget : ErpLedgerBudget
```

Individual entry of a given Ledger Budget, typically containing information such as amount, accounting date, accounting period, and is associated with the applicable general ledger account.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ErpLedBudLineItem [0..1]` (informative) | [ErpLedgerEntry](#CIM17v40-ErpLedgerEntry) | | |
| `ErpLedgerBudget [1]` (informative) | [ErpLedgerBudget](#CIM17v40-ErpLedgerBudget) | | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpLedger}
### (informative) ErpLedger

Inheritance path = [ErpDocument](#CIM17v40-ErpDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpLedger {

}

class ErpDocument {

}

ErpDocument <|-- ErpLedger : inherits from
```

In accounting transactions, a ledger is a book containing accounts to which debits and credits are posted from journals, where transactions are initially recorded. Journal entries are periodically posted to the ledger. Ledger Actual represents actual amounts by account within ledger within company or business area. Actual amounts may be generated in a source application and then loaded to a specific ledger within the enterprise general ledger or budget application.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpLedgerBudget}
### (informative) ErpLedgerBudget

Inheritance path = [ErpDocument](#CIM17v40-ErpDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpLedgerBudget {

}

class ErpDocument {

}

ErpDocument <|-- ErpLedgerBudget : inherits from
```

Information for utility Ledger Budgets. They support the transfer budget amounts between all possible source applications throughout an enterprise and a general ledger or budget application.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpLedgerEntry}
### (informative) ErpLedgerEntry

Inheritance path = [ErpIdentifiedObject](#CIM17v40-ErpIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpLedgerEntry {

+ accountID : String [0..1]
+ accountKind : enum:ErpAccountKind [0..1]
+ amount : Money [0..1]
+ postedDateTime : DateTime [0..1]
+ transactionDateTime : DateTime [0..1]
+ status : Status [0..1]
}

class ErpIdentifiedObject {

}

ErpIdentifiedObject <|-- ErpLedgerEntry : inherits from
class ErpJournalEntry {

}

ErpLedgerEntry --> "0..1" ErpJournalEntry : ErpJounalEntry
class ErpLedger {

}

ErpLedgerEntry --> "1" ErpLedger : ErpLedger
class ErpLedBudLineItem {

}

ErpLedgerEntry --> "0..1" ErpLedBudLineItem : ErpLedgerEntry
```

Details of an individual entry in a ledger, which was posted from a journal on the posted date.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| accountID [0..1] | [String](#CIM17v40-String) | Account identifier for this entry. | |
| accountKind [0..1] | [ErpAccountKind](#CIM17v40-ErpAccountKind) | Kind of account for this entry. | |
| amount [0..1] | [Money](#CIM17v40-Money) | The amount of the debit or credit for this account. | |
| postedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time this entry was posted to the ledger. | |
| transactionDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time journal entry was recorded. | |
| `ErpJounalEntry [0..1]` (informative) | [ErpJournalEntry](#CIM17v40-ErpJournalEntry) | | |
| `ErpLedger [1]` (informative) | [ErpLedger](#CIM17v40-ErpLedger) | | |
| `ErpLedgerEntry [0..1]` (informative) | [ErpLedBudLineItem](#CIM17v40-ErpLedBudLineItem) | | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpPOLineItem}
### (informative) ErpPOLineItem

Inheritance path = [ErpDocument](#CIM17v40-ErpDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpPOLineItem {

}

class ErpDocument {

}

ErpDocument <|-- ErpPOLineItem : inherits from
class AssetModelCatalogueItem {

}

ErpPOLineItem --> "0..1" AssetModelCatalogueItem : AssetModelCatalogueItem
class ErpPurchaseOrder {

}

ErpPOLineItem --> "1" ErpPurchaseOrder : ErpPurchaseOrder
class ErpRecDelvLineItem {

}

ErpPOLineItem --> "0..1" ErpRecDelvLineItem : ErpRecDelLineItem
class ErpReqLineItem {

}

ErpPOLineItem --> "0..1" ErpReqLineItem : ErpReqLineItem
```

Of an ErpPurchaseOrder, this is an individually ordered item or product along with the quantity, price and other descriptive information.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `AssetModelCatalogueItem [0..1]` (informative) | [AssetModelCatalogueItem](#CIM17v40-AssetModelCatalogueItem) | | |
| `ErpPurchaseOrder [1]` (informative) | [ErpPurchaseOrder](#CIM17v40-ErpPurchaseOrder) | | |
| `ErpRecDelLineItem [0..1]` (informative) | [ErpRecDelvLineItem](#CIM17v40-ErpRecDelvLineItem) | | |
| `ErpReqLineItem [0..1]` (informative) | [ErpReqLineItem](#CIM17v40-ErpReqLineItem) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpPayable}
### (informative) ErpPayable

Inheritance path = [ErpDocument](#CIM17v40-ErpDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpPayable {

}

class ErpDocument {

}

ErpDocument <|-- ErpPayable : inherits from
```

A transaction that represents an invoice from a supplier. A payable (or voucher) is an open item, approved and ready for payment, in the Accounts Payable ledger.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpPayableLineItem}
### (informative) ErpPayableLineItem

Inheritance path = [ErpIdentifiedObject](#CIM17v40-ErpIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpPayableLineItem {

+ status : Status [0..1]
}

class ErpIdentifiedObject {

}

ErpIdentifiedObject <|-- ErpPayableLineItem : inherits from
class ErpInvoiceLineItem {

}

ErpPayableLineItem --> "0..1" ErpInvoiceLineItem : ErpInvoiceLineItem
class ErpPayable {

}

ErpPayableLineItem --> "1" ErpPayable : ErpPayable
```

Of an ErpPayable, a line item references an ErpInvoiceLineitem or other source such as credit memos.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ErpInvoiceLineItem [0..1]` (informative) | [ErpInvoiceLineItem](#CIM17v40-ErpInvoiceLineItem) | | |
| `ErpPayable [1]` (informative) | [ErpPayable](#CIM17v40-ErpPayable) | | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpPayment}
### ErpPayment

Inheritance path = [ErpDocument](#CIM17v40-ErpDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpPayment {

+ termsPayment : String [0..1]
}

class ErpDocument {

}

ErpDocument <|-- ErpPayment : inherits from
```

Payment infromation and status for any individual line item of an ErpInvoice (e.g., when payment is from a customer). ErpPayable is also updated when payment is to a supplier and ErpReceivable is updated when payment is from a customer. Multiple payments can be made against a single line item and an individual payment can apply to more that one line item.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| termsPayment [0..1] | [String](#CIM17v40-String) | Payment terms (e.g., net 30). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpPersonnel}
### (informative) ErpPersonnel

Inheritance path = [ErpIdentifiedObject](#CIM17v40-ErpIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpPersonnel {

+ status : Status [0..1]
}

class ErpIdentifiedObject {

}

ErpIdentifiedObject <|-- ErpPersonnel : inherits from
```

Information that applies to the basic data about a utility person, used by ERP applications to transfer Personnel data for a worker.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpProjectAccounting}
### (informative) ErpProjectAccounting

Inheritance path = [ErpDocument](#CIM17v40-ErpDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpProjectAccounting {

}

class ErpDocument {

}

ErpDocument <|-- ErpProjectAccounting : inherits from
```

Utility Project Accounting information, used by ERP applications to enable all relevant sub-systems that submit single sided transactions to transfer information with a Project Accounting Application. This would include, but not necessarily be limited to: Accounts Payable, Accounts Receivable, Budget, Order Management, Purchasing, Time and Labor, Travel and Expense.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpPurchaseOrder}
### (informative) ErpPurchaseOrder

Inheritance path = [ErpDocument](#CIM17v40-ErpDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpPurchaseOrder {

}

class ErpDocument {

}

ErpDocument <|-- ErpPurchaseOrder : inherits from
```

A document that communicates an order to purchase goods from a buyer to a supplier. The PurchaseOrder carries information to and from the buyer and supplier. It is a legally binding document once both Parties agree to the contents and the specified terms and conditions of the order.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpQuote}
### (informative) ErpQuote

Inheritance path = [ErpDocument](#CIM17v40-ErpDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpQuote {

}

class ErpDocument {

}

ErpDocument <|-- ErpQuote : inherits from
```

Document describing the prices of goods or services provided by a supplier. It includes the terms of the purchase, delivery proposals, identification of goods or services ordered, as well as their quantities.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpQuoteLineItem}
### (informative) ErpQuoteLineItem

Inheritance path = [ErpIdentifiedObject](#CIM17v40-ErpIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpQuoteLineItem {

+ status : Status [0..1]
}

class ErpIdentifiedObject {

}

ErpIdentifiedObject <|-- ErpQuoteLineItem : inherits from
class AssetModelCatalogueItem {

}

ErpQuoteLineItem --> "0..1" AssetModelCatalogueItem : AssetModelCatalogueItem
class Design {

}

ErpQuoteLineItem --> "0..1" Design : Design
class ErpInvoiceLineItem {

}

ErpQuoteLineItem --> "0..1" ErpInvoiceLineItem : ErpInvoiceLineItem
class ErpQuote {

}

ErpQuoteLineItem --> "1" ErpQuote : ErpQuote
class ErpReqLineItem {

}

ErpQuoteLineItem --> "0..1" ErpReqLineItem : ErpReqLineItem
```

Of an ErpQuote, the item or product quoted along with quantity, price and other descriptive information.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `AssetModelCatalogueItem [0..1]` (informative) | [AssetModelCatalogueItem](#CIM17v40-AssetModelCatalogueItem) | | |
| `Design [0..1]` (informative) | [Design](#CIM17v40-Design) | | |
| `ErpInvoiceLineItem [0..1]` (informative) | [ErpInvoiceLineItem](#CIM17v40-ErpInvoiceLineItem) | Some utilities provide quotes to customer for services, where the customer accepts the quote by making a payment. An invoice is required for this to occur. | |
| `ErpQuote [1]` (informative) | [ErpQuote](#CIM17v40-ErpQuote) | | |
| `ErpReqLineItem [0..1]` (informative) | [ErpReqLineItem](#CIM17v40-ErpReqLineItem) | | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpRecDelvLineItem}
### (informative) ErpRecDelvLineItem

Inheritance path = [ErpIdentifiedObject](#CIM17v40-ErpIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpRecDelvLineItem {

+ status : Status [0..1]
}

class ErpIdentifiedObject {

}

ErpIdentifiedObject <|-- ErpRecDelvLineItem : inherits from
class ErpInvoiceLineItem {

}

ErpRecDelvLineItem --> "0..1" ErpInvoiceLineItem : ErpInvoiceLineItem
class ErpPOLineItem {

}

ErpRecDelvLineItem --> "0..1" ErpPOLineItem : ErpPOLineItem
class ErpReceiveDelivery {

}

ErpRecDelvLineItem --> "1" ErpReceiveDelivery : ErpReceiveDelivery
```

Of an ErpReceiveDelivery, this is an individually received good or service by the Organisation receiving goods or services. It may be used to indicate receipt of goods in conjunction with a purchase order line item.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ErpInvoiceLineItem [0..1]` (informative) | [ErpInvoiceLineItem](#CIM17v40-ErpInvoiceLineItem) | | |
| `ErpPOLineItem [0..1]` (informative) | [ErpPOLineItem](#CIM17v40-ErpPOLineItem) | | |
| `ErpReceiveDelivery [1]` (informative) | [ErpReceiveDelivery](#CIM17v40-ErpReceiveDelivery) | | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpRecLineItem}
### (informative) ErpRecLineItem

Inheritance path = [ErpIdentifiedObject](#CIM17v40-ErpIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpRecLineItem {

+ status : Status [0..1]
}

class ErpIdentifiedObject {

}

ErpIdentifiedObject <|-- ErpRecLineItem : inherits from
class ErpInvoiceLineItem {

}

ErpRecLineItem --> "0..1" ErpInvoiceLineItem : ErpInvoiceLineItem
class ErpReceivable {

}

ErpRecLineItem --> "1" ErpReceivable : ErpReceivable
```

Individual entry of an ErpReceivable, it is a particular transaction representing an invoice, credit memo or debit memo to a customer.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ErpInvoiceLineItem [0..1]` (informative) | [ErpInvoiceLineItem](#CIM17v40-ErpInvoiceLineItem) | | |
| `ErpReceivable [1]` (informative) | [ErpReceivable](#CIM17v40-ErpReceivable) | | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpReceivable}
### (informative) ErpReceivable

Inheritance path = [ErpDocument](#CIM17v40-ErpDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpReceivable {

}

class ErpDocument {

}

ErpDocument <|-- ErpReceivable : inherits from
```

Transaction representing an invoice, credit memo or debit memo to a customer. It is an open (unpaid) item in the Accounts Receivable ledger.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpReceiveDelivery}
### (informative) ErpReceiveDelivery

Inheritance path = [ErpDocument](#CIM17v40-ErpDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpReceiveDelivery {

}

class ErpDocument {

}

ErpDocument <|-- ErpReceiveDelivery : inherits from
```

Transaction for an Organisation receiving goods or services that may be used to indicate receipt of goods in conjunction with a purchase order. A receivable is an open (unpaid) item in the Accounts Receivable ledger.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpReqLineItem}
### (informative) ErpReqLineItem

Inheritance path = [ErpIdentifiedObject](#CIM17v40-ErpIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpReqLineItem {

+ code : String [0..1]
+ cost : Money [0..1]
+ deliveryDate : Date [0..1]
+ quantity : Integer [0..1]
+ status : Status [0..1]
}

class ErpIdentifiedObject {

}

ErpIdentifiedObject <|-- ErpReqLineItem : inherits from
class ErpPOLineItem {

}

ErpReqLineItem --> "0..1" ErpPOLineItem : ErpPOLineItem
class ErpQuoteLineItem {

}

ErpReqLineItem --> "0..1" ErpQuoteLineItem : ErpQuoteLineItem
class ErpRequisition {

}

ErpReqLineItem --> "1" ErpRequisition : ErpRequisition
class CatalogAssetType {

}

ErpReqLineItem --> "0..1" CatalogAssetType : TypeAsset
class TypeMaterial {

}

ErpReqLineItem --> "0..1" TypeMaterial : TypeMaterial
```

Information that describes a requested item and its attributes.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| code [0..1] | [String](#CIM17v40-String) | | |
| cost [0..1] | [Money](#CIM17v40-Money) | Cost of material. | |
| deliveryDate [0..1] | [Date](#CIM17v40-Date) | | |
| quantity [0..1] | [Integer](#CIM17v40-Integer) | Quantity of item requisitioned. | |
| `ErpPOLineItem [0..1]` (informative) | [ErpPOLineItem](#CIM17v40-ErpPOLineItem) | | |
| `ErpQuoteLineItem [0..1]` (informative) | [ErpQuoteLineItem](#CIM17v40-ErpQuoteLineItem) | | |
| `ErpRequisition [1]` (informative) | [ErpRequisition](#CIM17v40-ErpRequisition) | | |
| status [0..1] | [Status](#CIM17v40-Status) | | |
| `TypeAsset [0..1]` (informative) | [CatalogAssetType](#CIM17v40-CatalogAssetType) | | |
| `TypeMaterial [0..1]` (informative) | [TypeMaterial](#CIM17v40-TypeMaterial) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpRequisition}
### (informative) ErpRequisition

Inheritance path = [ErpDocument](#CIM17v40-ErpDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpRequisition {

}

class ErpDocument {

}

ErpDocument <|-- ErpRequisition : inherits from
```

General information that applies to a utility requisition that is a request for the purchase of goods or services. Typically, a requisition leads to the creation of a purchase order to a specific supplier.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpSalesOrder}
### ErpSalesOrder

Inheritance path = [ErpDocument](#CIM17v40-ErpDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpSalesOrder {

}

class ErpDocument {

}

ErpDocument <|-- ErpSalesOrder : inherits from
```

General purpose Sales Order is used for utility service orders, etc.

As used by the OAG, the SalesOrder is a step beyond a PurchaseOrder in that the receiving entity of the order also communicates SalesInformoration about the Order along with the Order itself.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpSiteLevelData}
### ErpSiteLevelData

Inheritance path = [ErpIdentifiedObject](#CIM17v40-ErpIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpSiteLevelData {

+ status : Status [0..1]
}

class ErpIdentifiedObject {

}

ErpIdentifiedObject <|-- ErpSiteLevelData : inherits from
class LandProperty {

}

ErpSiteLevelData --> "0..1" LandProperty : LandProperty
```

For a utility, general information that describes physical locations of organizations or the location codes and their meanings. This enables ERP applications to ensure that the physical location identifiers are synchronized between the business applications.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `LandProperty [0..1]` (informative) | [LandProperty](#CIM17v40-LandProperty) | | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpTimeEntry}
### ErpTimeEntry

Inheritance path = [ErpIdentifiedObject](#CIM17v40-ErpIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpTimeEntry {

+ status : Status [0..1]
}

class ErpIdentifiedObject {

}

ErpIdentifiedObject <|-- ErpTimeEntry : inherits from
class ErpProjectAccounting {

}

ErpTimeEntry --> "0..1" ErpProjectAccounting : ErpProjectAccounting
class ErpTimeSheet {

}

ErpTimeEntry --> "1" ErpTimeSheet : ErpTimeSheet
```

An individual entry on an ErpTimeSheet.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ErpProjectAccounting [0..1]` (informative) | [ErpProjectAccounting](#CIM17v40-ErpProjectAccounting) | | |
| `ErpTimeSheet [1]` (informative) | [ErpTimeSheet](#CIM17v40-ErpTimeSheet) | | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ErpTimeSheet}
### (informative) ErpTimeSheet

Inheritance path = [ErpDocument](#CIM17v40-ErpDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ErpTimeSheet {

}

class ErpDocument {

}

ErpDocument <|-- ErpTimeSheet : inherits from
```

Time sheet for employees and contractors. Note that ErpTimeSheet inherits the relationship to ErpPerson from Document.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-EstimatedRestorationTime}
### EstimatedRestorationTime


```mermaid
classDiagram
direction TB

class EstimatedRestorationTime {

+ confidenceKind : enum:ERTConfidenceKind [0..1]
+ ert : DateTime [0..1]
+ ertSource : String [0..1]
}

```

The Estimated Restoration Time (ERT) for a single outage


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| confidenceKind [0..1] | [ERTConfidenceKind](#CIM17v40-ERTConfidenceKind) | provides the confidence level that this ERT can be accomplished. This may be changed/updated as needed. | |
| ert [0..1] | [DateTime](#CIM17v40-DateTime) | estimated time the outage will be restored | |
| ertSource [0..1] | [String](#CIM17v40-String) | defines the source that provided the ERT value. | |

{#CIM17v40-ExPostLoss}
### ExPostLoss

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExPostLoss {

}

class MarketFactors {

}

MarketFactors <|-- ExPostLoss : inherits from
```

Model of ex-post calcultion of MW losses.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExPostLossResults}
### ExPostLossResults


```mermaid
classDiagram
direction TB

class ExPostLossResults {

+ ehvLossMW : Float [0..1]
+ totalLossMW : Float [0..1]
}

class ExPostLoss {

}

ExPostLossResults --> "1" ExPostLoss : ExPostLoss
class SubControlArea {

}

ExPostLossResults --> "0..1" SubControlArea : SubControlArea
```

Model results of ex-post calculation of MW losses. Summarizes loss in two categories losses on the the extra high voltage transmission and total losses. Calculated for each subcontrol area.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ehvLossMW [0..1] | [Float](#CIM17v40-Float) | EHV MW losses in the companyAttribute Usage: Information purposes - Output of LPA engine. | |
| totalLossMW [0..1] | [Float](#CIM17v40-Float) | Total MW losses in the companyAttribute Usage: Information purposes - Output of LPA engine. | |
| ExPostLoss [1] | [ExPostLoss](#CIM17v40-ExPostLoss) | | |
| SubControlArea [0..1] | [SubControlArea](#CIM17v40-SubControlArea) | | |

{#CIM17v40-ExPostMarketRegion}
### ExPostMarketRegion

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExPostMarketRegion {

}

class MarketFactors {

}

MarketFactors <|-- ExPostMarketRegion : inherits from
class ExPostMarketRegionResults {

}

ExPostMarketRegion --> "0..1" ExPostMarketRegionResults : ExPostMarketRegionResults
```

Model of ex-post calculation of cleared MW on a regional basis.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExPostMarketRegionResults [0..1] | [ExPostMarketRegionResults](#CIM17v40-ExPostMarketRegionResults) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExPostMarketRegionResults}
### ExPostMarketRegionResults


```mermaid
classDiagram
direction TB

class ExPostMarketRegionResults {

+ exPostClearedPrice : Float [0..1]
}

class ExPostMarketRegion {

}

ExPostMarketRegionResults --> "1" ExPostMarketRegion : ExPostMarketRegion
class MarketRegion {

}

ExPostMarketRegionResults --> "1" MarketRegion : MarketRegion
```

Model of expost calculation of cleared MW on a region basis. Includes cleared price.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| exPostClearedPrice [0..1] | [Float](#CIM17v40-Float) | | |
| ExPostMarketRegion [1] | [ExPostMarketRegion](#CIM17v40-ExPostMarketRegion) | | |
| MarketRegion [1] | [MarketRegion](#CIM17v40-MarketRegion) | | |

{#CIM17v40-ExPostPricing}
### ExPostPricing

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExPostPricing {

+ energyPrice : Float [0..1]
}

class MarketFactors {

}

MarketFactors <|-- ExPostPricing : inherits from
```

Model of ex-post pricing of nodes.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| energyPrice [0..1] | [Float](#CIM17v40-Float) | market energy price | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExPostPricingResults}
### ExPostPricingResults


```mermaid
classDiagram
direction TB

class ExPostPricingResults {

+ congestLMP : Float [0..1]
+ lmp : Float [0..1]
+ lossLMP : Float [0..1]
}

class ExPostPricing {

}

ExPostPricingResults --> "1" ExPostPricing : ExPostPricing
class Pnode {

}

ExPostPricingResults --> "1" Pnode : Pnode
```

Model of ex-post pricing of nodes. Includes LMP information, pnode based.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| congestLMP [0..1] | [Float](#CIM17v40-Float) | Congestion component of Location Marginal Price (LMP) in monetary units per MW; congestion component of the hourly LMP at a specific pricing nodeAttribute Usage: Result of the Security, Pricing, and Dispatch(SPD)/Simultaneous Feasibility Test(SFT) software and denotes the hourly congestion component of LMP for each pricing node. | |
| lmp [0..1] | [Float](#CIM17v40-Float) | 5 min weighted average LMP; the Location Marginal Price of the Pnode for which price calculation is carried out.Attribute Usage: 5 min weighted average LMP to be displayed on UI | |
| lossLMP [0..1] | [Float](#CIM17v40-Float) | Loss component of Location Marginal Price (LMP) in monetary units per MW; loss component of the hourly LMP at a specific pricing nodeAttribute Usage: Result of the Security, Pricing, and Dispatch(SPD)/Simultaneous Feasibility Test(SFT) software and denotes the hourly loss component of LMP for each pricing node. | |
| ExPostPricing [1] | [ExPostPricing](#CIM17v40-ExPostPricing) | | |
| Pnode [1] | [Pnode](#CIM17v40-Pnode) | | |

{#CIM17v40-ExPostResource}
### ExPostResource

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExPostResource {

}

class MarketFactors {

}

MarketFactors <|-- ExPostResource : inherits from
```

Model of ex-post pricing of resources.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExPostResourceResults}
### ExPostResourceResults


```mermaid
classDiagram
direction TB

class ExPostResourceResults {

+ congestionLMP : Float [0..1]
+ desiredMW : Float [0..1]
+ dispatchRate : Float [0..1]
+ lmp : Float [0..1]
+ lossLMP : Float [0..1]
+ maxEconomicMW : Float [0..1]
+ minEconomicMW : Float [0..1]
+ resourceMW : Float [0..1]
+ status : enum:EquipmentStatusType [0..1]
}

class ExPostResource {

}

ExPostResourceResults --> "1" ExPostResource : ExPostResource
class RegisteredResource {

}

ExPostResourceResults --> "0..1" RegisteredResource : RegisteredResource
```

Model of ex-post pricing of resources contains components of LMPs: energy, congestion, loss. Resource based.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| congestionLMP [0..1] | [Float](#CIM17v40-Float) | LMP component in USD (deprecated) | |
| desiredMW [0..1] | [Float](#CIM17v40-Float) | Desired output of unit | |
| dispatchRate [0..1] | [Float](#CIM17v40-Float) | Unit Dispatch rate from real time unit dispatch. | |
| lmp [0..1] | [Float](#CIM17v40-Float) | LMP (Local Marginal Price) in USD at the equipment (deprecated) | |
| lossLMP [0..1] | [Float](#CIM17v40-Float) | loss lmp (deprecated) | |
| maxEconomicMW [0..1] | [Float](#CIM17v40-Float) | Economic Maximum MW | |
| minEconomicMW [0..1] | [Float](#CIM17v40-Float) | Economic Minimum MW | |
| resourceMW [0..1] | [Float](#CIM17v40-Float) | Current MW output of the equipmentAttribute Usage: Information purposes - Information purposes - Output of LPA engine. | |
| status [0..1] | [EquipmentStatusType](#CIM17v40-EquipmentStatusType) | Status of equipment | |
| ExPostResource [1] | [ExPostResource](#CIM17v40-ExPostResource) | | |
| RegisteredResource [0..1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |

{#CIM17v40-ExcAC1A}
### ExcAC1A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcAC1A {

+ hvlvgates : Boolean [0..1]
+ ka : PU [0..1]
+ kc : PU [0..1]
+ kd : PU [0..1]
+ ke : PU [0..1]
+ kf : PU [0..1]
+ kf1 : PU [0..1]
+ kf2 : PU [0..1]
+ ks : PU [0..1]
+ seve1 : Float [0..1]
+ seve2 : Float [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ te : Seconds [0..1]
+ tf : Seconds [0..1]
+ vamax : PU [0..1]
+ vamin : PU [0..1]
+ ve1 : PU [0..1]
+ ve2 : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcAC1A : inherits from
```

Modified IEEE AC1A alternator-supplied rectifier excitation system with different rate feedback source.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| hvlvgates [0..1] | [Boolean](#CIM17v40-Boolean) | Indicates if both HV gate and LV gate are active (<i>HVLVgates</i>).true = gates are usedfalse = gates are not used.Typical value = true. | |
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>Ka</i>) (&gt; 0). Typical value = 400. | |
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier loading factor proportional to commutating reactance (<i>Kc</i>) (&gt;= 0). Typical value = 0,2. | |
| kd [0..1] | [PU](#CIM17v40-PU) | Demagnetizing factor, a function of exciter alternator reactances (<i>Kd</i>) (&gt;= 0). Typical value = 0,38. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>Ke</i>). Typical value = 1. | |
| kf [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gains (<i>Kf</i>) (&gt;= 0). Typical value = 0,03. | |
| kf1 [0..1] | [PU](#CIM17v40-PU) | Coefficient to allow different usage of the model (<i>Kf1</i>) (&gt;= 0). Typical value = 0. | |
| kf2 [0..1] | [PU](#CIM17v40-PU) | Coefficient to allow different usage of the model (<i>Kf2</i>) (&gt;= 0). Typical value = 1. | |
| ks [0..1] | [PU](#CIM17v40-PU) | Coefficient to allow different usage of the model-speed coefficient (<i>Ks</i>) (&gt;= 0). Typical value = 0. | |
| seve1 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>Ve</i><i><sub>1</sub></i>, back of commutating reactance (<i>Se[Ve</i><i><sub>1</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,1. | |
| seve2 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>Ve</i><i><sub>2</sub></i>, back of commutating reactance (<i>Se[Ve</i><i><sub>2</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,03. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Ta</i>) (&gt; 0). Typical value = 0,02. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tb</i>) (&gt;= 0). Typical value = 0. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>c</sub></i>) (&gt;= 0). Typical value = 0. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>Te</i>) (&gt; 0). Typical value = 0,8. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>Tf</i>) (&gt; 0). Typical value = 1. | |
| vamax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>V</i><i><sub>amax</sub></i>) (&gt; 0). Typical value = 14,5. | |
| vamin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>V</i><i><sub>amin</sub></i>) (&lt; 0). Typical value = -14,5. | |
| ve1 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>Ve1</i>) (&gt; 0). Typical value = 4,18. | |
| ve2 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>Ve2</i>) (&gt; 0). Typical value = 3,14. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator outputs (<i>Vrmax</i>) (&gt; 0). Typical value = 6,03. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator outputs (<i>Vrmin</i>) (&lt; 0). Typical value = -5,43. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcAC2A}
### ExcAC2A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcAC2A {

+ hvgate : Boolean [0..1]
+ ka : PU [0..1]
+ kb : PU [0..1]
+ kb1 : PU [0..1]
+ kc : PU [0..1]
+ kd : PU [0..1]
+ ke : PU [0..1]
+ kf : PU [0..1]
+ kh : PU [0..1]
+ kl : PU [0..1]
+ kl1 : PU [0..1]
+ ks : PU [0..1]
+ lvgate : Boolean [0..1]
+ seve1 : Float [0..1]
+ seve2 : Float [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ te : Seconds [0..1]
+ tf : Seconds [0..1]
+ vamax : PU [0..1]
+ vamin : PU [0..1]
+ ve1 : PU [0..1]
+ ve2 : PU [0..1]
+ vfemax : PU [0..1]
+ vlr : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcAC2A : inherits from
```

Modified IEEE AC2A alternator-supplied rectifier excitation system with different field current limit.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| hvgate [0..1] | [Boolean](#CIM17v40-Boolean) | Indicates if HV gate is active (<i>HVgate</i>).true = gate is usedfalse = gate is not used.Typical value = true. | |
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>Ka</i>) (&gt; 0). Typical value = 400. | |
| kb [0..1] | [PU](#CIM17v40-PU) | Second stage regulator gain (<i>Kb</i>) (&gt; 0). Exciter field current controller gain. Typical value = 25. | |
| kb1 [0..1] | [PU](#CIM17v40-PU) | Second stage regulator gain (<i>Kb1</i>). It is exciter field current controller gain used as alternative to <i>Kb</i> to represent a variant of the ExcAC2A model. Typical value = 25. | |
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier loading factor proportional to commutating reactance (<i>Kc</i>) (&gt;= 0). Typical value = 0,28. | |
| kd [0..1] | [PU](#CIM17v40-PU) | Demagnetizing factor, a function of exciter alternator reactances (<i>Kd</i>) (&gt;= 0). Typical value = 0,35. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>Ke</i>). Typical value = 1. | |
| kf [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gains (<i>Kf</i>) (&gt;= 0). Typical value = 0,03. | |
| kh [0..1] | [PU](#CIM17v40-PU) | Exciter field current feedback gain (<i>Kh</i>) (&gt;= 0). Typical value = 1. | |
| kl [0..1] | [PU](#CIM17v40-PU) | Exciter field current limiter gain (<i>Kl</i>). Typical value = 10. | |
| kl1 [0..1] | [PU](#CIM17v40-PU) | Coefficient to allow different usage of the model (<i>Kl1</i>). Typical value = 1. | |
| ks [0..1] | [PU](#CIM17v40-PU) | Coefficient to allow different usage of the model-speed coefficient (<i>Ks</i>) (&gt;= 0). Typical value = 0. | |
| lvgate [0..1] | [Boolean](#CIM17v40-Boolean) | Indicates if LV gate is active (<i>LVgate</i>).true = gate is usedfalse = gate is not used.Typical value = true. | |
| seve1 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>Ve</i><i><sub>1</sub></i>, back of commutating reactance (<i>Se[Ve</i><i><sub>1</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,037. | |
| seve2 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>Ve</i><i><sub>2</sub></i>, back of commutating reactance (<i>Se[Ve</i><i><sub>2</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,012. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Ta</i>) (&gt; 0). Typical value = 0,02. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tb</i>) (&gt;= 0). Typical value = 0. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tc</i>) (&gt;= 0). Typical value = 0. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>Te</i>) (&gt; 0). Typical value = 0,6. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>Tf</i>) (&gt; 0). Typical value = 1. | |
| vamax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>Vamax</i>) (&gt; 0). Typical value = 8. | |
| vamin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>Vamin</i>) (&lt; 0). Typical value = -8. | |
| ve1 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>Ve</i><i><sub>1</sub></i>) (&gt; 0). Typical value = 4,4. | |
| ve2 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>Ve</i><i><sub>2</sub></i>) (&gt; 0). Typical value = 3,3. | |
| vfemax [0..1] | [PU](#CIM17v40-PU) | Exciter field current limit reference (<i>Vfemax</i>) (&gt;= 0). Typical value = 4,4. | |
| vlr [0..1] | [PU](#CIM17v40-PU) | Maximum exciter field current (<i>Vlr</i>) (&gt; 0). Typical value = 4,4. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator outputs (<i>Vrmax</i>) (&gt; 0). Typical value = 105. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator outputs (<i>Vrmin</i>) (&lt; 0). Typical value = -95. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcAC3A}
### ExcAC3A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcAC3A {

+ efdn : PU [0..1]
+ ka : Seconds [0..1]
+ kc : PU [0..1]
+ kd : PU [0..1]
+ ke : PU [0..1]
+ kf : PU [0..1]
+ kf1 : PU [0..1]
+ kf2 : PU [0..1]
+ klv : PU [0..1]
+ kn : PU [0..1]
+ kr : PU [0..1]
+ ks : PU [0..1]
+ seve1 : Float [0..1]
+ seve2 : Float [0..1]
+ ta : PU [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ te : Seconds [0..1]
+ tf : Seconds [0..1]
+ vamax : PU [0..1]
+ vamin : PU [0..1]
+ ve1 : PU [0..1]
+ ve2 : PU [0..1]
+ vemin : PU [0..1]
+ vfemax : PU [0..1]
+ vlv : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcAC3A : inherits from
```

Modified IEEE AC3A alternator-supplied rectifier excitation system with different field current limit.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efdn [0..1] | [PU](#CIM17v40-PU) | Value of <i>Efd </i>at which feedback gain changes (<i>Efdn</i>) (&gt; 0). Typical value = 2,36. | |
| ka [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator gain (<i>Ka</i>) (&gt; 0). Typical value = 45,62. | |
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier loading factor proportional to commutating reactance (<i>Kc</i>) (&gt;= 0). Typical value = 0,104. | |
| kd [0..1] | [PU](#CIM17v40-PU) | Demagnetizing factor, a function of exciter alternator reactances (<i>Kd</i>) (&gt;= 0). Typical value = 0,499. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>Ke</i>). Typical value = 1. | |
| kf [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gains (<i>Kf</i>) (&gt;= 0). Typical value = 0,143. | |
| kf1 [0..1] | [PU](#CIM17v40-PU) | Coefficient to allow different usage of the model (<i>Kf1</i>). Typical value = 1. | |
| kf2 [0..1] | [PU](#CIM17v40-PU) | Coefficient to allow different usage of the model (<i>Kf2</i>). Typical value = 0. | |
| klv [0..1] | [PU](#CIM17v40-PU) | Gain used in the minimum field voltage limiter loop (<i>Klv</i>). Typical value = 0,194. | |
| kn [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gain (<i>Kn</i>) (&gt;= 0). Typical value =0,05. | |
| kr [0..1] | [PU](#CIM17v40-PU) | Constant associated with regulator and alternator field power supply (<i>Kr</i>) (&gt; 0). Typical value =3,77. | |
| ks [0..1] | [PU](#CIM17v40-PU) | Coefficient to allow different usage of the model-speed coefficient (<i>Ks</i>). Typical value = 0. | |
| seve1 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>Ve</i><i><sub>1</sub></i>, back of commutating reactance (<i>Se[Ve</i><i><sub>1</sub></i><i>]</i>) (&gt;= 0). Typical value = 1,143. | |
| seve2 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>Ve</i><i><sub>2</sub></i>, back of commutating reactance (<i>Se[Ve</i><i><sub>2</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,1. | |
| ta [0..1] | [PU](#CIM17v40-PU) | Voltage regulator time constant (<i>Ta</i>) (&gt; 0). Typical value = 0,013. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tb</i>) (&gt;= 0). Typical value = 0. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tc</i>) (&gt;= 0). Typical value = 0. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>Te</i>) (&gt; 0). Typical value = 1,17. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>Tf</i>) (&gt; 0). Typical value = 1. | |
| vamax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>Vamax</i>) (&gt; 0). Typical value = 1. | |
| vamin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>Vamin</i>) (&lt; 0). Typical value = -0,95. | |
| ve1 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>Ve</i><i><sub>1</sub></i>) (&gt; 0). Typical value = 6.24. | |
| ve2 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>Ve</i><i><sub>2</sub></i>) (&gt; 0). Typical value = 4,68. | |
| vemin [0..1] | [PU](#CIM17v40-PU) | Minimum exciter voltage output (<i>Vemin</i>) (&lt;= 0). Typical value = 0. | |
| vfemax [0..1] | [PU](#CIM17v40-PU) | Exciter field current limit reference (<i>Vfemax</i>) (&gt;= 0). Typical value = 16. | |
| vlv [0..1] | [PU](#CIM17v40-PU) | Field voltage used in the minimum field voltage limiter loop (<i>Vlv</i>). Typical value = 0,79. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcAC4A}
### ExcAC4A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcAC4A {

+ ka : PU [0..1]
+ kc : PU [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ vimax : PU [0..1]
+ vimin : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcAC4A : inherits from
```

Modified IEEE AC4A alternator-supplied rectifier excitation system with different minimum controller output.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>Ka</i>) (&gt; 0). Typical value = 200. | |
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier loading factor proportional to commutating reactance (<i>Kc</i>) (&gt;= 0). Typical value = 0. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Ta</i>) (&gt; 0). Typical value = 0,015. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tb</i>) (&gt;= 0). Typical value = 10. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tc</i>) (&gt;= 0). Typical value = 1. | |
| vimax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator input limit (<i>Vimax</i>) (&gt; 0). Typical value = 10. | |
| vimin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator input limit (<i>Vimin</i>) (&lt; 0). Typical value = -10. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>Vrmax</i>) (&gt; 0). Typical value = 5,64. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>Vrmin</i>) (&lt; 0). Typical value = -4,53. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcAC5A}
### ExcAC5A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcAC5A {

+ a : Float [0..1]
+ efd1 : PU [0..1]
+ efd2 : PU [0..1]
+ ka : PU [0..1]
+ ke : PU [0..1]
+ kf : PU [0..1]
+ ks : PU [0..1]
+ seefd1 : Float [0..1]
+ seefd2 : Float [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ te : Seconds [0..1]
+ tf1 : Seconds [0..1]
+ tf2 : Seconds [0..1]
+ tf3 : Seconds [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcAC5A : inherits from
```

Modified IEEE AC5A alternator-supplied rectifier excitation system with different minimum controller output.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| a [0..1] | [Float](#CIM17v40-Float) | Coefficient to allow different usage of the model (<i>a</i>). Typical value = 1. | |
| efd1 [0..1] | [PU](#CIM17v40-PU) | Exciter voltage at which exciter saturation is defined (<i>Efd1</i>) (&gt; 0). Typical value = 5,6. | |
| efd2 [0..1] | [PU](#CIM17v40-PU) | Exciter voltage at which exciter saturation is defined (<i>Efd2</i>) (&gt; 0). Typical value = 4,2. | |
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>Ka</i>) (&gt; 0). Typical value = 400. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>Ke</i>). Typical value = 1. | |
| kf [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gains (<i>Kf</i>) (&gt;= 0). Typical value = 0,03. | |
| ks [0..1] | [PU](#CIM17v40-PU) | Coefficient to allow different usage of the model-speed coefficient (<i>Ks</i>). Typical value = 0. | |
| seefd1 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>Efd</i><i><sub>1</sub></i> (<i>Se[Efd</i><i><sub>1</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,86. | |
| seefd2 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>Efd</i><i><sub>2</sub></i> (<i>Se[Efd</i><i><sub>2</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,5. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Ta</i>) (&gt; 0). Typical value = 0,02. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tb</i>) (&gt;= 0). Typical value = 0. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tc</i>) (&gt;= 0). Typical value = 0. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>Te</i>) (&gt; 0). Typical value = 0,8. | |
| tf1 [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>Tf1</i>) (&gt; 0). Typical value = 1. | |
| tf2 [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>Tf2</i>) (&gt;= 0). Typical value = 0,8. | |
| tf3 [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>Tf3</i>) (&gt;= 0). Typical value = 0. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>Vrmax</i>) (&gt; 0). Typical value = 7,3. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>Vrmin</i>) (&lt; 0). Typical value =-7,3. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcAC6A}
### ExcAC6A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcAC6A {

+ ka : PU [0..1]
+ kc : PU [0..1]
+ kd : PU [0..1]
+ ke : PU [0..1]
+ kh : PU [0..1]
+ ks : PU [0..1]
+ seve1 : Float [0..1]
+ seve2 : Float [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ te : Seconds [0..1]
+ th : Seconds [0..1]
+ tj : Seconds [0..1]
+ tk : Seconds [0..1]
+ vamax : PU [0..1]
+ vamin : PU [0..1]
+ ve1 : PU [0..1]
+ ve2 : PU [0..1]
+ vfelim : PU [0..1]
+ vhmax : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcAC6A : inherits from
```

Modified IEEE AC6A alternator-supplied rectifier excitation system with speed input.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>Ka</i>) (&gt; 0). Typical value = 536. | |
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier loading factor proportional to commutating reactance (<i>Kc</i>) (&gt;= 0). Typical value = 0,173. | |
| kd [0..1] | [PU](#CIM17v40-PU) | Demagnetizing factor, a function of exciter alternator reactances (<i>Kd</i>) (&gt;= 0). Typical value = 1,91. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>Ke</i>). Typical value = 1,6. | |
| kh [0..1] | [PU](#CIM17v40-PU) | Exciter field current limiter gain (<i>Kh</i>) (&gt;= 0). Typical value = 92. | |
| ks [0..1] | [PU](#CIM17v40-PU) | Coefficient to allow different usage of the model-speed coefficient (<i>Ks</i>). Typical value = 0. | |
| seve1 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>Ve</i><i><sub>1</sub></i>, back of commutating reactance (<i>Se[Ve</i><i><sub>1</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,214. | |
| seve2 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>Ve</i><i><sub>2</sub></i>, back of commutating reactance (<i>Se[Ve</i><i><sub>2</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,044. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Ta</i>) (&gt;= 0). Typical value = 0,086. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tb</i>) (&gt;= 0). Typical value = 9. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tc</i>) (&gt;= 0). Typical value = 3. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>Te</i>) (&gt; 0). Typical value = 1. | |
| th [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter field current limiter time constant (<i>Th</i>) (&gt; 0). Typical value = 0,08. | |
| tj [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter field current limiter time constant (<i>Tj</i>) (&gt;= 0). Typical value = 0,02. | |
| tk [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tk</i>) (&gt;= 0). Typical value = 0,18. | |
| vamax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>Vamax</i>) (&gt; 0). Typical value = 75. | |
| vamin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>Vamin</i>) (&lt; 0). Typical value = -75. | |
| ve1 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>Ve</i><i><sub>1</sub></i>) (&gt; 0). Typical value = 7,4. | |
| ve2 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>Ve</i><i><sub>2</sub></i>) (&gt; 0). Typical value = 5,55. | |
| vfelim [0..1] | [PU](#CIM17v40-PU) | Exciter field current limit reference (<i>Vfelim</i>) (&gt; 0). Typical value = 19. | |
| vhmax [0..1] | [PU](#CIM17v40-PU) | Maximum field current limiter signal reference (<i>Vhmax</i>) (&gt; 0). Typical value = 75. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>Vrmax</i>) (&gt; 0). Typical value = 44. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>Vrmin</i>) (&lt; 0). Typical value = -36. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcAC8B}
### ExcAC8B

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcAC8B {

+ inlim : Boolean [0..1]
+ ka : PU [0..1]
+ kc : PU [0..1]
+ kd : PU [0..1]
+ kdr : PU [0..1]
+ ke : PU [0..1]
+ kir : PU [0..1]
+ kpr : PU [0..1]
+ ks : PU [0..1]
+ pidlim : Boolean [0..1]
+ seve1 : Float [0..1]
+ seve2 : Float [0..1]
+ ta : Seconds [0..1]
+ tdr : Seconds [0..1]
+ te : Seconds [0..1]
+ telim : Boolean [0..1]
+ ve1 : PU [0..1]
+ ve2 : PU [0..1]
+ vemin : PU [0..1]
+ vfemax : PU [0..1]
+ vimax : PU [0..1]
+ vimin : PU [0..1]
+ vpidmax : PU [0..1]
+ vpidmin : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
+ vtmult : Boolean [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcAC8B : inherits from
```

Modified IEEE AC8B alternator-supplied rectifier excitation system with speed input and input limiter.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| inlim [0..1] | [Boolean](#CIM17v40-Boolean) | Input limiter indicator.true = input limiter <i>Vimax</i> and <i>Vimin</i> is consideredfalse = input limiter <i>Vimax </i>and <i>Vimin</i> is not considered.Typical value = true. | |
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>Ka</i>) (&gt; 0). Typical value = 1. | |
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier loading factor proportional to commutating reactance (<i>Kc</i>) (&gt;= 0). Typical value = 0,55. | |
| kd [0..1] | [PU](#CIM17v40-PU) | Demagnetizing factor, a function of exciter alternator reactances (<i>Kd</i>) (&gt;= 0). Typical value = 1,1. | |
| kdr [0..1] | [PU](#CIM17v40-PU) | Voltage regulator derivative gain (<i>Kdr</i>) (&gt;= 0). Typical value = 10. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>Ke</i>). Typical value = 1. | |
| kir [0..1] | [PU](#CIM17v40-PU) | Voltage regulator integral gain (<i>Kir</i>) (&gt;= 0). Typical value = 5. | |
| kpr [0..1] | [PU](#CIM17v40-PU) | Voltage regulator proportional gain (<i>Kpr</i>) (&gt; 0 if ExcAC8B.kir = 0). Typical value = 80. | |
| ks [0..1] | [PU](#CIM17v40-PU) | Coefficient to allow different usage of the model-speed coefficient (<i>Ks</i>). Typical value = 0. | |
| pidlim [0..1] | [Boolean](#CIM17v40-Boolean) | PID limiter indicator.true = input limiter <i>Vpidmax</i> and <i>Vpidmin</i> is consideredfalse = input limiter <i>Vpidmax</i> and <i>Vpidmin</i> is not considered.Typical value = true. | |
| seve1 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>Ve</i><i><sub>1</sub></i>, back of commutating reactance (<i>Se[Ve</i><i><sub>1</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,3. | |
| seve2 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>Ve</i><i><sub>2</sub></i>, back of commutating reactance (<i>Se[Ve</i><i><sub>2</sub></i><i>]</i>) (&gt;= 0). Typical value = 3. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Ta</i>) (&gt;= 0). Typical value = 0. | |
| tdr [0..1] | [Seconds](#CIM17v40-Seconds) | Lag time constant (<i>Tdr</i>) (&gt; 0 if ExcAC8B.kdr &gt; 0). Typical value = 0,1. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>Te</i>) (&gt; 0). Typical value = 1,2. | |
| telim [0..1] | [Boolean](#CIM17v40-Boolean) | Selector for the limiter on the block (<i>1/sTe</i>).See diagram for meaning of true and false.Typical value = false. | |
| ve1 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>Ve</i><i><sub>1</sub></i>) (&gt; 0). Typical value = 6,5. | |
| ve2 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>Ve</i><i><sub>2</sub></i>) (&gt; 0). Typical value = 9. | |
| vemin [0..1] | [PU](#CIM17v40-PU) | Minimum exciter voltage output (<i>Vemin</i>) (&lt;= 0). Typical value = 0. | |
| vfemax [0..1] | [PU](#CIM17v40-PU) | Exciter field current limit reference (<i>Vfemax</i>). Typical value = 6. | |
| vimax [0..1] | [PU](#CIM17v40-PU) | Input signal maximum (<i>Vimax</i>) (&gt; ExcAC8B.vimin). Typical value = 35. | |
| vimin [0..1] | [PU](#CIM17v40-PU) | Input signal minimum (<i>Vimin</i>) (&lt; ExcAC8B.vimax). Typical value = -10. | |
| vpidmax [0..1] | [PU](#CIM17v40-PU) | PID maximum controller output (<i>Vpidmax</i>) (&gt; ExcAC8B.vpidmin). Typical value = 35. | |
| vpidmin [0..1] | [PU](#CIM17v40-PU) | PID minimum controller output (<i>Vpidmin</i>) (&lt; ExcAC8B.vpidmax). Typical value = -10. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>Vrmax</i>) (&gt; 0). Typical value = 35. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>Vrmin</i>) (&lt; 0). Typical value = 0. | |
| vtmult [0..1] | [Boolean](#CIM17v40-Boolean) | Multiply by generator's terminal voltage indicator.true =the limits <i>Vrmax</i> and <i>Vrmin</i> are multiplied by the generator�s terminal voltage to represent a thyristor power stage fed from the generator terminalsfalse = limits are not multiplied by generator's terminal voltage.Typical value = false. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcANS}
### ExcANS

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcANS {

+ blint : Integer [0..1]
+ ifmn : PU [0..1]
+ ifmx : PU [0..1]
+ k2 : Float [0..1]
+ k3 : Float [0..1]
+ kce : Float [0..1]
+ krvecc : Integer [0..1]
+ kvfif : Integer [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ tb : Seconds [0..1]
+ vrmn : PU [0..1]
+ vrmx : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcANS : inherits from
```

Italian excitation system. It represents static field voltage or excitation current feedback excitation system.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| blint [0..1] | [Integer](#CIM17v40-Integer) | Governor control flag (<i>BLINT</i>).0 = lead-lag regulator1 = proportional integral regulator.Typical value = 0. | |
| ifmn [0..1] | [PU](#CIM17v40-PU) | Minimum exciter current (<i>I</i><i><sub>FMN</sub></i>). Typical value = -5,2. | |
| ifmx [0..1] | [PU](#CIM17v40-PU) | Maximum exciter current (<i>I</i><i><sub>FMX</sub></i>). Typical value = 6,5. | |
| k2 [0..1] | [Float](#CIM17v40-Float) | Exciter gain (<i>K</i><i><sub>2</sub></i>). Typical value = 20. | |
| k3 [0..1] | [Float](#CIM17v40-Float) | AVR gain (<i>K</i><i><sub>3</sub></i>). Typical value = 1000. | |
| kce [0..1] | [Float](#CIM17v40-Float) | Ceiling factor (<i>K</i><i><sub>CE</sub></i>). Typical value = 1. | |
| krvecc [0..1] | [Integer](#CIM17v40-Integer) | Feedback enabling (<i>K</i><i><sub>RVECC</sub></i>).0 = open loop control1 = closed loop control.Typical value = 1. | |
| kvfif [0..1] | [Integer](#CIM17v40-Integer) | Rate feedback signal flag (<i>K</i><i><sub>VFIF</sub></i>).0 = output voltage of the exciter1 = exciter field current.Typical value = 0. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>1</sub></i>) (&gt;= 0). Typical value = 20. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>2</sub></i>) (&gt;= 0). Typical value = 0,05. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>3</sub></i>) (&gt;= 0). Typical value = 1,6. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant (<i>T</i><i><sub>B</sub></i>) (&gt;= 0). Typical value = 0,04. | |
| vrmn [0..1] | [PU](#CIM17v40-PU) | Minimum AVR output (<i>V</i><i><sub>RMN</sub></i>). Typical value = -5,2. | |
| vrmx [0..1] | [PU](#CIM17v40-PU) | Maximum AVR output (<i>V</i><i><sub>RMX</sub></i>). Typical value = 6,5. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcAVR1}
### ExcAVR1

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcAVR1 {

+ e1 : PU [0..1]
+ e2 : PU [0..1]
+ ka : Float [0..1]
+ kf : Float [0..1]
+ se1 : Float [0..1]
+ se2 : Float [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ te : Seconds [0..1]
+ tf : Seconds [0..1]
+ vrmn : PU [0..1]
+ vrmx : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcAVR1 : inherits from
```

Italian excitation system corresponding to IEEE (1968) type 1 model. It represents an exciter dynamo and electromechanical regulator.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| e1 [0..1] | [PU](#CIM17v40-PU) | Field voltage value 1 (<i>E</i><i><sub>1</sub></i>). Typical value = 4.18. | |
| e2 [0..1] | [PU](#CIM17v40-PU) | Field voltage value 2 (<i>E</i><i><sub>2</sub></i>). Typical value = 3,14. | |
| ka [0..1] | [Float](#CIM17v40-Float) | AVR gain (<i>K</i><i><sub>A</sub></i>). Typical value = 500. | |
| kf [0..1] | [Float](#CIM17v40-Float) | Rate feedback gain (<i>K</i><i><sub>F</sub></i>). Typical value = 0,12. | |
| se1 [0..1] | [Float](#CIM17v40-Float) | Saturation factor at <i>E</i><i><sub>1</sub></i> (<i>S[E</i><i><sub>1</sub></i><i>]</i>). Typical value = 0,1. | |
| se2 [0..1] | [Float](#CIM17v40-Float) | Saturation factor at <i>E</i><i><sub>2</sub></i> (<i>S[E</i><i><sub>2</sub></i><i>]</i>). Typical value = 0,03. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | AVR time constant (<i>T</i><i><sub>A</sub></i>) (&gt;= 0). Typical value = 0,2. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | AVR time constant (<i>T</i><i><sub>B</sub></i>) (&gt;= 0). Typical value = 0. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant (<i>T</i><i><sub>E</sub></i>) (&gt;= 0). Typical value = 1. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Rate feedback time constant (<i>T</i><i><sub>F</sub></i>) (&gt;= 0). Typical value = 1. | |
| vrmn [0..1] | [PU](#CIM17v40-PU) | Minimum AVR output (<i>V</i><i><sub>RMN</sub></i>). Typical value = -6. | |
| vrmx [0..1] | [PU](#CIM17v40-PU) | Maximum AVR output (<i>V</i><i><sub>RMX</sub></i>). Typical value = 7. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcAVR2}
### ExcAVR2

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcAVR2 {

+ e1 : PU [0..1]
+ e2 : PU [0..1]
+ ka : Float [0..1]
+ kf : Float [0..1]
+ se1 : Float [0..1]
+ se2 : Float [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ te : Seconds [0..1]
+ tf1 : Seconds [0..1]
+ tf2 : Seconds [0..1]
+ vrmn : PU [0..1]
+ vrmx : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcAVR2 : inherits from
```

Italian excitation system corresponding to IEEE (1968) type 2 model. It represents an alternator and rotating diodes and electromechanic voltage regulators.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| e1 [0..1] | [PU](#CIM17v40-PU) | Field voltage value 1 (<i>E</i><i><sub>1</sub></i>). Typical value = 4,18. | |
| e2 [0..1] | [PU](#CIM17v40-PU) | Field voltage value 2 (<i>E</i><i><sub>2</sub></i>). Typical value = 3,14. | |
| ka [0..1] | [Float](#CIM17v40-Float) | AVR gain (<i>K</i><i><sub>A</sub></i>). Typical value = 500. | |
| kf [0..1] | [Float](#CIM17v40-Float) | Rate feedback gain (<i>K</i><i><sub>F</sub></i>). Typical value = 0,12. | |
| se1 [0..1] | [Float](#CIM17v40-Float) | Saturation factor at <i>E</i><i><sub>1</sub></i> (<i>S[E</i><i><sub>1</sub></i><i>]</i>). Typical value = 0.1. | |
| se2 [0..1] | [Float](#CIM17v40-Float) | Saturation factor at <i>E</i><i><sub>2</sub></i> (<i>S[E</i><i><sub>2</sub></i><i>]</i>). Typical value = 0,03. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | AVR time constant (<i>T</i><i><sub>A</sub></i>) (&gt;= 0). Typical value = 0,02. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | AVR time constant (<i>T</i><i><sub>B</sub></i>) (&gt;= 0). Typical value = 0. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant (<i>T</i><i><sub>E</sub></i>) (&gt;= 0). Typical value = 1. | |
| tf1 [0..1] | [Seconds](#CIM17v40-Seconds) | Rate feedback time constant (<i>T</i><i><sub>F1</sub></i>) (&gt;= 0). Typical value = 1. | |
| tf2 [0..1] | [Seconds](#CIM17v40-Seconds) | Rate feedback time constant (<i>T</i><i><sub>F2</sub></i>) (&gt;= 0). Typical value = 1. | |
| vrmn [0..1] | [PU](#CIM17v40-PU) | Minimum AVR output (<i>V</i><i><sub>RMN</sub></i>). Typical value = -6. | |
| vrmx [0..1] | [PU](#CIM17v40-PU) | Maximum AVR output (<i>V</i><i><sub>RMX</sub></i>). Typical value = 7. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcAVR3}
### ExcAVR3

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcAVR3 {

+ e1 : PU [0..1]
+ e2 : PU [0..1]
+ ka : Float [0..1]
+ se1 : Float [0..1]
+ se2 : Float [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ te : Seconds [0..1]
+ vrmn : PU [0..1]
+ vrmx : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcAVR3 : inherits from
```

Italian excitation system. It represents an exciter dynamo and electric regulator.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| e1 [0..1] | [PU](#CIM17v40-PU) | Field voltage value 1 (<i>E</i><i><sub>1</sub></i>). Typical value = 4,18. | |
| e2 [0..1] | [PU](#CIM17v40-PU) | Field voltage value 2 (<i>E</i><i><sub>2</sub></i>). Typical value = 3,14. | |
| ka [0..1] | [Float](#CIM17v40-Float) | AVR gain (<i>K</i><i><sub>A</sub></i>). Typical value = 100. | |
| se1 [0..1] | [Float](#CIM17v40-Float) | Saturation factor at <i>E</i><i><sub>1</sub></i><i> </i>(<i>S[E</i><i><sub>1</sub></i><i>]</i>). Typical value = 0,1. | |
| se2 [0..1] | [Float](#CIM17v40-Float) | Saturation factor at <i>E</i><i><sub>2</sub></i><i> </i>(<i>S[E</i><i><sub>2</sub></i><i>]</i>). Typical value = 0,03. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | AVR time constant (<i>T</i><i><sub>1</sub></i>) (&gt;= 0). Typical value = 20. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | AVR time constant (<i>T</i><i><sub>2</sub></i>) (&gt;= 0). Typical value = 1,6. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | AVR time constant (<i>T</i><i><sub>3</sub></i>) (&gt;= 0). Typical value = 0,66. | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | AVR time constant (<i>T</i><i><sub>4</sub></i>) (&gt;= 0). Typical value = 0,07. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant (<i>T</i><i><sub>E</sub></i>) (&gt;= 0). Typical value = 1. | |
| vrmn [0..1] | [PU](#CIM17v40-PU) | Minimum AVR output (<i>V</i><i><sub>RMN</sub></i>). Typical value = -7,5. | |
| vrmx [0..1] | [PU](#CIM17v40-PU) | Maximum AVR output (<i>V</i><i><sub>RMX</sub></i>). Typical value = 7,5. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcAVR4}
### ExcAVR4

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcAVR4 {

+ imul : Boolean [0..1]
+ ka : Float [0..1]
+ ke : Float [0..1]
+ kif : Float [0..1]
+ t1 : Seconds [0..1]
+ t1if : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ tif : Seconds [0..1]
+ vfmn : PU [0..1]
+ vfmx : PU [0..1]
+ vrmn : PU [0..1]
+ vrmx : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcAVR4 : inherits from
```

Italian excitation system. It represents a static exciter and electric voltage regulator.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| imul [0..1] | [Boolean](#CIM17v40-Boolean) | AVR output voltage dependency selector (<i>I</i><i><sub>MUL</sub></i>).true = selector is connectedfalse = selector is not connected.Typical value = true. | |
| ka [0..1] | [Float](#CIM17v40-Float) | AVR gain (<i>K</i><i><sub>A</sub></i>). Typical value = 300. | |
| ke [0..1] | [Float](#CIM17v40-Float) | Exciter gain (<i>K</i><i><sub>E</sub></i><i>)</i>. Typical value = 1. | |
| kif [0..1] | [Float](#CIM17v40-Float) | Exciter internal reactance (<i>K</i><i><sub>IF</sub></i>). Typical value = 0. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | AVR time constant (<i>T</i><i><sub>1</sub></i>) (&gt;= 0). Typical value = 4,8. | |
| t1if [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter current feedback time constant (<i>T</i><i><sub>1IF</sub></i>) (&gt;= 0). Typical value = 60. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | AVR time constant (<i>T</i><i><sub>2</sub></i>) (&gt;= 0). Typical value = 1,5. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | AVR time constant (<i>T</i><i><sub>3</sub></i>) (&gt;= 0). Typical value = 0. | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | AVR time constant (<i>T</i><i><sub>4</sub></i>) (&gt;= 0). Typical value = 0. | |
| tif [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter current feedback time constant (<i>T</i><i><sub>IF</sub></i>) (&gt;= 0). Typical value = 0. | |
| vfmn [0..1] | [PU](#CIM17v40-PU) | Minimum exciter output (<i>V</i><i><sub>FMN</sub></i>). Typical value = 0. | |
| vfmx [0..1] | [PU](#CIM17v40-PU) | Maximum exciter output (<i>V</i><i><sub>FMX</sub></i>). Typical value = 5. | |
| vrmn [0..1] | [PU](#CIM17v40-PU) | Minimum AVR output (<i>V</i><i><sub>RMN</sub></i>). Typical value = 0. | |
| vrmx [0..1] | [PU](#CIM17v40-PU) | Maximum AVR output (<i>V</i><i><sub>RMX</sub></i>). Typical value = 5. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcAVR5}
### ExcAVR5

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcAVR5 {

+ ka : PU [0..1]
+ rex : PU [0..1]
+ ta : Seconds [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcAVR5 : inherits from
```

Manual excitation control with field circuit resistance. This model can be used as a very simple representation of manual voltage control.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ka [0..1] | [PU](#CIM17v40-PU) | Gain (<i>Ka</i>). | |
| rex [0..1] | [PU](#CIM17v40-PU) | Effective output resistance (<i>Rex</i>). <i>Rex</i> represents the effective output resistance seen by the excitation system. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Ta</i>) (&gt;= 0). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcAVR7}
### ExcAVR7

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcAVR7 {

+ a1 : PU [0..1]
+ a2 : PU [0..1]
+ a3 : PU [0..1]
+ a4 : PU [0..1]
+ a5 : PU [0..1]
+ a6 : PU [0..1]
+ k1 : PU [0..1]
+ k3 : PU [0..1]
+ k5 : PU [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ t5 : Seconds [0..1]
+ t6 : Seconds [0..1]
+ vmax1 : PU [0..1]
+ vmax3 : PU [0..1]
+ vmax5 : PU [0..1]
+ vmin1 : PU [0..1]
+ vmin3 : PU [0..1]
+ vmin5 : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcAVR7 : inherits from
```

IVO excitation system.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| a1 [0..1] | [PU](#CIM17v40-PU) | Lead coefficient (<i>A</i><i><sub>1</sub></i>). Typical value = 0,5. | |
| a2 [0..1] | [PU](#CIM17v40-PU) | Lag coefficient (<i>A</i><i><sub>2</sub></i>). Typical value = 0,5. | |
| a3 [0..1] | [PU](#CIM17v40-PU) | Lead coefficient (<i>A</i><i><sub>3</sub></i>). Typical value = 0,5. | |
| a4 [0..1] | [PU](#CIM17v40-PU) | Lag coefficient (<i>A</i><i><sub>4</sub></i>). Typical value = 0,5. | |
| a5 [0..1] | [PU](#CIM17v40-PU) | Lead coefficient (<i>A</i><i><sub>5</sub></i>). Typical value = 0,5. | |
| a6 [0..1] | [PU](#CIM17v40-PU) | Lag coefficient (<i>A</i><i><sub>6</sub></i>). Typical value = 0,5. | |
| k1 [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K</i><i><sub>1</sub></i>). Typical value = 1. | |
| k3 [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K</i><i><sub>3</sub></i>). Typical value = 3. | |
| k5 [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K</i><i><sub>5</sub></i>). Typical value = 1. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead time constant (<i>T</i><i><sub>1</sub></i>) (&gt;= 0). Typical value = 0,05. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Lag time constant (<i>T</i><i><sub>2</sub></i>) (&gt;= 0). Typical value = 0,1. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead time constant (<i>T</i><i><sub>3</sub></i>) (&gt;= 0). Typical value = 0,1. | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Lag time constant (<i>T</i><i><sub>4</sub></i>) (&gt;= 0). Typical value = 0,1. | |
| t5 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead time constant (<i>T</i><i><sub>5</sub></i>) (&gt;= 0). Typical value = 0,1. | |
| t6 [0..1] | [Seconds](#CIM17v40-Seconds) | Lag time constant (<i>T</i><i><sub>6</sub></i>) (&gt;= 0). Typical value = 0,1. | |
| vmax1 [0..1] | [PU](#CIM17v40-PU) | Lead-lag maximum limit (<i>Vmax1</i>) (&gt; ExcAVR7.vmin1). Typical value = 5. | |
| vmax3 [0..1] | [PU](#CIM17v40-PU) | Lead-lag maximum limit (<i>Vmax3</i>) (&gt; ExcAVR7.vmin3). Typical value = 5. | |
| vmax5 [0..1] | [PU](#CIM17v40-PU) | Lead-lag maximum limit (<i>Vmax5</i>) (&gt; ExcAVR7.vmin5). Typical value = 5. | |
| vmin1 [0..1] | [PU](#CIM17v40-PU) | Lead-lag minimum limit (<i>Vmin1</i>) (&lt; ExcAVR7.vmax1). Typical value = -5. | |
| vmin3 [0..1] | [PU](#CIM17v40-PU) | Lead-lag minimum limit (<i>Vmin3</i>) (&lt; ExcAVR7.vmax3). Typical value = -5. | |
| vmin5 [0..1] | [PU](#CIM17v40-PU) | Lead-lag minimum limit (<i>Vmin5</i>) (&lt; ExcAVR7.vmax5). Typical value = -2. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcBBC}
### ExcBBC

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcBBC {

+ efdmax : PU [0..1]
+ efdmin : PU [0..1]
+ k : PU [0..1]
+ switch : Boolean [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
+ xe : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcBBC : inherits from
```

Transformer fed static excitation system (static with ABB regulator). This model represents a static excitation system in which a gated thyristor bridge fed by a transformer at the main generator terminals feeds the main generator directly.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efdmax [0..1] | [PU](#CIM17v40-PU) | Maximum open circuit exciter voltage (<i>Efdmax</i>) (&gt; ExcBBC.efdmin). Typical value = 5. | |
| efdmin [0..1] | [PU](#CIM17v40-PU) | Minimum open circuit exciter voltage (<i>Efdmin</i>) (&lt; ExcBBC.efdmax). Typical value = -5. | |
| k [0..1] | [PU](#CIM17v40-PU) | Steady state gain (<i>K</i>) (not = 0). Typical value = 300. | |
| switch [0..1] | [Boolean](#CIM17v40-Boolean) | Supplementary signal routing selector (<i>switch</i>).true = <i>Vs</i> connected to 3rd summing pointfalse = <i>Vs</i> connected to 1st summing point (see diagram).Typical value = false. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Controller time constant (<i>T1</i>) (&gt;= 0). Typical value = 6. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Controller time constant (<i>T2</i>) (&gt;= 0). Typical value = 1. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T3</i>) (&gt;= 0). If = 0, block is bypassed. Typical value = 0,05. | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T4</i>) (&gt;= 0). If = 0, block is bypassed. Typical value = 0,01. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum control element output (<i>Vrmax</i>) (&gt; ExcBBC.vrmin). Typical value = 5. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum control element output (<i>Vrmin</i>) (&lt; ExcBBC.vrmax). Typical value = -5. | |
| xe [0..1] | [PU](#CIM17v40-PU) | Effective excitation transformer reactance (<i>Xe</i>) (&gt;= 0). <i>Xe</i> models the regulation of the transformer/rectifier unit. Typical value = 0,05. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcCZ}
### ExcCZ

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcCZ {

+ efdmax : PU [0..1]
+ efdmin : PU [0..1]
+ ka : PU [0..1]
+ ke : PU [0..1]
+ kp : PU [0..1]
+ ta : Seconds [0..1]
+ tc : Seconds [0..1]
+ te : Seconds [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcCZ : inherits from
```

Czech proportion/integral exciter.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efdmax [0..1] | [PU](#CIM17v40-PU) | Exciter output maximum limit (<i>Efdmax</i>) (&gt; ExcCZ.efdmin). | |
| efdmin [0..1] | [PU](#CIM17v40-PU) | Exciter output minimum limit (<i>Efdmin</i>) (&lt; ExcCZ.efdmax). | |
| ka [0..1] | [PU](#CIM17v40-PU) | Regulator gain (<i>Ka</i>). | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>Ke</i>). | |
| kp [0..1] | [PU](#CIM17v40-PU) | Regulator proportional gain (<i>Kp</i>). | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Regulator time constant (<i>Ta</i>) (&gt;= 0). | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Regulator integral time constant (<i>Tc</i>) (&gt;= 0). | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>Te</i>) (&gt;= 0). | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Voltage regulator maximum limit (<i>Vrmax</i>) (&gt; ExcCZ.vrmin). | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Voltage regulator minimum limit (<i>Vrmin</i>) (&lt; ExcCZ.vrmax). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcDC1A}
### ExcDC1A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcDC1A {

+ efd1 : PU [0..1]
+ efd2 : PU [0..1]
+ efdmax : PU [0..1]
+ efdmin : PU [0..1]
+ exclim : Boolean [0..1]
+ ka : PU [0..1]
+ ke : PU [0..1]
+ kf : PU [0..1]
+ ks : PU [0..1]
+ seefd1 : Float [0..1]
+ seefd2 : Float [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ te : Seconds [0..1]
+ tf : Seconds [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcDC1A : inherits from
```

Modified IEEE DC1A direct current commutator exciter with speed input and without underexcitation limiters (UEL) inputs.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efd1 [0..1] | [PU](#CIM17v40-PU) | Exciter voltage at which exciter saturation is defined (<i>Efd</i><i><sub>1</sub></i>) (&gt; 0). Typical value = 3,1. | |
| efd2 [0..1] | [PU](#CIM17v40-PU) | Exciter voltage at which exciter saturation is defined (<i>Efd</i><i><sub>2</sub></i>) (&gt; 0). Typical value = 2,3. | |
| efdmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage exciter output limiter (<i>Efdmax</i>) (&gt; ExcDC1A.efdmin). Typical value = 99. | |
| efdmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage exciter output limiter (<i>Efdmin</i>) (&lt; ExcDC1A.edfmax). Typical value = -99. | |
| exclim [0..1] | [Boolean](#CIM17v40-Boolean) | (<i>exclim</i>). IEEE standard is ambiguous about lower limit on exciter output.true = a lower limit of zero is applied to integrator outputfalse = a lower limit of zero is not applied to integrator output.Typical value = true. | |
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>Ka</i>) (&gt; 0). Typical value = 46. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>Ke</i>). Typical value = 0. | |
| kf [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gain (<i>Kf</i>) (&gt;= 0). Typical value = 0,1. | |
| ks [0..1] | [PU](#CIM17v40-PU) | Coefficient to allow different usage of the model-speed coefficient (<i>Ks</i>). Typical value = 0. | |
| seefd1 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>Efd</i><i><sub>1</sub></i> (<i>Se[Eefd</i><i><sub>1</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,33. | |
| seefd2 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>Efd</i><i><sub>2</sub></i> (<i>Se[Eefd</i><i><sub>2</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,1. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Ta</i>) (&gt; 0). Typical value = 0,06. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tb</i>) (&gt;= 0). Typical value = 0. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tc</i>) (&gt;= 0). Typical value = 0. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>Te</i>) (&gt; 0). Typical value = 0,46. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>Tf</i>) (&gt; 0). Typical value = 1. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>Vrmax</i>) (&gt; ExcDC1A.vrmin). Typical value = 1. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>Vrmin</i>) (&lt; 0 and &lt; ExcDC1A.vrmax). Typical value = -0,9. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcDC2A}
### ExcDC2A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcDC2A {

+ efd1 : PU [0..1]
+ efd2 : PU [0..1]
+ exclim : Boolean [0..1]
+ ka : PU [0..1]
+ ke : PU [0..1]
+ kf : PU [0..1]
+ ks : PU [0..1]
+ seefd1 : Float [0..1]
+ seefd2 : Float [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ te : Seconds [0..1]
+ tf : Seconds [0..1]
+ tf1 : Seconds [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
+ vtlim : Boolean [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcDC2A : inherits from
```

Modified IEEE DC2A direct current commutator exciter with speed input, one more leg block in feedback loop and without underexcitation limiters (UEL) inputs. DC type 2 excitation system model with added speed multiplier, added lead-lag, and voltage-dependent limits.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efd1 [0..1] | [PU](#CIM17v40-PU) | Exciter voltage at which exciter saturation is defined (<i>Efd</i><i><sub>1</sub></i>) (&gt; 0). Typical value = 3,05. | |
| efd2 [0..1] | [PU](#CIM17v40-PU) | Exciter voltage at which exciter saturation is defined (<i>Efd</i><i><sub>2</sub></i>) (&gt; 0). Typical value = 2,29. | |
| exclim [0..1] | [Boolean](#CIM17v40-Boolean) | (<i>exclim</i>). IEEE standard is ambiguous about lower limit on exciter output.true = a lower limit of zero is applied to integrator outputfalse = a lower limit of zero is not applied to integrator output.Typical value = true. | |
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>Ka</i>) (&gt; 0). Typical value = 300. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>Ke</i>). If <i>Ke</i> is entered as zero, the model calculates an effective value of <i>Ke</i> such that the initial condition value of <i>Vr</i> is zero. The zero value of <i>Ke</i> is not changed. If <i>Ke</i> is entered as non-zero, its value is used directly, without change. Typical value = 1. | |
| kf [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gain (<i>Kf</i>) (&gt;= 0). Typical value = 0,1. | |
| ks [0..1] | [PU](#CIM17v40-PU) | Coefficient to allow different usage of the model-speed coefficient (<i>Ks</i>). Typical value = 0. | |
| seefd1 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>Efd</i><i><sub>1</sub></i> (<i>Se[Efd</i><i><sub>1</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,279. | |
| seefd2 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>Efd</i><i><sub>2</sub></i> (<i>Se[Efd</i><i><sub>2</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,117. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Ta</i>) (&gt; 0). Typical value = 0,01. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tb</i>) (&gt;= 0). Typical value = 0. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tc</i>) (&gt;= 0). Typical value = 0. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>Te</i>) (&gt; 0). Typical value = 1,33. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>Tf</i>) (&gt; 0). Typical value = 0,675. | |
| tf1 [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>Tf1</i>) (&gt;= 0). Typical value = 0. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>Vrmax</i>) (&gt; ExcDC2A.vrmin). Typical value = 4,95. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>Vrmin</i>) (&lt; 0 and &lt; ExcDC2A.vrmax). Typical value = -4,9. | |
| vtlim [0..1] | [Boolean](#CIM17v40-Boolean) | (<i>Vtlim</i>).true = limiter at the block (<i>Ka / [1 + sTa]</i>) is dependent on <i>Vt </i>false = limiter at the block is not dependent on <i>Vt</i>.Typical value = true. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcDC3A}
### ExcDC3A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcDC3A {

+ efd1 : PU [0..1]
+ efd2 : PU [0..1]
+ efdlim : Boolean [0..1]
+ efdmax : PU [0..1]
+ efdmin : PU [0..1]
+ exclim : Boolean [0..1]
+ ke : PU [0..1]
+ kr : PU [0..1]
+ ks : PU [0..1]
+ kv : PU [0..1]
+ seefd1 : Float [0..1]
+ seefd2 : Float [0..1]
+ te : Seconds [0..1]
+ trh : Seconds [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcDC3A : inherits from
```

Modified IEEE DC3A direct current commutator exciter with speed input, and deadband. DC old type 4.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efd1 [0..1] | [PU](#CIM17v40-PU) | Exciter voltage at which exciter saturation is defined (<i>Efd</i><i><sub>1</sub></i>) (&gt; 0). Typical value = 2,6. | |
| efd2 [0..1] | [PU](#CIM17v40-PU) | Exciter voltage at which exciter saturation is defined (<i>Efd</i><i><sub>2</sub></i>) (&gt; 0). Typical value = 3,45. | |
| efdlim [0..1] | [Boolean](#CIM17v40-Boolean) | (<i>Efdlim</i>).true = exciter output limiter is activefalse = exciter output limiter not active.Typical value = true. | |
| efdmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage exciter output limiter (<i>Efdmax</i>) (&gt; ExcDC3A.efdmin). Typical value = 99. | |
| efdmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage exciter output limiter (<i>Efdmin</i>) (&lt; ExcDC3A.efdmax). Typical value = -99. | |
| exclim [0..1] | [Boolean](#CIM17v40-Boolean) | (<i>exclim</i>). IEEE standard is ambiguous about lower limit on exciter output.true = a lower limit of zero is applied to integrator outputfalse = a lower limit of zero not applied to integrator output.Typical value = true. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>Ke</i>). Typical value = 1. | |
| kr [0..1] | [PU](#CIM17v40-PU) | Deadband (<i>Kr</i>). Typical value = 0. | |
| ks [0..1] | [PU](#CIM17v40-PU) | Coefficient to allow different usage of the model-speed coefficient (<i>Ks</i>). Typical value = 0. | |
| kv [0..1] | [PU](#CIM17v40-PU) | Fast raise/lower contact setting (<i>Kv</i>) (&gt; 0). Typical value = 0,05. | |
| seefd1 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>Efd</i><i><sub>1</sub></i> (<i>Se[Efd</i><i><sub>1</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,1. | |
| seefd2 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>Efd</i><i><sub>2</sub></i> (<i>Se[Efd</i><i><sub>2</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,35. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>Te</i>) (&gt; 0). Typical value = 1,83. | |
| trh [0..1] | [Seconds](#CIM17v40-Seconds) | Rheostat travel time (<i>Trh</i>) (&gt; 0). Typical value = 20. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>Vrmax</i>) (&gt; 0). Typical value = 5. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>Vrmin</i>) (&lt;= 0). Typical value = 0. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcDC3A1}
### ExcDC3A1

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcDC3A1 {

+ exclim : Boolean [0..1]
+ ka : PU [0..1]
+ ke : PU [0..1]
+ kf : PU [0..1]
+ ki : PU [0..1]
+ kp : PU [0..1]
+ ta : Seconds [0..1]
+ te : Seconds [0..1]
+ tf : Seconds [0..1]
+ vb1max : PU [0..1]
+ vblim : Boolean [0..1]
+ vbmax : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcDC3A1 : inherits from
```

Modified old IEEE type 3 excitation system.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| exclim [0..1] | [Boolean](#CIM17v40-Boolean) | (<i>exclim</i>).true = lower limit of zero is applied to integrator outputfalse = lower limit of zero not applied to integrator output.Typical value = true. | |
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>Ka</i>) (&gt; 0). Typical value = 300. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>Ke</i>). Typical value = 1. | |
| kf [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gain (<i>Kf</i>) (&gt;= 0). Typical value = 0,1. | |
| ki [0..1] | [PU](#CIM17v40-PU) | Potential circuit gain coefficient (<i>Ki</i>) (&gt;= 0). Typical value = 4,83. | |
| kp [0..1] | [PU](#CIM17v40-PU) | Potential circuit gain coefficient (<i>Kp</i>) (&gt;= 0). Typical value = 4,37. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Ta</i>) (&gt; 0). Typical value = 0,01. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>Te</i>) (&gt; 0). Typical value = 1,83. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>Tf</i>) (&gt;= 0). Typical value = 0,675. | |
| vb1max [0..1] | [PU](#CIM17v40-PU) | Available exciter voltage limiter (<i>Vb1max</i>) (&gt; 0). Typical value = 11,63. | |
| vblim [0..1] | [Boolean](#CIM17v40-Boolean) | Vb limiter indicator.true = exciter <i>Vbmax</i> limiter is activefalse = <i>Vb1max</i> is active.Typical value = true. | |
| vbmax [0..1] | [PU](#CIM17v40-PU) | Available exciter voltage limiter (<i>Vbmax</i>) (&gt; 0). Typical value = 11,63. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>Vrmax</i>) (&gt; ExcDC3A1.vrmin). Typical value = 5. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>Vrmin</i>) (&lt; 0 and &lt; ExcDC3A1.vrmax). Typical value = 0. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcELIN1}
### ExcELIN1

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcELIN1 {

+ dpnf : PU [0..1]
+ efmax : PU [0..1]
+ efmin : PU [0..1]
+ ks1 : PU [0..1]
+ ks2 : PU [0..1]
+ smax : PU [0..1]
+ tfi : Seconds [0..1]
+ tnu : Seconds [0..1]
+ ts1 : Seconds [0..1]
+ ts2 : Seconds [0..1]
+ tsw : Seconds [0..1]
+ vpi : PU [0..1]
+ vpnf : PU [0..1]
+ vpu : PU [0..1]
+ xe : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcELIN1 : inherits from
```

Static PI transformer fed excitation system ELIN (VATECH) - simplified model. This model represents an all-static excitation system. A PI voltage controller establishes a desired field current set point for a proportional current controller. The integrator of the PI controller has a follow-up input to match its signal to the present field current. A power system stabilizer with power input is included in the model.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dpnf [0..1] | [PU](#CIM17v40-PU) | Controller follow up deadband (<i>Dpnf</i>). Typical value = 0. | |
| efmax [0..1] | [PU](#CIM17v40-PU) | Maximum open circuit excitation voltage (<i>Efmax</i>) (&gt; ExcELIN1.efmin). Typical value = 5. | |
| efmin [0..1] | [PU](#CIM17v40-PU) | Minimum open circuit excitation voltage (<i>Efmin</i>) (&lt; ExcELIN1.efmax). Typical value = -5. | |
| ks1 [0..1] | [PU](#CIM17v40-PU) | Stabilizer gain 1 (<i>Ks1</i>). Typical value = 0. | |
| ks2 [0..1] | [PU](#CIM17v40-PU) | Stabilizer gain 2 (<i>Ks2</i>). Typical value = 0. | |
| smax [0..1] | [PU](#CIM17v40-PU) | Stabilizer limit output (<i>smax</i>). Typical value = 0,1. | |
| tfi [0..1] | [Seconds](#CIM17v40-Seconds) | Current transducer time constant (<i>Tfi</i>) (&gt;= 0). Typical value = 0. | |
| tnu [0..1] | [Seconds](#CIM17v40-Seconds) | Controller reset time constant (<i>Tnu</i>) (&gt;= 0). Typical value = 2. | |
| ts1 [0..1] | [Seconds](#CIM17v40-Seconds) | Stabilizer phase lag time constant (<i>Ts1</i>) (&gt;= 0). Typical value = 1. | |
| ts2 [0..1] | [Seconds](#CIM17v40-Seconds) | Stabilizer filter time constant (<i>Ts2</i>) (&gt;= 0). Typical value = 1. | |
| tsw [0..1] | [Seconds](#CIM17v40-Seconds) | Stabilizer parameters (<i>Tsw</i>) (&gt;= 0). Typical value = 3. | |
| vpi [0..1] | [PU](#CIM17v40-PU) | Current controller gain (<i>Vpi</i>). Typical value = 12,45. | |
| vpnf [0..1] | [PU](#CIM17v40-PU) | Controller follow up gain (<i>Vpnf</i>). Typical value = 2. | |
| vpu [0..1] | [PU](#CIM17v40-PU) | Voltage controller proportional gain (<i>Vpu</i>). Typical value = 34,5. | |
| xe [0..1] | [PU](#CIM17v40-PU) | Excitation transformer effective reactance (<i>Xe</i>) (&gt;= 0). <i>Xe</i> represents the regulation of the transformer/rectifier unit. Typical value = 0,06. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcELIN2}
### ExcELIN2

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcELIN2 {

+ efdbas : PU [0..1]
+ iefmax : PU [0..1]
+ iefmax2 : PU [0..1]
+ iefmin : PU [0..1]
+ k1 : PU [0..1]
+ k1ec : PU [0..1]
+ k2 : PU [0..1]
+ k3 : PU [0..1]
+ k4 : PU [0..1]
+ kd1 : PU [0..1]
+ ke2 : PU [0..1]
+ ketb : PU [0..1]
+ pid1max : PU [0..1]
+ seve1 : PU [0..1]
+ seve2 : PU [0..1]
+ tb1 : Seconds [0..1]
+ te : Seconds [0..1]
+ te2 : Seconds [0..1]
+ ti1 : PU [0..1]
+ ti3 : Seconds [0..1]
+ ti4 : Seconds [0..1]
+ tr4 : Seconds [0..1]
+ upmax : PU [0..1]
+ upmin : PU [0..1]
+ ve1 : PU [0..1]
+ ve2 : PU [0..1]
+ xp : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcELIN2 : inherits from
```

Detailed excitation system ELIN (VATECH). This model represents an all-static excitation system. A PI voltage controller establishes a desired field current set point for a proportional current controller. The integrator of the PI controller has a follow-up input to match its signal to the present field current. Power system stabilizer models used in conjunction with this excitation system model: PssELIN2, PssIEEE2B, Pss2B.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efdbas [0..1] | [PU](#CIM17v40-PU) | Gain (<i>Efdbas</i>). Typical value = 0,1. | |
| iefmax [0..1] | [PU](#CIM17v40-PU) | Limiter (<i>I</i><i><sub>efmax</sub></i>) (&gt; ExcELIN2.iefmin). Typical value = 1. | |
| iefmax2 [0..1] | [PU](#CIM17v40-PU) | Minimum open circuit excitation voltage (<i>I</i><i><sub>efmax2</sub></i>). Typical value = -5. | |
| iefmin [0..1] | [PU](#CIM17v40-PU) | Limiter (<i>I</i><i><sub>efmin</sub></i>) (&lt; ExcELIN2.iefmax). Typical value = 1. | |
| k1 [0..1] | [PU](#CIM17v40-PU) | Voltage regulator input gain (<i>K1</i>). Typical value = 0. | |
| k1ec [0..1] | [PU](#CIM17v40-PU) | Voltage regulator input limit (<i>K1ec</i>). Typical value = 2. | |
| k2 [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K2</i>). Typical value = 5. | |
| k3 [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K3</i>). Typical value = 0,1. | |
| k4 [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K4</i>). Typical value = 0. | |
| kd1 [0..1] | [PU](#CIM17v40-PU) | Voltage controller derivative gain (<i>Kd1</i>). Typical value = 34,5. | |
| ke2 [0..1] | [PU](#CIM17v40-PU) | Gain (<i>Ke2</i>). Typical value = 0,1. | |
| ketb [0..1] | [PU](#CIM17v40-PU) | Gain (<i>Ketb</i>). Typical value = 0,06. | |
| pid1max [0..1] | [PU](#CIM17v40-PU) | Controller follow up gain (<i>PID1max</i>). Typical value = 2. | |
| seve1 [0..1] | [PU](#CIM17v40-PU) | Exciter saturation function value at the corresponding exciter voltage, <i>Ve</i><i><sub>1</sub></i>, back of commutating reactance (<i>Se[Ve</i><i><sub>1</sub></i><i>]</i>) (&gt;= 0). Typical value = 0. | |
| seve2 [0..1] | [PU](#CIM17v40-PU) | Exciter saturation function value at the corresponding exciter voltage, <i>Ve</i><i><sub>2</sub></i>, back of commutating reactance (<i>Se[Ve</i><i><sub>2</sub></i><i>]</i>) (&gt;= 0). Typical value = 1. | |
| tb1 [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage controller derivative washout time constant (<i>Tb1</i>) (&gt;= 0). Typical value = 12,45. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Te</i>) (&gt;= 0). Typical value = 0. | |
| te2 [0..1] | [Seconds](#CIM17v40-Seconds) | Time Constant (<i>T</i><i><sub>e2</sub></i>) (&gt;= 0). Typical value = 1. | |
| ti1 [0..1] | [PU](#CIM17v40-PU) | Controller follow up deadband (<i>Ti1</i>). Typical value = 0. | |
| ti3 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>i3</sub></i>) (&gt;= 0). Typical value = 3. | |
| ti4 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>i4</sub></i>) (&gt;= 0). Typical value = 0. | |
| tr4 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>r4</sub></i>) (&gt;= 0). Typical value = 1. | |
| upmax [0..1] | [PU](#CIM17v40-PU) | Limiter (<i>Upmax</i>) (&gt; ExcELIN2.upmin). Typical value = 3. | |
| upmin [0..1] | [PU](#CIM17v40-PU) | Limiter (<i>Upmin</i>) (&lt; ExcELIN2.upmax). Typical value = 0. | |
| ve1 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>Ve</i><i><sub>1</sub></i>) (&gt; 0). Typical value = 3. | |
| ve2 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>Ve</i><i><sub>2</sub></i>) (&gt; 0). Typical value = 0. | |
| xp [0..1] | [PU](#CIM17v40-PU) | Excitation transformer effective reactance (<i>Xp</i>). Typical value = 1. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcHU}
### ExcHU

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcHU {

+ ae : PU [0..1]
+ ai : PU [0..1]
+ atr : PU [0..1]
+ emax : PU [0..1]
+ emin : PU [0..1]
+ imax : PU [0..1]
+ imin : PU [0..1]
+ ke : Float [0..1]
+ ki : Float [0..1]
+ te : Seconds [0..1]
+ ti : Seconds [0..1]
+ tr : Seconds [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcHU : inherits from
```

Hungarian excitation system, with built-in voltage transducer.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ae [0..1] | [PU](#CIM17v40-PU) | Major loop PI tag gain factor (<i>Ae</i>). Typical value = 3. | |
| ai [0..1] | [PU](#CIM17v40-PU) | Minor loop PI tag gain factor (<i>Ai</i>). Typical value = 22. | |
| atr [0..1] | [PU](#CIM17v40-PU) | AVR constant (<i>Atr</i>). Typical value = 2,19. | |
| emax [0..1] | [PU](#CIM17v40-PU) | Field voltage control signal upper limit on AVR base (<i>Emax</i>) (&gt; ExcHU.emin). Typical value = 0,996. | |
| emin [0..1] | [PU](#CIM17v40-PU) | Field voltage control signal lower limit on AVR base (<i>Emin</i>) (&lt; ExcHU.emax). Typical value = -0,866. | |
| imax [0..1] | [PU](#CIM17v40-PU) | Major loop PI tag output signal upper limit (<i>Imax</i>) (&gt; ExcHU.imin). Typical value = 2,19. | |
| imin [0..1] | [PU](#CIM17v40-PU) | Major loop PI tag output signal lower limit (<i>Imin</i>) (&lt; ExcHU.imax). Typical value = 0,1. | |
| ke [0..1] | [Float](#CIM17v40-Float) | Voltage base conversion constant (<i>Ke</i>). Typical value = 4,666. | |
| ki [0..1] | [Float](#CIM17v40-Float) | Current base conversion constant (<i>Ki</i>). Typical value = 0,21428. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Major loop PI tag integration time constant (<i>Te</i>) (&gt;= 0). Typical value = 0,154. | |
| ti [0..1] | [Seconds](#CIM17v40-Seconds) | Minor loop PI control tag integration time constant (<i>Ti</i>) (&gt;= 0). Typical value = 0,01333. | |
| tr [0..1] | [Seconds](#CIM17v40-Seconds) | Filter time constant (<i>Tr</i>) (&gt;= 0). If a voltage compensator is used in conjunction with this excitation system model, <i>Tr </i>should be set to 0. Typical value = 0,01. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcIEEEAC1A}
### ExcIEEEAC1A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcIEEEAC1A {

+ ka : PU [0..1]
+ kc : PU [0..1]
+ kd : PU [0..1]
+ ke : PU [0..1]
+ kf : PU [0..1]
+ seve1 : Float [0..1]
+ seve2 : Float [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ te : Seconds [0..1]
+ tf : Seconds [0..1]
+ vamax : PU [0..1]
+ vamin : PU [0..1]
+ ve1 : PU [0..1]
+ ve2 : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcIEEEAC1A : inherits from
```

IEEE 421.5-2005 type AC1A model. The model represents the field-controlled alternator-rectifier excitation systems designated type AC1A. These excitation systems consist of an alternator main exciter with non-controlled rectifiers.

Reference: IEEE 421.5-2005, 6.1.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>K</i><i><sub>A</sub></i>) (&gt; 0). Typical value = 400. | |
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier loading factor proportional to commutating reactance (<i>K</i><i><sub>C</sub></i>) (&gt;= 0). Typical value = 0,2. | |
| kd [0..1] | [PU](#CIM17v40-PU) | Demagnetizing factor, a function of exciter alternator reactances (<i>K</i><i><sub>D</sub></i>) (&gt;= 0). Typical value = 0,38. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>K</i><i><sub>E</sub></i>). Typical value = 1. | |
| kf [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gains (<i>K</i><i><sub>F</sub></i>) (&gt;= 0). Typical value = 0,03. | |
| seve1 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>V</i><i><sub>E1</sub></i>, back of commutating reactance (<i>S</i><i><sub>E</sub></i><i>[V</i><i><sub>E1</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,1. | |
| seve2 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>V</i><i><sub>E2</sub></i>, back of commutating reactance (<i>S</i><i><sub>E</sub></i><i>[V</i><i><sub>E2</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,03. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>A</sub></i>) (&gt; 0). Typical value = 0,02. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>B</sub></i>) (&gt;= 0). Typical value = 0. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>C</sub></i>) (&gt;= 0). Typical value = 0. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>T</i><i><sub>E</sub></i>) (&gt; 0). Typical value = 0,8. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>T</i><i><sub>F</sub></i>) (&gt; 0). Typical value = 1. | |
| vamax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>V</i><i><sub>AMAX</sub></i>) (&gt; 0). Typical value = 14,5. | |
| vamin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>V</i><i><sub>AMIN</sub></i>) (&lt; 0). Typical value = -14,5. | |
| ve1 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>V</i><i><sub>E1</sub></i>) (&gt; 0). Typical value = 4,18. | |
| ve2 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>V</i><i><sub>E2</sub></i>) (&gt; 0). Typical value = 3,14. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator outputs (<i>V</i><i><sub>RMAX</sub></i>) (&gt; 0). Typical value = 6,03. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator outputs (<i>V</i><i><sub>RMIN</sub></i>) (&lt; 0). Typical value = -5,43. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcIEEEAC2A}
### ExcIEEEAC2A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcIEEEAC2A {

+ ka : PU [0..1]
+ kb : PU [0..1]
+ kc : PU [0..1]
+ kd : PU [0..1]
+ ke : PU [0..1]
+ kf : PU [0..1]
+ kh : PU [0..1]
+ seve1 : Float [0..1]
+ seve2 : Float [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ te : Seconds [0..1]
+ tf : Seconds [0..1]
+ vamax : PU [0..1]
+ vamin : PU [0..1]
+ ve1 : PU [0..1]
+ ve2 : PU [0..1]
+ vfemax : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcIEEEAC2A : inherits from
```

IEEE 421.5-2005 type AC2A model. The model represents a high initial response field-controlled alternator-rectifier excitation system. The alternator main exciter is used with non-controlled rectifiers. The type AC2A model is similar to that of type AC1A except for the inclusion of exciter time constant compensation and exciter field current limiting elements.

Reference: IEEE 421.5-2005, 6.2.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>K</i><i><sub>A</sub></i>) (&gt; 0). Typical value = 400. | |
| kb [0..1] | [PU](#CIM17v40-PU) | Second stage regulator gain (<i>K</i><i><sub>B</sub></i>) (&gt; 0). Typical value = 25. | |
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier loading factor proportional to commutating reactance (<i>K</i><i><sub>C</sub></i>) (&gt;= 0). Typical value = 0,28. | |
| kd [0..1] | [PU](#CIM17v40-PU) | Demagnetizing factor, a function of exciter alternator reactances (<i>K</i><i><sub>D</sub></i>) (&gt;= 0). Typical value = 0,35. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>K</i><i><sub>E</sub></i>) (&gt;= 0). Typical value = 1. | |
| kf [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gains (<i>K</i><i><sub>F</sub></i>) (&gt;= 0). Typical value = 0,03. | |
| kh [0..1] | [PU](#CIM17v40-PU) | Exciter field current feedback gain (<i>K</i><i><sub>H</sub></i>) (&gt;= 0). Typical value = 1. | |
| seve1 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>V</i><i><sub>E1</sub></i>, back of commutating reactance (<i>S</i><i><sub>E</sub></i><i>[V</i><i><sub>E1</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,037. | |
| seve2 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>V</i><i><sub>E2</sub></i>, back of commutating reactance (<i>S</i><i><sub>E</sub></i><i>[V</i><i><sub>E2</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,012. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>A</sub></i>) (&gt; 0). Typical value = 0,02. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>B</sub></i>) (&gt;= 0). Typical value = 0. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>C</sub></i>) (&gt;= 0). Typical value = 0. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>T</i><i><sub>E</sub></i>) (&gt; 0). Typical value = 0,6. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>T</i><i><sub>F</sub></i>) (&gt; 0). Typical value = 1. | |
| vamax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>V</i><i><sub>AMAX</sub></i>) (&gt; 0). Typical value = 8. | |
| vamin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>V</i><i><sub>AMIN</sub></i>) (&lt; 0). Typical value = -8. | |
| ve1 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>V</i><i><sub>E1</sub></i>) (&gt; 0). Typical value = 4,4. | |
| ve2 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>V</i><i><sub>E2</sub></i>) (&gt; 0). Typical value = 3,3. | |
| vfemax [0..1] | [PU](#CIM17v40-PU) | Exciter field current limit reference (<i>V</i><i><sub>FEMAX</sub></i>) (&gt; 0). Typical value = 4,4. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator outputs (<i>V</i><i><sub>RMAX</sub></i>) (&gt; 0). Typical value = 105. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator outputs (<i>V</i><i><sub>RMIN</sub></i>) (&lt; 0). Typical value = -95. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcIEEEAC3A}
### ExcIEEEAC3A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcIEEEAC3A {

+ efdn : PU [0..1]
+ ka : PU [0..1]
+ kc : PU [0..1]
+ kd : PU [0..1]
+ ke : PU [0..1]
+ kf : PU [0..1]
+ kn : PU [0..1]
+ kr : PU [0..1]
+ seve1 : Float [0..1]
+ seve2 : Float [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ te : Seconds [0..1]
+ tf : Seconds [0..1]
+ vamax : PU [0..1]
+ vamin : PU [0..1]
+ ve1 : PU [0..1]
+ ve2 : PU [0..1]
+ vemin : PU [0..1]
+ vfemax : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcIEEEAC3A : inherits from
```

IEEE 421.5-2005 type AC3A model. The model represents the field-controlled alternator-rectifier excitation systems designated type AC3A. These excitation systems include an alternator main exciter with non-controlled rectifiers. The exciter employs self-excitation, and the voltage regulator power is derived from the exciter output voltage. Therefore, this system has an additional nonlinearity, simulated by the use of a multiplier whose inputs are the voltage regulator command signal, <i>Va</i>, and the exciter output voltage, <i>Efd</i>, times <i>K</i><i><sub>R</sub></i>. This model is applicable to excitation systems employing static voltage regulators.

Reference: IEEE 421.5-2005, 6.3.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efdn [0..1] | [PU](#CIM17v40-PU) | Value of <i>Efd </i>at which feedback gain changes (<i>E</i><i><sub>FDN</sub></i>) (&gt; 0). Typical value = 2,36. | |
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>K</i><i><sub>A</sub></i>) (&gt; 0). Typical value = 45,62. | |
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier loading factor proportional to commutating reactance (<i>K</i><i><sub>C</sub></i>) (&gt;= 0). Typical value = 0,104. | |
| kd [0..1] | [PU](#CIM17v40-PU) | Demagnetizing factor, a function of exciter alternator reactances (<i>K</i><i><sub>D</sub></i>) (&gt;= 0). Typical value = 0,499. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>K</i><i><sub>E</sub></i>). Typical value = 1. | |
| kf [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gains (<i>K</i><i><sub>F</sub></i>) (&gt;= 0). Typical value = 0,143. | |
| kn [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gain (<i>K</i><i><sub>N</sub></i>) (&gt;= 0). Typical value = 0,05. | |
| kr [0..1] | [PU](#CIM17v40-PU) | Constant associated with regulator and alternator field power supply (<i>K</i><i><sub>R</sub></i>) (&gt; 0). Typical value = 3,77. | |
| seve1 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>V</i><i><sub>E1</sub></i>, back of commutating reactance (<i>S</i><i><sub>E</sub></i><i>[V</i><i><sub>E1</sub></i><i>]</i>) (&gt;= 0). Typical value = 1,143. | |
| seve2 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>V</i><i><sub>E2</sub></i>, back of commutating reactance (<i>S</i><i><sub>E</sub></i><i>[V</i><i><sub>E2</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,1. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>A</sub></i>) (&gt; 0). Typical value = 0,013. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>B</sub></i>) (&gt;= 0). Typical value = 0. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>C</sub></i>) (&gt;= 0). Typical value = 0. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>T</i><i><sub>E</sub></i>) (&gt; 0). Typical value = 1,17. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>T</i><i><sub>F</sub></i>) (&gt; 0). Typical value = 1. | |
| vamax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>V</i><i><sub>AMAX</sub></i>) (&gt; 0). Typical value = 1. | |
| vamin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>V</i><i><sub>AMIN</sub></i>) (&lt; 0). Typical value = -0,95. | |
| ve1 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>V</i><i><sub>E1</sub></i>) (&gt; 0). Typical value = 6,24. | |
| ve2 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>V</i><i><sub>E2</sub></i>) (&gt; 0). Typical value = 4,68. | |
| vemin [0..1] | [PU](#CIM17v40-PU) | Minimum exciter voltage output (<i>V</i><i><sub>EMIN</sub></i>) (&lt;= 0). Typical value = 0. | |
| vfemax [0..1] | [PU](#CIM17v40-PU) | Exciter field current limit reference (<i>V</i><i><sub>FEMAX</sub></i>) (&gt;= 0). Typical value = 16. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcIEEEAC4A}
### ExcIEEEAC4A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcIEEEAC4A {

+ ka : PU [0..1]
+ kc : PU [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ vimax : PU [0..1]
+ vimin : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcIEEEAC4A : inherits from
```

IEEE 421.5-2005 type AC4A model. The model represents type AC4A alternator-supplied controlled-rectifier excitation system which is quite different from the other types of AC systems. This high initial response excitation system utilizes a full thyristor bridge in the exciter output circuit. The voltage regulator controls the firing of the thyristor bridges. The exciter alternator uses an independent voltage regulator to control its output voltage to a constant value. These effects are not modelled; however, transient loading effects on the exciter alternator are included.

Reference: IEEE 421.5-2005, 6.4.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>K</i><i><sub>A</sub></i>) (&gt; 0). Typical value = 200. | |
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier loading factor proportional to commutating reactance (<i>K</i><i><sub>C</sub></i>) (&gt;= 0). Typical value = 0. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>A</sub></i>) (&gt; 0). Typical value = 0,015. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>B</sub></i>) (&gt;= 0). Typical value = 10. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>C</sub></i>) (&gt;= 0). Typical value = 1. | |
| vimax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator input limit (<i>V</i><i><sub>IMAX</sub></i>) (&gt; 0). Typical value = 10. | |
| vimin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator input limit (<i>V</i><i><sub>IMIN</sub></i>) (&lt; 0). Typical value = -10. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>V</i><i><sub>RMAX</sub></i>) (&gt; 0). Typical value = 5,64. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>V</i><i><sub>RMIN</sub></i>) (&lt; 0). Typical value = -4,53. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcIEEEAC5A}
### ExcIEEEAC5A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcIEEEAC5A {

+ efd1 : PU [0..1]
+ efd2 : PU [0..1]
+ ka : PU [0..1]
+ ke : PU [0..1]
+ kf : PU [0..1]
+ seefd1 : Float [0..1]
+ seefd2 : Float [0..1]
+ ta : Seconds [0..1]
+ te : Seconds [0..1]
+ tf1 : Seconds [0..1]
+ tf2 : Seconds [0..1]
+ tf3 : Seconds [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcIEEEAC5A : inherits from
```

IEEE 421.5-2005 type AC5A model. The model represents a simplified model for brushless excitation systems. The regulator is supplied from a source, such as a permanent magnet generator, which is not affected by system disturbances. Unlike other AC models, this model uses loaded rather than open circuit exciter saturation data in the same way as it is used for the DC models. Because the model has been widely implemented by the industry, it is sometimes used to represent other types of systems when either detailed data for them are not available or simplified models are required.

Reference: IEEE 421.5-2005, 6.5.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efd1 [0..1] | [PU](#CIM17v40-PU) | Exciter voltage at which exciter saturation is defined (<i>E</i><i><sub>FD1</sub></i>) (&gt; 0). Typical value = 5,6. | |
| efd2 [0..1] | [PU](#CIM17v40-PU) | Exciter voltage at which exciter saturation is defined (<i>E</i><i><sub>FD2</sub></i>) (&gt; 0). Typical value = 4,2. | |
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>K</i><i><sub>A</sub></i>) (&gt; 0). Typical value = 400. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>K</i><i><sub>E</sub></i>). Typical value = 1. | |
| kf [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gains (<i>K</i><i><sub>F</sub></i>) (&gt;= 0). Typical value = 0,03. | |
| seefd1 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>E</i><i><sub>FD1</sub></i> (<i>S</i><i><sub>E</sub></i><i>[E</i><i><sub>FD1</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,86. | |
| seefd2 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>E</i><i><sub>FD2</sub></i> (<i>S</i><i><sub>E</sub></i><i>[E</i><i><sub>FD2</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,5. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>A</sub></i>) (&gt; 0). Typical value = 0,02. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>T</i><i><sub>E</sub></i>) (&gt; 0). Typical value = 0,8. | |
| tf1 [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>T</i><i><sub>F1</sub></i>) (&gt; 0). Typical value = 1. | |
| tf2 [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>T</i><i><sub>F2</sub></i>) (&gt;= 0). Typical value = 1. | |
| tf3 [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>T</i><i><sub>F3</sub></i>) (&gt;= 0). Typical value = 1. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>V</i><i><sub>RMAX</sub></i>) (&gt; 0). Typical value = 7,3. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>V</i><i><sub>RMIN</sub></i>) (&lt; 0). Typical value = -7,3. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcIEEEAC6A}
### ExcIEEEAC6A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcIEEEAC6A {

+ ka : PU [0..1]
+ kc : PU [0..1]
+ kd : PU [0..1]
+ ke : PU [0..1]
+ kh : PU [0..1]
+ seve1 : Float [0..1]
+ seve2 : Float [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ te : Seconds [0..1]
+ th : Seconds [0..1]
+ tj : Seconds [0..1]
+ tk : Seconds [0..1]
+ vamax : PU [0..1]
+ vamin : PU [0..1]
+ ve1 : PU [0..1]
+ ve2 : PU [0..1]
+ vfelim : PU [0..1]
+ vhmax : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcIEEEAC6A : inherits from
```

IEEE 421.5-2005 type AC6A model. The model represents field-controlled alternator-rectifier excitation systems with system-supplied electronic voltage regulators. The maximum output of the regulator, <i>V</i><i><sub>R</sub></i>, is a function of terminal voltage, <i>V</i><i><sub>T</sub></i>. The field current limiter included in the original model AC6A remains in the 2005 update.

Reference: IEEE 421.5-2005, 6.6.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>K</i><i><sub>A</sub></i>) (&gt; 0). Typical value = 536. | |
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier loading factor proportional to commutating reactance (<i>K</i><i><sub>C</sub></i>) (&gt;= 0). Typical value = 0,173. | |
| kd [0..1] | [PU](#CIM17v40-PU) | Demagnetizing factor, a function of exciter alternator reactances (<i>K</i><i><sub>D</sub></i>) (&gt;= 0). Typical value = 1,91. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>K</i><i><sub>E</sub></i>). Typical value = 1,6. | |
| kh [0..1] | [PU](#CIM17v40-PU) | Exciter field current limiter gain (<i>K</i><i><sub>H</sub></i>) (&gt;= 0). Typical value = 92. | |
| seve1 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>V</i><i><sub>E1</sub></i>, back of commutating reactance (<i>S</i><i><sub>E</sub></i><i>[V</i><i><sub>E1</sub></i><i>])</i> (&gt;= 0). Typical value = 0,214. | |
| seve2 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>V</i><i><sub>E2</sub></i>, back of commutating reactance (<i>S</i><i><sub>E</sub></i><i>[V</i><i><sub>E2</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,044. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>A</sub></i>) (&gt;= 0). Typical value = 0,086. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>B</sub></i>) (&gt;= 0). Typical value = 9. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>C</sub></i>) (&gt;= 0). Typical value = 3. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>T</i><i><sub>E</sub></i>) (&gt; 0). Typical value = 1. | |
| th [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter field current limiter time constant (<i>T</i><i><sub>H</sub></i>) (&gt; 0). Typical value = 0,08. | |
| tj [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter field current limiter time constant (<i>T</i><i><sub>J</sub></i>) (&gt;= 0). Typical value = 0,02. | |
| tk [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>K</sub></i>) (&gt;= 0). Typical value = 0,18. | |
| vamax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>V</i><i><sub>AMAX</sub></i>) (&gt; 0). Typical value = 75. | |
| vamin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (V<sub>AMIN</sub>) (&lt; 0). Typical value = -75. | |
| ve1 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>V</i><i><sub>E1</sub></i>) (&gt; 0). Typical value = 7,4. | |
| ve2 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>V</i><i><sub>E2</sub></i>) (&gt; 0). Typical value = 5,55. | |
| vfelim [0..1] | [PU](#CIM17v40-PU) | Exciter field current limit reference (<i>V</i><i><sub>FELIM</sub></i>) (&gt; 0). Typical value = 19. | |
| vhmax [0..1] | [PU](#CIM17v40-PU) | Maximum field current limiter signal reference (<i>V</i><i><sub>HMAX</sub></i>) (&gt; 0). Typical value = 75. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>V</i><i><sub>RMAX</sub></i>) (&gt; 0). Typical value = 44. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>V</i><i><sub>RMIN</sub></i>) (&lt; 0). Typical value = -36. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcIEEEAC7B}
### ExcIEEEAC7B

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcIEEEAC7B {

+ kc : PU [0..1]
+ kd : PU [0..1]
+ kdr : PU [0..1]
+ ke : PU [0..1]
+ kf1 : PU [0..1]
+ kf2 : PU [0..1]
+ kf3 : PU [0..1]
+ kia : PU [0..1]
+ kir : PU [0..1]
+ kl : PU [0..1]
+ kp : PU [0..1]
+ kpa : PU [0..1]
+ kpr : PU [0..1]
+ seve1 : Float [0..1]
+ seve2 : Float [0..1]
+ tdr : Seconds [0..1]
+ te : Seconds [0..1]
+ tf : Seconds [0..1]
+ vamax : PU [0..1]
+ vamin : PU [0..1]
+ ve1 : PU [0..1]
+ ve2 : PU [0..1]
+ vemin : PU [0..1]
+ vfemax : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcIEEEAC7B : inherits from
```

IEEE 421.5-2005 type AC7B model. The model represents excitation systems which consist of an AC alternator with either stationary or rotating rectifiers to produce the DC field requirements. It is an upgrade to earlier AC excitation systems, which replace only the controls but retain the AC alternator and diode rectifier bridge.

Reference: IEEE 421.5-2005, 6.7. Note, however, that in IEEE 421.5-2005, the [1 / <i>sT</i><i><sub>E</sub></i>] block is shown as [1 / (1 + <i>sT</i><i><sub>E</sub></i>)], which is incorrect.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier loading factor proportional to commutating reactance (<i>K</i><i><sub>C</sub></i>) (&gt;= 0). Typical value = 0,18. | |
| kd [0..1] | [PU](#CIM17v40-PU) | Demagnetizing factor, a function of exciter alternator reactances (<i>K</i><i><sub>D</sub></i>) (&gt;= 0). Typical value = 0,02. | |
| kdr [0..1] | [PU](#CIM17v40-PU) | Voltage regulator derivative gain (<i>K</i><i><sub>DR</sub></i>) (&gt;= 0). Typical value = 0. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>K</i><i><sub>E</sub></i>). Typical value = 1. | |
| kf1 [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gain (<i>K</i><i><sub>F1</sub></i>) (&gt;= 0). Typical value = 0,212. | |
| kf2 [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gain (<i>K</i><i><sub>F2</sub></i>) (&gt;= 0). Typical value = 0. | |
| kf3 [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gain (<i>K</i><i><sub>F3</sub></i>) (&gt;= 0). Typical value = 0. | |
| kia [0..1] | [PU](#CIM17v40-PU) | Voltage regulator integral gain (<i>K</i><i><sub>IA</sub></i>) (&gt;= 0). Typical value = 59,69. | |
| kir [0..1] | [PU](#CIM17v40-PU) | Voltage regulator integral gain (<i>K</i><i><sub>IR</sub></i>) (&gt;= 0). Typical value = 4,24. | |
| kl [0..1] | [PU](#CIM17v40-PU) | Exciter field voltage lower limit parameter (<i>K</i><i><sub>L</sub></i>). Typical value = 10. | |
| kp [0..1] | [PU](#CIM17v40-PU) | Potential circuit gain coefficient (<i>K</i><i><sub>P</sub></i>) (&gt; 0). Typical value = 4,96. | |
| kpa [0..1] | [PU](#CIM17v40-PU) | Voltage regulator proportional gain (<i>K</i><i><sub>PA</sub></i>) (&gt; 0 if ExcIEEEAC7B.kia = 0). Typical value = 65,36. | |
| kpr [0..1] | [PU](#CIM17v40-PU) | Voltage regulator proportional gain (<i>K</i><i><sub>PR</sub></i>) (&gt; 0 if ExcIEEEAC7B.kir = 0). Typical value = 4,24. | |
| seve1 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>V</i><i><sub>E1</sub></i>, back of commutating reactance (<i>S</i><i><sub>E</sub></i><i>[V</i><i><sub>E1</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,44. | |
| seve2 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>V</i><i><sub>E2</sub></i>, back of commutating reactance (<i>S</i><i><sub>E</sub></i><i>[V</i><i><sub>E2</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,075. | |
| tdr [0..1] | [Seconds](#CIM17v40-Seconds) | Lag time constant (<i>T</i><i><sub>DR</sub></i>) (&gt;= 0). Typical value = 0. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>T</i><i><sub>E</sub></i>) (&gt; 0). Typical value = 1,1. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>T</i><i><sub>F</sub></i>) (&gt; 0). Typical value = 1. | |
| vamax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>V</i><i><sub>AMAX</sub></i>) (&gt; 0). Typical value = 1. | |
| vamin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>V</i><i><sub>AMIN</sub></i>) (&lt; 0). Typical value = -0,95. | |
| ve1 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>V</i><i><sub>E1</sub></i>) (&gt; 0). Typical value = 6,3. | |
| ve2 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>V</i><i><sub>E2</sub></i>) (&gt; 0). Typical value = 3,02. | |
| vemin [0..1] | [PU](#CIM17v40-PU) | Minimum exciter voltage output (<i>V</i><i><sub>EMIN</sub></i>) (&lt;= 0). Typical value = 0. | |
| vfemax [0..1] | [PU](#CIM17v40-PU) | Exciter field current limit reference (<i>V</i><i><sub>FEMAX</sub></i>). Typical value = 6,9. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>V</i><i><sub>RMAX</sub></i>) (&gt; 0). Typical value = 5,79. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>V</i><i><sub>RMIN</sub></i>) (&lt; 0). Typical value = -5,79. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcIEEEAC8B}
### ExcIEEEAC8B

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcIEEEAC8B {

+ ka : PU [0..1]
+ kc : PU [0..1]
+ kd : PU [0..1]
+ kdr : PU [0..1]
+ ke : PU [0..1]
+ kir : PU [0..1]
+ kpr : PU [0..1]
+ seve1 : Float [0..1]
+ seve2 : Float [0..1]
+ ta : Seconds [0..1]
+ tdr : Seconds [0..1]
+ te : Seconds [0..1]
+ ve1 : PU [0..1]
+ ve2 : PU [0..1]
+ vemin : PU [0..1]
+ vfemax : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcIEEEAC8B : inherits from
```

IEEE 421.5-2005 type AC8B model. This model represents a PID voltage regulator with either a brushless exciter or DC exciter. The AVR in this model consists of PID control, with separate constants for the proportional (<i>K</i><i><sub>PR</sub></i>), integral (<i>K</i><i><sub>IR</sub></i>), and derivative (<i>K</i><i><sub>DR</sub></i>) gains. The representation of the brushless exciter (<i>T</i><i><sub>E</sub></i>, <i>K</i><i><sub>E</sub></i>, <i>S</i><i><sub>E</sub></i>, <i>K</i><i><sub>C</sub></i>, <i>K</i><i><sub>D</sub></i>) is similar to the model type AC2A. The type AC8B model can be used to represent static voltage regulators applied to brushless excitation systems. Digitally based voltage regulators feeding DC rotating main exciters can be represented with the AC type AC8B model with the parameters <i>K</i><i><sub>C</sub></i> and <i>K</i><i><sub>D</sub></i> set to 0. For thyristor power stages fed from the generator terminals, the limits <i>V</i><i><sub>RMAX</sub></i> and <i>V</i><i><sub>RMIN</sub></i><i> </i>should be a function of terminal voltage: V<i><sub>T</sub></i> x <i>V</i><i><sub>RMAX</sub></i><sub> </sub>and <i>V</i><i><sub>T</sub></i> x <i>V</i><i><sub>RMIN</sub></i>.

Reference: IEEE 421.5-2005, 6.8.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>K</i><i><sub>A</sub></i>) (&gt; 0). Typical value = 1. | |
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier loading factor proportional to commutating reactance (<i>K</i><i><sub>C</sub></i>) (&gt;= 0). Typical value = 0,55. | |
| kd [0..1] | [PU](#CIM17v40-PU) | Demagnetizing factor, a function of exciter alternator reactances (<i>K</i><i><sub>D</sub></i>) (&gt;= 0). Typical value = 1,1. | |
| kdr [0..1] | [PU](#CIM17v40-PU) | Voltage regulator derivative gain (<i>K</i><i><sub>DR</sub></i>) (&gt;= 0). Typical value = 10. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>K</i><i><sub>E</sub></i>). Typical value = 1. | |
| kir [0..1] | [PU](#CIM17v40-PU) | Voltage regulator integral gain (<i>K</i><i><sub>IR</sub></i>) (&gt;= 0). Typical value = 5. | |
| kpr [0..1] | [PU](#CIM17v40-PU) | Voltage regulator proportional gain (<i>K</i><i><sub>PR</sub></i>) (&gt; 0 if ExcIEEEAC8B.kir = 0). Typical value = 80. | |
| seve1 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>V</i><i><sub>E1</sub></i>, back of commutating reactance (<i>S</i><i><sub>E</sub></i><i>[V</i><i><sub>E1</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,3. | |
| seve2 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>V</i><i><sub>E2</sub></i>, back of commutating reactance (<i>S</i><i><sub>E</sub></i><i>[V</i><i><sub>E2</sub></i><i>]</i>) (&gt;= 0). Typical value = 3. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>A</sub></i>) (&gt;= 0). Typical value = 0. | |
| tdr [0..1] | [Seconds](#CIM17v40-Seconds) | Lag time constant (<i>T</i><i><sub>DR</sub></i>) (&gt; 0). Typical value = 0,1. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>T</i><i><sub>E</sub></i>) (&gt; 0). Typical value = 1,2. | |
| ve1 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>V</i><i><sub>E1</sub></i>) (&gt; 0). Typical value = 6,5. | |
| ve2 [0..1] | [PU](#CIM17v40-PU) | Exciter alternator output voltages back of commutating reactance at which saturation is defined (<i>V</i><i><sub>E2</sub></i>) (&gt; 0). Typical value = 9. | |
| vemin [0..1] | [PU](#CIM17v40-PU) | Minimum exciter voltage output (<i>V</i><i><sub>EMIN</sub></i>) (&lt;= 0). Typical value = 0. | |
| vfemax [0..1] | [PU](#CIM17v40-PU) | Exciter field current limit reference (<i>V</i><i><sub>FEMAX</sub></i>). Typical value = 6. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>V</i><i><sub>RMAX</sub></i>) (&gt; 0). Typical value = 35. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>V</i><i><sub>RMIN</sub></i>) (&lt;= 0). Typical value = 0. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcIEEEDC1A}
### ExcIEEEDC1A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcIEEEDC1A {

+ efd1 : PU [0..1]
+ efd2 : PU [0..1]
+ exclim : Boolean [0..1]
+ ka : PU [0..1]
+ ke : PU [0..1]
+ kf : PU [0..1]
+ seefd1 : Float [0..1]
+ seefd2 : Float [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ te : Seconds [0..1]
+ tf : Seconds [0..1]
+ uelin : Boolean [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcIEEEDC1A : inherits from
```

IEEE 421.5-2005 type DC1A model. This model represents field-controlled DC commutator exciters with continuously acting voltage regulators (especially the direct-acting rheostatic, rotating amplifier, and magnetic amplifier types). Because this model has been widely implemented by the industry, it is sometimes used to represent other types of systems when detailed data for them are not available or when a simplified model is required.

Reference: IEEE 421.5-2005, 5.1.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efd1 [0..1] | [PU](#CIM17v40-PU) | Exciter voltage at which exciter saturation is defined (<i>E</i><i><sub>FD1</sub></i>) (&gt; 0). Typical value = 3,1. | |
| efd2 [0..1] | [PU](#CIM17v40-PU) | Exciter voltage at which exciter saturation is defined (<i>E</i><i><sub>FD2</sub></i>) (&gt; 0). Typical value = 2,3. | |
| exclim [0..1] | [Boolean](#CIM17v40-Boolean) | (<i>exclim</i>). IEEE standard is ambiguous about lower limit on exciter output.true = a lower limit of zero is applied to integrator outputfalse = a lower limit of zero is not applied to integrator output.Typical value = true. | |
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>K</i><i><sub>A</sub></i>) (&gt; 0). Typical value = 46. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>K</i><i><sub>E</sub></i>). Typical value = 0. | |
| kf [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gain (<i>K</i><i><sub>F</sub></i>) (&gt;= 0). Typical value = 0.1. | |
| seefd1 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>E</i><i><sub>FD1</sub></i> (<i>S</i><i><sub>E</sub></i><i>[E</i><i><sub>FD1</sub></i><i>]</i>) (&gt;= 0). Typical value = 0.33. | |
| seefd2 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>E</i><i><sub>FD2</sub></i> (<i>S</i><i><sub>E</sub></i><i>[E</i><i><sub>FD2</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,1. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>A</sub></i>) (&gt; 0). Typical value = 0,06. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>B</sub></i>) (&gt;= 0). Typical value = 0. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>C</sub></i>) (&gt;= 0). Typical value = 0. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>T</i><i><sub>E</sub></i>) (&gt; 0). Typical value = 0,46. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>T</i><i><sub>F</sub></i>) (&gt; 0). Typical value = 1. | |
| uelin [0..1] | [Boolean](#CIM17v40-Boolean) | UEL input (<i>uelin</i>).true = input is connected to the HV gatefalse = input connects to the error signal.Typical value = true. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>V</i><i><sub>RMAX</sub></i>) (&gt; ExcIEEEDC1A.vrmin). Typical value = 1. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>V</i><i><sub>RMIN</sub></i>) (&lt; 0 and &lt; ExcIEEEDC1A.vrmax). Typical value = -0,9. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcIEEEDC2A}
### ExcIEEEDC2A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcIEEEDC2A {

+ efd1 : PU [0..1]
+ efd2 : PU [0..1]
+ exclim : PU [0..1]
+ ka : PU [0..1]
+ ke : PU [0..1]
+ kf : PU [0..1]
+ seefd1 : Float [0..1]
+ seefd2 : Float [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ te : Seconds [0..1]
+ tf : Seconds [0..1]
+ uelin : Boolean [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcIEEEDC2A : inherits from
```

IEEE 421.5-2005 type DC2A model. This model represents field-controlled DC commutator exciters with continuously acting voltage regulators having supplies obtained from the generator or auxiliary bus. It differs from the type DC1A model only in the voltage regulator output limits, which are now proportional to terminal voltage <i>V</i><i><sub>T</sub></i>.

It is representative of solid-state replacements for various forms of older mechanical and rotating amplifier regulating equipment connected to DC commutator exciters.

Reference: IEEE 421.5-2005, 5.2.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efd1 [0..1] | [PU](#CIM17v40-PU) | Exciter voltage at which exciter saturation is defined (<i>E</i><i><sub>FD1</sub></i>) (&gt; 0). Typical value = 3,05. | |
| efd2 [0..1] | [PU](#CIM17v40-PU) | Exciter voltage at which exciter saturation is defined (<i>E</i><i><sub>FD2</sub></i>) (&gt; 0). Typical value = 2,29. | |
| exclim [0..1] | [PU](#CIM17v40-PU) | (<i>exclim</i>). IEEE standard is ambiguous about lower limit on exciter output. Typical value = - 999 which means that there is no limit applied. | |
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>K</i><i><sub>A</sub></i>) (&gt; 0). Typical value = 300. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>K</i><i><sub>E</sub></i>). Typical value = 1. | |
| kf [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gain (<i>K</i><i><sub>F</sub></i>) (&gt;= 0). Typical value = 0,1. | |
| seefd1 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>E</i><i><sub>FD1</sub></i> (<i>S</i><i><sub>E</sub></i><i>[E</i><i><sub>FD1</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,279. | |
| seefd2 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>E</i><i><sub>FD2</sub></i> (<i>S</i><i><sub>E</sub></i><i>[E</i><i><sub>FD2</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,117. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>A</sub></i>) (&gt; 0). Typical value = 0,01. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>B</sub></i>) (&gt;= 0). Typical value = 0. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>C</sub></i>) (&gt;= 0). Typical value = 0. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>T</i><i><sub>E</sub></i>) (&gt; 0). Typical value = 1,33. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>T</i><i><sub>F</sub></i>) (&gt; 0). Typical value = 0,675. | |
| uelin [0..1] | [Boolean](#CIM17v40-Boolean) | UEL input (<i>uelin</i>).true = input is connected to the HV gatefalse = input connects to the error signal.Typical value = true. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>V</i><i><sub>RMAX</sub></i>)(&gt; ExcIEEEDC2A.vrmin). Typical value = 4,95. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>V</i><i><sub>RMIN</sub></i>) (&lt; 0 and &lt; ExcIEEEDC2A.vrmax). Typical value = -4,9. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcIEEEDC3A}
### ExcIEEEDC3A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcIEEEDC3A {

+ efd1 : PU [0..1]
+ efd2 : PU [0..1]
+ exclim : Boolean [0..1]
+ ke : PU [0..1]
+ kv : PU [0..1]
+ seefd1 : Float [0..1]
+ seefd2 : Float [0..1]
+ te : Seconds [0..1]
+ trh : Seconds [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcIEEEDC3A : inherits from
```

IEEE 421.5-2005 type DC3A model. This model represents older systems, in particular those DC commutator exciters with non-continuously acting regulators that were commonly used before the development of the continuously acting varieties. These systems respond at basically two different rates, depending upon the magnitude of voltage error. For small errors, adjustment is made periodically with a signal to a motor-operated rheostat. Larger errors cause resistors to be quickly shorted or inserted and a strong forcing signal applied to the exciter. Continuous motion of the motor-operated rheostat occurs for these larger error signals, even though it is bypassed by contactor action.

Reference: IEEE 421.5-2005, 5.3.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efd1 [0..1] | [PU](#CIM17v40-PU) | Exciter voltage at which exciter saturation is defined (<i>E</i><i><sub>FD1</sub></i>) (&gt; 0). Typical value = 3,375. | |
| efd2 [0..1] | [PU](#CIM17v40-PU) | Exciter voltage at which exciter saturation is defined (<i>E</i><i><sub>FD2</sub></i>) (&gt; 0). Typical value = 3,15. | |
| exclim [0..1] | [Boolean](#CIM17v40-Boolean) | (<i>exclim</i>). IEEE standard is ambiguous about lower limit on exciter output.true = a lower limit of zero is applied to integrator outputfalse = a lower limit of zero is not applied to integrator output.Typical value = true. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>K</i><i><sub>E</sub></i>). Typical value = 0,05. | |
| kv [0..1] | [PU](#CIM17v40-PU) | Fast raise/lower contact setting (<i>K</i><i><sub>V</sub></i>) (&gt; 0). Typical value = 0,05. | |
| seefd1 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>E</i><i><sub>FD1</sub></i> (<i>S</i><i><sub>E</sub></i><i>[E</i><i><sub>FD1</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,267. | |
| seefd2 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>E</i><i><sub>FD2</sub></i> (<i>S</i><i><sub>E</sub></i><i>[E</i><i><sub>FD2</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,068. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>T</i><i><sub>E</sub></i>) (&gt; 0). Typical value = 0,5. | |
| trh [0..1] | [Seconds](#CIM17v40-Seconds) | Rheostat travel time (<i>T</i><i><sub>RH</sub></i>) (&gt; 0). Typical value = 20. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>V</i><i><sub>RMAX</sub></i>) (&gt; 0). Typical value = 1. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>V</i><i><sub>RMIN</sub></i>) (&lt;= 0). Typical value = 0. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcIEEEDC4B}
### ExcIEEEDC4B

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcIEEEDC4B {

+ efd1 : PU [0..1]
+ efd2 : PU [0..1]
+ ka : PU [0..1]
+ kd : PU [0..1]
+ ke : PU [0..1]
+ kf : PU [0..1]
+ ki : PU [0..1]
+ kp : PU [0..1]
+ oelin : Boolean [0..1]
+ seefd1 : Float [0..1]
+ seefd2 : Float [0..1]
+ ta : Seconds [0..1]
+ td : Seconds [0..1]
+ te : Seconds [0..1]
+ tf : Seconds [0..1]
+ uelin : Boolean [0..1]
+ vemin : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcIEEEDC4B : inherits from
```

IEEE 421.5-2005 type DC4B model. These excitation systems utilize a field-controlled DC commutator exciter with a continuously acting voltage regulator having supplies obtained from the generator or auxiliary bus.

Reference: IEEE 421.5-2005, 5.4.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efd1 [0..1] | [PU](#CIM17v40-PU) | Exciter voltage at which exciter saturation is defined (<i>E</i><i><sub>FD1</sub></i>) (&gt; 0). Typical value = 1,75. | |
| efd2 [0..1] | [PU](#CIM17v40-PU) | Exciter voltage at which exciter saturation is defined (<i>E</i><i><sub>FD2</sub></i>) (&gt; 0). Typical value = 2,33. | |
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>K</i><i><sub>A</sub></i>) (&gt; 0). Typical value = 1. | |
| kd [0..1] | [PU](#CIM17v40-PU) | Regulator derivative gain (<i>K</i><i><sub>D</sub></i>) (&gt;= 0). Typical value = 20. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>K</i><i><sub>E</sub></i>). Typical value = 1. | |
| kf [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gain (<i>K</i><i><sub>F</sub></i>) (&gt;= 0). Typical value = 0. | |
| ki [0..1] | [PU](#CIM17v40-PU) | Regulator integral gain (<i>K</i><i><sub>I</sub></i>) (&gt;= 0). Typical value = 20. | |
| kp [0..1] | [PU](#CIM17v40-PU) | Regulator proportional gain (<i>K</i><i><sub>P</sub></i>) (&gt;= 0). Typical value = 20. | |
| oelin [0..1] | [Boolean](#CIM17v40-Boolean) | OEL input (<i>OELin</i>).true = LV gatefalse = subtract from error signal.Typical value = true. | |
| seefd1 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>E</i><i><sub>FD1</sub></i> (<i>S</i><i><sub>E</sub></i><i>[E</i><i><sub>FD1</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,08. | |
| seefd2 [0..1] | [Float](#CIM17v40-Float) | Exciter saturation function value at the corresponding exciter voltage, <i>E</i><i><sub>FD2</sub></i> (<i>S</i><i><sub>E</sub></i><i>[E</i><i><sub>FD2</sub></i><i>]</i>) (&gt;= 0). Typical value = 0,27. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>A</sub></i>) (&gt; 0). Typical value = 0,2. | |
| td [0..1] | [Seconds](#CIM17v40-Seconds) | Regulator derivative filter time constant (<i>T</i><i><sub>D</sub></i>) (&gt; 0 if ExcIEEEDC4B.kd &gt; 0). Typical value = 0,01. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>T</i><i><sub>E</sub></i>) (&gt; 0). Typical value = 0,8. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>T</i><i><sub>F</sub></i>) (&gt;= 0). Typical value = 1. | |
| uelin [0..1] | [Boolean](#CIM17v40-Boolean) | UEL input (<i>UELin</i>).true = HV gatefalse = add to error signal.Typical value = true. | |
| vemin [0..1] | [PU](#CIM17v40-PU) | Minimum exciter voltage output (<i>V</i><i><sub>EMIN</sub></i>) (&lt;= 0). Typical value = 0. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>V</i><i><sub>RMAX</sub></i>) (&gt; ExcIEEEDC4B.vrmin). Typical value = 2,7. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>V</i><i><sub>RMIN</sub></i>) (&lt;= 0 and &lt; ExcIEEEDC4B.vrmax). Typical value = -0,9. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcIEEEST1A}
### ExcIEEEST1A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcIEEEST1A {

+ ilr : PU [0..1]
+ ka : PU [0..1]
+ kc : PU [0..1]
+ kf : PU [0..1]
+ klr : PU [0..1]
+ pssin : Boolean [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ tb1 : Seconds [0..1]
+ tc : Seconds [0..1]
+ tc1 : Seconds [0..1]
+ tf : Seconds [0..1]
+ uelin : enum:ExcIEEEST1AUELselectorKind [0..1]
+ vamax : PU [0..1]
+ vamin : PU [0..1]
+ vimax : PU [0..1]
+ vimin : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcIEEEST1A : inherits from
```

IEEE 421.5-2005 type ST1A model. This model represents systems in which excitation power is supplied through a transformer from the generator terminals (or the unit�s auxiliary bus) and is regulated by a controlled rectifier. The maximum exciter voltage available from such systems is directly related to the generator terminal voltage.

Reference: IEEE 421.5-2005, 7.1.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ilr [0..1] | [PU](#CIM17v40-PU) | Exciter output current limit reference (<i>I</i><i><sub>LR</sub></i><i>)</i>. Typical value = 0. | |
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>K</i><i><sub>A</sub></i>) (&gt; 0). Typical value = 190. | |
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier loading factor proportional to commutating reactance (<i>K</i><i><sub>C</sub></i>) (&gt;= 0). Typical value = 0,08. | |
| kf [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gains (<i>K</i><i><sub>F</sub></i>) (&gt;= 0). Typical value = 0. | |
| klr [0..1] | [PU](#CIM17v40-PU) | Exciter output current limiter gain (<i>K</i><i><sub>LR</sub></i>). Typical value = 0. | |
| pssin [0..1] | [Boolean](#CIM17v40-Boolean) | Selector of the Power System Stabilizer (PSS) input (<i>PSSin</i>).true = PSS input (<i>Vs</i>) added to error signalfalse = PSS input (<i>Vs</i>) added to voltage regulator output.Typical value = true. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>A</sub></i>) (&gt;= 0). Typical value = 0. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>B</sub></i>) (&gt;= 0). Typical value = 10. | |
| tb1 [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>B1</sub></i>) (&gt;= 0). Typical value = 0. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>C</sub></i>) (&gt;= 0). Typical value = 1. | |
| tc1 [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>C1</sub></i>) (&gt;= 0). Typical value = 0. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>T</i><i><sub>F</sub></i>) (&gt;= 0). Typical value = 1. | |
| uelin [0..1] | [ExcIEEEST1AUELselectorKind](#CIM17v40-ExcIEEEST1AUELselectorKind) | Selector of the connection of the UEL input (<i>UELin</i>). Typical value = ignoreUELsignal. | |
| vamax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>V</i><i><sub>AMAX</sub></i>) (&gt; 0). Typical value = 14,5. | |
| vamin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>V</i><i><sub>AMIN</sub></i>) (&lt; 0). Typical value = -14,5. | |
| vimax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator input limit (<i>V</i><i><sub>IMAX</sub></i>) (&gt; 0). Typical value = 999. | |
| vimin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator input limit (<i>V</i><i><sub>IMIN</sub></i>) (&lt; 0). Typical value = -999. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator outputs (<i>V</i><i><sub>RMAX</sub></i>) (&gt; 0). Typical value = 7,8. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator outputs (<i>V</i><i><sub>RMIN</sub></i>) (&lt; 0). Typical value = -6,7. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcIEEEST2A}
### ExcIEEEST2A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcIEEEST2A {

+ efdmax : PU [0..1]
+ ka : PU [0..1]
+ kc : PU [0..1]
+ ke : PU [0..1]
+ kf : PU [0..1]
+ ki : PU [0..1]
+ kp : PU [0..1]
+ ta : Seconds [0..1]
+ te : Seconds [0..1]
+ tf : Seconds [0..1]
+ uelin : Boolean [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcIEEEST2A : inherits from
```

IEEE 421.5-2005 type ST2A model. Some static systems use both current and voltage sources (generator terminal quantities) to comprise the power source. The regulator controls the exciter output through controlled saturation of the power transformer components. These compound-source rectifier excitation systems are designated type ST2A and are represented by ExcIEEEST2A.

Reference: IEEE 421.5-2005, 7.2.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efdmax [0..1] | [PU](#CIM17v40-PU) | Maximum field voltage (<i>E</i><i><sub>FDMax</sub></i>) (&gt;= 0). Typical value = 99. | |
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>K</i><i><sub>A</sub></i>) (&gt; 0). Typical value = 120. | |
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier loading factor proportional to commutating reactance (<i>K</i><i><sub>C</sub></i>) (&gt;= 0). Typical value = 1,82. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>K</i><i><sub>E</sub></i>). Typical value = 1. | |
| kf [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gains (<i>K</i><i><sub>F</sub></i>) (&gt;= 0). Typical value = 0,05. | |
| ki [0..1] | [PU](#CIM17v40-PU) | Potential circuit gain coefficient (<i>K</i><i><sub>I</sub></i>) (&gt;= 0). Typical value = 8. | |
| kp [0..1] | [PU](#CIM17v40-PU) | Potential circuit gain coefficient (<i>K</i><i><sub>P</sub></i>) (&gt;= 0). Typical value = 4,88. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>A</sub></i>) (&gt; 0). Typical value = 0,15. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>T</i><i><sub>E</sub></i>) (&gt; 0). Typical value = 0,5. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>T</i><i><sub>F</sub></i>) (&gt;= 0). Typical value = 1. | |
| uelin [0..1] | [Boolean](#CIM17v40-Boolean) | UEL input (<i>UELin</i>).true = HV gatefalse = add to error signal.Typical value = true. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator outputs (<i>V</i><i><sub>RMAX</sub></i>) (&gt; 0). Typical value = 1. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator outputs (<i>V</i><i><sub>RMIN</sub></i>) (&lt;= 0). Typical value = 0. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcIEEEST3A}
### ExcIEEEST3A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcIEEEST3A {

+ ka : PU [0..1]
+ kc : PU [0..1]
+ kg : PU [0..1]
+ ki : PU [0..1]
+ km : PU [0..1]
+ kp : PU [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ thetap : AngleDegrees [0..1]
+ tm : Seconds [0..1]
+ vbmax : PU [0..1]
+ vgmax : PU [0..1]
+ vimax : PU [0..1]
+ vimin : PU [0..1]
+ vmmax : PU [0..1]
+ vmmin : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
+ xl : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcIEEEST3A : inherits from
```

IEEE 421.5-2005 type ST3A model. Some static systems utilize a field voltage control loop to linearize the exciter control characteristic. This also makes the output independent of supply source variations until supply limitations are reached. These systems utilize a variety of controlled-rectifier designs: full thyristor complements or hybrid bridges in either series or shunt configurations. The power source can consist of only a potential source, either fed from the machine terminals or from internal windings. Some designs can have compound power sources utilizing both machine potential and current. These power sources are represented as phasor combinations of machine terminal current and voltage and are accommodated by suitable parameters in model type ST3A which is represented by ExcIEEEST3A.

Reference: IEEE 421.5-2005, 7.3.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>K</i><i><sub>A</sub></i>) (&gt; 0). This is parameter <i>K</i> in the IEEE standard. Typical value = 200. | |
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier loading factor proportional to commutating reactance (<i>K</i><i><sub>C</sub></i>) (&gt;= 0). Typical value = 0,2. | |
| kg [0..1] | [PU](#CIM17v40-PU) | Feedback gain constant of the inner loop field regulator (<i>K</i><i><sub>G</sub></i>) (&gt;= 0). Typical value = 1. | |
| ki [0..1] | [PU](#CIM17v40-PU) | Potential circuit gain coefficient (<i>K</i><i><sub>I</sub></i>) (&gt;= 0). Typical value = 0. | |
| km [0..1] | [PU](#CIM17v40-PU) | Forward gain constant of the inner loop field regulator (<i>K</i><i><sub>M</sub></i>) (&gt; 0). Typical value = 7,93. | |
| kp [0..1] | [PU](#CIM17v40-PU) | Potential circuit gain coefficient (<i>K</i><i><sub>P</sub></i>) (&gt; 0). Typical value = 6,15. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>A</sub></i>) (&gt;= 0). Typical value = 0. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>B</sub></i>) (&gt;= 0). Typical value = 10. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>C</sub></i>) (&gt;= 0). Typical value = 1. | |
| thetap [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Potential circuit phase angle (<i>thetap</i>). Typical value = 0. | |
| tm [0..1] | [Seconds](#CIM17v40-Seconds) | Forward time constant of inner loop field regulator (<i>T</i><i><sub>M</sub></i>) (&gt; 0). Typical value = 0,4. | |
| vbmax [0..1] | [PU](#CIM17v40-PU) | Maximum excitation voltage (<i>V</i><i><sub>BMax</sub></i>) (&gt; 0). Typical value = 6,9. | |
| vgmax [0..1] | [PU](#CIM17v40-PU) | Maximum inner loop feedback voltage (<i>V</i><i><sub>GMax</sub></i>) (&gt;= 0). Typical value = 5,8. | |
| vimax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator input limit (<i>V</i><i><sub>IMAX</sub></i>) (&gt; 0). Typical value = 0,2. | |
| vimin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator input limit (<i>V</i><i><sub>IMIN</sub></i>) (&lt; 0). Typical value = -0,2. | |
| vmmax [0..1] | [PU](#CIM17v40-PU) | Maximum inner loop output (<i>V</i><i><sub>MMax</sub></i>) (&gt; 0). Typical value = 1. | |
| vmmin [0..1] | [PU](#CIM17v40-PU) | Minimum inner loop output (<i>V</i><i><sub>MMin</sub></i>) (&lt;= 0). Typical value = 0. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>V</i><i><sub>RMAX</sub></i>) (&gt; 0). Typical value = 10. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>V</i><i><sub>RMIN</sub></i>) (&lt; 0). Typical value = -10. | |
| xl [0..1] | [PU](#CIM17v40-PU) | Reactance associated with potential source (<i>X</i><i><sub>L</sub></i>) (&gt;= 0). Typical value = 0,081. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcIEEEST4B}
### ExcIEEEST4B

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcIEEEST4B {

+ kc : PU [0..1]
+ kg : PU [0..1]
+ ki : PU [0..1]
+ kim : PU [0..1]
+ kir : PU [0..1]
+ kp : PU [0..1]
+ kpm : PU [0..1]
+ kpr : PU [0..1]
+ ta : Seconds [0..1]
+ thetap : AngleDegrees [0..1]
+ vbmax : PU [0..1]
+ vmmax : PU [0..1]
+ vmmin : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
+ xl : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcIEEEST4B : inherits from
```

IEEE 421.5-2005 type ST4B model. This model is a variation of the type ST3A model, with a proportional plus integral (PI) regulator block replacing the lag-lead regulator characteristic that is in the ST3A model. Both potential and compound source rectifier excitation systems are modelled. The PI regulator blocks have non-windup limits that are represented. The voltage regulator of this model is typically implemented digitally.

Reference: IEEE 421.5-2005, 7.4.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier loading factor proportional to commutating reactance (<i>K</i><i><sub>C</sub></i>) (&gt;= 0). Typical value = 0,113. | |
| kg [0..1] | [PU](#CIM17v40-PU) | Feedback gain constant of the inner loop field regulator (<i>K</i><i><sub>G</sub></i>) (&gt;= 0). Typical value = 0. | |
| ki [0..1] | [PU](#CIM17v40-PU) | Potential circuit gain coefficient (<i>K</i><i><sub>I</sub></i>) (&gt;= 0). Typical value = 0. | |
| kim [0..1] | [PU](#CIM17v40-PU) | Voltage regulator integral gain output (<i>K</i><i><sub>IM</sub></i>). Typical value = 0. | |
| kir [0..1] | [PU](#CIM17v40-PU) | Voltage regulator integral gain (<i>K</i><i><sub>IR</sub></i>). Typical value = 10,75. | |
| kp [0..1] | [PU](#CIM17v40-PU) | Potential circuit gain coefficient (<i>K</i><i><sub>P</sub></i>) (&gt; 0). Typical value = 9,3. | |
| kpm [0..1] | [PU](#CIM17v40-PU) | Voltage regulator proportional gain output (<i>K</i><i><sub>PM</sub></i>). Typical value = 1. | |
| kpr [0..1] | [PU](#CIM17v40-PU) | Voltage regulator proportional gain (<i>K</i><i><sub>PR</sub></i>). Typical value = 10,75. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>A</sub></i>) (&gt;= 0). Typical value = 0,02. | |
| thetap [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Potential circuit phase angle (<i>thetap</i>). Typical value = 0. | |
| vbmax [0..1] | [PU](#CIM17v40-PU) | Maximum excitation voltage (<i>V</i><i><sub>BMax</sub></i>) (&gt; 0). Typical value = 11,63. | |
| vmmax [0..1] | [PU](#CIM17v40-PU) | Maximum inner loop output (<i>V</i><i><sub>MMax</sub></i>) (&gt; ExcIEEEST4B.vmmin). Typical value = 99. | |
| vmmin [0..1] | [PU](#CIM17v40-PU) | Minimum inner loop output (<i>V</i><i><sub>MMin</sub></i>) (&lt; ExcIEEEST4B.vmmax). Typical value = -99. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>V</i><i><sub>RMAX</sub></i>) (&gt; 0). Typical value = 1. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>V</i><i><sub>RMIN</sub></i>) (&lt; 0). Typical value = -0,87. | |
| xl [0..1] | [PU](#CIM17v40-PU) | Reactance associated with potential source (<i>X</i><i><sub>L</sub></i>) (&gt;= 0). Typical value = 0,124. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcIEEEST5B}
### ExcIEEEST5B

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcIEEEST5B {

+ kc : PU [0..1]
+ kr : PU [0..1]
+ t1 : Seconds [0..1]
+ tb1 : Seconds [0..1]
+ tb2 : Seconds [0..1]
+ tc1 : Seconds [0..1]
+ tc2 : Seconds [0..1]
+ tob1 : Seconds [0..1]
+ tob2 : Seconds [0..1]
+ toc1 : Seconds [0..1]
+ toc2 : Seconds [0..1]
+ tub1 : Seconds [0..1]
+ tub2 : Seconds [0..1]
+ tuc1 : Seconds [0..1]
+ tuc2 : Seconds [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcIEEEST5B : inherits from
```

IEEE 421.5-2005 type ST5B model. The type ST5B excitation system is a variation of the type ST1A model, with alternative overexcitation and underexcitation inputs and additional limits.

The block diagram in the IEEE 421.5 standard has input signal <i>Vc </i>and does not indicate the summation point with <i>Vref</i>. The implementation of the ExcIEEEST5B shall consider summation point with <i>Vref</i>.

Reference: IEEE 421.5-2005, 7.5.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier regulation factor (<i>K</i><i><sub>C</sub></i>) (&gt;= 0). Typical value = 0,004. | |
| kr [0..1] | [PU](#CIM17v40-PU) | Regulator gain (<i>K</i><i><sub>R</sub></i>) (&gt; 0). Typical value = 200. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Firing circuit time constant (<i>T1</i>) (&gt;= 0). Typical value = 0,004. | |
| tb1 [0..1] | [Seconds](#CIM17v40-Seconds) | Regulator lag time constant (<i>T</i><i><sub>B1</sub></i>) (&gt;= 0). Typical value = 6. | |
| tb2 [0..1] | [Seconds](#CIM17v40-Seconds) | Regulator lag time constant (<i>T</i><i><sub>B2</sub></i>) (&gt;= 0). Typical value = 0,01. | |
| tc1 [0..1] | [Seconds](#CIM17v40-Seconds) | Regulator lead time constant (<i>T</i><i><sub>C1</sub></i>) (&gt;= 0). Typical value = 0,8. | |
| tc2 [0..1] | [Seconds](#CIM17v40-Seconds) | Regulator lead time constant (<i>T</i><i><sub>C2</sub></i>) (&gt;= 0). Typical value = 0,08. | |
| tob1 [0..1] | [Seconds](#CIM17v40-Seconds) | OEL lag time constant (<i>T</i><i><sub>OB1</sub></i>) (&gt;= 0). Typical value = 2. | |
| tob2 [0..1] | [Seconds](#CIM17v40-Seconds) | OEL lag time constant (<i>T</i><i><sub>OB2</sub></i>) (&gt;= 0). Typical value = 0,08. | |
| toc1 [0..1] | [Seconds](#CIM17v40-Seconds) | OEL lead time constant (<i>T</i><i><sub>OC1</sub></i>) (&gt;= 0). Typical value = 0,1. | |
| toc2 [0..1] | [Seconds](#CIM17v40-Seconds) | OEL lead time constant (<i>T</i><i><sub>OC2</sub></i>) (&gt;= 0). Typical value = 0,08. | |
| tub1 [0..1] | [Seconds](#CIM17v40-Seconds) | UEL lag time constant (<i>T</i><i><sub>UB1</sub></i>) (&gt;= 0). Typical value = 10. | |
| tub2 [0..1] | [Seconds](#CIM17v40-Seconds) | UEL lag time constant (<i>T</i><i><sub>UB2</sub></i>) (&gt;= 0). Typical value = 0,05. | |
| tuc1 [0..1] | [Seconds](#CIM17v40-Seconds) | UEL lead time constant (<i>T</i><i><sub>UC1</sub></i>) (&gt;= 0). Typical value = 2. | |
| tuc2 [0..1] | [Seconds](#CIM17v40-Seconds) | UEL lead time constant (<i>T</i><i><sub>UC2</sub></i>) (&gt;= 0). Typical value = 0,1. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>V</i><i><sub>RMAX</sub></i>) (&gt; 0). Typical value = 5. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>V</i><i><sub>RMIN</sub></i>) (&lt; 0). Typical value = -4. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcIEEEST6B}
### ExcIEEEST6B

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcIEEEST6B {

+ ilr : PU [0..1]
+ kci : PU [0..1]
+ kff : PU [0..1]
+ kg : PU [0..1]
+ kia : PU [0..1]
+ klr : PU [0..1]
+ km : PU [0..1]
+ kpa : PU [0..1]
+ oelin : enum:ExcST6BOELselectorKind [0..1]
+ tg : Seconds [0..1]
+ vamax : PU [0..1]
+ vamin : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcIEEEST6B : inherits from
```

IEEE 421.5-2005 type ST6B model. This model consists of a PI voltage regulator with an inner loop field voltage regulator and pre-control. The field voltage regulator implements a proportional control. The pre-control and the delay in the feedback circuit increase the dynamic response.

Reference: IEEE 421.5-2005, 7.6.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ilr [0..1] | [PU](#CIM17v40-PU) | Exciter output current limit reference (<i>I</i><i><sub>LR</sub></i>) (&gt; 0). Typical value = 4,164. | |
| kci [0..1] | [PU](#CIM17v40-PU) | Exciter output current limit adjustment (<i>K</i><i><sub>CI</sub></i>) (&gt; 0). Typical value = 1,0577. | |
| kff [0..1] | [PU](#CIM17v40-PU) | Pre-control gain constant of the inner loop field regulator (<i>K</i><i><sub>FF</sub></i>). Typical value = 1. | |
| kg [0..1] | [PU](#CIM17v40-PU) | Feedback gain constant of the inner loop field regulator (<i>K</i><i><sub>G</sub></i>) (&gt;= 0). Typical value = 1. | |
| kia [0..1] | [PU](#CIM17v40-PU) | Voltage regulator integral gain (<i>K</i><i><sub>IA</sub></i>) (&gt; 0). Typical value = 45,094. | |
| klr [0..1] | [PU](#CIM17v40-PU) | Exciter output current limiter gain (<i>K</i><i><sub>LR</sub></i>) (&gt; 0). Typical value = 17,33. | |
| km [0..1] | [PU](#CIM17v40-PU) | Forward gain constant of the inner loop field regulator (<i>K</i><i><sub>M</sub></i>). Typical value = 1. | |
| kpa [0..1] | [PU](#CIM17v40-PU) | Voltage regulator proportional gain (<u>K</u><u><sub>PA</sub></u>) (&gt; 0). Typical value = 18,038. | |
| oelin [0..1] | [ExcST6BOELselectorKind](#CIM17v40-ExcST6BOELselectorKind) | OEL input selector (<i>OELin</i>). Typical value = noOELinput. | |
| tg [0..1] | [Seconds](#CIM17v40-Seconds) | Feedback time constant of inner loop field voltage regulator (<i>T</i><i><sub>G</sub></i>) (&gt;= 0). Typical value = 0,02. | |
| vamax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (V<i><sub>AMAX</sub></i>) (&gt; 0). Typical value = 4,81. | |
| vamin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>V</i><i><sub>AMIN</sub></i>) (&lt; 0). Typical value = -3,85. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>V</i><i><sub>RMAX</sub></i>) (&gt; 0). Typical value = 4,81. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>V</i><i><sub>RMIN</sub></i>) (&lt; 0). Typical value = -3,85. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcIEEEST7B}
### ExcIEEEST7B

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcIEEEST7B {

+ kh : PU [0..1]
+ kia : PU [0..1]
+ kl : PU [0..1]
+ kpa : PU [0..1]
+ oelin : enum:ExcST7BOELselectorKind [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ tf : Seconds [0..1]
+ tg : Seconds [0..1]
+ tia : Seconds [0..1]
+ uelin : enum:ExcST7BUELselectorKind [0..1]
+ vmax : PU [0..1]
+ vmin : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcIEEEST7B : inherits from
```

IEEE 421.5-2005 type ST7B model. This model is representative of static potential-source excitation systems. In this system, the AVR consists of a PI voltage regulator. A phase lead-lag filter in series allows the introduction of a derivative function, typically used with brushless excitation systems. In that case, the regulator is of the PID type. In addition, the terminal voltage channel includes a phase lead-lag filter. The AVR includes the appropriate inputs on its reference for overexcitation limiter (OEL1), underexcitation limiter (UEL), stator current limiter (SCL), and current compensator (DROOP). All these limitations, when they work at voltage reference level, keep the PSS (VS signal from PSS) in operation. However, the UEL limitation can also be transferred to the high value (HV) gate acting on the output signal. In addition, the output signal passes through a low value (LV) gate for a ceiling overexcitation limiter (OEL2).

Reference: IEEE 421.5-2005, 7.7.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kh [0..1] | [PU](#CIM17v40-PU) | High-value gate feedback gain (<i>K</i><i><sub>H</sub></i>) (&gt;= 0). Typical value = 1. | |
| kia [0..1] | [PU](#CIM17v40-PU) | Voltage regulator integral gain (<i>K</i><i><sub>IA</sub></i>) (&gt;= 0). Typical value = 1. | |
| kl [0..1] | [PU](#CIM17v40-PU) | Low-value gate feedback gain (<i>K</i><i><sub>L</sub></i>) (&gt;= 0). Typical value = 1. | |
| kpa [0..1] | [PU](#CIM17v40-PU) | Voltage regulator proportional gain (<i>K</i><i><sub>PA</sub></i>) (&gt; 0). Typical value = 40. | |
| oelin [0..1] | [ExcST7BOELselectorKind](#CIM17v40-ExcST7BOELselectorKind) | OEL input selector (<i>OELin</i>). Typical value = noOELinput. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Regulator lag time constant (<i>T</i><i><sub>B</sub></i>) (&gt;= 0). Typical value = 1. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Regulator lead time constant (<i>T</i><i><sub>C</sub></i>) (&gt;= 0). Typical value = 1. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>T</i><i><sub>F</sub></i>) (&gt;= 0). Typical value = 1. | |
| tg [0..1] | [Seconds](#CIM17v40-Seconds) | Feedback time constant of inner loop field voltage regulator (<i>T</i><i><sub>G</sub></i>) (&gt;= 0). Typical value = 1. | |
| tia [0..1] | [Seconds](#CIM17v40-Seconds) | Feedback time constant (<i>T</i><i><sub>IA</sub></i>) (&gt;= 0). Typical value = 3. | |
| uelin [0..1] | [ExcST7BUELselectorKind](#CIM17v40-ExcST7BUELselectorKind) | UEL input selector (<i>UELin</i>). Typical value = noUELinput. | |
| vmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage reference signal (<i>V</i><i><sub>MAX</sub></i>) (&gt; 0 and &gt; ExcIEEEST7B.vmin). Typical value = 1,1. | |
| vmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage reference signal (<i>V</i><i><sub>MIN</sub></i>) (&gt; 0 and &lt; ExcIEEEST7B.vmax). Typical value = 0,9. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>V</i><i><sub>RMAX</sub></i>) (&gt; 0). Typical value = 5. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>V</i><i><sub>RMIN</sub></i>) (&lt; 0). Typical value = -4,5. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcNI}
### ExcNI

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcNI {

+ busFedSelector : Boolean [0..1]
+ ka : PU [0..1]
+ kf : PU [0..1]
+ r : PU [0..1]
+ ta : Seconds [0..1]
+ tf1 : Seconds [0..1]
+ tf2 : Seconds [0..1]
+ tr : Seconds [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcNI : inherits from
```

Bus or solid fed SCR (silicon-controlled rectifier) bridge excitation system model type NI (NVE).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| busFedSelector [0..1] | [Boolean](#CIM17v40-Boolean) | Fed by selector (<i>BusFedSelector</i>).true = bus fed (switch is closed)false = solid fed (switch is open).Typical value = true. | |
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>Ka</i>) (&gt; 0). Typical value = 210. | |
| kf [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gain (<i>Kf</i>) (&gt; 0). Typical value 0,01. | |
| r [0..1] | [PU](#CIM17v40-PU) | <i>rc</i> / <i>rfd</i> (<i>R</i>) (&gt;= 0).0 means exciter has negative current capability&gt; 0 means exciter does not have negative current capability.Typical value = 5. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Ta</i>) (&gt; 0). Typical value = 0,02. | |
| tf1 [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>Tf1</i>) (&gt; 0). Typical value = 1,0. | |
| tf2 [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>Tf2</i>) (&gt; 0). Typical value = 0,1. | |
| tr [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Tr</i>) (&gt;= 0). Typical value = 0,02. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator ouput (<i>Vrmax</i>) (&gt; ExcNI.vrmin). Typical value = 5,0. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator ouput (<i>Vrmin</i>) (&lt; ExcNI.vrmax). Typical value = -2,0. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcOEX3T}
### ExcOEX3T

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcOEX3T {

+ e1 : PU [0..1]
+ e2 : PU [0..1]
+ ka : PU [0..1]
+ kc : PU [0..1]
+ kd : PU [0..1]
+ ke : PU [0..1]
+ kf : PU [0..1]
+ see1 : PU [0..1]
+ see2 : PU [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ t5 : Seconds [0..1]
+ t6 : Seconds [0..1]
+ te : Seconds [0..1]
+ tf : Seconds [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcOEX3T : inherits from
```

Modified IEEE type ST1 excitation system with semi-continuous and acting terminal voltage limiter.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| e1 [0..1] | [PU](#CIM17v40-PU) | Saturation parameter (<i>E</i><i><sub>1</sub></i>). | |
| e2 [0..1] | [PU](#CIM17v40-PU) | Saturation parameter (<i>E</i><i><sub>2</sub></i>). | |
| ka [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K</i><i><sub>A</sub></i>). | |
| kc [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K</i><i><sub>C</sub></i>). | |
| kd [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K</i><i><sub>D</sub></i>). | |
| ke [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K</i><i><sub>E</sub></i>). | |
| kf [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K</i><i><sub>F</sub></i>). | |
| see1 [0..1] | [PU](#CIM17v40-PU) | Saturation parameter (<i>S</i><i><sub>E</sub></i><i>[E</i><i><sub>1</sub></i><i>]</i>). | |
| see2 [0..1] | [PU](#CIM17v40-PU) | Saturation parameter (<i>S</i><i><sub>E</sub></i><i>[E</i><i><sub>2</sub></i><i>]</i>). | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>1</sub></i>) (&gt;= 0). | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>2</sub></i>) (&gt;= 0). | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>3</sub></i>) (&gt;= 0). | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>4</sub></i>) (&gt;= 0). | |
| t5 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>5</sub></i>) (&gt;= 0). | |
| t6 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>6</sub></i>) (&gt;= 0). | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>E</sub></i>) (&gt;= 0). | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>F</sub></i>) (&gt;= 0). | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Limiter (<i>V</i><i><sub>RMAX</sub></i>) (&gt; ExcOEX3T.vrmin). | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Limiter (<i>V</i><i><sub>RMIN</sub></i>) (&lt; ExcOEX3T.vrmax). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcPIC}
### ExcPIC

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcPIC {

+ e1 : PU [0..1]
+ e2 : PU [0..1]
+ efdmax : PU [0..1]
+ efdmin : PU [0..1]
+ ka : PU [0..1]
+ kc : PU [0..1]
+ ke : PU [0..1]
+ kf : PU [0..1]
+ ki : PU [0..1]
+ kp : PU [0..1]
+ se1 : PU [0..1]
+ se2 : PU [0..1]
+ ta1 : Seconds [0..1]
+ ta2 : Seconds [0..1]
+ ta3 : Seconds [0..1]
+ ta4 : Seconds [0..1]
+ te : Seconds [0..1]
+ tf1 : Seconds [0..1]
+ tf2 : Seconds [0..1]
+ vr1 : PU [0..1]
+ vr2 : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcPIC : inherits from
```

Proportional/integral regulator excitation system. This model can be used to represent excitation systems with a proportional-integral (PI) voltage regulator controller.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| e1 [0..1] | [PU](#CIM17v40-PU) | Field voltage value 1 (<i>E</i><i><sub>1</sub></i>). Typical value = 0. | |
| e2 [0..1] | [PU](#CIM17v40-PU) | Field voltage value 2 (<i>E</i><i><sub>2</sub></i>). Typical value = 0. | |
| efdmax [0..1] | [PU](#CIM17v40-PU) | Exciter maximum limit (<i>E</i><i><sub>fdmax</sub></i>) (&gt; ExcPIC.efdmin). Typical value = 8. | |
| efdmin [0..1] | [PU](#CIM17v40-PU) | Exciter minimum limit (<i>E</i><i><sub>fdmin</sub></i>) (&lt; ExcPIC.efdmax). Typical value = -0,87. | |
| ka [0..1] | [PU](#CIM17v40-PU) | PI controller gain (<i>K</i><i><sub>a</sub></i>). Typical value = 3,15. | |
| kc [0..1] | [PU](#CIM17v40-PU) | Exciter regulation factor (<i>K</i><i><sub>c</sub></i>). Typical value = 0,08. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant (<i>K</i><i><sub>e</sub></i>). Typical value = 0. | |
| kf [0..1] | [PU](#CIM17v40-PU) | Rate feedback gain (<i>K</i><i><sub>f</sub></i>). Typical value = 0. | |
| ki [0..1] | [PU](#CIM17v40-PU) | Current source gain (<i>K</i><i><sub>i</sub></i>). Typical value = 0. | |
| kp [0..1] | [PU](#CIM17v40-PU) | Potential source gain (<i>K</i><i><sub>p</sub></i>). Typical value = 6,5. | |
| se1 [0..1] | [PU](#CIM17v40-PU) | Saturation factor at <i>E</i><i><sub>1</sub></i> (<i>Se</i><i><sub>1</sub></i>). Typical value = 0. | |
| se2 [0..1] | [PU](#CIM17v40-PU) | Saturation factor at <i>E</i><i><sub>2</sub></i> (<i>Se</i><i><sub>2</sub></i>). Typical value = 0. | |
| ta1 [0..1] | [Seconds](#CIM17v40-Seconds) | PI controller time constant (<i>T</i><i><sub>a1</sub></i>) (&gt;= 0). Typical value = 1. | |
| ta2 [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>T</i><i><sub>a2</sub></i>) (&gt;= 0). Typical value = 0,01. | |
| ta3 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead time constant (<i>T</i><i><sub>a3</sub></i>) (&gt;= 0). Typical value = 0. | |
| ta4 [0..1] | [Seconds](#CIM17v40-Seconds) | Lag time constant (<i>T</i><i><sub>a4</sub></i>) (&gt;= 0). Typical value = 0. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant (<i>T</i><i><sub>e</sub></i>) (&gt;= 0). Typical value = 0. | |
| tf1 [0..1] | [Seconds](#CIM17v40-Seconds) | Rate feedback time constant (<i>T</i><i><sub>f1</sub></i>) (&gt;= 0). Typical value = 0. | |
| tf2 [0..1] | [Seconds](#CIM17v40-Seconds) | Rate feedback lag time constant (<i>T</i><i><sub>f2</sub></i>) (&gt;= 0). Typical value = 0. | |
| vr1 [0..1] | [PU](#CIM17v40-PU) | PI maximum limit (<i>V</i><i><sub>r1</sub></i>). Typical value = 1. | |
| vr2 [0..1] | [PU](#CIM17v40-PU) | PI minimum limit (<i>V</i><i><sub>r2</sub></i>). Typical value = -0,87. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Voltage regulator maximum limit (<i>V</i><i><sub>rmax</sub></i>) (&gt; ExcPIC.vrmin). Typical value = 1. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Voltage regulator minimum limit (<i>V</i><i><sub>rmin</sub></i>) (&lt; ExcPIC.vrmax). Typical value = -0,87. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcREXS}
### ExcREXS

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcREXS {

+ e1 : PU [0..1]
+ e2 : PU [0..1]
+ fbf : enum:ExcREXSFeedbackSignalKind [0..1]
+ flimf : PU [0..1]
+ kc : PU [0..1]
+ kd : PU [0..1]
+ ke : PU [0..1]
+ kefd : PU [0..1]
+ kf : Seconds [0..1]
+ kh : PU [0..1]
+ kii : PU [0..1]
+ kip : PU [0..1]
+ ks : PU [0..1]
+ kvi : PU [0..1]
+ kvp : PU [0..1]
+ kvphz : PU [0..1]
+ nvphz : PU [0..1]
+ se1 : PU [0..1]
+ se2 : PU [0..1]
+ ta : Seconds [0..1]
+ tb1 : Seconds [0..1]
+ tb2 : Seconds [0..1]
+ tc1 : Seconds [0..1]
+ tc2 : Seconds [0..1]
+ te : Seconds [0..1]
+ tf : Seconds [0..1]
+ tf1 : Seconds [0..1]
+ tf2 : Seconds [0..1]
+ tp : Seconds [0..1]
+ vcmax : PU [0..1]
+ vfmax : PU [0..1]
+ vfmin : PU [0..1]
+ vimax : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
+ xc : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcREXS : inherits from
```

General purpose rotating excitation system. This model can be used to represent a wide range of excitation systems whose DC power source is an AC or DC generator. It encompasses IEEE type AC1, AC2, DC1, and DC2 excitation system models.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| e1 [0..1] | [PU](#CIM17v40-PU) | Field voltage value 1 (<i>E</i><i><sub>1</sub></i>). Typical value = 3. | |
| e2 [0..1] | [PU](#CIM17v40-PU) | Field voltage value 2 (<i>E</i><i><sub>2</sub></i>). Typical value = 4. | |
| fbf [0..1] | [ExcREXSFeedbackSignalKind](#CIM17v40-ExcREXSFeedbackSignalKind) | Rate feedback signal flag (<i>fbf</i>). Typical value = fieldCurrent. | |
| flimf [0..1] | [PU](#CIM17v40-PU) | Limit type flag (<i>Flimf</i>). Typical value = 0. | |
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier regulation factor (<i>Kc</i>). Typical value = 0,05. | |
| kd [0..1] | [PU](#CIM17v40-PU) | Exciter regulation factor (<i>Kd</i>). Typical value = 2. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter field proportional constant (<i>Ke</i>). Typical value = 1. | |
| kefd [0..1] | [PU](#CIM17v40-PU) | Field voltage feedback gain (<i>Kefd</i>). Typical value = 0. | |
| kf [0..1] | [Seconds](#CIM17v40-Seconds) | Rate feedback gain (<i>Kf</i>) (&gt;= 0). Typical value = 0,05. | |
| kh [0..1] | [PU](#CIM17v40-PU) | Field voltage controller feedback gain (<i>Kh</i>). Typical value = 0. | |
| kii [0..1] | [PU](#CIM17v40-PU) | Field current regulator integral gain (<i>Kii</i>). Typical value = 0. | |
| kip [0..1] | [PU](#CIM17v40-PU) | Field current regulator proportional gain (<i>Kip</i>). Typical value = 1. | |
| ks [0..1] | [PU](#CIM17v40-PU) | Coefficient to allow different usage of the model-speed coefficient (<i>Ks</i>). Typical value = 0. | |
| kvi [0..1] | [PU](#CIM17v40-PU) | Voltage regulator integral gain (<i>Kvi</i>). Typical value = 0. | |
| kvp [0..1] | [PU](#CIM17v40-PU) | Voltage regulator proportional gain (<i>Kvp</i>). Typical value = 2800. | |
| kvphz [0..1] | [PU](#CIM17v40-PU) | V/Hz limiter gain (<i>Kvphz</i>). Typical value = 0. | |
| nvphz [0..1] | [PU](#CIM17v40-PU) | Pickup speed of V/Hz limiter (<i>Nvphz</i>). Typical value = 0. | |
| se1 [0..1] | [PU](#CIM17v40-PU) | Saturation factor at <i>E</i><i><sub>1</sub></i><i> </i>(<i>Se</i><i><sub>1</sub></i>). Typical value = 0,0001. | |
| se2 [0..1] | [PU](#CIM17v40-PU) | Saturation factor at <i>E</i><i><sub>2</sub></i> (<i>Se</i><i><sub>2</sub></i>). Typical value = 0,001. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Ta</i>) (&gt;= 0). If = 0, block is bypassed. Typical value = 0,01. | |
| tb1 [0..1] | [Seconds](#CIM17v40-Seconds) | Lag time constant (<i>Tb1</i>) (&gt;= 0). If = 0, block is bypassed. Typical value = 0. | |
| tb2 [0..1] | [Seconds](#CIM17v40-Seconds) | Lag time constant (<i>Tb2</i>) (&gt;= 0). If = 0, block is bypassed. Typical value = 0. | |
| tc1 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead time constant (<i>Tc1</i>) (&gt;= 0). Typical value = 0. | |
| tc2 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead time constant (<i>Tc2</i>) (&gt;= 0). Typical value = 0. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter field time constant (<i>Te</i>) (&gt; 0). Typical value = 1,2. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Rate feedback time constant (<i>Tf</i>) (&gt;= 0). If = 0, the feedback path is not used. Typical value = 1. | |
| tf1 [0..1] | [Seconds](#CIM17v40-Seconds) | Feedback lead time constant (<i>Tf1</i>) (&gt;= 0). Typical value = 0. | |
| tf2 [0..1] | [Seconds](#CIM17v40-Seconds) | Feedback lag time constant (<i>Tf2</i>) (&gt;= 0). If = 0, block is bypassed. Typical value = 0. | |
| tp [0..1] | [Seconds](#CIM17v40-Seconds) | Field current bridge time constant (<i>Tp</i>) (&gt;= 0). Typical value = 0. | |
| vcmax [0..1] | [PU](#CIM17v40-PU) | Maximum compounding voltage (<i>Vcmax</i>). Typical value = 0. | |
| vfmax [0..1] | [PU](#CIM17v40-PU) | Maximum exciter field current (<i>Vfmax</i>) (&gt; ExcREXS.vfmin). Typical value = 47. | |
| vfmin [0..1] | [PU](#CIM17v40-PU) | Minimum exciter field current (<i>Vfmin</i>) (&lt; ExcREXS.vfmax). Typical value = -20. | |
| vimax [0..1] | [PU](#CIM17v40-PU) | Voltage regulator input limit (<i>Vimax</i>). Typical value = 0,1. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum controller output (V<i>rmax</i>) (&gt; ExcREXS.vrmin). Typical value = 47. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum controller output (<i>Vrmin</i>) (&lt; ExcREXS.vrmax). Typical value = -20. | |
| xc [0..1] | [PU](#CIM17v40-PU) | Exciter compounding reactance (<i>Xc</i>). Typical value = 0. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcRQB}
### ExcRQB

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcRQB {

+ ki0 : Float [0..1]
+ ki1 : Float [0..1]
+ klir : Float [0..1]
+ klus : Float [0..1]
+ lsat : PU [0..1]
+ lus : PU [0..1]
+ mesu : Seconds [0..1]
+ t4m : Seconds [0..1]
+ tc : Seconds [0..1]
+ te : Seconds [0..1]
+ tf : Seconds [0..1]
+ ucmax : PU [0..1]
+ ucmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcRQB : inherits from
```

Excitation system type RQB (four-loop regulator, r?gulateur quatre boucles, developed in France) primarily used in nuclear or thermal generating units. This excitation system shall be always used together with power system stabilizer type PssRQB.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ki0 [0..1] | [Float](#CIM17v40-Float) | Voltage reference input gain (<i>Ki0</i>). Typical value = 12,7. | |
| ki1 [0..1] | [Float](#CIM17v40-Float) | Voltage input gain (<i>Ki1</i>). Typical value = -16,8. | |
| klir [0..1] | [Float](#CIM17v40-Float) | OEL input gain (<i>KLIR</i>). Typical value = 12,13. | |
| klus [0..1] | [Float](#CIM17v40-Float) | Limiter gain (<i>KLUS</i>). Typical value = 50. | |
| lsat [0..1] | [PU](#CIM17v40-PU) | Integrator limiter (<i>LSAT</i>). Typical value = 5,73. | |
| lus [0..1] | [PU](#CIM17v40-PU) | Setpoint (<i>LUS</i>). Typical value = 0,12. | |
| mesu [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage input time constant (<i>MESU</i>) (&gt;= 0). Typical value = 0,02. | |
| t4m [0..1] | [Seconds](#CIM17v40-Seconds) | Input time constant (<i>T4M</i>) (&gt;= 0). Typical value = 5. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Lead lag time constant (<i>TC</i>) (&gt;= 0). Typical value = 0,02. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Lead lag time constant (<i>TE</i>) (&gt;= 0). Typical value = 0,22. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant (<i>TF</i>) (&gt;= 0). Typical value = 0,01. | |
| ucmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage reference limit (<i>UCMAX</i>) (&gt; ExcRQB.ucmin). Typical value = 1,1. | |
| ucmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage reference limit (<i>UCMIN</i>) (&lt; ExcRQB.ucmax). Typical value = 0,9. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcSCRX}
### ExcSCRX

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcSCRX {

+ cswitch : Boolean [0..1]
+ emax : PU [0..1]
+ emin : PU [0..1]
+ k : PU [0..1]
+ rcrfd : Float [0..1]
+ tatb : Float [0..1]
+ tb : Seconds [0..1]
+ te : Seconds [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcSCRX : inherits from
```

Simple excitation system with generic characteristics typical of many excitation systems; intended for use where negative field current could be a problem.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| cswitch [0..1] | [Boolean](#CIM17v40-Boolean) | Power source switch (<i>Cswitch</i>).true = fixed voltage of 1.0 PUfalse = generator terminal voltage. | |
| emax [0..1] | [PU](#CIM17v40-PU) | Maximum field voltage output (<i>Emax</i>) (&gt; ExcSCRX.emin). Typical value = 5. | |
| emin [0..1] | [PU](#CIM17v40-PU) | Minimum field voltage output (<i>Emin</i>) (&lt; ExcSCRX.emax). Typical value = 0. | |
| k [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K</i>) (&gt; 0). Typical value = 200. | |
| rcrfd [0..1] | [Float](#CIM17v40-Float) | Ratio of field discharge resistance to field winding resistance ([<i>rc / rfd]</i>). Typical value = 0. | |
| tatb [0..1] | [Float](#CIM17v40-Float) | Gain reduction ratio of lag-lead element ([<i>Ta</i> / <i>Tb</i>]). The parameter <i>Ta</i> is not defined explicitly. Typical value = 0.1. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Denominator time constant of lag-lead block (<i>Tb</i>) (&gt;= 0). Typical value = 10. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant of gain block (<i>Te</i>) (&gt; 0). Typical value = 0,02. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcSEXS}
### ExcSEXS

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcSEXS {

+ efdmax : PU [0..1]
+ efdmin : PU [0..1]
+ emax : PU [0..1]
+ emin : PU [0..1]
+ k : PU [0..1]
+ kc : PU [0..1]
+ tatb : Float [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ te : Seconds [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcSEXS : inherits from
```

Simplified excitation system.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efdmax [0..1] | [PU](#CIM17v40-PU) | Field voltage clipping maximum limit (<i>Efdmax</i>) (&gt; ExcSEXS.efdmin). Typical value = 5. | |
| efdmin [0..1] | [PU](#CIM17v40-PU) | Field voltage clipping minimum limit (<i>Efdmin</i>) (&lt; ExcSEXS.efdmax). Typical value = -5. | |
| emax [0..1] | [PU](#CIM17v40-PU) | Maximum field voltage output (<i>Emax</i>) (&gt; ExcSEXS.emin). Typical value = 5. | |
| emin [0..1] | [PU](#CIM17v40-PU) | Minimum field voltage output (<i>Emin</i>) (&lt; ExcSEXS.emax). Typical value = -5. | |
| k [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K</i>) (&gt; 0). Typical value = 100. | |
| kc [0..1] | [PU](#CIM17v40-PU) | PI controller gain (<i>Kc</i>) (&gt; 0 if ExcSEXS.tc &gt; 0). Typical value = 0,08. | |
| tatb [0..1] | [Float](#CIM17v40-Float) | Gain reduction ratio of lag-lead element (<i>[Ta / Tb]</i>). Typical value = 0,1. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Denominator time constant of lag-lead block (<i>Tb</i>) (&gt;= 0). Typical value = 10. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | PI controller phase lead time constant (<i>Tc</i>) (&gt;= 0). Typical value = 0. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant of gain block (<i>Te</i>) (&gt; 0). Typical value = 0,05. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcSK}
### ExcSK

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcSK {

+ efdmax : PU [0..1]
+ efdmin : PU [0..1]
+ emax : PU [0..1]
+ emin : PU [0..1]
+ k : PU [0..1]
+ k1 : PU [0..1]
+ k2 : PU [0..1]
+ kc : PU [0..1]
+ kce : PU [0..1]
+ kd : PU [0..1]
+ kgob : PU [0..1]
+ kp : PU [0..1]
+ kqi : PU [0..1]
+ kqob : PU [0..1]
+ kqp : PU [0..1]
+ nq : PU [0..1]
+ qconoff : Boolean [0..1]
+ qz : PU [0..1]
+ remote : Boolean [0..1]
+ sbase : ApparentPower [0..1]
+ tc : Seconds [0..1]
+ te : Seconds [0..1]
+ ti : Seconds [0..1]
+ tp : Seconds [0..1]
+ tr : Seconds [0..1]
+ uimax : PU [0..1]
+ uimin : PU [0..1]
+ urmax : PU [0..1]
+ urmin : PU [0..1]
+ vtmax : PU [0..1]
+ vtmin : PU [0..1]
+ yp : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcSK : inherits from
```

Slovakian excitation system. UEL and secondary voltage control are included in this model. When this model is used, there cannot be a separate underexcitation limiter or VAr controller model.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efdmax [0..1] | [PU](#CIM17v40-PU) | Field voltage clipping upper level limit (<i>Efdmax</i>) (&gt; ExcSK.efdmin). | |
| efdmin [0..1] | [PU](#CIM17v40-PU) | Field voltage clipping lower level limit (<i>Efdmin</i>) (&lt; ExcSK.efdmax). | |
| emax [0..1] | [PU](#CIM17v40-PU) | Maximum field voltage output (<i>Emax</i>) (&gt; ExcSK.emin). Typical value = 20. | |
| emin [0..1] | [PU](#CIM17v40-PU) | Minimum field voltage output (<i>Emin</i>) (&lt; ExcSK.emax). Typical value = -20. | |
| k [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K</i>). Typical value = 1. | |
| k1 [0..1] | [PU](#CIM17v40-PU) | Parameter of underexcitation limit (<i>K1</i>). Typical value = 0,1364. | |
| k2 [0..1] | [PU](#CIM17v40-PU) | Parameter of underexcitation limit (<i>K2</i>). Typical value = -0,3861. | |
| kc [0..1] | [PU](#CIM17v40-PU) | PI controller gain (<i>Kc</i>). Typical value = 70. | |
| kce [0..1] | [PU](#CIM17v40-PU) | Rectifier regulation factor (<i>Kce</i>). Typical value = 0. | |
| kd [0..1] | [PU](#CIM17v40-PU) | Exciter internal reactance (<i>Kd</i>). Typical value = 0. | |
| kgob [0..1] | [PU](#CIM17v40-PU) | P controller gain (<i>Kgob</i>). Typical value = 10. | |
| kp [0..1] | [PU](#CIM17v40-PU) | PI controller gain (<i>Kp</i>). Typical value = 1. | |
| kqi [0..1] | [PU](#CIM17v40-PU) | PI controller gain of integral component (<i>Kqi</i>). Typical value = 0. | |
| kqob [0..1] | [PU](#CIM17v40-PU) | Rate of rise of the reactive power (<i>Kqob</i>). | |
| kqp [0..1] | [PU](#CIM17v40-PU) | PI controller gain (<i>Kqp</i>). Typical value = 0. | |
| nq [0..1] | [PU](#CIM17v40-PU) | Deadband of reactive power (<i>nq</i>). Determines the range of sensitivity. Typical value = 0,001. | |
| qconoff [0..1] | [Boolean](#CIM17v40-Boolean) | Secondary voltage control state (<i>Qc_on_off</i>).true = secondary voltage control is onfalse = secondary voltage control is off.Typical value = false. | |
| qz [0..1] | [PU](#CIM17v40-PU) | Desired value (setpoint) of reactive power, manual setting (<i>Qz</i>). | |
| remote [0..1] | [Boolean](#CIM17v40-Boolean) | Selector to apply automatic calculation in secondary controller model (<i>remote</i>).true = automatic calculation is activatedfalse = manual set is active; the use of desired value of reactive power (<i>Qz</i>) is required.Typical value = true. | |
| sbase [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | Apparent power of the unit (<i>Sbase</i>) (&gt; 0). Unit = MVA. Typical value = 259. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | PI controller phase lead time constant (<i>Tc</i>) (&gt;= 0). Typical value = 8. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant of gain block (<i>Te</i>) (&gt;= 0). Typical value = 0,1. | |
| ti [0..1] | [Seconds](#CIM17v40-Seconds) | PI controller phase lead time constant (<i>Ti</i>) (&gt;= 0). Typical value = 2. | |
| tp [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Tp</i>) (&gt;= 0). Typical value = 0,1. | |
| tr [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage transducer time constant (<i>Tr</i>) (&gt;= 0). Typical value = 0,01. | |
| uimax [0..1] | [PU](#CIM17v40-PU) | Maximum error (<i>UImax</i>) (&gt; ExcSK.uimin). Typical value = 10. | |
| uimin [0..1] | [PU](#CIM17v40-PU) | Minimum error (<i>UImin</i>) (&lt; ExcSK.uimax). Typical value = -10. | |
| urmax [0..1] | [PU](#CIM17v40-PU) | Maximum controller output (<i>URmax</i>) (&gt; ExcSK.urmin). Typical value = 10. | |
| urmin [0..1] | [PU](#CIM17v40-PU) | Minimum controller output (<i>URmin</i>) (&lt; ExcSK.urmax). Typical value = -10. | |
| vtmax [0..1] | [PU](#CIM17v40-PU) | Maximum terminal voltage input (<i>Vtmax</i>) (&gt; ExcSK.vtmin). Determines the range of voltage deadband. Typical value = 1,05. | |
| vtmin [0..1] | [PU](#CIM17v40-PU) | Minimum terminal voltage input (<i>Vtmin</i>) (&lt; ExcSK.vtmax). Determines the range of voltage deadband. Typical value = 0,95. | |
| yp [0..1] | [PU](#CIM17v40-PU) | Maximum output (<i>Yp</i>). Typical value = 1. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcST1A}
### ExcST1A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcST1A {

+ ilr : PU [0..1]
+ ka : PU [0..1]
+ kc : PU [0..1]
+ kf : PU [0..1]
+ klr : PU [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ tb1 : Seconds [0..1]
+ tc : Seconds [0..1]
+ tc1 : Seconds [0..1]
+ tf : Seconds [0..1]
+ vamax : PU [0..1]
+ vamin : PU [0..1]
+ vimax : PU [0..1]
+ vimin : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
+ xe : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcST1A : inherits from
```

Modification of an old IEEE ST1A static excitation system without overexcitation limiter (OEL) and underexcitation limiter (UEL).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ilr [0..1] | [PU](#CIM17v40-PU) | Exciter output current limit reference (<i>Ilr</i>). Typical value = 0. | |
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>Ka</i>) (&gt; 0). Typical value = 190. | |
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier loading factor proportional to commutating reactance (<i>Kc</i>) (&gt;= 0). Typical value = 0,05. | |
| kf [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gains (<i>Kf</i>) (&gt;= 0). Typical value = 0. | |
| klr [0..1] | [PU](#CIM17v40-PU) | Exciter output current limiter gain (<i>Klr</i>). Typical value = 0. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Ta</i>) (&gt;= 0). Typical value = 0,02. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tb</i>) (&gt;= 0). Typical value = 10. | |
| tb1 [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tb1</i>) (&gt;= 0). Typical value = 0. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tc</i>) (&gt;= 0). Typical value = 1. | |
| tc1 [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tc1</i>) (&gt;= 0). Typical value = 0. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>Tf</i>) (&gt;= 0). Typical value = 1. | |
| vamax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>Vamax</i>) (&gt; 0). Typical value = 999. | |
| vamin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>Vamin</i>) (&lt; 0). Typical value = -999. | |
| vimax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator input limit (<i>Vimax</i>) (&gt; 0). Typical value = 999. | |
| vimin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator input limit (<i>Vimin</i>) (&lt; 0). Typical value = -999. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator outputs (<i>Vrmax</i>) (&gt; 0) . Typical value = 7,8. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator outputs (<i>Vrmin</i>) (&lt; 0). Typical value = -6,7. | |
| xe [0..1] | [PU](#CIM17v40-PU) | Excitation xfmr effective reactance (<i>Xe</i>). Typical value = 0,04. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcST2A}
### ExcST2A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcST2A {

+ efdmax : PU [0..1]
+ ka : PU [0..1]
+ kc : PU [0..1]
+ ke : PU [0..1]
+ kf : PU [0..1]
+ ki : PU [0..1]
+ kp : PU [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ te : Seconds [0..1]
+ tf : Seconds [0..1]
+ uelin : Boolean [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcST2A : inherits from
```

Modified IEEE ST2A static excitation system with another lead-lag block added to match the model defined by WECC.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efdmax [0..1] | [PU](#CIM17v40-PU) | Maximum field voltage (<i>Efdmax</i>) (&gt;= 0). Typical value = 99. | |
| ka [0..1] | [PU](#CIM17v40-PU) | Voltage regulator gain (<i>Ka</i>) (&gt; 0). Typical value = 120. | |
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier loading factor proportional to commutating reactance (<i>Kc</i>) (&gt;= 0). Typical value = 1,82. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Exciter constant related to self-excited field (<i>Ke</i>). Typical value = 1. | |
| kf [0..1] | [PU](#CIM17v40-PU) | Excitation control system stabilizer gains (<i>kf</i>) (&gt;= 0). Typical value = 0,05. | |
| ki [0..1] | [PU](#CIM17v40-PU) | Potential circuit gain coefficient (<i>K</i><i><sub>i</sub></i>) (&gt;= 0). Typical value = 8. | |
| kp [0..1] | [PU](#CIM17v40-PU) | Potential circuit gain coefficient (<i>K</i><i><sub>p</sub></i>) (&gt;= 0). Typical value = 4,88. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Ta</i>) (&gt; 0). Typical value = 0,15. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tb</i>) (&gt;= 0). Typical value = 0. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tc</i>) (&gt;= 0). Typical value = 0. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Exciter time constant, integration rate associated with exciter control (<i>Te</i>) (&gt; 0). Typical value = 0,5. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>Tf</i>) (&gt;= 0). Typical value = 0,7. | |
| uelin [0..1] | [Boolean](#CIM17v40-Boolean) | UEL input (<i>UELin</i>).true = HV gatefalse = add to error signal.Typical value = false. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator outputs (<i>Vrmax</i>) (&gt; 0). Typical value = 1. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator outputs (<i>Vrmin</i>) (&lt; 0). Typical value = -1. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcST3A}
### ExcST3A

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcST3A {

+ efdmax : PU [0..1]
+ kc : PU [0..1]
+ kg : PU [0..1]
+ ki : PU [0..1]
+ kj : PU [0..1]
+ km : PU [0..1]
+ kp : PU [0..1]
+ ks : PU [0..1]
+ ks1 : PU [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ thetap : AngleDegrees [0..1]
+ tm : Seconds [0..1]
+ vbmax : PU [0..1]
+ vgmax : PU [0..1]
+ vimax : PU [0..1]
+ vimin : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
+ xl : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcST3A : inherits from
```

Modified IEEE ST3A static excitation system with added speed multiplier.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efdmax [0..1] | [PU](#CIM17v40-PU) | Maximum AVR output (<i>Efdmax</i>) (&gt;= 0). Typical value = 6,9. | |
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier loading factor proportional to commutating reactance (<i>Kc</i>) (&gt;= 0). Typical value = 1,1. | |
| kg [0..1] | [PU](#CIM17v40-PU) | Feedback gain constant of the inner loop field regulator (<i>Kg</i>) (&gt;= 0). Typical value = 1. | |
| ki [0..1] | [PU](#CIM17v40-PU) | Potential circuit gain coefficient (<i>K</i><i><sub>i</sub></i>) (&gt;= 0). Typical value = 4,83. | |
| kj [0..1] | [PU](#CIM17v40-PU) | AVR gain (<i>Kj</i>) (&gt; 0). Typical value = 200. | |
| km [0..1] | [PU](#CIM17v40-PU) | Forward gain constant of the inner loop field regulator (<i>Km</i>) (&gt; 0). Typical value = 7,04. | |
| kp [0..1] | [PU](#CIM17v40-PU) | Potential source gain (<i>K</i><i><sub>p</sub></i>) (&gt; 0). Typical value = 4,37. | |
| ks [0..1] | [PU](#CIM17v40-PU) | Coefficient to allow different usage of the model-speed coefficient (<i>Ks</i>). Typical value = 0. | |
| ks1 [0..1] | [PU](#CIM17v40-PU) | Coefficient to allow different usage of the model-speed coefficient (<i>Ks1</i>). Typical value = 0. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tb</i>) (&gt;= 0). Typical value = 6,67. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Tc</i>) (&gt;= 0). Typical value = 1. | |
| thetap [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Potential circuit phase angle (<i>theta</i><i><sub>p</sub></i>). Typical value = 20. | |
| tm [0..1] | [Seconds](#CIM17v40-Seconds) | Forward time constant of inner loop field regulator (<i>Tm</i>) (&gt; 0). Typical value = 1. | |
| vbmax [0..1] | [PU](#CIM17v40-PU) | Maximum excitation voltage (<i>Vbmax</i>) (&gt; 0). Typical value = 8,63. | |
| vgmax [0..1] | [PU](#CIM17v40-PU) | Maximum inner loop feedback voltage (<i>Vgmax</i>) (&gt;= 0). Typical value = 6,53. | |
| vimax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator input limit (<i>Vimax</i>) (&gt; 0). Typical value = 0,2. | |
| vimin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator input limit (<i>Vimin</i>) (&lt; 0). Typical value = -0,2. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>Vrmax</i>) (&gt; 0). Typical value = 1. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>Vrmin</i>) (&lt; 0). Typical value = -1. | |
| xl [0..1] | [PU](#CIM17v40-PU) | Reactance associated with potential source (<i>Xl</i>) (&gt;= 0). Typical value = 0,09. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcST4B}
### ExcST4B

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcST4B {

+ kc : PU [0..1]
+ kg : PU [0..1]
+ ki : PU [0..1]
+ kim : PU [0..1]
+ kir : PU [0..1]
+ kp : PU [0..1]
+ kpm : PU [0..1]
+ kpr : PU [0..1]
+ lvgate : Boolean [0..1]
+ ta : Seconds [0..1]
+ thetap : AngleDegrees [0..1]
+ uel : Boolean [0..1]
+ vbmax : PU [0..1]
+ vgmax : PU [0..1]
+ vmmax : PU [0..1]
+ vmmin : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
+ xl : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcST4B : inherits from
```

Modified IEEE ST4B static excitation system with maximum inner loop feedback gain <i>Vgmax</i>.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kc [0..1] | [PU](#CIM17v40-PU) | Rectifier loading factor proportional to commutating reactance (<i>Kc</i>) (&gt;= 0). Typical value = 0,113. | |
| kg [0..1] | [PU](#CIM17v40-PU) | Feedback gain constant of the inner loop field regulator (<i>Kg</i>) (&gt;= 0). Typical value = 0. | |
| ki [0..1] | [PU](#CIM17v40-PU) | Potential circuit gain coefficient (<i>Ki</i>) (&gt;= 0). Typical value = 0. | |
| kim [0..1] | [PU](#CIM17v40-PU) | Voltage regulator integral gain output (<i>Kim</i>). Typical value = 0. | |
| kir [0..1] | [PU](#CIM17v40-PU) | Voltage regulator integral gain (<i>Kir</i>). Typical value = 10,75. | |
| kp [0..1] | [PU](#CIM17v40-PU) | Potential circuit gain coefficient (<i>Kp</i>) (&gt; 0). Typical value = 9,3. | |
| kpm [0..1] | [PU](#CIM17v40-PU) | Voltage regulator proportional gain output (<i>Kpm</i>). Typical value = 1. | |
| kpr [0..1] | [PU](#CIM17v40-PU) | Voltage regulator proportional gain (<i>Kpr</i>). Typical value = 10,75. | |
| lvgate [0..1] | [Boolean](#CIM17v40-Boolean) | Selector (<i>LVGate</i>).true = <i>LVGate</i> is part of the block diagramfalse = <i>LVGate</i> is not part of the block diagram.Typical value = false. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator time constant (<i>Ta</i>) (&gt;= 0). Typical value = 0,02. | |
| thetap [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Potential circuit phase angle (<i>theta</i><i><sub>p</sub></i>). Typical value = 0. | |
| uel [0..1] | [Boolean](#CIM17v40-Boolean) | Selector (<i>UEL</i>).true = <i>UEL</i> is part of block diagramfalse = <i>UEL</i> is not part of block diagram.Typical value = false. | |
| vbmax [0..1] | [PU](#CIM17v40-PU) | Maximum excitation voltage (<i>Vbmax</i>) (&gt; 0). Typical value = 11,63. | |
| vgmax [0..1] | [PU](#CIM17v40-PU) | Maximum inner loop feedback voltage (<i>Vgmax</i>) (&gt;= 0). Typical value = 5,8. | |
| vmmax [0..1] | [PU](#CIM17v40-PU) | Maximum inner loop output (<i>Vmmax</i>) (&gt; ExcST4B.vmmin). Typical value = 99. | |
| vmmin [0..1] | [PU](#CIM17v40-PU) | Minimum inner loop output (<i>Vmmin</i>) (&lt; ExcST4B.vmmax). Typical value = -99. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>Vrmax</i>) (&gt; 0). Typical value = 1. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>Vrmin</i>) (&lt; 0). Typical value = -0,87. | |
| xl [0..1] | [PU](#CIM17v40-PU) | Reactance associated with potential source (<i>Xl</i>) (&gt;= 0). Typical value = 0,124. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcST6B}
### ExcST6B

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcST6B {

+ ilr : PU [0..1]
+ k1 : Boolean [0..1]
+ kcl : PU [0..1]
+ kff : PU [0..1]
+ kg : PU [0..1]
+ kia : PU [0..1]
+ klr : PU [0..1]
+ km : PU [0..1]
+ kpa : PU [0..1]
+ kvd : PU [0..1]
+ oelin : enum:ExcST6BOELselectorKind [0..1]
+ tg : Seconds [0..1]
+ ts : Seconds [0..1]
+ tvd : Seconds [0..1]
+ vamax : PU [0..1]
+ vamin : PU [0..1]
+ vilim : Boolean [0..1]
+ vimax : PU [0..1]
+ vimin : PU [0..1]
+ vmult : Boolean [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
+ xc : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcST6B : inherits from
```

Modified IEEE ST6B static excitation system with PID controller and optional inner feedback loop.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ilr [0..1] | [PU](#CIM17v40-PU) | Exciter output current limit reference (<i>Ilr</i>) (&gt; 0). Typical value = 4,164. | |
| k1 [0..1] | [Boolean](#CIM17v40-Boolean) | Selector (<i>K1</i>).true = feedback is from <i>Ifd</i>false = feedback is not from <i>Ifd</i>.Typical value = true. | |
| kcl [0..1] | [PU](#CIM17v40-PU) | Exciter output current limit adjustment (<i>Kcl</i>) (&gt; 0). Typical value = 1,0577. | |
| kff [0..1] | [PU](#CIM17v40-PU) | Pre-control gain constant of the inner loop field regulator (<i>Kff</i>). Typical value = 1. | |
| kg [0..1] | [PU](#CIM17v40-PU) | Feedback gain constant of the inner loop field regulator (<i>Kg</i>) (&gt;= 0). Typical value = 1. | |
| kia [0..1] | [PU](#CIM17v40-PU) | Voltage regulator integral gain (<i>Kia</i>) (&gt; 0). Typical value = 45,094. | |
| klr [0..1] | [PU](#CIM17v40-PU) | Exciter output current limit adjustment (<i>Kcl</i>) (&gt; 0). Typical value = 17,33. | |
| km [0..1] | [PU](#CIM17v40-PU) | Forward gain constant of the inner loop field regulator (<i>Km</i>). Typical value = 1. | |
| kpa [0..1] | [PU](#CIM17v40-PU) | Voltage regulator proportional gain (<i>Kpa</i>) (&gt; 0). Typical value = 18,038. | |
| kvd [0..1] | [PU](#CIM17v40-PU) | Voltage regulator derivative gain (<i>Kvd</i>). Typical value = 0. | |
| oelin [0..1] | [ExcST6BOELselectorKind](#CIM17v40-ExcST6BOELselectorKind) | OEL input selector (<i>OELin</i>). Typical value = noOELinput (corresponds to <i>OELin</i> = 0 on diagram). | |
| tg [0..1] | [Seconds](#CIM17v40-Seconds) | Feedback time constant of inner loop field voltage regulator (<i>Tg</i>) (&gt;= 0). Typical value = 0,02. | |
| ts [0..1] | [Seconds](#CIM17v40-Seconds) | Rectifier firing time constant (<i>Ts</i>) (&gt;= 0). Typical value = 0. | |
| tvd [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage regulator derivative gain (<i>Tvd</i>) (&gt;= 0). Typical value = 0. | |
| vamax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>Vamax</i>) (&gt; 0). Typical value = 4,81. | |
| vamin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>Vamin</i>) (&lt; 0). Typical value = -3,85. | |
| vilim [0..1] | [Boolean](#CIM17v40-Boolean) | Selector (<i>Vilim</i>).true = <i>Vimin</i>-<i>Vimax</i> limiter is activefalse = <i>Vimin</i>-<i>Vimax</i> limiter is not active.Typical value = true. | |
| vimax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator input limit (<i>Vimax</i>) (&gt; ExcST6B.vimin). Typical value = 10. | |
| vimin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator input limit (<i>Vimin</i>) (&lt; ExcST6B.vimax). Typical value = -10. | |
| vmult [0..1] | [Boolean](#CIM17v40-Boolean) | Selector (<i>vmult</i>).true = multiply regulator output by terminal voltagefalse = do not multiply regulator output by terminal voltage.Typical value = true. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>Vrmax</i>) (&gt; 0). Typical value = 4,81. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>Vrmin</i>) (&lt; 0). Typical value = -3,85. | |
| xc [0..1] | [PU](#CIM17v40-PU) | Excitation source reactance (<i>Xc</i>). Typical value = 0,05. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcST7B}
### ExcST7B

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcST7B {

+ kh : PU [0..1]
+ kia : PU [0..1]
+ kl : PU [0..1]
+ kpa : PU [0..1]
+ oelin : enum:ExcST7BOELselectorKind [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ tf : Seconds [0..1]
+ tg : Seconds [0..1]
+ tia : Seconds [0..1]
+ ts : Seconds [0..1]
+ uelin : enum:ExcST7BUELselectorKind [0..1]
+ vmax : PU [0..1]
+ vmin : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcST7B : inherits from
```

Modified IEEE ST7B static excitation system without stator current limiter (SCL) and current compensator (DROOP) inputs.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kh [0..1] | [PU](#CIM17v40-PU) | High-value gate feedback gain (<i>Kh</i>) (&gt;= 0). Typical value = 1. | |
| kia [0..1] | [PU](#CIM17v40-PU) | Voltage regulator integral gain (<i>Kia</i>) (&gt;= 0). Typical value = 1. | |
| kl [0..1] | [PU](#CIM17v40-PU) | Low-value gate feedback gain (<i>Kl</i>) (&gt;= 0). Typical value = 1. | |
| kpa [0..1] | [PU](#CIM17v40-PU) | Voltage regulator proportional gain (<i>Kpa</i>) (&gt; 0). Typical value = 40. | |
| oelin [0..1] | [ExcST7BOELselectorKind](#CIM17v40-ExcST7BOELselectorKind) | OEL input selector (<i>OELin</i>). Typical value = noOELinput. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Regulator lag time constant (<i>Tb</i>) (&gt;= 0). Typical value = 1. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Regulator lead time constant (<i>Tc</i>) (&gt;= 0). Typical value = 1. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Excitation control system stabilizer time constant (<i>Tf</i>) (&gt;= 0). Typical value = 1. | |
| tg [0..1] | [Seconds](#CIM17v40-Seconds) | Feedback time constant of inner loop field voltage regulator (<i>Tg</i>) (&gt;= 0). Typical value = 1. | |
| tia [0..1] | [Seconds](#CIM17v40-Seconds) | Feedback time constant (<i>Tia</i>) (&gt;= 0). Typical value = 3. | |
| ts [0..1] | [Seconds](#CIM17v40-Seconds) | Rectifier firing time constant (<i>Ts</i>) (&gt;= 0). Typical value = 0. | |
| uelin [0..1] | [ExcST7BUELselectorKind](#CIM17v40-ExcST7BUELselectorKind) | UEL input selector (<i>UELin</i>). Typical value = noUELinput. | |
| vmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage reference signal (<i>Vmax</i>) (&gt; 0 and &gt; ExcST7B.vmin)). Typical value = 1,1. | |
| vmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage reference signal (<i>Vmin</i>) (&gt; 0 and &lt; ExcST7B.vmax). Typical value = 0,9. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage regulator output (<i>Vrmax</i>) (&gt; 0). Typical value = 5. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage regulator output (<i>Vrmin</i>) (&lt; 0). Typical value = -4,5. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcitationSystemDynamics}
### ExcitationSystemDynamics

Inheritance path = [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcitationSystemDynamics {

}

class DynamicsFunctionBlock {

}

DynamicsFunctionBlock <|-- ExcitationSystemDynamics : inherits from
class DiscontinuousExcitationControlDynamics {

}

ExcitationSystemDynamics --> "0..1" DiscontinuousExcitationControlDynamics : DiscontinuousExcitationControlDynamics
class OverexcitationLimiterDynamics {

}

ExcitationSystemDynamics --> "0..1" OverexcitationLimiterDynamics : OverexcitationLimiterDynamics
class PFVArControllerType1Dynamics {

}

ExcitationSystemDynamics --> "0..1" PFVArControllerType1Dynamics : PFVArControllerType1Dynamics
class PFVArControllerType2Dynamics {

}

ExcitationSystemDynamics --> "0..1" PFVArControllerType2Dynamics : PFVArControllerType2Dynamics
class PowerSystemStabilizerDynamics {

}

ExcitationSystemDynamics --> "0..1" PowerSystemStabilizerDynamics : PowerSystemStabilizerDynamics
class SynchronousMachineDynamics {

}

ExcitationSystemDynamics --> "1" SynchronousMachineDynamics : SynchronousMachineDynamics
class UnderexcitationLimiterDynamics {

}

ExcitationSystemDynamics --> "0..1" UnderexcitationLimiterDynamics : UnderexcitationLimiterDynamics
class VoltageCompensatorDynamics {

}

ExcitationSystemDynamics --> "1" VoltageCompensatorDynamics : VoltageCompensatorDynamics
```

Excitation system function block whose behaviour is described by reference to a standard model <font color="#0f0f0f">or by definition of a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | Discontinuous excitation control model associated with this excitation system model. | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | Overexcitation limiter model associated with this excitation system model. | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | Power factor or VAr controller type 1 model associated with this excitation system model. | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | Power factor or VAr controller type 2 model associated with this excitation system model. | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | Power system stabilizer model associated with this excitation system model. | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | Synchronous machine model with which this excitation system model is associated. | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | Undrexcitation limiter model associated with this excitation system model. | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | Voltage compensator model associated with this excitation system model. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExcitationSystemUserDefined}
### ExcitationSystemUserDefined

Inheritance path = [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExcitationSystemUserDefined {

+ proprietary : Boolean [0..1]
}

class ExcitationSystemDynamics {

}

ExcitationSystemDynamics <|-- ExcitationSystemUserDefined : inherits from
```

Excitation system function block whose dynamic behaviour is described by <font color="#0f0f0f">a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| proprietary [0..1] | [Boolean](#CIM17v40-Boolean) | Behaviour is based on a proprietary model as opposed to a detailed model.true = user-defined model is proprietary with behaviour mutually understood by sending and receiving applications and parameters passed as general attributesfalse = user-defined model is explicitly defined in terms of control blocks and their input and output signals. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| OverexcitationLimiterDynamics [0..1] | [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PFVArControllerType2Dynamics [0..1] | [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| VoltageCompensatorDynamics [1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | see [ExcitationSystemDynamics](CIM17v40-ExcitationSystemDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExpectedEnergy}
### ExpectedEnergy


```mermaid
classDiagram
direction TB

class ExpectedEnergy {

+ intervalStartTime : DateTime [0..1]
+ updateTimeStamp : DateTime [0..1]
+ updateUser : String [0..1]
}

```

Model Expected Energy from Market Clearing, interval based.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| updateTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| updateUser [0..1] | [String](#CIM17v40-String) | | |

{#CIM17v40-ExpectedEnergyValues}
### ExpectedEnergyValues


```mermaid
classDiagram
direction TB

class ExpectedEnergyValues {

+ energyTypeCode : String [0..1]
+ expectedMwh : Float [0..1]
}

class ExpectedEnergy {

}

ExpectedEnergyValues --> "1" ExpectedEnergy : ExpectedEnergy
class RegisteredResource {

}

ExpectedEnergyValues --> "0..1" RegisteredResource : RegisteredResource
```

Model Expected Energy from Market Clearing.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| energyTypeCode [0..1] | [String](#CIM17v40-String) | | |
| expectedMwh [0..1] | [Float](#CIM17v40-Float) | | |
| `ExpectedEnergy [1]` (OfAggregate) | [ExpectedEnergy](#CIM17v40-ExpectedEnergy) | | |
| RegisteredResource [0..1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |

{#CIM17v40-ExternalCustomerAgreement}
### ExternalCustomerAgreement

Inheritance path = [Agreement](#CIM17v40-Agreement) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExternalCustomerAgreement {

}

class Agreement {

}

Agreement <|-- ExternalCustomerAgreement : inherits from
```

A type of customer agreement involving an external agency. For example, a customer may form a contracts with an Energy Service Supplier if Direct Access is permitted.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| signDate [0..1] | [Date](#CIM17v40-Date) | see [Agreement](#CIM17v40-Agreement) | |
| validityInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [Agreement](CIM17v40-Agreement) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ExternalNetworkInjection}
### ExternalNetworkInjection

Inheritance path = [RegulatingCondEq](#CIM17v40-RegulatingCondEq) => [EnergyConnection](#CIM17v40-EnergyConnection) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ExternalNetworkInjection {

+ governorSCD : ActivePowerPerFrequency [0..1]
+ ikSecond : Boolean [0..1]
+ maxInitialSymShCCurrent : CurrentFlow [0..1]
+ maxP : ActivePower [0..1]
+ maxQ : ReactivePower [0..1]
+ maxR0ToX0Ratio : Float [0..1]
+ maxR1ToX1Ratio : Float [0..1]
+ maxZ0ToZ1Ratio : Float [0..1]
+ minInitialSymShCCurrent : CurrentFlow [0..1]
+ minP : ActivePower [0..1]
+ minQ : ReactivePower [0..1]
+ minR0ToX0Ratio : Float [0..1]
+ minR1ToX1Ratio : Float [0..1]
+ minZ0ToZ1Ratio : Float [0..1]
+ p : ActivePower [0..1]
+ q : ReactivePower [0..1]
+ referencePriority : Integer [0..1]
+ voltageFactor : PU [0..1]
}

class RegulatingCondEq {

}

RegulatingCondEq <|-- ExternalNetworkInjection : inherits from
```

This class represents the external network and it is used for IEC 60909 calculations.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| governorSCD [0..1] | [ActivePowerPerFrequency](#CIM17v40-ActivePowerPerFrequency) | Power Frequency Bias. This is the change in power injection divided by the change in frequency and negated. A positive value of the power frequency bias provides additional power injection upon a drop in frequency. | |
| ikSecond [0..1] | [Boolean](#CIM17v40-Boolean) | Indicates whether initial symmetrical short-circuit current and power have been calculated according to IEC (Ik"). Used only if short circuit calculations are done according to superposition method. | |
| maxInitialSymShCCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Maximum initial symmetrical short-circuit currents (Ik" max) in A (Ik" = Sk"/(SQRT(3) Un)). Used for short circuit data exchange according to IEC 60909. | |
| maxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | Maximum active power of the injection. | |
| maxQ [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Maximum reactive power limit. It is used for modelling of infeed for load flow exchange and not for short circuit modelling. | |
| maxR0ToX0Ratio [0..1] | [Float](#CIM17v40-Float) | Maximum ratio of zero sequence resistance of Network Feeder to its zero sequence reactance (R(0)/X(0) max). Used for short circuit data exchange according to IEC 60909. | |
| maxR1ToX1Ratio [0..1] | [Float](#CIM17v40-Float) | Maximum ratio of positive sequence resistance of Network Feeder to its positive sequence reactance (R(1)/X(1) max). Used for short circuit data exchange according to IEC 60909. | |
| maxZ0ToZ1Ratio [0..1] | [Float](#CIM17v40-Float) | Maximum ratio of zero sequence impedance to its positive sequence impedance (Z(0)/Z(1) max). Used for short circuit data exchange according to IEC 60909. | |
| minInitialSymShCCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Minimum initial symmetrical short-circuit currents (Ik" min) in A (Ik" = Sk"/(SQRT(3) Un)). Used for short circuit data exchange according to IEC 60909. | |
| minP [0..1] | [ActivePower](#CIM17v40-ActivePower) | Minimum active power of the injection. | |
| minQ [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Minimum reactive power limit. It is used for modelling of infeed for load flow exchange and not for short circuit modelling. | |
| minR0ToX0Ratio [0..1] | [Float](#CIM17v40-Float) | Indicates whether initial symmetrical short-circuit current and power have been calculated according to IEC (Ik"). Used for short circuit data exchange according to IEC 6090. | |
| minR1ToX1Ratio [0..1] | [Float](#CIM17v40-Float) | Minimum ratio of positive sequence resistance of Network Feeder to its positive sequence reactance (R(1)/X(1) min). Used for short circuit data exchange according to IEC 60909. | |
| minZ0ToZ1Ratio [0..1] | [Float](#CIM17v40-Float) | Minimum ratio of zero sequence impedance to its positive sequence impedance (Z(0)/Z(1) min). Used for short circuit data exchange according to IEC 60909. | |
| p [0..1] | [ActivePower](#CIM17v40-ActivePower) | Active power injection. Load sign convention is used, i.e. positive sign means flow out from a node.Starting value for steady state solutions. | |
| q [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Reactive power injection. Load sign convention is used, i.e. positive sign means flow out from a node.Starting value for steady state solutions. | |
| referencePriority [0..1] | [Integer](#CIM17v40-Integer) | Priority of unit for use as powerflow voltage phase angle reference bus selection. 0 = don t care (default) 1 = highest priority. 2 is less than 1 and so on. | |
| voltageFactor [0..1] | [PU](#CIM17v40-PU) | Voltage factor in pu, which was used to calculate short-circuit current Ik" and power Sk". Used only if short circuit calculations are done according to superposition method. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| controlEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [RegulatingCondEq](#CIM17v40-RegulatingCondEq) | |
| RegulatingControl [0..1] | [RegulatingControl](#CIM17v40-RegulatingControl) | see [RegulatingCondEq](CIM17v40-RegulatingCondEq) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-FACTSDevice}
### FACTSDevice

Inheritance path = [Asset](#CIM17v40-Asset) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class FACTSDevice {

+ kind : enum:FACTSDeviceKind [0..1]
}

class Asset {

}

Asset <|-- FACTSDevice : inherits from
```

FACTS device asset.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [FACTSDeviceKind](#CIM17v40-FACTSDeviceKind) | Kind of FACTS device. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | see [Asset](#CIM17v40-Asset) | |
| initialCondition [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | see [Asset](CIM17v40-Asset) | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | see [Asset](CIM17v40-Asset) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [Asset](CIM17v40-Asset) | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | see [Asset](CIM17v40-Asset) | |
| lotNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| position [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | see [Asset](CIM17v40-Asset) | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | see [Asset](CIM17v40-Asset) | |
| serialNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| type [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| utcNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | see [Asset](CIM17v40-Asset) | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | see [Asset](CIM17v40-Asset) | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | see [Asset](CIM17v40-Asset) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [Asset](CIM17v40-Asset) | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | see [Asset](CIM17v40-Asset) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Asset](CIM17v40-Asset) | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | see [Asset](CIM17v40-Asset) | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | see [Asset](CIM17v40-Asset) | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | see [Asset](CIM17v40-Asset) | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | see [Asset](CIM17v40-Asset) | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | see [Asset](CIM17v40-Asset) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Asset](CIM17v40-Asset) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [Asset](CIM17v40-Asset) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [Asset](CIM17v40-Asset) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Asset](CIM17v40-Asset) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-FTR}
### FTR

Inheritance path = [Agreement](#CIM17v40-Agreement) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class FTR {

+ action : String [0..1]
+ baseEnergy : ActivePower [0..1]
+ class : String [0..1]
+ ftrType : String [0..1]
+ optimized : String [0..1]
}

class Agreement {

}

Agreement <|-- FTR : inherits from
class EnergyPriceCurve {

}

FTR --> "0..1" EnergyPriceCurve : EnergyPriceCurve
class Flowgate {

}

FTR --> "0..1" Flowgate : Flowgate
```

Financial Transmission Rights (FTR) regarding transmission capacity at a flowgate.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| action [0..1] | [String](#CIM17v40-String) | Buy, Sell | |
| baseEnergy [0..1] | [ActivePower](#CIM17v40-ActivePower) | Quantity, typically MWs - Seller owns all rights being offered, MWs over time on same Point of Receipt, Point of Delivery, or Resource. | |
| class [0..1] | [String](#CIM17v40-String) | Peak, Off-peak, 24-hour | |
| ftrType [0..1] | [String](#CIM17v40-String) | Type of rights being offered (product) allowed to be auctioned (option, obligation). | |
| optimized [0..1] | [String](#CIM17v40-String) | Fixed (covers re-configuration, grandfathering) or Optimized (up for sale/purchase | |
| `EnergyPriceCurve [0..1]` (informative) | [EnergyPriceCurve](#CIM17v40-EnergyPriceCurve) | | |
| `Flowgate [0..1]` (informative) | [Flowgate](#CIM17v40-Flowgate) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| signDate [0..1] | [Date](#CIM17v40-Date) | see [Agreement](#CIM17v40-Agreement) | |
| validityInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [Agreement](CIM17v40-Agreement) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Facility}
### Facility

Inheritance path = [AssetContainer](#CIM17v40-AssetContainer) => [Asset](#CIM17v40-Asset) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Facility {

+ kind : String [0..1]
}

class AssetContainer {

}

AssetContainer <|-- Facility : inherits from
```

A facility may contain buildings, storage facilities, switching facilities, power generation, manufacturing facilities, maintenance facilities, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [String](#CIM17v40-String) | Kind of this facility. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | see [Asset](#CIM17v40-Asset) | |
| initialCondition [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | see [Asset](CIM17v40-Asset) | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | see [Asset](CIM17v40-Asset) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [Asset](CIM17v40-Asset) | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | see [Asset](CIM17v40-Asset) | |
| lotNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| position [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | see [Asset](CIM17v40-Asset) | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | see [Asset](CIM17v40-Asset) | |
| serialNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| type [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| utcNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | see [Asset](CIM17v40-Asset) | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | see [Asset](CIM17v40-Asset) | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | see [Asset](CIM17v40-Asset) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [Asset](CIM17v40-Asset) | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | see [Asset](CIM17v40-Asset) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Asset](CIM17v40-Asset) | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | see [Asset](CIM17v40-Asset) | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | see [Asset](CIM17v40-Asset) | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | see [Asset](CIM17v40-Asset) | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | see [Asset](CIM17v40-Asset) | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | see [Asset](CIM17v40-Asset) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Asset](CIM17v40-Asset) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [Asset](CIM17v40-Asset) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [Asset](CIM17v40-Asset) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Asset](CIM17v40-Asset) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-FailureEvent}
### FailureEvent

Inheritance path = [ActivityRecord](#CIM17v40-ActivityRecord) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class FailureEvent {

+ breakerFailureReason : enum:BreakerFailureReasonKind [0..1]
+ corporateCode : String [0..1]
+ failureClassification : enum:AssetFailureClassification [0..1]
+ failureDateTime : DateTime [0..1]
+ failureIsolationMethod : enum:FailureIsolationMethodKind [0..1]
+ failureMode : enum:AssetFailureMode [1]
+ faultLocatingMethod : String [0..1]
+ location : String [0..1]
+ rootCause : String [0..1]
+ transformerFailureReason : enum:TransformerFailureReasonKind [0..1]
}

class ActivityRecord {

}

ActivityRecord <|-- FailureEvent : inherits from
```

An event where an asset has failed to perform its functions within specified parameters. This class is intended to reflect the failure itself. Additional information resulting from forensic analysis could be captured by a diagnosis data set.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| breakerFailureReason [0..1] | [BreakerFailureReasonKind](#CIM17v40-BreakerFailureReasonKind) | Reason for breaker failure. | |
| corporateCode [0..1] | [String](#CIM17v40-String) | Code for asset failure. | |
| failureClassification [0..1] | [AssetFailureClassification](#CIM17v40-AssetFailureClassification) | Classification of failure. | |
| failureDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Time and date of asset failure. | |
| failureIsolationMethod [0..1] | [FailureIsolationMethodKind](#CIM17v40-FailureIsolationMethodKind) | How the asset failure was isolated from the system. | |
| failureMode [1] | [AssetFailureMode](#CIM17v40-AssetFailureMode) | What asset failed to be able to do. | |
| faultLocatingMethod [0..1] | [String](#CIM17v40-String) | The method used for locating the faulted part of the asset. For example, cable options include: Cap Discharge-Thumping, Bridge Method, Visual Inspection, Other. | |
| location [0..1] | [String](#CIM17v40-String) | Failure location on an object. | |
| rootCause [0..1] | [String](#CIM17v40-String) | Root cause of asset failure. | |
| transformerFailureReason [0..1] | [TransformerFailureReasonKind](#CIM17v40-TransformerFailureReasonKind) | Reason for transformer failure. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| reason [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| severity [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| type [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| Document [0..1] | [Document](#CIM17v40-Document) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Fault}
### Fault

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Fault {

+ kind : enum:PhaseConnectedFaultKind [0..1]
+ occurredDateTime : DateTime [0..1]
+ phases : enum:PhaseCode [0..1]
+ impedance : FaultImpedance [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Fault : inherits from
class Equipment {

}

Fault --> "0..1" Equipment : FaultyEquipment
class Location {

}

Fault --> "0..1" Location : Location
class Outage {

}

Fault --> "0..1" Outage : Outage
```

Abnormal condition causing current flow through conducting equipment, such as caused by equipment failure or short circuits from objects not typically modelled (for example, a tree falling on a line).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [PhaseConnectedFaultKind](#CIM17v40-PhaseConnectedFaultKind) | The kind of phase fault. | |
| occurredDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | The date and time at which the fault occurred. | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | The phases participating in the fault. The fault connections into these phases are further specified by the type of fault. | |
| FaultyEquipment [0..1] | [Equipment](#CIM17v40-Equipment) | Equipment carrying this fault. | |
| impedance [0..1] | [FaultImpedance](#CIM17v40-FaultImpedance) | Fault impedance. Its usage is described by 'kind'. | |
| Location [0..1] | [Location](#CIM17v40-Location) | Location of this fault. | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | Outage associated with this fault. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-FaultCauseType}
### FaultCauseType

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class FaultCauseType {

}

class IdentifiedObject {

}

IdentifiedObject <|-- FaultCauseType : inherits from
```

Type of cause of the fault.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-FaultIndicator}
### FaultIndicator

Inheritance path = [AuxiliaryEquipment](#CIM17v40-AuxiliaryEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class FaultIndicator {

}

class AuxiliaryEquipment {

}

AuxiliaryEquipment <|-- FaultIndicator : inherits from
```

A FaultIndicator is typically only an indicator (which may or may not be remotely monitored), and not a piece of equipment that actually initiates a protection event. It is used for FLISR (Fault Location, Isolation and Restoration) purposes, assisting with the dispatch of crews to "most likely" part of the network (i.e. assists with determining circuit section where the fault most likely happened).


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Terminal [1] | [Terminal](#CIM17v40-Terminal) | see [AuxiliaryEquipment](CIM17v40-AuxiliaryEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-FaultIndicatorInfo}
### FaultIndicatorInfo

Inheritance path = [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class FaultIndicatorInfo {

+ resetKind : enum:FaultIndicatorResetKind [0..1]
}

class AssetInfo {

}

AssetInfo <|-- FaultIndicatorInfo : inherits from
```

Parameters of fault indicator asset.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| resetKind [0..1] | [FaultIndicatorResetKind](#CIM17v40-FaultIndicatorResetKind) | Kind of reset mechanisim of this fault indicator. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Feeder}
### Feeder

Inheritance path = [EquipmentContainer](#CIM17v40-EquipmentContainer) => [ConnectivityNodeContainer](#CIM17v40-ConnectivityNodeContainer) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Feeder {

}

class EquipmentContainer {

}

EquipmentContainer <|-- Feeder : inherits from
class Substation {

}

Feeder --> "0..*" Substation : NamingSecondarySubstation
class Substation {

}

Feeder --> "0..*" Substation : NormalEnergizedSubstation
class Substation {

}

Feeder --> "0..1" Substation : NormalEnergizingSubstation
```

A collection of equipment for organizational purposes, used for grouping distribution resources.

The organization a feeder does not necessarily reflect connectivity or current operation state.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `NamingSecondarySubstation [0..*]` (AggregateOf) | [Substation](#CIM17v40-Substation) | The secondary substations that are normally energized from the feeder. Used for naming purposes. Should be consistent with the other associations for energizing terminal specification and the feeder energization specification. | |
| NormalEnergizedSubstation [0..*] | [Substation](#CIM17v40-Substation) | The substations that are normally energized by the feeder. | |
| `NormalEnergizingSubstation [0..1]` (OfAggregate) | [Substation](#CIM17v40-Substation) | The substation that nominally energizes the feeder. Also used for naming purposes. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-FieldDispatchHistory}
### FieldDispatchHistory

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class FieldDispatchHistory {

}

class IdentifiedObject {

}

IdentifiedObject <|-- FieldDispatchHistory : inherits from
class Crew {

}

FieldDispatchHistory --> "0..1" Crew : Crew
class PlannedOutage {

}

FieldDispatchHistory --> "0..1" PlannedOutage : PlannedOutage
class UnplannedOutage {

}

FieldDispatchHistory --> "0..1" UnplannedOutage : UnplannedOutage
```

The history of field dispatch statuses for this work.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Crew [0..1] | [Crew](#CIM17v40-Crew) | The crew that has this field dispatch history. | |
| PlannedOutage [0..1] | [PlannedOutage](#CIM17v40-PlannedOutage) | The planned outage that has the field dispatch history. | |
| UnplannedOutage [0..1] | [UnplannedOutage](#CIM17v40-UnplannedOutage) | The unplanned outage that has the field dispatch history. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-FieldDispatchStep}
### FieldDispatchStep


```mermaid
classDiagram
direction TB

class FieldDispatchStep {

+ dispatchStatus : enum:CrewStatusKind [1]
+ occurredDateTime : DateTime [0..1]
+ remarks : String [0..1]
+ sequenceNumber : Integer [0..1]
}

class FieldDispatchHistory {

}

FieldDispatchStep --> "1" FieldDispatchHistory : FieldDispatchHistory
```

Details of the step in the field dispatch history.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dispatchStatus [1] | [CrewStatusKind](#CIM17v40-CrewStatusKind) | The status of one or more crews dispatched to perform field work at one or more work sites | |
| occurredDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | The date and time at which the dispatch status occurred. | |
| remarks [0..1] | [String](#CIM17v40-String) | freeform comments related to the dispatch to perform field work. | |
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | The sequence number of the field dispatch step within the field dispatch history. Begins with 1 and increments up. | |
| FieldDispatchHistory [1] | [FieldDispatchHistory](#CIM17v40-FieldDispatchHistory) | The dispatch history associated with the field dispatch step | |

{#CIM17v40-FieldSafetySupervisor}
### FieldSafetySupervisor

Inheritance path = [CrewMember](#CIM17v40-CrewMember) => [OperationPersonRole](#CIM17v40-OperationPersonRole) => [PersonRole](#CIM17v40-PersonRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class FieldSafetySupervisor {

}

class CrewMember {

}

CrewMember <|-- FieldSafetySupervisor : inherits from
```

Crew member on work site responsible for all local safety measures for the work crew doing maintenance, construction and repair in a substation or on a power line/cable.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Crew [0..1] | [Crew](#CIM17v40-Crew) | see [CrewMember](CIM17v40-CrewMember) | |
| Person [0..1] | [Person](#CIM17v40-Person) | see [PersonRole](CIM17v40-PersonRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-FinancialInfo}
### FinancialInfo

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class FinancialInfo {

+ account : String [0..1]
+ actualPurchaseCost : Money [0..1]
+ costDescription : String [0..1]
+ costType : String [0..1]
+ financialValue : Money [0..1]
+ plantTransferDateTime : DateTime [0..1]
+ purchaseDateTime : DateTime [0..1]
+ purchaseOrderNumber : String [0..1]
+ valueDateTime : DateTime [0..1]
+ warrantyEndDateTime : DateTime [0..1]
+ quantity : IntegerQuantity [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- FinancialInfo : inherits from
class Asset {

}

FinancialInfo --> "0..1" Asset : Asset
```

Various current financial properties associated with a particular asset. Historical properties may be determined by ActivityRecords associated with the asset.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| account [0..1] | [String](#CIM17v40-String) | The account to which this actual material item is charged. | |
| actualPurchaseCost [0..1] | [Money](#CIM17v40-Money) | The actual purchase cost of this particular asset. | |
| costDescription [0..1] | [String](#CIM17v40-String) | Description of the cost. | |
| costType [0..1] | [String](#CIM17v40-String) | Type of cost to which this Material Item belongs. | |
| financialValue [0..1] | [Money](#CIM17v40-Money) | Value of asset as of 'valueDateTime'. | |
| plantTransferDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time asset's financial value was put in plant for regulatory accounting purposes (e.g., for rate base calculations). This is sometime referred to as the "in-service date". | |
| purchaseDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time asset was purchased. | |
| purchaseOrderNumber [0..1] | [String](#CIM17v40-String) | Purchase order identifier. | |
| valueDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time at which the financial value was last established. | |
| warrantyEndDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time warranty on asset expires. | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | The asset to which this financial information relates. | |
| quantity [0..1] | [IntegerQuantity](#CIM17v40-IntegerQuantity) | The quantity of the asset if per unit length, for example conductor. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Fire}
### Fire

Inheritance path = [GeosphericPhenomenon](#CIM17v40-GeosphericPhenomenon) => [EnvironmentalPhenomenon](#CIM17v40-EnvironmentalPhenomenon)

```mermaid
classDiagram
direction TB

class Fire {

}

class GeosphericPhenomenon {

}

GeosphericPhenomenon <|-- Fire : inherits from
```

A fire, often uncontrolled, covering an area of land which typically contains combustible vegetation. Associated location information is assumed to describe the total area burned as of a specified time.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| PhenomenonClassification [0..1] | [PhenomenonClassification](#CIM17v40-PhenomenonClassification) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| timeInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |

{#CIM17v40-FiveMinAuxiliaryData}
### FiveMinAuxiliaryData


```mermaid
classDiagram
direction TB

class FiveMinAuxiliaryData {

+ intervalStartTime : DateTime [0..1]
+ updateTimeStamp : DateTime [0..1]
+ updateUser : String [0..1]
}

```

Models 5-Minutes Auxiliary Data.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| updateTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| updateUser [0..1] | [String](#CIM17v40-String) | | |

{#CIM17v40-Flood}
### Flood

Inheritance path = [HydrosphericPhenomenon](#CIM17v40-HydrosphericPhenomenon) => [EnvironmentalPhenomenon](#CIM17v40-EnvironmentalPhenomenon)

```mermaid
classDiagram
direction TB

class Flood {

}

class HydrosphericPhenomenon {

}

HydrosphericPhenomenon <|-- Flood : inherits from
```

A flood, an overflowing of a large amount of water beyond its normal confines, esp. over what is normally dry land.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| PhenomenonClassification [0..1] | [PhenomenonClassification](#CIM17v40-PhenomenonClassification) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| timeInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |

{#CIM17v40-FlowDirection}
### FlowDirection


```mermaid
classDiagram
direction TB

class FlowDirection {

+ direction : String [0..1]
}

```

The coded identification of the direction of energy flow.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| direction [0..1] | [String](#CIM17v40-String) | The coded identification of the direction of energy flow. | |

{#CIM17v40-Flowgate}
### (informative) Flowgate

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Flowgate {

+ direction : enum:InterTieDirection [0..1]
+ exportMWRating : ActivePower [0..1]
+ importMWRating : ActivePower [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- Flowgate : inherits from
class CongestionRevenueRight {

}

Flowgate --> "0..1" CongestionRevenueRight : CongestionRevenueRight
class SubControlArea {

}

Flowgate --> "0..1" SubControlArea : From_SubControlArea
class GenericConstraints {

}

Flowgate --> "0..1" GenericConstraints : GenericConstraints
class HostControlArea {

}

Flowgate --> "0..1" HostControlArea : HostControlArea
class SecurityConstraints {

}

Flowgate --> "0..1" SecurityConstraints : SecurityConstraints
class SubControlArea {

}

Flowgate --> "0..1" SubControlArea : To_SubControlArea
```

A flowgate, is single or group of transmission elements intended to model MW flow impact relating to transmission limitations and transmission service usage.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| direction [0..1] | [InterTieDirection](#CIM17v40-InterTieDirection) | The direction of the flowgate, export or import | |
| exportMWRating [0..1] | [ActivePower](#CIM17v40-ActivePower) | Export MW rating | |
| importMWRating [0..1] | [ActivePower](#CIM17v40-ActivePower) | Import MW rating | |
| CongestionRevenueRight [0..1] | [CongestionRevenueRight](#CIM17v40-CongestionRevenueRight) | | |
| From_SubControlArea [0..1] | [SubControlArea](#CIM17v40-SubControlArea) | | |
| GenericConstraints [0..1] | [GenericConstraints](#CIM17v40-GenericConstraints) | | |
| HostControlArea [0..1] | [HostControlArea](#CIM17v40-HostControlArea) | | |
| SecurityConstraints [0..1] | [SecurityConstraints](#CIM17v40-SecurityConstraints) | | |
| To_SubControlArea [0..1] | [SubControlArea](#CIM17v40-SubControlArea) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-FlowgatePartner}
### FlowgatePartner

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class FlowgatePartner {

}

class IdentifiedObject {

}

IdentifiedObject <|-- FlowgatePartner : inherits from
class FlowgateValue {

}

FlowgatePartner --> "0..1" FlowgateValue : FlowgateValue
```

Flowgate defined partner.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| FlowgateValue [0..1] | [FlowgateValue](#CIM17v40-FlowgateValue) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-FlowgateRelief}
### FlowgateRelief


```mermaid
classDiagram
direction TB

class FlowgateRelief {

+ effectiveDate : DateTime [0..1]
+ idcTargetMktFlow : Integer [0..1]
+ terminateDate : DateTime [0..1]
}

class Flowgate {

}

FlowgateRelief --> "1" Flowgate : Flowgate
```

IDC (Interchange Distribution Calulator) sends data for a TLR (Transmission Loading Relief).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| effectiveDate [0..1] | [DateTime](#CIM17v40-DateTime) | Date/Time when record becomes effectiveUsed to determine when a record becomes effective. | |
| idcTargetMktFlow [0..1] | [Integer](#CIM17v40-Integer) | Energy Flow level that should be maintained according to the TLR rules as specified by the IDC.For Realtime Markets use in dispatch to control constraints under TLR and calculate unconstrained market flows | |
| terminateDate [0..1] | [DateTime](#CIM17v40-DateTime) | Date/Time when record is no longer effectiveUsed to determine when a record is no longer effective | |
| Flowgate [1] | [Flowgate](#CIM17v40-Flowgate) | | |

{#CIM17v40-FlowgateValue}
### FlowgateValue


```mermaid
classDiagram
direction TB

class FlowgateValue {

+ economicDispatchLimit : Integer [0..1]
+ effectiveDate : DateTime [0..1]
+ firmNetworkLimit : Integer [0..1]
+ flowDirectionFlag : enum:FlowDirectionType [0..1]
+ mktFlow : Integer [0..1]
+ netFirmNetworkLimit : Integer [0..1]
}

class Flowgate {

}

FlowgateValue --> "1" Flowgate : Flowgate
class FlowgatePartner {

}

FlowgateValue --> "0..1" FlowgatePartner : FlowgatePartner
```

Day Ahead, Network Native Load, Economic Dispatch, values used for calculation of Network Native Load (NNL) Determinator process.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| economicDispatchLimit [0..1] | [Integer](#CIM17v40-Integer) | Limit for Economic Dispatch priority 6 energy flow on the specified flowgate for the specified time period. | |
| effectiveDate [0..1] | [DateTime](#CIM17v40-DateTime) | Date/Time when record becomes effectiveUsed to determine when a record becomes effective | |
| firmNetworkLimit [0..1] | [Integer](#CIM17v40-Integer) | Limit for firm flow on the specified flowgate for the specified time period. The amount of energy flow over a specifed flowgate due to generation in the market which can be classified as Firm Network priority. | |
| flowDirectionFlag [0..1] | [FlowDirectionType](#CIM17v40-FlowDirectionType) | Specifies the direction of energy flow in the flowgate | |
| mktFlow [0..1] | [Integer](#CIM17v40-Integer) | The amount of energy flow over a specifed flowgate due to generation in the market. | |
| netFirmNetworkLimit [0..1] | [Integer](#CIM17v40-Integer) | Net Energy flow in flowgate for the associated FlowgatePartner | |
| Flowgate [1] | [Flowgate](#CIM17v40-Flowgate) | | |
| FlowgatePartner [0..1] | [FlowgatePartner](#CIM17v40-FlowgatePartner) | | |

{#CIM17v40-ForbiddenRegion}
### ForbiddenRegion

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ForbiddenRegion {

+ crossingCost : Float [0..1]
+ crossTime : Integer [0..1]
+ highMW : Float [0..1]
+ lowMW : Float [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ForbiddenRegion : inherits from
```

Forbbiden region is operating ranges where the units are unable to maintain steady operation without causing equipment damage. The four attributes that define a forbidden region are the low MW, the High MW, the crossing time, and the crossing cost.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| crossingCost [0..1] | [Float](#CIM17v40-Float) | Cost associated with crossing the forbidden region | |
| crossTime [0..1] | [Integer](#CIM17v40-Integer) | Time to cross the forbidden region in minutes. | |
| highMW [0..1] | [Float](#CIM17v40-Float) | High end of the region definition | |
| lowMW [0..1] | [Float](#CIM17v40-Float) | Low end of the region definition. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Forecast}
### Forecast

Inheritance path = [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Forecast {

+ validFor : DateTimeInterval [0..1]
}

class EnvironmentalInformation {

}

EnvironmentalInformation <|-- Forecast : inherits from
```

A forecast group of value sets and/or phenomena characteristics.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| validFor [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | The interval for which the forecast is valid. For example, a forecast issued now for tomorrow might be valid for the next 2 hours. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| created [0..1] | [DateTime](#CIM17v40-DateTime) | see [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | |
| EnvironmentalDataProvider [0..1] | [EnvironmentalDataProvider](#CIM17v40-EnvironmentalDataProvider) | see [EnvironmentalInformation](CIM17v40-EnvironmentalInformation) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-FormerReference}
### FormerReference

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class FormerReference {

}

class IdentifiedObject {

}

IdentifiedObject <|-- FormerReference : inherits from
class RegisteredResource {

}

FormerReference --> "1" RegisteredResource : RegisteredResource
```

Used to indicate former references to the same piece of equipment. The ID, name, and effectivity dates are utilized.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| RegisteredResource [1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-FossilFuel}
### FossilFuel

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class FossilFuel {

+ fossilFuelType : enum:FuelType [0..1]
+ fuelCost : CostPerHeatUnit [0..1]
+ fuelDispatchCost : CostPerHeatUnit [0..1]
+ fuelEffFactor : PU [0..1]
+ fuelHandlingCost : CostPerHeatUnit [0..1]
+ fuelHeatContent : Float [0..1]
+ fuelMixture : PerCent [0..1]
+ fuelSulfur : PU [0..1]
+ highBreakpointP : ActivePower [0..1]
+ lowBreakpointP : ActivePower [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- FossilFuel : inherits from
class ThermalGeneratingUnit {

}

FossilFuel --> "1" ThermalGeneratingUnit : ThermalGeneratingUnit
```

The fossil fuel consumed by the non-nuclear thermal generating unit. For example, coal, oil, gas, etc. These are the specific fuels that the generating unit can consume.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| fossilFuelType [0..1] | [FuelType](#CIM17v40-FuelType) | The type of fossil fuel, such as coal, oil, or gas. | |
| fuelCost [0..1] | [CostPerHeatUnit](#CIM17v40-CostPerHeatUnit) | The cost in terms of heat value for the given type of fuel. | |
| fuelDispatchCost [0..1] | [CostPerHeatUnit](#CIM17v40-CostPerHeatUnit) | The cost of fuel used for economic dispatching which includes: fuel cost, transportation cost, and incremental maintenance cost. | |
| fuelEffFactor [0..1] | [PU](#CIM17v40-PU) | The efficiency factor for the fuel (per unit) in terms of the effective energy absorbed. | |
| fuelHandlingCost [0..1] | [CostPerHeatUnit](#CIM17v40-CostPerHeatUnit) | Handling and processing cost associated with this fuel. | |
| fuelHeatContent [0..1] | [Float](#CIM17v40-Float) | The amount of heat per weight (or volume) of the given type of fuel. | |
| fuelMixture [0..1] | [PerCent](#CIM17v40-PerCent) | Relative amount of the given type of fuel, when multiple fuels are being consumed. | |
| fuelSulfur [0..1] | [PU](#CIM17v40-PU) | The fuel's fraction of pollution credit per unit of heat content. | |
| highBreakpointP [0..1] | [ActivePower](#CIM17v40-ActivePower) | The active power output level of the unit at which the given type of fuel is switched on. This fuel (e.g., oil) is sometimes used to supplement the base fuel (e.g., coal) at high active power output levels. | |
| lowBreakpointP [0..1] | [ActivePower](#CIM17v40-ActivePower) | The active power output level of the unit at which the given type of fuel is switched off. This fuel (e.g., oil) is sometimes used to stabilize the base fuel (e.g., coal) at low active power output levels. | |
| ThermalGeneratingUnit [1] | [ThermalGeneratingUnit](#CIM17v40-ThermalGeneratingUnit) | A thermal generating unit may have one or more fossil fuels. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-FossilSteamSupply}
### FossilSteamSupply

Inheritance path = [SteamSupply](#CIM17v40-SteamSupply) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class FossilSteamSupply {

+ auxPowerVersusFrequency : PU [0..1]
+ auxPowerVersusVoltage : PU [0..1]
+ boilerControlMode : enum:BoilerControlMode [0..1]
+ controlErrorBiasP : Float [0..1]
+ controlIC : Float [0..1]
+ controlPC : Float [0..1]
+ controlPEB : Float [0..1]
+ controlPED : PU [0..1]
+ controlTC : Float [0..1]
+ feedWaterIG : Float [0..1]
+ feedWaterPG : Float [0..1]
+ feedWaterTC : Seconds [0..1]
+ fuelDemandLimit : PU [0..1]
+ fuelSupplyDelay : Seconds [0..1]
+ fuelSupplyTC : Seconds [0..1]
+ maxErrorRateP : Float [0..1]
+ mechPowerSensorLag : Seconds [0..1]
+ minErrorRateP : Float [0..1]
+ pressureCtrlDG : Float [0..1]
+ pressureCtrlIG : Float [0..1]
+ pressureCtrlPG : Float [0..1]
+ pressureFeedback : Integer [0..1]
+ superHeater1Capacity : Float [0..1]
+ superHeater2Capacity : Float [0..1]
+ superHeaterPipePD : Float [0..1]
+ throttlePressureSP : PU [0..1]
}

class SteamSupply {

}

SteamSupply <|-- FossilSteamSupply : inherits from
```

Fossil fuelled boiler (e.g., coal, oil, gas).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| auxPowerVersusFrequency [0..1] | [PU](#CIM17v40-PU) | Off nominal frequency effect on auxiliary real power. Per unit active power variation versus per unit frequency variation. | |
| auxPowerVersusVoltage [0..1] | [PU](#CIM17v40-PU) | Off nominal voltage effect on auxiliary real power. Per unit active power variation versus per unit voltage variation. | |
| boilerControlMode [0..1] | [BoilerControlMode](#CIM17v40-BoilerControlMode) | The control mode of the boiler. | |
| controlErrorBiasP [0..1] | [Float](#CIM17v40-Float) | Active power error bias ratio. | |
| controlIC [0..1] | [Float](#CIM17v40-Float) | Integral constant. | |
| controlPC [0..1] | [Float](#CIM17v40-Float) | Proportional constant. | |
| controlPEB [0..1] | [Float](#CIM17v40-Float) | Pressure error bias ratio. | |
| controlPED [0..1] | [PU](#CIM17v40-PU) | Pressure error deadband. | |
| controlTC [0..1] | [Float](#CIM17v40-Float) | Time constant. | |
| feedWaterIG [0..1] | [Float](#CIM17v40-Float) | Feedwater integral gain ratio. | |
| feedWaterPG [0..1] | [Float](#CIM17v40-Float) | Feedwater proportional gain ratio. | |
| feedWaterTC [0..1] | [Seconds](#CIM17v40-Seconds) | Feedwater time constant ratio. | |
| fuelDemandLimit [0..1] | [PU](#CIM17v40-PU) | Fuel demand limit. | |
| fuelSupplyDelay [0..1] | [Seconds](#CIM17v40-Seconds) | Fuel delay. | |
| fuelSupplyTC [0..1] | [Seconds](#CIM17v40-Seconds) | Fuel supply time constant. | |
| maxErrorRateP [0..1] | [Float](#CIM17v40-Float) | Active power maximum error rate limit. | |
| mechPowerSensorLag [0..1] | [Seconds](#CIM17v40-Seconds) | Mechanical power sensor lag. | |
| minErrorRateP [0..1] | [Float](#CIM17v40-Float) | Active power minimum error rate limit. | |
| pressureCtrlDG [0..1] | [Float](#CIM17v40-Float) | Pressure control derivative gain ratio. | |
| pressureCtrlIG [0..1] | [Float](#CIM17v40-Float) | Pressure control integral gain ratio. | |
| pressureCtrlPG [0..1] | [Float](#CIM17v40-Float) | Pressure control proportional gain ratio. | |
| pressureFeedback [0..1] | [Integer](#CIM17v40-Integer) | Pressure feedback indicator. | |
| superHeater1Capacity [0..1] | [Float](#CIM17v40-Float) | Drum/primary superheater capacity. | |
| superHeater2Capacity [0..1] | [Float](#CIM17v40-Float) | Secondary superheater capacity. | |
| superHeaterPipePD [0..1] | [Float](#CIM17v40-Float) | Superheater pipe pressure drop constant. | |
| throttlePressureSP [0..1] | [PU](#CIM17v40-PU) | Throttle pressure setpoint. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| steamSupplyRating [0..1] | [Float](#CIM17v40-Float) | see [SteamSupply](#CIM17v40-SteamSupply) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-FrameworkPart}
### FrameworkPart

Inheritance path = [ModelAuthoritySet](#CIM17v40-ModelAuthoritySet) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class FrameworkPart {

}

class ModelAuthoritySet {

}

ModelAuthoritySet <|-- FrameworkPart : inherits from
class NetworkFrame {

}

FrameworkPart --> "0..1" NetworkFrame : Frame
class ModelFrameType {

}

FrameworkPart --> "1" ModelFrameType : ModelFrameType
```

The type of alternate model frame. For example, it could be generator group used to represent generators in state estimator, planning, planning dynamics, short circuit, or real-time dynamics etc., but does not specifically represent any one alternative model. This need to know what objects to be removed in the realization of any one alternate model.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Frame [0..1]` (informative) | [NetworkFrame](#CIM17v40-NetworkFrame) | | |
| `ModelFrameType [1]` (informative) | [ModelFrameType](#CIM17v40-ModelFrameType) | Model frame type of the model frame. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ModelingAuthority [1]` (informative) | [ModelAuthority](#CIM17v40-ModelAuthority) | see [ModelAuthoritySet](CIM17v40-ModelAuthoritySet) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-FrequencyConverter}
### FrequencyConverter

Inheritance path = [RegulatingCondEq](#CIM17v40-RegulatingCondEq) => [EnergyConnection](#CIM17v40-EnergyConnection) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class FrequencyConverter {

+ frequency : Frequency [0..1]
+ maxP : ActivePower [0..1]
+ maxU : Voltage [0..1]
+ minP : ActivePower [0..1]
+ minU : Voltage [0..1]
}

class RegulatingCondEq {

}

RegulatingCondEq <|-- FrequencyConverter : inherits from
```

A device to convert from one frequency to another (e.g., frequency F1 to F2) comprises a pair of FrequencyConverter instances. One converts from F1 to DC, the other converts the DC to F2.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| frequency [0..1] | [Frequency](#CIM17v40-Frequency) | Frequency on the AC side. | |
| maxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | The maximum active power on the DC side at which the frequency converter should operate. | |
| maxU [0..1] | [Voltage](#CIM17v40-Voltage) | The maximum voltage on the DC side at which the frequency converter should operate. | |
| minP [0..1] | [ActivePower](#CIM17v40-ActivePower) | The minimum active power on the DC side at which the frequency converter should operate. | |
| minU [0..1] | [Voltage](#CIM17v40-Voltage) | The minimum voltage on the DC side at which the frequency converter should operate. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| controlEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [RegulatingCondEq](#CIM17v40-RegulatingCondEq) | |
| RegulatingControl [0..1] | [RegulatingControl](#CIM17v40-RegulatingControl) | see [RegulatingCondEq](CIM17v40-RegulatingCondEq) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-FuelAllocationSchedule}
### FuelAllocationSchedule

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class FuelAllocationSchedule {

+ fuelAllocationEndDate : DateTime [0..1]
+ fuelAllocationStartDate : DateTime [0..1]
+ fuelType : enum:FuelType [0..1]
+ maxFuelAllocation : Float [0..1]
+ minFuelAllocation : Float [0..1]
}

class Curve {

}

Curve <|-- FuelAllocationSchedule : inherits from
class FossilFuel {

}

FuelAllocationSchedule --> "1" FossilFuel : FossilFuel
class ThermalGeneratingUnit {

}

FuelAllocationSchedule --> "1" ThermalGeneratingUnit : ThermalGeneratingUnit
```

The amount of fuel of a given type which is allocated for consumption over a specified period of time.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| fuelAllocationEndDate [0..1] | [DateTime](#CIM17v40-DateTime) | The end time and date of the fuel allocation schedule. | |
| fuelAllocationStartDate [0..1] | [DateTime](#CIM17v40-DateTime) | The start time and date of the fuel allocation schedule. | |
| fuelType [0..1] | [FuelType](#CIM17v40-FuelType) | The type of fuel, which also indicates the corresponding measurement unit. | |
| maxFuelAllocation [0..1] | [Float](#CIM17v40-Float) | The maximum amount of fuel that is allocated for consumption for the scheduled time period. | |
| minFuelAllocation [0..1] | [Float](#CIM17v40-Float) | The minimum amount of fuel that is allocated for consumption for the scheduled time period, e.g., based on a "take-or-pay" contract. | |
| FossilFuel [1] | [FossilFuel](#CIM17v40-FossilFuel) | A fuel allocation schedule shall have a fossil fuel. | |
| `ThermalGeneratingUnit [1]` (OfAggregate) | [ThermalGeneratingUnit](#CIM17v40-ThermalGeneratingUnit) | A thermal generating unit may have one or more fuel allocation schedules. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-FuelCostCurve}
### FuelCostCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class FuelCostCurve {

}

class Curve {

}

Curve <|-- FuelCostCurve : inherits from
class RegisteredGenerator {

}

FuelCostCurve --> "0..1" RegisteredGenerator : RegisteredGenerator
```

Relationship between unit fuel cost in $/kWh(Y-axis) and unit output in MW (X-axis).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| RegisteredGenerator [0..1] | [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-FuelRegion}
### FuelRegion

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class FuelRegion {

+ fuelRegionType : String [0..1]
+ lastModified : DateTime [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- FuelRegion : inherits from
class GasPrice {

}

FuelRegion --> "1" GasPrice : GasPrice
class OilPrice {

}

FuelRegion --> "1" OilPrice : OilPrice
class RTO {

}

FuelRegion --> "1" RTO : RTO
```

Indication of region for fuel inventory purposes.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| fuelRegionType [0..1] | [String](#CIM17v40-String) | The type of fuel region | |
| lastModified [0..1] | [DateTime](#CIM17v40-DateTime) | Time of last update | |
| GasPrice [1] | [GasPrice](#CIM17v40-GasPrice) | | |
| OilPrice [1] | [OilPrice](#CIM17v40-OilPrice) | | |
| RTO [1] | [RTO](#CIM17v40-RTO) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Fuse}
### Fuse

Inheritance path = [Switch](#CIM17v40-Switch) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Fuse {

}

class Switch {

}

Switch <|-- Fuse : inherits from
```

An overcurrent protective device with a circuit opening fusible part that is heated and severed by the passage of overcurrent through it. A fuse is considered a switching device because it breaks current.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| locked [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| normalOpen [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| open [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [Switch](CIM17v40-Switch) | |
| retained [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| `switchOnCount [0..1]` (deprecated) | [Integer](#CIM17v40-Integer) | see [Switch](#CIM17v40-Switch) | |
| `switchOnDate [0..1]` (deprecated) | [DateTime](#CIM17v40-DateTime) | see [Switch](#CIM17v40-Switch) | |
| `CompositeSwitch [0..1]` (OfAggregate) | [CompositeSwitch](#CIM17v40-CompositeSwitch) | see [Switch](CIM17v40-Switch) | |
| SwitchAction [0..1] | [SwitchAction](#CIM17v40-SwitchAction) | see [Switch](CIM17v40-Switch) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GasPrice}
### GasPrice


```mermaid
classDiagram
direction TB

class GasPrice {

+ gasPriceIndex : Float [0..1]
}

class FuelRegion {

}

GasPrice --> "1" FuelRegion : FuelRegion
```

Price of gas in monetary units.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| gasPriceIndex [0..1] | [Float](#CIM17v40-Float) | The average natural gas price at a defined fuel region. | |
| FuelRegion [1] | [FuelRegion](#CIM17v40-FuelRegion) | | |

{#CIM17v40-Gate}
### (informative) Gate

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Gate {

+ kind : enum:GateLogicKind [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Gate : inherits from
```

Logical gate than support logical operation based on the input.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [GateLogicKind](#CIM17v40-GateLogicKind) | The logical operation of the gate. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GateInputPin}
### GateInputPin

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GateInputPin {

+ absoluteValue : Boolean [0..1]
+ aDLogicKind : enum:AnalogToDigitalLogicKind [0..1]
+ duration : Seconds [0..1]
+ negate : Boolean [0..1]
+ thresholdPercentage : PerCent [0..1]
+ thresholdValue : Float [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- GateInputPin : inherits from
class Gate {

}

GateInputPin --> "1" Gate : Gate
```

Input pin for a logical gate. The condition described in the input pin will give a logical true or false. Result from measurement and calculation are converted to a true or false.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| absoluteValue [0..1] | [Boolean](#CIM17v40-Boolean) | If true, use the absolute value for compare.. | |
| aDLogicKind [0..1] | [AnalogToDigitalLogicKind](#CIM17v40-AnalogToDigitalLogicKind) | The compare operation. | |
| duration [0..1] | [Seconds](#CIM17v40-Seconds) | The duration the compare condition need to be present before given a true. Default is 0 seconds. | |
| negate [0..1] | [Boolean](#CIM17v40-Boolean) | Invert/negate the result of the compare. | |
| thresholdPercentage [0..1] | [PerCent](#CIM17v40-PerCent) | The threshold percentage that should be used for compare with the percentage change between input value and threshold value. | |
| thresholdValue [0..1] | [Float](#CIM17v40-Float) | The threshold value that should be used for compare with the input value. | |
| `Gate [1]` (OfAggregate, informative) | [Gate](#CIM17v40-Gate) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GenDistributionFactor}
### GenDistributionFactor


```mermaid
classDiagram
direction TB

class GenDistributionFactor {

+ factor : Float [0..1]
}

class AggregatedPnode {

}

GenDistributionFactor --> "0..1" AggregatedPnode : AggregatedPnode
class IndividualPnode {

}

GenDistributionFactor --> "0..1" IndividualPnode : IndividualPnode
```

This class models the generation distribution factors. This class needs to be used along with the AggregatedPnode and the IndividualPnode to show the distribution of each individual party.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| factor [0..1] | [Float](#CIM17v40-Float) | Used to calculate generation "participation" of an individual pnond in an AggregatePnode. | |
| AggregatedPnode [0..1] | [AggregatedPnode](#CIM17v40-AggregatedPnode) | | |
| IndividualPnode [0..1] | [IndividualPnode](#CIM17v40-IndividualPnode) | | |

{#CIM17v40-GenICompensationForGenJ}
### GenICompensationForGenJ

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GenICompensationForGenJ {

+ rcij : PU [0..1]
+ xcij : PU [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- GenICompensationForGenJ : inherits from
class SynchronousMachineDynamics {

}

GenICompensationForGenJ --> "1" SynchronousMachineDynamics : SynchronousMachineDynamics
class VCompIEEEType2 {

}

GenICompensationForGenJ --> "1" VCompIEEEType2 : VcompIEEEType2
```

Resistive and reactive components of compensation for generator associated with IEEE type 2 voltage compensator for current flow out of another generator in the interconnection.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| rcij [0..1] | [PU](#CIM17v40-PU) | <font color="#0f0f0f">Resistive component of compensation of generator associated with this IEEE type 2 voltage compensator for current flow out of another generator (<i>Rcij</i>).</font> | |
| xcij [0..1] | [PU](#CIM17v40-PU) | <font color="#0f0f0f">Reactive component of compensation of generator associated with this IEEE type 2 voltage compensator for current flow out of another generator (<i>Xcij</i>).</font> | |
| SynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | Standard synchronous machine out of which current flow is being compensated for. | |
| VcompIEEEType2 [1] | [VCompIEEEType2](#CIM17v40-VCompIEEEType2) | The standard IEEE type 2 voltage compensator of this compensation. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GenUnitOpCostCurve}
### GenUnitOpCostCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GenUnitOpCostCurve {

+ isNetGrossP : Boolean [0..1]
}

class Curve {

}

Curve <|-- GenUnitOpCostCurve : inherits from
class GeneratingUnit {

}

GenUnitOpCostCurve --> "1" GeneratingUnit : GeneratingUnit
```

Relationship between unit operating cost (Y-axis) and unit output active power (X-axis). The operating cost curve for thermal units is derived from heat input and fuel costs. The operating cost curve for hydro units is derived from water flow rates and equivalent water costs.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| isNetGrossP [0..1] | [Boolean](#CIM17v40-Boolean) | Flag is set to true when output is expressed in net active power. | |
| `GeneratingUnit [1]` (OfAggregate) | [GeneratingUnit](#CIM17v40-GeneratingUnit) | A generating unit may have one or more cost curves, depending upon fuel mixture and fuel cost. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GenUnitOpSchedule}
### GenUnitOpSchedule

Inheritance path = [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) => [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GenUnitOpSchedule {

}

class RegularIntervalSchedule {

}

RegularIntervalSchedule <|-- GenUnitOpSchedule : inherits from
class GeneratingUnit {

}

GenUnitOpSchedule --> "1" GeneratingUnit : GeneratingUnit
```

The generating unit's Operator-approved current operating schedule (or plan), typically produced with the aid of unit commitment type analyses. The X-axis represents absolute time. The Y1-axis represents the status (0=off-line and unavailable: 1=available: 2=must run: 3=must run at fixed power value: etc.). The Y2-axis represents the must run fixed power value where required.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `GeneratingUnit [1]` (OfAggregate) | [GeneratingUnit](#CIM17v40-GeneratingUnit) | A generating unit may have an operating schedule, indicating the planned operation of the unit. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | see [RegularIntervalSchedule](CIM17v40-RegularIntervalSchedule) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GeneralClearing}
### GeneralClearing

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GeneralClearing {

}

class MarketFactors {

}

MarketFactors <|-- GeneralClearing : inherits from
```

Model of clearing result of the market run at the market level. Identifies interval.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GeneralClearingResults}
### GeneralClearingResults


```mermaid
classDiagram
direction TB

class GeneralClearingResults {

+ loadForecast : ActivePower [0..1]
+ totalLoad : Float [0..1]
+ totalNetInterchange : Float [0..1]
}

class GeneralClearing {

}

GeneralClearingResults --> "0..1" GeneralClearing : GeneralClearing
class SubControlArea {

}

GeneralClearingResults --> "0..1" SubControlArea : SubControlArea
```

Provides the adjusted load forecast value on a load forecast zone basis.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| loadForecast [0..1] | [ActivePower](#CIM17v40-ActivePower) | Load Prediction/Forecast (MW), by Time Period (5', 10', 15') | |
| totalLoad [0..1] | [Float](#CIM17v40-Float) | Amount of load in the control zoneAttribute Usage: hourly load value for the specific area | |
| totalNetInterchange [0..1] | [Float](#CIM17v40-Float) | Amount of interchange for the control zoneAttribute Usage: hourly interchange value for the specific area | |
| GeneralClearing [0..1] | [GeneralClearing](#CIM17v40-GeneralClearing) | | |
| SubControlArea [0..1] | [SubControlArea](#CIM17v40-SubControlArea) | | |

{#CIM17v40-GeneratingBid}
### GeneratingBid

Inheritance path = [ResourceBid](#CIM17v40-ResourceBid) => [Bid](#CIM17v40-Bid) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GeneratingBid {

+ combinedCycleUnitOffer : String [0..1]
+ downTimeMax : Float [0..1]
+ installedCapacity : Float [0..1]
+ lowerRampRate : ActivePowerChangeRate [0..1]
+ maxEmergencyMW : ActivePower [0..1]
+ maximumEconomicMW : Float [0..1]
+ minEmergencyMW : ActivePower [0..1]
+ minimumEconomicMW : Float [0..1]
+ noLoadCost : Float [0..1]
+ notificationTime : Float [0..1]
+ operatingMode : String [0..1]
+ raiseRampRate : ActivePowerChangeRate [0..1]
+ rampCurveType : Integer [0..1]
+ startupCost : Float [0..1]
+ startUpRampRate : ActivePowerChangeRate [0..1]
+ startUpType : Integer [0..1]
+ upTimeMax : Float [0..1]
}

class ResourceBid {

}

ResourceBid <|-- GeneratingBid : inherits from
class BidSet {

}

GeneratingBid --> "0..1" BidSet : BidSet
class NotificationTimeCurve {

}

GeneratingBid --> "0..1" NotificationTimeCurve : NotificationTimeCurve
class RegisteredGenerator {

}

GeneratingBid --> "0..1" RegisteredGenerator : RegisteredGenerator
class StartUpCostCurve {

}

GeneratingBid --> "0..1" StartUpCostCurve : StartUpCostCurve
class StartUpTimeCurve {

}

GeneratingBid --> "0..1" StartUpTimeCurve : StartUpTimeCurve
```

Offer to supply energy/ancillary services from a generating unit or resource.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| combinedCycleUnitOffer [0..1] | [String](#CIM17v40-String) | Will indicate if the unit is part of a CC offer or not | |
| downTimeMax [0..1] | [Float](#CIM17v40-Float) | Maximum down time. | |
| installedCapacity [0..1] | [Float](#CIM17v40-Float) | Installed Capacity value | |
| lowerRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | Maximum Dn ramp rate in MW/min | |
| maxEmergencyMW [0..1] | [ActivePower](#CIM17v40-ActivePower) | Power rating available for unit under emergency conditions greater than or equal to maximum economic limit. | |
| maximumEconomicMW [0..1] | [Float](#CIM17v40-Float) | Maximum high economic MW limit, that should not exceed the maximum operating MW limit | |
| minEmergencyMW [0..1] | [ActivePower](#CIM17v40-ActivePower) | Minimum power rating for unit under emergency conditions, which is less than or equal to the economic minimum. | |
| minimumEconomicMW [0..1] | [Float](#CIM17v40-Float) | Low economic MW limit that shall be greater than or equal to the minimum operating MW limit | |
| noLoadCost [0..1] | [Float](#CIM17v40-Float) | Resource fixed no load cost. | |
| notificationTime [0..1] | [Float](#CIM17v40-Float) | Time required for crew notification prior to start up of the unit. | |
| operatingMode [0..1] | [String](#CIM17v40-String) | Bid operating mode ('C' - cycling, 'F' - fixed, 'M' - must run, 'U' - unavailable) | |
| raiseRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | Maximum Up ramp rate in MW/min | |
| rampCurveType [0..1] | [Integer](#CIM17v40-Integer) | Ramp curve type:0 - Fixed ramp rate independent of rate function unit MW output1 - Static ramp rates as a function of unit MW output only2 - Dynamic ramp rates as a function of unit MW output and ramping time | |
| startupCost [0..1] | [Float](#CIM17v40-Float) | Startup cost/price | |
| startUpRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | Resource startup ramp rate (MW/minute) | |
| startUpType [0..1] | [Integer](#CIM17v40-Integer) | Resource startup type:1 - Fixed startup time and fixed startup cost2 - Startup time as a function of down time and fixed startup cost3 - Startup cost as a function of down time | |
| upTimeMax [0..1] | [Float](#CIM17v40-Float) | Maximum up time. | |
| `BidSet [0..1]` (OfAggregate) | [BidSet](#CIM17v40-BidSet) | | |
| NotificationTimeCurve [0..1] | [NotificationTimeCurve](#CIM17v40-NotificationTimeCurve) | | |
| RegisteredGenerator [0..1] | [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | | |
| StartUpCostCurve [0..1] | [StartUpCostCurve](#CIM17v40-StartUpCostCurve) | | |
| StartUpTimeCurve [0..1] | [StartUpTimeCurve](#CIM17v40-StartUpTimeCurve) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aggregationFlag [0..1] | [Integer](#CIM17v40-Integer) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| bidStatus [0..1] | [String](#CIM17v40-String) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| commodityType [0..1] | [String](#CIM17v40-String) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| contingencyAvailFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [ResourceBid](CIM17v40-ResourceBid) | |
| createdISO [0..1] | [YesNo](#CIM17v40-YesNo) | see [ResourceBid](CIM17v40-ResourceBid) | |
| energyMaxDay [0..1] | [Float](#CIM17v40-Float) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| energyMinDay [0..1] | [Float](#CIM17v40-Float) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| marketSepFlag [0..1] | [String](#CIM17v40-String) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| minDispatchTime [0..1] | [Integer](#CIM17v40-Integer) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| resourceLoadingType [0..1] | [Integer](#CIM17v40-Integer) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| shutDownsMaxDay [0..1] | [Integer](#CIM17v40-Integer) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| shutDownsMaxWeek [0..1] | [Integer](#CIM17v40-Integer) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| startUpsMaxDay [0..1] | [Integer](#CIM17v40-Integer) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| startUpsMaxWeek [0..1] | [Integer](#CIM17v40-Integer) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| virtual [0..1] | [Boolean](#CIM17v40-Boolean) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| marketType [0..1] | [MarketType](#CIM17v40-MarketType) | see [Bid](CIM17v40-Bid) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Bid](#CIM17v40-Bid) | |
| stopTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Bid](#CIM17v40-Bid) | |
| ActionRequest [1] | [ActionRequest](#CIM17v40-ActionRequest) | see [Bid](CIM17v40-Bid) | |
| EnergyMarket [1] | [EnergyMarket](#CIM17v40-EnergyMarket) | see [Bid](CIM17v40-Bid) | |
| MarketParticipant [0..1] | [MarketParticipant](#CIM17v40-MarketParticipant) | see [Bid](CIM17v40-Bid) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GeneratingUnit}
### GeneratingUnit

Inheritance path = [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GeneratingUnit {

+ allocSpinResP : ActivePower [0..1]
+ autoCntrlMarginP : ActivePower [0..1]
+ baseP : ActivePower [0..1]
+ controlDeadband : ActivePower [0..1]
+ controlPulseHigh : Seconds [0..1]
+ controlPulseLow : Seconds [0..1]
+ controlResponseRate : ActivePowerChangeRate [0..1]
+ efficiency : PerCent [0..1]
+ genControlMode : enum:GeneratorControlMode [0..1]
+ genControlSource : enum:GeneratorControlSource [0..1]
+ governorMPL : PU [0..1]
+ governorSCD : PerCent [0..1]
+ highControlLimit : ActivePower [0..1]
+ initialP : ActivePower [0..1]
+ longPF : Float [0..1]
+ lowControlLimit : ActivePower [0..1]
+ lowerRampRate : ActivePowerChangeRate [0..1]
+ maxEconomicP : ActivePower [0..1]
+ maximumAllowableSpinningReserve : ActivePower [0..1]
+ maxOperatingP : ActivePower [0..1]
+ minEconomicP : ActivePower [0..1]
+ minimumOffTime : Seconds [0..1]
+ minOperatingP : ActivePower [0..1]
+ modelDetail : Classification [0..1]
+ nominalP : ActivePower [0..1]
+ normalPF : Float [0..1]
+ penaltyFactor : Float [0..1]
+ raiseRampRate : ActivePowerChangeRate [0..1]
+ ratedGrossMaxP : ActivePower [0..1]
+ ratedGrossMinP : ActivePower [0..1]
+ ratedNetMaxP : ActivePower [0..1]
+ shortPF : Float [0..1]
+ startupCost : Money [0..1]
+ startupTime : Seconds [0..1]
+ tieLinePF : Float [0..1]
+ totalEfficiency : PerCent [0..1]
+ variableCost : Money [0..1]
}

class Equipment {

}

Equipment <|-- GeneratingUnit : inherits from
class GenUnitOpSchedule {

}

GeneratingUnit --> "0..1" GenUnitOpSchedule : GenUnitOpSchedule
```

A single or set of synchronous machines for converting mechanical power into alternating-current power. For example, individual machines within a set may be defined for scheduling purposes while a single control signal is derived for the set. In this case there would be a GeneratingUnit for each member of the set and an additional GeneratingUnit corresponding to the set.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| allocSpinResP [0..1] | [ActivePower](#CIM17v40-ActivePower) | The planned unused capacity (spinning reserve) which can be used to support emergency load. | |
| autoCntrlMarginP [0..1] | [ActivePower](#CIM17v40-ActivePower) | The planned unused capacity which can be used to support automatic control overruns. | |
| baseP [0..1] | [ActivePower](#CIM17v40-ActivePower) | For dispatchable units, this value represents the economic active power basepoint, for units that are not dispatchable, this value represents the fixed generation value. The value shall be between the operating low and high limits. | |
| controlDeadband [0..1] | [ActivePower](#CIM17v40-ActivePower) | Unit control error deadband. When a unit's desired active power change is less than this deadband, then no control pulses will be sent to the unit. | |
| controlPulseHigh [0..1] | [Seconds](#CIM17v40-Seconds) | Pulse high limit which is the largest control pulse that the unit can respond to. | |
| controlPulseLow [0..1] | [Seconds](#CIM17v40-Seconds) | Pulse low limit which is the smallest control pulse that the unit can respond to. | |
| controlResponseRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | Unit response rate which specifies the active power change for a control pulse of one second in the most responsive loading level of the unit. | |
| efficiency [0..1] | [PerCent](#CIM17v40-PerCent) | The efficiency of the unit in converting mechanical energy, from the prime mover, into electrical energy. | |
| genControlMode [0..1] | [GeneratorControlMode](#CIM17v40-GeneratorControlMode) | The unit control mode. | |
| genControlSource [0..1] | [GeneratorControlSource](#CIM17v40-GeneratorControlSource) | The source of controls for a generating unit. Defines the control status of the generating unit. | |
| governorMPL [0..1] | [PU](#CIM17v40-PU) | Governor motor position limit. | |
| governorSCD [0..1] | [PerCent](#CIM17v40-PerCent) | Governor Speed Changer Droop. This is the change in generator power output divided by the change in frequency normalized by the nominal power of the generator and the nominal frequency and expressed in percent and negated. A positive value of speed change droop provides additional generator output upon a drop in frequency. | |
| highControlLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | High limit for secondary (AGC) control. | |
| initialP [0..1] | [ActivePower](#CIM17v40-ActivePower) | Default initial active power which is used to store a powerflow result for the initial active power for this unit in this network configuration. | |
| longPF [0..1] | [Float](#CIM17v40-Float) | Generating unit long term economic participation factor. | |
| lowControlLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | Low limit for secondary (AGC) control. | |
| lowerRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | The normal maximum rate the generating unit active power output can be lowered by control actions. | |
| maxEconomicP [0..1] | [ActivePower](#CIM17v40-ActivePower) | Maximum high economic active power limit, that should not exceed the maximum operating active power limit. | |
| maximumAllowableSpinningReserve [0..1] | [ActivePower](#CIM17v40-ActivePower) | Maximum allowable spinning reserve. Spinning reserve will never be considered greater than this value regardless of the current operating point. | |
| maxOperatingP [0..1] | [ActivePower](#CIM17v40-ActivePower) | This is the maximum operating active power limit the dispatcher can enter for this unit. | |
| minEconomicP [0..1] | [ActivePower](#CIM17v40-ActivePower) | Low economic active power limit that shall be greater than or equal to the minimum operating active power limit. | |
| minimumOffTime [0..1] | [Seconds](#CIM17v40-Seconds) | Minimum time interval between unit shutdown and startup. | |
| minOperatingP [0..1] | [ActivePower](#CIM17v40-ActivePower) | This is the minimum operating active power limit the dispatcher can enter for this unit. | |
| modelDetail [0..1] | [Classification](#CIM17v40-Classification) | Detail level of the generator model data. | |
| nominalP [0..1] | [ActivePower](#CIM17v40-ActivePower) | The nominal power of the generating unit. Used to give precise meaning to percentage based attributes such as the governor speed change droop (governorSCD attribute).The attribute shall be a positive value equal to or less than RotatingMachine.ratedS. | |
| normalPF [0..1] | [Float](#CIM17v40-Float) | Generating unit economic participation factor. The sum of the participation factors across generating units does not have to sum to one. It is used for representing distributed slack participation factor. The attribute shall be a positive value or zero. | |
| penaltyFactor [0..1] | [Float](#CIM17v40-Float) | Defined as: 1 / ( 1 - Incremental Transmission Loss); with the Incremental Transmission Loss expressed as a plus or minus value. The typical range of penalty factors is (0.9 to 1.1). | |
| raiseRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | The normal maximum rate the generating unit active power output can be raised by control actions. | |
| ratedGrossMaxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | The unit's gross rated maximum capacity (book value).The attribute shall be a positive value. | |
| ratedGrossMinP [0..1] | [ActivePower](#CIM17v40-ActivePower) | The gross rated minimum generation level which the unit can safely operate at while delivering power to the transmission grid.The attribute shall be a positive value. | |
| ratedNetMaxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | The net rated maximum capacity determined by subtracting the auxiliary power used to operate the internal plant machinery from the rated gross maximum capacity.The attribute shall be a positive value. | |
| shortPF [0..1] | [Float](#CIM17v40-Float) | Generating unit short term economic participation factor. | |
| startupCost [0..1] | [Money](#CIM17v40-Money) | The initial startup cost incurred for each start of the GeneratingUnit. | |
| startupTime [0..1] | [Seconds](#CIM17v40-Seconds) | Time it takes to get the unit on-line, from the time that the prime mover mechanical power is applied. | |
| tieLinePF [0..1] | [Float](#CIM17v40-Float) | Generating unit economic participation factor. | |
| totalEfficiency [0..1] | [PerCent](#CIM17v40-PerCent) | The efficiency of the unit in converting the fuel into electrical energy. | |
| variableCost [0..1] | [Money](#CIM17v40-Money) | The variable cost component of production per unit of ActivePower. | |
| `GenUnitOpSchedule [0..1]` (AggregateOf) | [GenUnitOpSchedule](#CIM17v40-GenUnitOpSchedule) | A generating unit may have an operating schedule, indicating the planned operation of the unit. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GeneratingUnitDynamicValues}
### GeneratingUnitDynamicValues


```mermaid
classDiagram
direction TB

class GeneratingUnitDynamicValues {

+ lossFactor : Float [0..1]
+ maximumMW : Float [0..1]
+ minimumMW : Float [0..1]
+ mVAR : Float [0..1]
+ mw : Float [0..1]
+ sensitivity : Float [0..1]
}

class Flowgate {

}

GeneratingUnitDynamicValues --> "0..1" Flowgate : Flowgate
class MktGeneratingUnit {

}

GeneratingUnitDynamicValues --> "1" MktGeneratingUnit : MktGeneratingUnit
```

Optimal Power Flow or State Estimator Unit Data for Operator Training Simulator. This is used for RealTime, Study and Maintenance Users.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| lossFactor [0..1] | [Float](#CIM17v40-Float) | Loss Factor | |
| maximumMW [0..1] | [Float](#CIM17v40-Float) | The maximum active power generation of the unit in MW | |
| minimumMW [0..1] | [Float](#CIM17v40-Float) | The minimum active power generation of the unit in MW | |
| mVAR [0..1] | [Float](#CIM17v40-Float) | Unit reactive power generation in MVAR | |
| mw [0..1] | [Float](#CIM17v40-Float) | Unit active power generation in MW | |
| sensitivity [0..1] | [Float](#CIM17v40-Float) | Unit sencivity factor. The distribution factors (DFAX) for the unit | |
| Flowgate [0..1] | [Flowgate](#CIM17v40-Flowgate) | | |
| MktGeneratingUnit [1] | [MktGeneratingUnit](#CIM17v40-MktGeneratingUnit) | | |

{#CIM17v40-GenerationProvider}
### (informative) GenerationProvider

Inheritance path = [Organisation](#CIM17v40-Organisation) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GenerationProvider {

}

class Organisation {

}

Organisation <|-- GenerationProvider : inherits from
```

The energy seller in the energy marketplace.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Organisation](CIM17v40-Organisation) | |
| ParentOrganisation [0..1] | [ParentOrganization](#CIM17v40-ParentOrganization) | see [Organisation](CIM17v40-Organisation) | |
| phone1 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Organisation](CIM17v40-Organisation) | |
| phone2 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Organisation](CIM17v40-Organisation) | |
| postalAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Organisation](CIM17v40-Organisation) | |
| streetAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Organisation](CIM17v40-Organisation) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GeneratorTypeAsset}
### GeneratorTypeAsset

Inheritance path = [CatalogAssetType](#CIM17v40-CatalogAssetType) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GeneratorTypeAsset {

+ maxP : ActivePower [0..1]
+ maxQ : ReactivePower [0..1]
+ minP : ActivePower [0..1]
+ minQ : ReactivePower [0..1]
+ rDirectSubtrans : Resistance [0..1]
+ rDirectSync : Resistance [0..1]
+ rDirectTrans : Resistance [0..1]
+ rQuadSubtrans : Resistance [0..1]
+ rQuadSync : Resistance [0..1]
+ rQuadTrans : Resistance [0..1]
+ xDirectSubtrans : Reactance [0..1]
+ xDirectSync : Reactance [0..1]
+ xDirectTrans : Reactance [0..1]
+ xQuadSubtrans : Reactance [0..1]
+ xQuadSync : Reactance [0..1]
+ xQuadTrans : Reactance [0..1]
}

class CatalogAssetType {

}

CatalogAssetType <|-- GeneratorTypeAsset : inherits from
```

Generic generation equipment that may be used for various purposes such as work planning. It defines both the Real and Reactive power properties (modelled at the PSR level as a GeneratingUnit + SynchronousMachine).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | Maximum real power limit. | |
| maxQ [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Maximum reactive power limit. | |
| minP [0..1] | [ActivePower](#CIM17v40-ActivePower) | Minimum real power generated. | |
| minQ [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Minimum reactive power generated. | |
| rDirectSubtrans [0..1] | [Resistance](#CIM17v40-Resistance) | Direct-axis subtransient resistance. | |
| rDirectSync [0..1] | [Resistance](#CIM17v40-Resistance) | Direct-axis synchronous resistance. | |
| rDirectTrans [0..1] | [Resistance](#CIM17v40-Resistance) | Direct-axis transient resistance. | |
| rQuadSubtrans [0..1] | [Resistance](#CIM17v40-Resistance) | Quadrature-axis subtransient resistance. | |
| rQuadSync [0..1] | [Resistance](#CIM17v40-Resistance) | Quadrature-axis synchronous resistance. | |
| rQuadTrans [0..1] | [Resistance](#CIM17v40-Resistance) | Quadrature-axis transient resistance. | |
| xDirectSubtrans [0..1] | [Reactance](#CIM17v40-Reactance) | Direct-axis subtransient reactance. | |
| xDirectSync [0..1] | [Reactance](#CIM17v40-Reactance) | Direct-axis synchronous reactance. | |
| xDirectTrans [0..1] | [Reactance](#CIM17v40-Reactance) | Direct-axis transient reactance. | |
| xQuadSubtrans [0..1] | [Reactance](#CIM17v40-Reactance) | Quadrature-axis subtransient reactance. | |
| xQuadSync [0..1] | [Reactance](#CIM17v40-Reactance) | Quadrature-axis synchronous reactance. | |
| xQuadTrans [0..1] | [Reactance](#CIM17v40-Reactance) | Quadrature-axis transient reactance. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| estimatedUnitCost [0..1] | [Money](#CIM17v40-Money) | see [CatalogAssetType](CIM17v40-CatalogAssetType) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [CatalogAssetType](CIM17v40-CatalogAssetType) | |
| stockItem [0..1] | [Boolean](#CIM17v40-Boolean) | see [CatalogAssetType](#CIM17v40-CatalogAssetType) | |
| type [0..1] | [String](#CIM17v40-String) | see [CatalogAssetType](#CIM17v40-CatalogAssetType) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [CatalogAssetType](CIM17v40-CatalogAssetType) | |
| quantity [0..1] | [StringQuantity](#CIM17v40-StringQuantity) | see [CatalogAssetType](CIM17v40-CatalogAssetType) | |
| `TypeAssetCatalogue [0..1]` (informative) | [TypeAssetCatalogue](#CIM17v40-TypeAssetCatalogue) | see [CatalogAssetType](CIM17v40-CatalogAssetType) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GenericAction}
### GenericAction

Inheritance path = [SwitchingAction](#CIM17v40-SwitchingAction) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GenericAction {

}

class SwitchingAction {

}

SwitchingAction <|-- GenericAction : inherits from
class PowerSystemResource {

}

GenericAction --> "0..1" PowerSystemResource : PowerSystemResource
```

An arbitrary switching step.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| PowerSystemResource [0..1] | [PowerSystemResource](#CIM17v40-PowerSystemResource) | The power system resource that the generic action is performed on | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| executedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| issuedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| plannedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| Operator [0..1] | [Operator](#CIM17v40-Operator) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingEvent [0..1] | [SwitchingEvent](#CIM17v40-SwitchingEvent) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingStep [0..1] | [SwitchingStep](#CIM17v40-SwitchingStep) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GenericConstraints}
### GenericConstraints

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GenericConstraints {

+ intervalEndTime : DateTime [0..1]
+ intervalStartTime : DateTime [0..1]
+ maxLimit : Float [0..1]
+ minLimit : Float [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- GenericConstraints : inherits from
```

Generic constraints can represent secure areas, voltage profile, transient stability and voltage collapse limits.

The generic constraints can be one of the following forms:

a) Thermal MW limit constraints type

b) Group line flow constraint type


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | Interval End Time | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | Interval Start Time | |
| maxLimit [0..1] | [Float](#CIM17v40-Float) | Maximum Limit (MW) | |
| minLimit [0..1] | [Float](#CIM17v40-Float) | Minimum Limit (MW) | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GenericDataSetVersion}
### GenericDataSetVersion


```mermaid
classDiagram
direction TB

class GenericDataSetVersion {

+ majorVersion : String [0..1]
+ minorVersion : String [0..1]
+ published : Date [0..1]
}

```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| majorVersion [0..1] | [String](#CIM17v40-String) | The universal CIM version name describing a consistent set of packages. | |
| minorVersion [0..1] | [String](#CIM17v40-String) | Describe minor updates and error corrections. | |
| published [0..1] | [Date](#CIM17v40-Date) | The date when the complete CIM canonical model is published and made available for use,After the publication the major version and name space are updated. | |

{#CIM17v40-GeographicalRegion}
### GeographicalRegion

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GeographicalRegion {

}

class IdentifiedObject {

}

IdentifiedObject <|-- GeographicalRegion : inherits from
```

A geographical region of a power system network model.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GeosphericAnalog}
### GeosphericAnalog

Inheritance path = [EnvironmentalAnalog](#CIM17v40-EnvironmentalAnalog) => [Analog](#CIM17v40-Analog) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GeosphericAnalog {

+ kind : enum:GeosphericAnalogKind [0..1]
}

class EnvironmentalAnalog {

}

EnvironmentalAnalog <|-- GeosphericAnalog : inherits from
```

Analog (float) measuring a geospheric condition.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [GeosphericAnalogKind](#CIM17v40-GeosphericAnalogKind) | Kind of geospheric analog. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ClassificationCondition [0..1] | [ClassificationCondition](#CIM17v40-ClassificationCondition) | see [EnvironmentalAnalog](CIM17v40-EnvironmentalAnalog) | |
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | see [EnvironmentalAnalog](CIM17v40-EnvironmentalAnalog) | |
| EnvironmentalMonitoringStation [0..1] | [EnvironmentalMonitoringStation](#CIM17v40-EnvironmentalMonitoringStation) | see [EnvironmentalAnalog](CIM17v40-EnvironmentalAnalog) | |
| ReportingCapability [0..1] | [ReportingCapability](#CIM17v40-ReportingCapability) | see [EnvironmentalAnalog](CIM17v40-EnvironmentalAnalog) | |
| maxValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| minValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| normalValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| positiveFlowIn [0..1] | [Boolean](#CIM17v40-Boolean) | see [Analog](#CIM17v40-Analog) | |
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GeosphericPhenomenon}
### GeosphericPhenomenon

Inheritance path = [EnvironmentalPhenomenon](#CIM17v40-EnvironmentalPhenomenon)

```mermaid
classDiagram
direction TB

class GeosphericPhenomenon {

}

class EnvironmentalPhenomenon {

}

EnvironmentalPhenomenon <|-- GeosphericPhenomenon : inherits from
```

A geospheric phenomenon.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| PhenomenonClassification [0..1] | [PhenomenonClassification](#CIM17v40-PhenomenonClassification) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| timeInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |

{#CIM17v40-GovCT1}
### GovCT1

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovCT1 {

+ aset : Float [0..1]
+ db : PU [0..1]
+ dm : PU [0..1]
+ ka : PU [0..1]
+ kdgov : PU [0..1]
+ kigov : PU [0..1]
+ kiload : PU [0..1]
+ kimw : PU [0..1]
+ kpgov : PU [0..1]
+ kpload : PU [0..1]
+ kturb : PU [0..1]
+ ldref : PU [0..1]
+ maxerr : PU [0..1]
+ minerr : PU [0..1]
+ mwbase : ActivePower [0..1]
+ r : PU [0..1]
+ rclose : Float [0..1]
+ rdown : PU [0..1]
+ ropen : Float [0..1]
+ rselect : enum:DroopSignalFeedbackKind [0..1]
+ rup : PU [0..1]
+ ta : Seconds [0..1]
+ tact : Seconds [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ tdgov : Seconds [0..1]
+ teng : Seconds [0..1]
+ tfload : Seconds [0..1]
+ tpelec : Seconds [0..1]
+ tsa : Seconds [0..1]
+ tsb : Seconds [0..1]
+ vmax : PU [0..1]
+ vmin : PU [0..1]
+ wfnl : PU [0..1]
+ wfspd : Boolean [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovCT1 : inherits from
```

General model for any prime mover with a PID governor, used primarily for combustion turbine and combined cycle units.

This model can be used to represent a variety of prime movers controlled by PID governors. It is suitable, for example, for the representation of:

<ul>

<li>gas turbine and single shaft combined cycle turbines</li>

</ul>

<ul>

<li>diesel engines with modern electronic or digital governors </li>

</ul>

<ul>

<li>steam turbines where steam is supplied from a large boiler drum or a large header whose pressure is substantially constant over the period under study</li>

<li>simple hydro turbines in dam configurations where the water column length is short and water inertia effects are minimal.</li>

</ul>

Additional information on this model is available in the 2012 IEEE report, <i><u>Dynamic Models for Turbine-Governors in Power System Studies</u></i>, 3.1.2.3 pages 3-4 (GGOV1).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aset [0..1] | [Float](#CIM17v40-Float) | Acceleration limiter setpoint (<i>Aset</i>). Unit = PU / s. Typical value = 0,01. | |
| db [0..1] | [PU](#CIM17v40-PU) | Speed governor deadband in PU speed (<i>db</i>). In the majority of applications, it is recommended that this value be set to zero. Typical value = 0. | |
| dm [0..1] | [PU](#CIM17v40-PU) | Speed sensitivity coefficient (<i>Dm</i>). <i>Dm</i> can represent either the variation of the engine power with the shaft speed or the variation of maximum power capability with shaft speed. If it is positive it describes the falling slope of the engine speed verses power characteristic as speed increases. A slightly falling characteristic is typical for reciprocating engines and some aero-derivative turbines. If it is negative the engine power is assumed to be unaffected by the shaft speed, but the maximum permissible fuel flow is taken to fall with falling shaft speed. This is characteristic of single-shaft industrial turbines due to exhaust temperature limits. Typical value = 0. | |
| ka [0..1] | [PU](#CIM17v40-PU) | Acceleration limiter gain (<i>Ka</i>). Typical value = 10. | |
| kdgov [0..1] | [PU](#CIM17v40-PU) | Governor derivative gain (<i>Kdgov</i>). Typical value = 0. | |
| kigov [0..1] | [PU](#CIM17v40-PU) | Governor integral gain (<i>Kigov</i>). Typical value = 2. | |
| kiload [0..1] | [PU](#CIM17v40-PU) | Load limiter integral gain for PI controller (<i>Kiload</i>). Typical value = 0,67. | |
| kimw [0..1] | [PU](#CIM17v40-PU) | Power controller (reset) gain (<i>Kimw</i>). The default value of 0,01 corresponds to a reset time of 100 s. A value of 0,001 corresponds to a relatively slow-acting load controller. Typical value = 0,01. | |
| kpgov [0..1] | [PU](#CIM17v40-PU) | Governor proportional gain (<i>Kpgov</i>). Typical value = 10. | |
| kpload [0..1] | [PU](#CIM17v40-PU) | Load limiter proportional gain for PI controller (<i>Kpload</i>). Typical value = 2. | |
| kturb [0..1] | [PU](#CIM17v40-PU) | Turbine gain (<i>Kturb</i>) (&gt; 0). Typical value = 1,5. | |
| ldref [0..1] | [PU](#CIM17v40-PU) | Load limiter reference value (<i>Ldref</i>). Typical value = 1. | |
| maxerr [0..1] | [PU](#CIM17v40-PU) | Maximum value for speed error signal (<i>maxerr</i>) (&gt; GovCT1.minerr). Typical value = 0,05. | |
| minerr [0..1] | [PU](#CIM17v40-PU) | Minimum value for speed error signal (<i>minerr</i>) (&lt; GovCT1.maxerr). Typical value = -0,05. | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| r [0..1] | [PU](#CIM17v40-PU) | Permanent droop (<i>R</i>). Typical value = 0,04. | |
| rclose [0..1] | [Float](#CIM17v40-Float) | Minimum valve closing rate (<i>Rclose</i>). Unit = PU / s. Typical value = -0,1. | |
| rdown [0..1] | [PU](#CIM17v40-PU) | Maximum rate of load limit decrease (<i>Rdown</i>). Typical value = -99. | |
| ropen [0..1] | [Float](#CIM17v40-Float) | Maximum valve opening rate (<i>Ropen</i>). Unit = PU / s. Typical value = 0.10. | |
| rselect [0..1] | [DroopSignalFeedbackKind](#CIM17v40-DroopSignalFeedbackKind) | Feedback signal for droop (<i>Rselect</i>). Typical value = electricalPower. | |
| rup [0..1] | [PU](#CIM17v40-PU) | Maximum rate of load limit increase (<i>Rup</i>). Typical value = 99. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Acceleration limiter time constant (<i>Ta</i>) (&gt; 0). Typical value = 0,1. | |
| tact [0..1] | [Seconds](#CIM17v40-Seconds) | Actuator time constant (<i>Tact</i>) (&gt;= 0). Typical value = 0,5. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Turbine lag time constant (<i>Tb</i>) (&gt; 0). Typical value = 0,5. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Turbine lead time constant (<i>Tc</i>) (&gt;= 0). Typical value = 0. | |
| tdgov [0..1] | [Seconds](#CIM17v40-Seconds) | Governor derivative controller time constant (<i>Tdgov</i>) (&gt;= 0). Typical value = 1. | |
| teng [0..1] | [Seconds](#CIM17v40-Seconds) | Transport time delay for diesel engine used in representing diesel engines where there is a small but measurable transport delay between a change in fuel flow setting and the development of torque (<i>Teng</i>) (&gt;= 0). <i>Teng</i> should be zero in all but special cases where this transport delay is of particular concern. Typical value = 0. | |
| tfload [0..1] | [Seconds](#CIM17v40-Seconds) | Load-limiter time constant (<i>Tfload</i>) (&gt; 0). Typical value = 3. | |
| tpelec [0..1] | [Seconds](#CIM17v40-Seconds) | Electrical power transducer time constant (<i>Tpelec</i>) (&gt; 0). Typical value = 1. | |
| tsa [0..1] | [Seconds](#CIM17v40-Seconds) | Temperature detection lead time constant (<i>Tsa</i>) (&gt;= 0). Typical value = 4. | |
| tsb [0..1] | [Seconds](#CIM17v40-Seconds) | Temperature detection lag time constant (<i>Tsb</i>) (&gt;= 0). Typical value = 5. | |
| vmax [0..1] | [PU](#CIM17v40-PU) | Maximum valve position limit (<i>Vmax</i>) (&gt; GovCT1.vmin). Typical value = 1. | |
| vmin [0..1] | [PU](#CIM17v40-PU) | Minimum valve position limit (<i>Vmin</i>) (&lt; GovCT1.vmax). Typical value = 0,15. | |
| wfnl [0..1] | [PU](#CIM17v40-PU) | No load fuel flow (<i>Wfnl</i>). Typical value = 0,2. | |
| wfspd [0..1] | [Boolean](#CIM17v40-Boolean) | Switch for fuel source characteristic to recognize that fuel flow, for a given fuel valve stroke, can be proportional to engine speed (<i>Wfspd</i>).true = fuel flow proportional to speed (for some gas turbines and diesel engines with positive displacement fuel injectors)false = fuel control system keeps fuel flow independent of engine speed.Typical value = true. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovCT2}
### GovCT2

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovCT2 {

+ aset : Float [0..1]
+ db : PU [0..1]
+ dm : PU [0..1]
+ flim1 : Frequency [0..1]
+ flim10 : Frequency [0..1]
+ flim2 : Frequency [0..1]
+ flim3 : Frequency [0..1]
+ flim4 : Frequency [0..1]
+ flim5 : Frequency [0..1]
+ flim6 : Frequency [0..1]
+ flim7 : Frequency [0..1]
+ flim8 : Frequency [0..1]
+ flim9 : Frequency [0..1]
+ ka : PU [0..1]
+ kdgov : PU [0..1]
+ kigov : PU [0..1]
+ kiload : PU [0..1]
+ kimw : PU [0..1]
+ kpgov : PU [0..1]
+ kpload : PU [0..1]
+ kturb : PU [0..1]
+ ldref : PU [0..1]
+ maxerr : PU [0..1]
+ minerr : PU [0..1]
+ mwbase : ActivePower [0..1]
+ plim1 : PU [0..1]
+ plim10 : PU [0..1]
+ plim2 : PU [0..1]
+ plim3 : PU [0..1]
+ plim4 : PU [0..1]
+ plim5 : PU [0..1]
+ plim6 : PU [0..1]
+ plim7 : PU [0..1]
+ plim8 : PU [0..1]
+ plim9 : PU [0..1]
+ prate : PU [0..1]
+ r : PU [0..1]
+ rclose : Float [0..1]
+ rdown : PU [0..1]
+ ropen : Float [0..1]
+ rselect : enum:DroopSignalFeedbackKind [0..1]
+ rup : PU [0..1]
+ ta : Seconds [0..1]
+ tact : Seconds [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ tdgov : Seconds [0..1]
+ teng : Seconds [0..1]
+ tfload : Seconds [0..1]
+ tpelec : Seconds [0..1]
+ tsa : Seconds [0..1]
+ tsb : Seconds [0..1]
+ vmax : PU [0..1]
+ vmin : PU [0..1]
+ wfnl : PU [0..1]
+ wfspd : Boolean [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovCT2 : inherits from
```

General governor with frequency-dependent fuel flow limit. This model is a modification of the GovCT1<b> </b>model in order to represent the frequency-dependent fuel flow limit of a specific gas turbine manufacturer.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aset [0..1] | [Float](#CIM17v40-Float) | Acceleration limiter setpoint (<i>Aset</i>). Unit = PU / s. Typical value = 10. | |
| db [0..1] | [PU](#CIM17v40-PU) | Speed governor deadband in PU speed (<i>db</i>). In the majority of applications, it is recommended that this value be set to zero. Typical value = 0. | |
| dm [0..1] | [PU](#CIM17v40-PU) | Speed sensitivity coefficient (<i>Dm</i>). <i>Dm</i> can represent either the variation of the engine power with the shaft speed or the variation of maximum power capability with shaft speed. If it is positive it describes the falling slope of the engine speed verses power characteristic as speed increases. A slightly falling characteristic is typical for reciprocating engines and some aero-derivative turbines. If it is negative the engine power is assumed to be unaffected by the shaft speed, but the maximum permissible fuel flow is taken to fall with falling shaft speed. This is characteristic of single-shaft industrial turbines due to exhaust temperature limits. Typical value = 0. | |
| flim1 [0..1] | [Frequency](#CIM17v40-Frequency) | Frequency threshold 1 (<i>Flim1</i>). Unit = Hz. Typical value = 59. | |
| flim10 [0..1] | [Frequency](#CIM17v40-Frequency) | Frequency threshold 10 (<i>Flim10</i>). Unit = Hz. Typical value = 0. | |
| flim2 [0..1] | [Frequency](#CIM17v40-Frequency) | Frequency threshold 2 (<i>Flim2</i>). Unit = Hz. Typical value = 0. | |
| flim3 [0..1] | [Frequency](#CIM17v40-Frequency) | Frequency threshold 3 (<i>Flim3</i>). Unit = Hz. Typical value = 0. | |
| flim4 [0..1] | [Frequency](#CIM17v40-Frequency) | Frequency threshold 4 (<i>Flim4</i>). Unit = Hz. Typical value = 0. | |
| flim5 [0..1] | [Frequency](#CIM17v40-Frequency) | Frequency threshold 5 (<i>Flim5</i>). Unit = Hz. Typical value = 0. | |
| flim6 [0..1] | [Frequency](#CIM17v40-Frequency) | Frequency threshold 6 (<i>Flim6</i>). Unit = Hz. Typical value = 0. | |
| flim7 [0..1] | [Frequency](#CIM17v40-Frequency) | Frequency threshold 7 (<i>Flim7</i>). Unit = Hz. Typical value = 0. | |
| flim8 [0..1] | [Frequency](#CIM17v40-Frequency) | Frequency threshold 8 (<i>Flim8</i>). Unit = Hz. Typical value = 0. | |
| flim9 [0..1] | [Frequency](#CIM17v40-Frequency) | Frequency threshold 9 (<i>Flim9</i>). Unit = Hz. Typical value = 0. | |
| ka [0..1] | [PU](#CIM17v40-PU) | Acceleration limiter gain (<i>Ka</i>). Typical value = 10. | |
| kdgov [0..1] | [PU](#CIM17v40-PU) | Governor derivative gain (<i>Kdgov</i>). Typical value = 0. | |
| kigov [0..1] | [PU](#CIM17v40-PU) | Governor integral gain (<i>Kigov</i>). Typical value = 0,45. | |
| kiload [0..1] | [PU](#CIM17v40-PU) | Load limiter integral gain for PI controller (<i>Kiload</i>). Typical value = 1. | |
| kimw [0..1] | [PU](#CIM17v40-PU) | Power controller (reset) gain (<i>Kimw</i>). The default value of 0,01 corresponds to a reset time of 100 seconds. A value of 0,001 corresponds to a relatively slow-acting load controller. Typical value = 0. | |
| kpgov [0..1] | [PU](#CIM17v40-PU) | Governor proportional gain (<i>Kpgov</i>). Typical value = 4. | |
| kpload [0..1] | [PU](#CIM17v40-PU) | Load limiter proportional gain for PI controller (<i>Kpload</i>). Typical value = 1. | |
| kturb [0..1] | [PU](#CIM17v40-PU) | Turbine gain (<i>Kturb</i>). Typical value = 1,9168. | |
| ldref [0..1] | [PU](#CIM17v40-PU) | Load limiter reference value (<i>Ldref</i>). Typical value = 1. | |
| maxerr [0..1] | [PU](#CIM17v40-PU) | Maximum value for speed error signal (<i>Maxerr</i>) (&gt; GovCT2.minerr). Typical value = 1. | |
| minerr [0..1] | [PU](#CIM17v40-PU) | Minimum value for speed error signal (<i>Minerr</i>) (&lt; GovCT2.maxerr). Typical value = -1. | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| plim1 [0..1] | [PU](#CIM17v40-PU) | Power limit 1 (<i>Plim1</i>). Typical value = 0,8325. | |
| plim10 [0..1] | [PU](#CIM17v40-PU) | Power limit 10 (<i>Plim10</i>). Typical value = 0. | |
| plim2 [0..1] | [PU](#CIM17v40-PU) | Power limit 2 (Plim2). Typical value = 0. | |
| plim3 [0..1] | [PU](#CIM17v40-PU) | Power limit 3 (<i>Plim3</i>). Typical value = 0. | |
| plim4 [0..1] | [PU](#CIM17v40-PU) | Power limit 4 (<i>Plim4</i>). Typical value = 0. | |
| plim5 [0..1] | [PU](#CIM17v40-PU) | Power limit 5 (<i>Plim5</i>). Typical value = 0. | |
| plim6 [0..1] | [PU](#CIM17v40-PU) | Power limit 6 (<i>Plim6</i>). Typical value = 0. | |
| plim7 [0..1] | [PU](#CIM17v40-PU) | Power limit 7 (<i>Plim7</i>). Typical value = 0. | |
| plim8 [0..1] | [PU](#CIM17v40-PU) | Power limit 8 (<i>Plim8</i>). Typical value = 0. | |
| plim9 [0..1] | [PU](#CIM17v40-PU) | Power Limit 9 (<i>Plim9</i>). Typical value = 0. | |
| prate [0..1] | [PU](#CIM17v40-PU) | Ramp rate for frequency-dependent power limit (<i>Prate</i>). Typical value = 0,017. | |
| r [0..1] | [PU](#CIM17v40-PU) | Permanent droop (<i>R</i>). Typical value = 0,05. | |
| rclose [0..1] | [Float](#CIM17v40-Float) | Minimum valve closing rate (<i>Rclose</i>). Unit = PU / s. Typical value = -99. | |
| rdown [0..1] | [PU](#CIM17v40-PU) | Maximum rate of load limit decrease (<i>Rdown</i>). Typical value = -99. | |
| ropen [0..1] | [Float](#CIM17v40-Float) | Maximum valve opening rate (<i>Ropen</i>). Unit = PU / s. Typical value = 99. | |
| rselect [0..1] | [DroopSignalFeedbackKind](#CIM17v40-DroopSignalFeedbackKind) | Feedback signal for droop (<i>Rselect</i>). Typical value = electricalPower. | |
| rup [0..1] | [PU](#CIM17v40-PU) | Maximum rate of load limit increase (<i>Rup</i>). Typical value = 99. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Acceleration limiter time constant (<i>Ta</i>) (&gt;= 0). Typical value = 1. | |
| tact [0..1] | [Seconds](#CIM17v40-Seconds) | Actuator time constant (<i>Tact</i>) (&gt;= 0). Typical value = 0,4. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Turbine lag time constant (<i>Tb</i>) (&gt;= 0). Typical value = 0,1. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Turbine lead time constant (<i>Tc</i>) (&gt;= 0). Typical value = 0. | |
| tdgov [0..1] | [Seconds](#CIM17v40-Seconds) | Governor derivative controller time constant (<i>Tdgov</i>) (&gt;= 0). Typical value = 1. | |
| teng [0..1] | [Seconds](#CIM17v40-Seconds) | Transport time delay for diesel engine used in representing diesel engines where there is a small but measurable transport delay between a change in fuel flow setting and the development of torque (<i>Teng</i>) (&gt;= 0). <i>Teng</i> should be zero in all but special cases where this transport delay is of particular concern. Typical value = 0. | |
| tfload [0..1] | [Seconds](#CIM17v40-Seconds) | Load limiter time constant (<i>Tfload</i>) (&gt;= 0). Typical value = 3. | |
| tpelec [0..1] | [Seconds](#CIM17v40-Seconds) | Electrical power transducer time constant (<i>Tpelec</i>) (&gt;= 0). Typical value = 2,5. | |
| tsa [0..1] | [Seconds](#CIM17v40-Seconds) | Temperature detection lead time constant (<i>Tsa</i>) (&gt;= 0). Typical value = 0. | |
| tsb [0..1] | [Seconds](#CIM17v40-Seconds) | Temperature detection lag time constant (<i>Tsb</i>) (&gt;= 0). Typical value = 50. | |
| vmax [0..1] | [PU](#CIM17v40-PU) | Maximum valve position limit (<i>Vmax</i>) (&gt; GovCT2.vmin). Typical value = 1. | |
| vmin [0..1] | [PU](#CIM17v40-PU) | Minimum valve position limit (<i>Vmin</i>) (&lt; GovCT2.vmax). Typical value = 0,175. | |
| wfnl [0..1] | [PU](#CIM17v40-PU) | No load fuel flow (<i>Wfnl</i>). Typical value = 0,187. | |
| wfspd [0..1] | [Boolean](#CIM17v40-Boolean) | Switch for fuel source characteristic to recognize that fuel flow, for a given fuel valve stroke, can be proportional to engine speed (<i>Wfspd</i>).true = fuel flow proportional to speed (for some gas turbines and diesel engines with positive displacement fuel injectors)false = fuel control system keeps fuel flow independent of engine speed.Typical value = false. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovGAST}
### GovGAST

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovGAST {

+ at : PU [0..1]
+ dturb : PU [0..1]
+ kt : PU [0..1]
+ mwbase : ActivePower [0..1]
+ r : PU [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ vmax : PU [0..1]
+ vmin : PU [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovGAST : inherits from
```

Single shaft gas turbine.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| at [0..1] | [PU](#CIM17v40-PU) | Ambient temperature load limit (<i>Load Limit</i>). Typical value = 1. | |
| dturb [0..1] | [PU](#CIM17v40-PU) | Turbine damping factor (<i>Dturb</i>). Typical value = 0,18. | |
| kt [0..1] | [PU](#CIM17v40-PU) | Temperature limiter gain (<i>Kt</i>). Typical value = 3. | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| r [0..1] | [PU](#CIM17v40-PU) | Permanent droop (<i>R</i>) (&gt;0). Typical value = 0,04. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Governor mechanism time constant (<i>T1</i>) (&gt;= 0). <i>T1</i> represents the natural valve positioning time constant of the governor for small disturbances, as seen when rate limiting is not in effect. Typical value = 0,5. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Turbine power time constant (<i>T2</i>) (&gt;= 0). <i>T2</i> represents delay due to internal energy storage of the gas turbine engine. <i>T2</i> can be used to give a rough approximation to the delay associated with acceleration of the compressor spool of a multi-shaft engine, or with the compressibility of gas in the plenum of a free power turbine of an aero-derivative unit, for example. Typical value = 0,5. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Turbine exhaust temperature time constant (<i>T3</i>) (&gt;= 0). Typical value = 3. | |
| vmax [0..1] | [PU](#CIM17v40-PU) | Maximum turbine power, PU of MWbase (<i>Vmax</i>) (&gt; GovGAST.vmin). Typical value = 1. | |
| vmin [0..1] | [PU](#CIM17v40-PU) | Minimum turbine power, PU of MWbase (<i>Vmin</i>) (&lt; GovGAST.vmax). Typical value = 0. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovGAST1}
### GovGAST1

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovGAST1 {

+ a : Float [0..1]
+ b : Float [0..1]
+ db1 : Frequency [0..1]
+ db2 : ActivePower [0..1]
+ eps : Frequency [0..1]
+ fidle : PU [0..1]
+ gv1 : PU [0..1]
+ gv2 : PU [0..1]
+ gv3 : PU [0..1]
+ gv4 : PU [0..1]
+ gv5 : PU [0..1]
+ gv6 : PU [0..1]
+ ka : PU [0..1]
+ kt : PU [0..1]
+ lmax : PU [0..1]
+ loadinc : PU [0..1]
+ ltrate : Float [0..1]
+ mwbase : ActivePower [0..1]
+ pgv1 : PU [0..1]
+ pgv2 : PU [0..1]
+ pgv3 : PU [0..1]
+ pgv4 : PU [0..1]
+ pgv5 : PU [0..1]
+ pgv6 : PU [0..1]
+ r : PU [0..1]
+ rmax : Float [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ t5 : Seconds [0..1]
+ tltr : Seconds [0..1]
+ vmax : PU [0..1]
+ vmin : PU [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovGAST1 : inherits from
```

Modified single shaft gas turbine.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| a [0..1] | [Float](#CIM17v40-Float) | Turbine power time constant numerator scale factor (<i>a</i>). Typical value = 0,8. | |
| b [0..1] | [Float](#CIM17v40-Float) | Turbine power time constant denominator scale factor (<i>b</i>) (&gt;0). Typical value = 1. | |
| db1 [0..1] | [Frequency](#CIM17v40-Frequency) | Intentional dead-band width (<i>db1</i>). Unit = Hz. Typical value = 0. | |
| db2 [0..1] | [ActivePower](#CIM17v40-ActivePower) | Unintentional dead-band (<i>db2</i>). Unit = MW. Typical value = 0. | |
| eps [0..1] | [Frequency](#CIM17v40-Frequency) | Intentional db hysteresis (<i>eps</i>). Unit = Hz. Typical value = 0. | |
| fidle [0..1] | [PU](#CIM17v40-PU) | Fuel flow at zero power output (<i>Fidle</i>). Typical value = 0,18. | |
| gv1 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 1, PU gv (<i>Gv1</i>). Typical value = 0. | |
| gv2 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 2,PU gv (<i>Gv2</i>). Typical value = 0. | |
| gv3 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 3, PU gv (<i>Gv3</i>). Typical value = 0. | |
| gv4 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 4, PU gv (<i>Gv4</i>). Typical value = 0. | |
| gv5 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 5, PU gv (<i>Gv5</i>). Typical value = 0. | |
| gv6 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 6, PU gv (<i>Gv6</i>). Typical value = 0. | |
| ka [0..1] | [PU](#CIM17v40-PU) | Governor gain (<i>Ka</i>). Typical value = 0. | |
| kt [0..1] | [PU](#CIM17v40-PU) | Temperature limiter gain (<i>Kt</i>). Typical value = 3. | |
| lmax [0..1] | [PU](#CIM17v40-PU) | Ambient temperature load limit (<i>Lmax</i>). <i>Lmax</i> is the turbine power output corresponding to the limiting exhaust gas temperature. Typical value = 1. | |
| loadinc [0..1] | [PU](#CIM17v40-PU) | Valve position change allowed at fast rate (<i>Loadinc</i>). Typical value = 0,05. | |
| ltrate [0..1] | [Float](#CIM17v40-Float) | Maximum long term fuel valve opening rate (<i>Ltrate</i>). Typical value = 0,02. | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| pgv1 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 1, PU power (<i>Pgv1</i>). Typical value = 0. | |
| pgv2 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 2, PU power (<i>Pgv2</i>). Typical value = 0. | |
| pgv3 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 3, PU power (<i>Pgv3</i>). Typical value = 0. | |
| pgv4 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 4, PU power (<i>Pgv4</i>). Typical value = 0. | |
| pgv5 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 5, PU power (<i>Pgv5</i>). Typical value = 0. | |
| pgv6 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 6, PU power (<i>Pgv6</i>). Typical value = 0. | |
| r [0..1] | [PU](#CIM17v40-PU) | Permanent droop (<i>R</i>) (&gt;0). Typical value = 0,04. | |
| rmax [0..1] | [Float](#CIM17v40-Float) | Maximum fuel valve opening rate (<i>Rmax</i>). Unit = PU / s. Typical value = 1. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Governor mechanism time constant (<i>T1</i>) (&gt;= 0). <i>T1</i> represents the natural valve positioning time constant of the governor for small disturbances, as seen when rate limiting is not in effect. Typical value = 0,5. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Turbine power time constant (<i>T2</i>) (&gt;= 0). <i>T2</i> represents delay due to internal energy storage of the gas turbine engine. <i>T2</i> can be used to give a rough approximation to the delay associated with acceleration of the compressor spool of a multi-shaft engine, or with the compressibility of gas in the plenum of the free power turbine of an aero-derivative unit, for example. Typical value = 0,5. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Turbine exhaust temperature time constant (<i>T3</i>) (&gt;= 0). <i>T3</i> represents delay in the exhaust temperature and load limiting system. Typical value = 3. | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Governor lead time constant (<i>T4</i>) (&gt;= 0). Typical value = 0. | |
| t5 [0..1] | [Seconds](#CIM17v40-Seconds) | Governor lag time constant (<i>T5</i>) (&gt;= 0). If = 0, entire gain and lead-lag block is bypassed. Typical value = 0. | |
| tltr [0..1] | [Seconds](#CIM17v40-Seconds) | Valve position averaging time constant (<i>Tltr</i>) (&gt;= 0). Typical value = 10. | |
| vmax [0..1] | [PU](#CIM17v40-PU) | Maximum turbine power, PU of MWbase (<i>Vmax</i>) (&gt; GovGAST1.vmin). Typical value = 1. | |
| vmin [0..1] | [PU](#CIM17v40-PU) | Minimum turbine power, PU of MWbase (<i>Vmin</i>) (&lt; GovGAST1.vmax). Typical value = 0. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovGAST2}
### GovGAST2

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovGAST2 {

+ a : Float [0..1]
+ af1 : PU [0..1]
+ af2 : PU [0..1]
+ b : Float [0..1]
+ bf1 : PU [0..1]
+ bf2 : PU [0..1]
+ c : Float [0..1]
+ cf2 : PU [0..1]
+ ecr : Seconds [0..1]
+ etd : Seconds [0..1]
+ k3 : PU [0..1]
+ k4 : PU [0..1]
+ k5 : PU [0..1]
+ k6 : PU [0..1]
+ kf : PU [0..1]
+ mwbase : ActivePower [0..1]
+ t : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ t5 : Seconds [0..1]
+ tc : Temperature [0..1]
+ tcd : Seconds [0..1]
+ tf : Seconds [0..1]
+ tmax : PU [0..1]
+ tmin : PU [0..1]
+ tr : Temperature [0..1]
+ trate : ActivePower [0..1]
+ tt : Seconds [0..1]
+ w : PU [0..1]
+ x : Seconds [0..1]
+ y : Seconds [0..1]
+ z : Integer [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovGAST2 : inherits from
```

Gas turbine.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| a [0..1] | [Float](#CIM17v40-Float) | Valve positioner (<i>A</i>). | |
| af1 [0..1] | [PU](#CIM17v40-PU) | Exhaust temperature parameter (<i>Af1</i>). Unit = PU temperature. Based on temperature in degrees C. | |
| af2 [0..1] | [PU](#CIM17v40-PU) | Coefficient equal to 0,5(1-speed) (<i>Af2</i>). | |
| b [0..1] | [Float](#CIM17v40-Float) | Valve positioner (<i>B</i>). | |
| bf1 [0..1] | [PU](#CIM17v40-PU) | (<i>Bf1</i>). <i>Bf1</i> = <i>E</i>(1 - <i>W</i>) where <i>E</i> (speed sensitivity coefficient) is 0,55 to 0,65 x <i>Tr</i>. Unit = PU temperature. Based on temperature in degrees C. | |
| bf2 [0..1] | [PU](#CIM17v40-PU) | Turbine torque coefficient K<sub>hhv</sub> (depends on heating value of fuel stream in combustion chamber) (<i>Bf2</i>). | |
| c [0..1] | [Float](#CIM17v40-Float) | Valve positioner (<i>C</i>). | |
| cf2 [0..1] | [PU](#CIM17v40-PU) | Coefficient defining fuel flow where power output is 0% (<i>Cf2</i>). Synchronous but no output. Typically 0,23 x K<sub>hhv</sub> (23% fuel flow). | |
| ecr [0..1] | [Seconds](#CIM17v40-Seconds) | Combustion reaction time delay (<i>Ecr</i>) (&gt;= 0). | |
| etd [0..1] | [Seconds](#CIM17v40-Seconds) | Turbine and exhaust delay (<i>Etd</i>) (&gt;= 0). | |
| k3 [0..1] | [PU](#CIM17v40-PU) | Ratio of fuel adjustment (<i>K3</i>). | |
| k4 [0..1] | [PU](#CIM17v40-PU) | Gain of radiation shield (<i>K4</i>). | |
| k5 [0..1] | [PU](#CIM17v40-PU) | Gain of radiation shield (<i>K5</i>). | |
| k6 [0..1] | [PU](#CIM17v40-PU) | Minimum fuel flow (<i>K6</i>). | |
| kf [0..1] | [PU](#CIM17v40-PU) | Fuel system feedback (<i>Kf</i>). | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| t [0..1] | [Seconds](#CIM17v40-Seconds) | Fuel control time constant (<i>T</i>) (&gt;= 0). | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Radiation shield time constant (<i>T3</i>) (&gt;= 0). | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Thermocouple time constant (<i>T4</i>) (&gt;= 0). | |
| t5 [0..1] | [Seconds](#CIM17v40-Seconds) | Temperature control time constant (<i>T5</i>) (&gt;= 0). | |
| tc [0..1] | [Temperature](#CIM17v40-Temperature) | Temperature control (<i>Tc</i>). Unit = �F or �C depending on parameters <i>Af1</i> and <i>Bf1</i>. | |
| tcd [0..1] | [Seconds](#CIM17v40-Seconds) | Compressor discharge time constant (<i>Tcd</i>) (&gt;= 0). | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Fuel system time constant (<i>Tf</i>) (&gt;= 0). | |
| tmax [0..1] | [PU](#CIM17v40-PU) | Maximum turbine limit (<i>Tmax</i>) (&gt; GovGAST2.tmin). | |
| tmin [0..1] | [PU](#CIM17v40-PU) | Minimum turbine limit (<i>Tmin</i>) (&lt; GovGAST2.tmax). | |
| tr [0..1] | [Temperature](#CIM17v40-Temperature) | Rated temperature (<i>Tr</i>). Unit = �C depending on parameters<i> Af1 </i>and <i>Bf1</i>. | |
| trate [0..1] | [ActivePower](#CIM17v40-ActivePower) | Turbine rating (<i>Trate</i>). Unit = MW. | |
| tt [0..1] | [Seconds](#CIM17v40-Seconds) | Temperature controller integration rate (<i>Tt</i>) (&gt;= 0). | |
| w [0..1] | [PU](#CIM17v40-PU) | Governor gain (1/droop) on turbine rating (<i>W</i>). | |
| x [0..1] | [Seconds](#CIM17v40-Seconds) | Governor lead time constant (<i>X</i>) (&gt;= 0). | |
| y [0..1] | [Seconds](#CIM17v40-Seconds) | Governor lag time constant (<i>Y</i>) (&gt; 0). | |
| z [0..1] | [Integer](#CIM17v40-Integer) | Governor mode (<i>Z</i>).1 = droop0 = isochronous. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovGAST3}
### GovGAST3

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovGAST3 {

+ bca : Float [0..1]
+ bp : PU [0..1]
+ dtc : Temperature [0..1]
+ ka : PU [0..1]
+ kac : Float [0..1]
+ kca : Float [0..1]
+ ksi : Float [0..1]
+ ky : Float [0..1]
+ mnef : PU [0..1]
+ mxef : PU [0..1]
+ rcmn : PU [0..1]
+ rcmx : PU [0..1]
+ tac : Seconds [0..1]
+ tc : Seconds [0..1]
+ td : Seconds [0..1]
+ tfen : Temperature [0..1]
+ tg : Seconds [0..1]
+ tsi : Seconds [0..1]
+ tt : Temperature [0..1]
+ ttc : Seconds [0..1]
+ ty : Seconds [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovGAST3 : inherits from
```

Generic turbogas with acceleration and temperature controller.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| bca [0..1] | [Float](#CIM17v40-Float) | Acceleration limit set-point (<i>Bca</i>). Unit = 1/s. Typical value = 0,01. | |
| bp [0..1] | [PU](#CIM17v40-PU) | Droop (<i>bp</i>). Typical value = 0,05. | |
| dtc [0..1] | [Temperature](#CIM17v40-Temperature) | Exhaust temperature variation due to fuel flow increasing from 0 to 1 PU (<i>deltaTc</i>). Typical value = 390. | |
| ka [0..1] | [PU](#CIM17v40-PU) | Minimum fuel flow (<i>Ka</i>). Typical value = 0,23. | |
| kac [0..1] | [Float](#CIM17v40-Float) | Fuel system feedback (<i>K</i><i><sub>AC</sub></i>). Typical value = 0. | |
| kca [0..1] | [Float](#CIM17v40-Float) | Acceleration control integral gain (<i>Kca</i>). Unit = 1/s. Typical value = 100. | |
| ksi [0..1] | [Float](#CIM17v40-Float) | Gain of radiation shield (<i>Ksi</i>). Typical value = 0,8. | |
| ky [0..1] | [Float](#CIM17v40-Float) | Coefficient of transfer function of fuel valve positioner (<i>Ky</i>). Typical value = 1. | |
| mnef [0..1] | [PU](#CIM17v40-PU) | Fuel flow maximum negative error value (<i>MNef</i>). Typical value = -0,05. | |
| mxef [0..1] | [PU](#CIM17v40-PU) | Fuel flow maximum positive error value (<i>MXef</i>). Typical value = 0,05. | |
| rcmn [0..1] | [PU](#CIM17v40-PU) | Minimum fuel flow (<i>RCMN</i>). Typical value = -0,1. | |
| rcmx [0..1] | [PU](#CIM17v40-PU) | Maximum fuel flow (<i>RCMX</i>). Typical value = 1. | |
| tac [0..1] | [Seconds](#CIM17v40-Seconds) | Fuel control time constant (<i>Tac</i>) (&gt;= 0). Typical value = 0,1. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Compressor discharge volume time constant (<i>Tc</i>) (&gt;= 0). Typical value = 0,2. | |
| td [0..1] | [Seconds](#CIM17v40-Seconds) | Temperature controller derivative gain (<i>Td</i>) (&gt;= 0). Typical value = 3,3. | |
| tfen [0..1] | [Temperature](#CIM17v40-Temperature) | Turbine rated exhaust temperature correspondent to Pm=1 PU (<i>Tfen</i>). Typical value = 540. | |
| tg [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant of speed governor (<i>Tg</i>) (&gt;= 0). Typical value = 0,05. | |
| tsi [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant of radiation shield (<i>Tsi</i>) (&gt;= 0). Typical value = 15. | |
| tt [0..1] | [Temperature](#CIM17v40-Temperature) | Temperature controller integration rate (<i>Tt</i>). Typical value = 250. | |
| ttc [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant of thermocouple (<i>Ttc</i>) (&gt;= 0). Typical value = 2,5. | |
| ty [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant of fuel valve positioner (<i>Ty</i>) (&gt;= 0). Typical value = 0,2. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovGAST4}
### GovGAST4

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovGAST4 {

+ bp : PU [0..1]
+ ktm : PU [0..1]
+ mnef : PU [0..1]
+ mxef : PU [0..1]
+ rymn : PU [0..1]
+ rymx : PU [0..1]
+ ta : Seconds [0..1]
+ tc : Seconds [0..1]
+ tcm : Seconds [0..1]
+ tm : Seconds [0..1]
+ ty : Seconds [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovGAST4 : inherits from
```

Generic turbogas.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| bp [0..1] | [PU](#CIM17v40-PU) | Droop (<i>b</i><i><sub>p</sub></i>). Typical value = 0,05. | |
| ktm [0..1] | [PU](#CIM17v40-PU) | Compressor gain (<i>Ktm</i>). Typical value = 0. | |
| mnef [0..1] | [PU](#CIM17v40-PU) | Fuel flow maximum negative error value (<i>MNef</i>). Typical value = -0,05. | |
| mxef [0..1] | [PU](#CIM17v40-PU) | Fuel flow maximum positive error value (<i>MXef</i>). Typical value = 0,05. | |
| rymn [0..1] | [PU](#CIM17v40-PU) | Minimum valve opening (<i>RYMN</i>). Typical value = 0. | |
| rymx [0..1] | [PU](#CIM17v40-PU) | Maximum valve opening (<i>RYMX</i>). Typical value = 1,1. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Maximum gate opening velocity (<i>TA</i>) (&gt;= 0). Typical value = 3. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Maximum gate closing velocity (<i>TC</i>) (&gt;= 0). Typical value = 0,5. | |
| tcm [0..1] | [Seconds](#CIM17v40-Seconds) | Fuel control time constant (<i>Tcm</i>) (&gt;= 0). Typical value = 0,1. | |
| tm [0..1] | [Seconds](#CIM17v40-Seconds) | Compressor discharge volume time constant (<i>Tm</i>) (&gt;= 0). Typical value = 0,2. | |
| ty [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant of fuel valve positioner (<i>Ty</i>) (&gt;= 0). Typical value = 0,1. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovGASTWD}
### GovGASTWD

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovGASTWD {

+ a : Float [0..1]
+ af1 : PU [0..1]
+ af2 : PU [0..1]
+ b : Float [0..1]
+ bf1 : PU [0..1]
+ bf2 : PU [0..1]
+ c : Float [0..1]
+ cf2 : PU [0..1]
+ ecr : Seconds [0..1]
+ etd : Seconds [0..1]
+ k3 : PU [0..1]
+ k4 : PU [0..1]
+ k5 : PU [0..1]
+ k6 : PU [0..1]
+ kd : PU [0..1]
+ kdroop : PU [0..1]
+ kf : PU [0..1]
+ ki : PU [0..1]
+ kp : PU [0..1]
+ mwbase : ActivePower [0..1]
+ t : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ t5 : Seconds [0..1]
+ tc : Temperature [0..1]
+ tcd : Seconds [0..1]
+ td : Seconds [0..1]
+ tf : Seconds [0..1]
+ tmax : PU [0..1]
+ tmin : PU [0..1]
+ tr : Temperature [0..1]
+ trate : ActivePower [0..1]
+ tt : Seconds [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovGASTWD : inherits from
```

Woodward� gas turbine governor.

[Footnote: Woodward gas turbines are an example of suitable products available commercially. This information is given for the convenience of users of this document and does not constitute an endorsement by IEC of these products.]


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| a [0..1] | [Float](#CIM17v40-Float) | Valve positioner (<i>A</i>). | |
| af1 [0..1] | [PU](#CIM17v40-PU) | Exhaust temperature parameter (<i>Af1</i>). | |
| af2 [0..1] | [PU](#CIM17v40-PU) | Coefficient equal to 0,5(1-speed) (<i>Af2</i>). | |
| b [0..1] | [Float](#CIM17v40-Float) | Valve positioner (<i>B</i>). | |
| bf1 [0..1] | [PU](#CIM17v40-PU) | (<i>Bf1</i>). <i>Bf1</i> = <i>E</i>(1-<i>w</i>) where <i>E</i> (speed sensitivity coefficient) is 0,55 to 0,65 x <i>Tr</i>. | |
| bf2 [0..1] | [PU](#CIM17v40-PU) | Turbine torque coefficient K<sub>hhv</sub> (depends on heating value of fuel stream in combustion chamber) (<i>Bf2</i>). | |
| c [0..1] | [Float](#CIM17v40-Float) | Valve positioner (<i>C</i>). | |
| cf2 [0..1] | [PU](#CIM17v40-PU) | Coefficient defining fuel flow where power output is 0 % (<i>Cf2</i>). Synchronous but no output. Typically 0,23 x K<sub>hhv </sub>(23 % fuel flow). | |
| ecr [0..1] | [Seconds](#CIM17v40-Seconds) | Combustion reaction time delay (<i>Ecr</i>) (&gt;= 0). | |
| etd [0..1] | [Seconds](#CIM17v40-Seconds) | Turbine and exhaust delay (<i>Etd</i>) (&gt;= 0). | |
| k3 [0..1] | [PU](#CIM17v40-PU) | Ratio of fuel adjustment (<i>K3</i>). | |
| k4 [0..1] | [PU](#CIM17v40-PU) | Gain of radiation shield (<i>K4</i>). | |
| k5 [0..1] | [PU](#CIM17v40-PU) | Gain of radiation shield (<i>K5</i>). | |
| k6 [0..1] | [PU](#CIM17v40-PU) | Minimum fuel flow (<i>K6</i>). | |
| kd [0..1] | [PU](#CIM17v40-PU) | Drop governor gain (<i>Kd</i>). | |
| kdroop [0..1] | [PU](#CIM17v40-PU) | (<i>Kdroop</i>) (&gt;= 0). | |
| kf [0..1] | [PU](#CIM17v40-PU) | Fuel system feedback (<i>Kf</i>). | |
| ki [0..1] | [PU](#CIM17v40-PU) | Isochronous Governor Gain (<i>Ki</i>). | |
| kp [0..1] | [PU](#CIM17v40-PU) | PID proportional gain (<i>Kp</i>). | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| t [0..1] | [Seconds](#CIM17v40-Seconds) | Fuel control time constant (<i>T</i>) (&gt;= 0). | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Radiation shield time constant (<i>T3</i>) (&gt;= 0). | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Thermocouple time constant (<i>T4</i>) (&gt;= 0). | |
| t5 [0..1] | [Seconds](#CIM17v40-Seconds) | Temperature control time constant (<i>T5</i>) (&gt;= 0). | |
| tc [0..1] | [Temperature](#CIM17v40-Temperature) | Temperature control (<i>Tc</i>). | |
| tcd [0..1] | [Seconds](#CIM17v40-Seconds) | Compressor discharge time constant (<i>Tcd</i>) (&gt;= 0). | |
| td [0..1] | [Seconds](#CIM17v40-Seconds) | Power transducer time constant (<i>Td</i>) (&gt;= 0). | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Fuel system time constant (<i>Tf</i>) (&gt;= 0). | |
| tmax [0..1] | [PU](#CIM17v40-PU) | Maximum Turbine limit (<i>Tmax</i>) (&gt; GovGASTWD.tmin). | |
| tmin [0..1] | [PU](#CIM17v40-PU) | Minimum turbine limit (<i>Tmin</i>) (&lt; GovGASTWD.tmax). | |
| tr [0..1] | [Temperature](#CIM17v40-Temperature) | Rated temperature (<i>Tr</i>). | |
| trate [0..1] | [ActivePower](#CIM17v40-ActivePower) | Turbine rating (<i>Trate</i>). Unit = MW. | |
| tt [0..1] | [Seconds](#CIM17v40-Seconds) | Temperature controller integration rate (<i>Tt</i>) (&gt;= 0). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovHydro1}
### GovHydro1

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovHydro1 {

+ at : PU [0..1]
+ dturb : PU [0..1]
+ gmax : PU [0..1]
+ gmin : PU [0..1]
+ hdam : PU [0..1]
+ mwbase : ActivePower [0..1]
+ qnl : PU [0..1]
+ rperm : PU [0..1]
+ rtemp : PU [0..1]
+ tf : Seconds [0..1]
+ tg : Seconds [0..1]
+ tr : Seconds [0..1]
+ tw : Seconds [0..1]
+ velm : Float [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovHydro1 : inherits from
```

Basic hydro turbine governor.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| at [0..1] | [PU](#CIM17v40-PU) | Turbine gain (<i>At</i>) (&gt; 0). Typical value = 1,2. | |
| dturb [0..1] | [PU](#CIM17v40-PU) | Turbine damping factor (<i>Dturb</i>) (&gt;= 0). Typical value = 0,5. | |
| gmax [0..1] | [PU](#CIM17v40-PU) | Maximum gate opening (<i>Gmax</i>) (&gt; 0 and &gt; GovHydro.gmin). Typical value = 1. | |
| gmin [0..1] | [PU](#CIM17v40-PU) | Minimum gate opening (<i>Gmin</i>) (&gt;= 0 and &lt; GovHydro1.gmax). Typical value = 0. | |
| hdam [0..1] | [PU](#CIM17v40-PU) | Turbine nominal head (<i>hdam</i>). Typical value = 1. | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| qnl [0..1] | [PU](#CIM17v40-PU) | No-load flow at nominal head (<i>qnl</i>) (&gt;= 0). Typical value = 0,08. | |
| rperm [0..1] | [PU](#CIM17v40-PU) | Permanent droop (<i>R</i>) (&gt; 0). Typical value = 0,04. | |
| rtemp [0..1] | [PU](#CIM17v40-PU) | Temporary droop (<i>r</i>) (&gt; GovHydro1.rperm). Typical value = 0,3. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Filter time constant (<i>Tf</i>) (&gt; 0). Typical value = 0,05. | |
| tg [0..1] | [Seconds](#CIM17v40-Seconds) | Gate servo time constant (<i>Tg</i>) (&gt; 0). Typical value = 0,5. | |
| tr [0..1] | [Seconds](#CIM17v40-Seconds) | Washout time constant (<i>Tr</i>) (&gt; 0). Typical value = 5. | |
| tw [0..1] | [Seconds](#CIM17v40-Seconds) | Water inertia time constant (<i>Tw</i>) (&gt; 0). Typical value = 1. | |
| velm [0..1] | [Float](#CIM17v40-Float) | Maximum gate velocity (<i>Vlem</i>) (&gt; 0). Typical value = 0,2. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovHydro2}
### GovHydro2

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovHydro2 {

+ aturb : PU [0..1]
+ bturb : PU [0..1]
+ db1 : Frequency [0..1]
+ db2 : ActivePower [0..1]
+ eps : Frequency [0..1]
+ gv1 : PU [0..1]
+ gv2 : PU [0..1]
+ gv3 : PU [0..1]
+ gv4 : PU [0..1]
+ gv5 : PU [0..1]
+ gv6 : PU [0..1]
+ kturb : PU [0..1]
+ mwbase : ActivePower [0..1]
+ pgv1 : PU [0..1]
+ pgv2 : PU [0..1]
+ pgv3 : PU [0..1]
+ pgv4 : PU [0..1]
+ pgv5 : PU [0..1]
+ pgv6 : PU [0..1]
+ pmax : PU [0..1]
+ pmin : PU [0..1]
+ rperm : PU [0..1]
+ rtemp : PU [0..1]
+ tg : Seconds [0..1]
+ tp : Seconds [0..1]
+ tr : Seconds [0..1]
+ tw : Seconds [0..1]
+ uc : Float [0..1]
+ uo : Float [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovHydro2 : inherits from
```

IEEE hydro turbine governor with straightforward penstock configuration and hydraulic-dashpot governor.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aturb [0..1] | [PU](#CIM17v40-PU) | Turbine numerator multiplier (<i>Aturb</i>). Typical value = -1. | |
| bturb [0..1] | [PU](#CIM17v40-PU) | Turbine denominator multiplier (<i>Bturb</i>) (&gt; 0). Typical value = 0,5. | |
| db1 [0..1] | [Frequency](#CIM17v40-Frequency) | Intentional deadband width (<i>db1</i>). Unit = Hz. Typical value = 0. | |
| db2 [0..1] | [ActivePower](#CIM17v40-ActivePower) | Unintentional deadband (<i>db2</i>). Unit = MW. Typical value = 0. | |
| eps [0..1] | [Frequency](#CIM17v40-Frequency) | Intentional db hysteresis (<i>eps</i>). Unit = Hz. Typical value = 0. | |
| gv1 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 1, PU gv (<i>Gv1</i>). Typical value = 0. | |
| gv2 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 2, PU gv (<i>Gv2</i>). Typical value = 0. | |
| gv3 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 3, PU gv (<i>Gv3</i>). Typical value = 0. | |
| gv4 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 4, PU gv (<i>Gv4</i>). Typical value = 0. | |
| gv5 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 5, PU gv (<i>Gv5</i>). Typical value = 0. | |
| gv6 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 6, PU gv (<i>Gv6</i>). Typical value = 0. | |
| kturb [0..1] | [PU](#CIM17v40-PU) | Turbine gain (<i>Kturb</i>). Typical value = 1. | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| pgv1 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 1, PU power (<i>Pgv1</i>). Typical value = 0. | |
| pgv2 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 2, PU power (<i>Pgv2</i>). Typical value = 0. | |
| pgv3 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 3, PU power (<i>Pgv3</i>). Typical value = 0. | |
| pgv4 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 4, PU power (P<i>gv4</i>). Typical value = 0. | |
| pgv5 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 5, PU power (<i>Pgv5</i>). Typical value = 0. | |
| pgv6 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 6, PU power (<i>Pgv6</i>). Typical value = 0. | |
| pmax [0..1] | [PU](#CIM17v40-PU) | Maximum gate opening (<i>Pmax</i>) (&gt; GovHydro2.pmin). Typical value = 1. | |
| pmin [0..1] | [PU](#CIM17v40-PU) | Minimum gate opening (<i>Pmin</i>) (&lt; GovHydro2.pmax). Typical value = 0. | |
| rperm [0..1] | [PU](#CIM17v40-PU) | Permanent droop (<i>Rperm</i>). Typical value = 0,05. | |
| rtemp [0..1] | [PU](#CIM17v40-PU) | Temporary droop (<i>Rtemp</i>). Typical value = 0,5. | |
| tg [0..1] | [Seconds](#CIM17v40-Seconds) | Gate servo time constant (<i>Tg</i>) (&gt; 0). Typical value = 0,5. | |
| tp [0..1] | [Seconds](#CIM17v40-Seconds) | Pilot servo valve time constant (<i>Tp</i>) (&gt;= 0). Typical value = 0,03. | |
| tr [0..1] | [Seconds](#CIM17v40-Seconds) | Dashpot time constant (<i>Tr</i>) (&gt;= 0). Typical value = 12. | |
| tw [0..1] | [Seconds](#CIM17v40-Seconds) | Water inertia time constant (<i>Tw</i>) (&gt;= 0). Typical value = 2. | |
| uc [0..1] | [Float](#CIM17v40-Float) | Maximum gate closing velocity (<i>Uc</i>) (&lt; 0). Unit = PU / s. Typical value = -0,1. | |
| uo [0..1] | [Float](#CIM17v40-Float) | Maximum gate opening velocity (<i>Uo</i>). Unit = PU / s. Typical value = 0,1. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovHydro3}
### GovHydro3

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovHydro3 {

+ at : PU [0..1]
+ db1 : Frequency [0..1]
+ db2 : ActivePower [0..1]
+ dturb : PU [0..1]
+ eps : Frequency [0..1]
+ governorControl : Boolean [0..1]
+ gv1 : PU [0..1]
+ gv2 : PU [0..1]
+ gv3 : PU [0..1]
+ gv4 : PU [0..1]
+ gv5 : PU [0..1]
+ gv6 : PU [0..1]
+ h0 : PU [0..1]
+ k1 : PU [0..1]
+ k2 : PU [0..1]
+ kg : PU [0..1]
+ ki : PU [0..1]
+ mwbase : ActivePower [0..1]
+ pgv1 : PU [0..1]
+ pgv2 : PU [0..1]
+ pgv3 : PU [0..1]
+ pgv4 : PU [0..1]
+ pgv5 : PU [0..1]
+ pgv6 : PU [0..1]
+ pmax : PU [0..1]
+ pmin : PU [0..1]
+ qnl : PU [0..1]
+ relec : PU [0..1]
+ rgate : PU [0..1]
+ td : Seconds [0..1]
+ tf : Seconds [0..1]
+ tp : Seconds [0..1]
+ tt : Seconds [0..1]
+ tw : Seconds [0..1]
+ velcl : Float [0..1]
+ velop : Float [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovHydro3 : inherits from
```

Modified IEEE hydro governor-turbine. This model differs from that defined in the IEEE modelling guideline paper in that the limits on gate position and velocity do not permit "wind up" of the upstream signals.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| at [0..1] | [PU](#CIM17v40-PU) | Turbine gain (<i>At</i>) (&gt;0). Typical value = 1,2. | |
| db1 [0..1] | [Frequency](#CIM17v40-Frequency) | Intentional dead-band width (<i>db1</i>). Unit = Hz. Typical value = 0. | |
| db2 [0..1] | [ActivePower](#CIM17v40-ActivePower) | Unintentional dead-band (<i>db2</i>). Unit = MW. Typical value = 0. | |
| dturb [0..1] | [PU](#CIM17v40-PU) | Turbine damping factor (<i>Dturb</i>). Typical value = 0,2. | |
| eps [0..1] | [Frequency](#CIM17v40-Frequency) | Intentional db hysteresis (<i>eps</i>). Unit = Hz. Typical value = 0. | |
| governorControl [0..1] | [Boolean](#CIM17v40-Boolean) | Governor control flag (<i>Cflag</i>).true = PID control is activefalse = double derivative control is active.Typical value = true. | |
| gv1 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 1, PU gv (<i>Gv1</i>). Typical value = 0. | |
| gv2 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 2, PU gv (<i>Gv2</i>). Typical value = 0. | |
| gv3 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 3, PU gv (<i>Gv3</i>). Typical value = 0. | |
| gv4 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 4, PU gv (<i>Gv4</i>). Typical value = 0. | |
| gv5 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 5, PU gv (<i>Gv5</i>). Typical value = 0. | |
| gv6 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 6, PU gv (<i>Gv6</i>). Typical value = 0. | |
| h0 [0..1] | [PU](#CIM17v40-PU) | Turbine nominal head (<i>H0</i>). Typical value = 1. | |
| k1 [0..1] | [PU](#CIM17v40-PU) | Derivative gain (<i>K1</i>). Typical value = 0,01. | |
| k2 [0..1] | [PU](#CIM17v40-PU) | Double derivative gain, if <i>Cflag</i> = -1 (<i>K2</i>). Typical value = 2,5. | |
| kg [0..1] | [PU](#CIM17v40-PU) | Gate servo gain (<i>Kg</i>). Typical value = 2. | |
| ki [0..1] | [PU](#CIM17v40-PU) | Integral gain (<i>Ki</i>). Typical value = 0,5. | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| pgv1 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 1, PU power (<i>Pgv1</i>). Typical value = 0. | |
| pgv2 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 2, PU power (<i>Pgv2</i>). Typical value = 0. | |
| pgv3 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 3, PU power (<i>Pgv3</i>). Typical value = 0. | |
| pgv4 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 4, PU power (<i>Pgv4</i>). Typical value = 0. | |
| pgv5 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 5, PU power (<i>Pgv5</i>). Typical value = 0. | |
| pgv6 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 6, PU power (<i>Pgv6</i>). Typical value = 0. | |
| pmax [0..1] | [PU](#CIM17v40-PU) | Maximum gate opening, PU of MWbase (<i>Pmax</i>) (&gt; GovHydro3.pmin). Typical value = 1. | |
| pmin [0..1] | [PU](#CIM17v40-PU) | Minimum gate opening, PU of <i>MWbase</i> (<i>Pmin</i>) (&lt; GovHydro3.pmax). Typical value = 0. | |
| qnl [0..1] | [PU](#CIM17v40-PU) | No-load turbine flow at nominal head (<i>Qnl</i>). Typical value = 0,08. | |
| relec [0..1] | [PU](#CIM17v40-PU) | Steady-state droop, PU, for electrical power feedback (<i>Relec</i>). Typical value = 0,05. | |
| rgate [0..1] | [PU](#CIM17v40-PU) | Steady-state droop, PU, for governor output feedback (<i>Rgate</i>). Typical value = 0. | |
| td [0..1] | [Seconds](#CIM17v40-Seconds) | Input filter time constant (<i>Td</i>) (&gt;= 0). Typical value = 0,05. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Washout time constant (<i>Tf</i>) (&gt;= 0). Typical value = 0,1. | |
| tp [0..1] | [Seconds](#CIM17v40-Seconds) | Gate servo time constant (<i>Tp</i>) (&gt;= 0). Typical value = 0,05. | |
| tt [0..1] | [Seconds](#CIM17v40-Seconds) | Power feedback time constant (<i>Tt</i>) (&gt;= 0). Typical value = 0,2. | |
| tw [0..1] | [Seconds](#CIM17v40-Seconds) | Water inertia time constant (<i>Tw</i>) (&gt;= 0). If = 0, block is bypassed. Typical value = 1. | |
| velcl [0..1] | [Float](#CIM17v40-Float) | Maximum gate closing velocity (<i>Velcl</i>). Unit = PU / s. Typical value = -0,2. | |
| velop [0..1] | [Float](#CIM17v40-Float) | Maximum gate opening velocity (<i>Velop</i>). Unit = PU / s. Typical value = 0,2. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovHydro4}
### GovHydro4

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovHydro4 {

+ at : PU [0..1]
+ bgv0 : PU [0..1]
+ bgv1 : PU [0..1]
+ bgv2 : PU [0..1]
+ bgv3 : PU [0..1]
+ bgv4 : PU [0..1]
+ bgv5 : PU [0..1]
+ bmax : Float [0..1]
+ db1 : Frequency [0..1]
+ db2 : ActivePower [0..1]
+ dturb : PU [0..1]
+ eps : Frequency [0..1]
+ gmax : PU [0..1]
+ gmin : PU [0..1]
+ gv0 : PU [0..1]
+ gv1 : PU [0..1]
+ gv2 : PU [0..1]
+ gv3 : PU [0..1]
+ gv4 : PU [0..1]
+ gv5 : PU [0..1]
+ hdam : PU [0..1]
+ model : enum:GovHydro4ModelKind [0..1]
+ mwbase : ActivePower [0..1]
+ pgv0 : PU [0..1]
+ pgv1 : PU [0..1]
+ pgv2 : PU [0..1]
+ pgv3 : PU [0..1]
+ pgv4 : PU [0..1]
+ pgv5 : PU [0..1]
+ qnl : PU [0..1]
+ rperm : Seconds [0..1]
+ rtemp : Seconds [0..1]
+ tblade : Seconds [0..1]
+ tg : Seconds [0..1]
+ tp : Seconds [0..1]
+ tr : Seconds [0..1]
+ tw : Seconds [0..1]
+ uc : Float [0..1]
+ uo : Float [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovHydro4 : inherits from
```

Hydro turbine and governor. Represents plants with straight-forward penstock configurations and hydraulic governors of the traditional 'dashpot' type. This model can be used to represent simple, Francis/Pelton or Kaplan turbines.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| at [0..1] | [PU](#CIM17v40-PU) | Turbine gain (<i>At</i>). Typical value = 1,2. | |
| bgv0 [0..1] | [PU](#CIM17v40-PU) | Kaplan blade servo point 0 (<i>Bgv0</i>) (= 0 for simple, = 0 for Francis/Pelton). Typical value for Kaplan = 0. | |
| bgv1 [0..1] | [PU](#CIM17v40-PU) | Kaplan blade servo point 1 (<i>Bgv1</i>) (= 0 for simple, = 0 for Francis/Pelton). Typical value for Kaplan = 0. | |
| bgv2 [0..1] | [PU](#CIM17v40-PU) | Kaplan blade servo point 2 (<i>Bgv2</i>) (= 0 for simple, = 0 for Francis/Pelton). Typical value for Kaplan = 0,1. | |
| bgv3 [0..1] | [PU](#CIM17v40-PU) | Kaplan blade servo point 3 (<i>Bgv3</i>) (= 0 for simple, = 0 for Francis/Pelton). Typical value for Kaplan = 0,667. | |
| bgv4 [0..1] | [PU](#CIM17v40-PU) | Kaplan blade servo point 4 (<i>Bgv4</i>) (= 0 for simple, = 0 for Francis/Pelton). Typical value for Kaplan = 0,9. | |
| bgv5 [0..1] | [PU](#CIM17v40-PU) | Kaplan blade servo point 5 (<i>Bgv5</i>) (= 0 for simple, = 0 for Francis/Pelton). Typical value for Kaplan = 1. | |
| bmax [0..1] | [Float](#CIM17v40-Float) | Maximum blade adjustment factor (<i>Bmax</i>) (= 0 for simple, = 0 for Francis/Pelton). Typical value for Kaplan = 1,1276. | |
| db1 [0..1] | [Frequency](#CIM17v40-Frequency) | Intentional deadband width (<i>db1</i>). Unit = Hz. Typical value = 0. | |
| db2 [0..1] | [ActivePower](#CIM17v40-ActivePower) | Unintentional dead-band (<i>db2</i>). Unit = MW. Typical value = 0. | |
| dturb [0..1] | [PU](#CIM17v40-PU) | Turbine damping factor (<i>Dturb</i>). Unit = delta P (PU of <i>MWbase</i>) / delta speed (PU). Typical value for simple = 0,5, Francis/Pelton = 1,1, Kaplan = 1,1. | |
| eps [0..1] | [Frequency](#CIM17v40-Frequency) | Intentional db hysteresis (<i>eps</i>). Unit = Hz. Typical value = 0. | |
| gmax [0..1] | [PU](#CIM17v40-PU) | Maximum gate opening, PU of <i>MWbase</i> (<i>Gmax</i>) (&gt; GovHydro4.gmin). Typical value = 1. | |
| gmin [0..1] | [PU](#CIM17v40-PU) | Minimum gate opening, PU of <i>MWbase</i> (<i>Gmin</i>) (&lt; GovHydro4.gmax). Typical value = 0. | |
| gv0 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 0, PU gv (<i>Gv0</i>) (= 0 for simple). Typical for Francis/Pelton = 0,1, Kaplan = 0,1. | |
| gv1 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 1, PU gv (<i>Gv1</i>) (= 0 for simple, &gt; GovHydro4.gv0 for Francis/Pelton and Kaplan). Typical value for Francis/Pelton = 0,4, Kaplan = 0,4. | |
| gv2 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 2, PU gv (<i>Gv2</i>) (= 0 for simple, &gt; GovHydro4.gv1 for Francis/Pelton and Kaplan). Typical value for Francis/Pelton = 0,5, Kaplan = 0,5. | |
| gv3 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 3, PU gv (<i>Gv3</i>) (= 0 for simple, &gt; GovHydro4.gv2 for Francis/Pelton and Kaplan). Typical value for Francis/Pelton = 0,7, Kaplan = 0,7. | |
| gv4 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 4, PU gv (<i>Gv4</i>) (= 0 for simple, &gt; GovHydro4.gv3 for Francis/Pelton and Kaplan). Typical value for Francis/Pelton = 0,8, Kaplan = 0,8. | |
| gv5 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 5, PU gv (<i>Gv5</i>) (= 0 for simple, &lt; 1 and &gt; GovHydro4.gv4 for Francis/Pelton and Kaplan). Typical value for Francis/Pelton = 0,9, Kaplan = 0,9. | |
| hdam [0..1] | [PU](#CIM17v40-PU) | Head available at dam (<i>hdam</i>). Typical value = 1. | |
| model [0..1] | [GovHydro4ModelKind](#CIM17v40-GovHydro4ModelKind) | The kind of model being represented (simple, Francis/Pelton or Kaplan). | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| pgv0 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 0, PU power (<i>Pgv0</i>) (= 0 for simple). Typical value = 0. | |
| pgv1 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 1, PU power (<i>Pgv1</i>) (= 0 for simple).Typical value for Francis/Pelton = 0,42, Kaplan = 0,35. | |
| pgv2 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 2, PU power (<i>Pgv2</i>) (= 0 for simple).Typical value for Francis/Pelton = 0,56, Kaplan = 0,468. | |
| pgv3 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 3, PU power (<i>Pgv3</i>) (= 0 for simple).Typical value for Francis/Pelton = 0,8, Kaplan = 0,796. | |
| pgv4 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 4, PU power (<i>Pgv4</i>) (= 0 for simple).Typical value for Francis/Pelton = 0,9, Kaplan = 0,917. | |
| pgv5 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 5, PU power (<i>Pgv5</i>) (= 0 for simple).Typical value for Francis/Pelton = 0,97, Kaplan = 0,99. | |
| qnl [0..1] | [PU](#CIM17v40-PU) | No-load flow at nominal head (<i>Qnl</i>).Typical value for simple = 0,08, Francis/Pelton = 0, Kaplan = 0. | |
| rperm [0..1] | [Seconds](#CIM17v40-Seconds) | Permanent droop (<i>Rperm</i>) (&gt;= 0). Typical value = 0,05. | |
| rtemp [0..1] | [Seconds](#CIM17v40-Seconds) | Temporary droop (<i>Rtemp</i>) (&gt;= 0). Typical value = 0,3. | |
| tblade [0..1] | [Seconds](#CIM17v40-Seconds) | Blade servo time constant (<i>Tblade</i>) (&gt;= 0). Typical value = 100. | |
| tg [0..1] | [Seconds](#CIM17v40-Seconds) | Gate servo time constant (<i>Tg</i>) (&gt; 0). Typical value = 0,5. | |
| tp [0..1] | [Seconds](#CIM17v40-Seconds) | Pilot servo time constant (<i>Tp</i>) (&gt;= 0). Typical value = 0,1. | |
| tr [0..1] | [Seconds](#CIM17v40-Seconds) | Dashpot time constant (<i>Tr</i>) (&gt;= 0). Typical value = 5. | |
| tw [0..1] | [Seconds](#CIM17v40-Seconds) | Water inertia time constant (<i>Tw</i>) (&gt; 0). Typical value = 1. | |
| uc [0..1] | [Float](#CIM17v40-Float) | Max gate closing velocity (<i>Uc</i>). Typical value = 0,2. | |
| uo [0..1] | [Float](#CIM17v40-Float) | Max gate opening velocity (<i>Uo</i>). Typical value = 0,2. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovHydroDD}
### GovHydroDD

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovHydroDD {

+ aturb : PU [0..1]
+ bturb : PU [0..1]
+ db1 : Frequency [0..1]
+ db2 : ActivePower [0..1]
+ eps : Frequency [0..1]
+ gmax : PU [0..1]
+ gmin : PU [0..1]
+ gv1 : PU [0..1]
+ gv2 : PU [0..1]
+ gv3 : PU [0..1]
+ gv4 : PU [0..1]
+ gv5 : PU [0..1]
+ gv6 : PU [0..1]
+ inputSignal : Boolean [0..1]
+ k1 : PU [0..1]
+ k2 : PU [0..1]
+ kg : PU [0..1]
+ ki : PU [0..1]
+ mwbase : ActivePower [0..1]
+ pgv1 : PU [0..1]
+ pgv2 : PU [0..1]
+ pgv3 : PU [0..1]
+ pgv4 : PU [0..1]
+ pgv5 : PU [0..1]
+ pgv6 : PU [0..1]
+ pmax : PU [0..1]
+ pmin : PU [0..1]
+ r : PU [0..1]
+ td : Seconds [0..1]
+ tf : Seconds [0..1]
+ tp : Seconds [0..1]
+ tt : Seconds [0..1]
+ tturb : Seconds [0..1]
+ velcl : Float [0..1]
+ velop : Float [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovHydroDD : inherits from
```

Double derivative hydro governor and turbine.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aturb [0..1] | [PU](#CIM17v40-PU) | Turbine numerator multiplier (<i>Aturb</i>) (see parameter detail 3). Typical value = -1. | |
| bturb [0..1] | [PU](#CIM17v40-PU) | Turbine denominator multiplier (<i>Bturb</i>) (see parameter detail 3). Typical value = 0,5. | |
| db1 [0..1] | [Frequency](#CIM17v40-Frequency) | Intentional dead-band width (<i>db1</i>). Unit = Hz. Typical value = 0. | |
| db2 [0..1] | [ActivePower](#CIM17v40-ActivePower) | Unintentional dead-band (<i>db2</i>). Unit = MW. Typical value = 0. | |
| eps [0..1] | [Frequency](#CIM17v40-Frequency) | Intentional db hysteresis (<i>eps</i>). Unit = Hz. Typical value = 0. | |
| gmax [0..1] | [PU](#CIM17v40-PU) | Maximum gate opening (<i>Gmax</i>) (&gt; GovHydroDD.gmin). Typical value = 0. | |
| gmin [0..1] | [PU](#CIM17v40-PU) | Minimum gate opening (<i>Gmin</i>) (&lt; GovHydroDD.gmax). Typical value = 0. | |
| gv1 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 1, PU gv (<i>Gv1</i>). Typical value = 0. | |
| gv2 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 2, PU gv (<i>Gv2</i>). Typical value = 0. | |
| gv3 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 3, PU gv (<i>Gv3</i>). Typical value = 0. | |
| gv4 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 4, PU gv (<i>Gv4</i>). Typical value = 0. | |
| gv5 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 5, PU gv (<i>Gv5</i>). Typical value = 0. | |
| gv6 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 6, PU gv (<i>Gv6</i>). Typical value = 0. | |
| inputSignal [0..1] | [Boolean](#CIM17v40-Boolean) | Input signal switch (<i>Flag</i>).true = <i>Pe</i> input is usedfalse = feedback is received from <i>CV</i>.<i>Flag</i> is normally dependent on <i>Tt</i>. If <i>Tt</i> is zero, <i>Flag</i> is set to false. If <i>Tt</i> is not zero, <i>Flag</i> is set to true.Typical value = true. | |
| k1 [0..1] | [PU](#CIM17v40-PU) | Single derivative gain (<i>K1</i>). Typical value = 3,6. | |
| k2 [0..1] | [PU](#CIM17v40-PU) | Double derivative gain (<i>K2</i>). Typical value = 0,2. | |
| kg [0..1] | [PU](#CIM17v40-PU) | Gate servo gain (<i>Kg</i>). Typical value = 3. | |
| ki [0..1] | [PU](#CIM17v40-PU) | Integral gain (<i>Ki</i>). Typical value = 1. | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt;0). Unit = MW. | |
| pgv1 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 1, PU power (<i>Pgv1</i>). Typical value = 0. | |
| pgv2 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 2, PU power (<i>Pgv2</i>). Typical value = 0. | |
| pgv3 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 3, PU power (<i>Pgv3</i>). Typical value = 0. | |
| pgv4 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 4, PU power (<i>Pgv4</i>). Typical value = 0. | |
| pgv5 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 5, PU power (<i>Pgv5</i>). Typical value = 0. | |
| pgv6 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 6, PU power (<i>Pgv6</i>). Typical value = 0. | |
| pmax [0..1] | [PU](#CIM17v40-PU) | Maximum gate opening, PU of <i>MWbase</i> (<i>Pmax</i>) (&gt; GovHydroDD.pmin). Typical value = 1. | |
| pmin [0..1] | [PU](#CIM17v40-PU) | Minimum gate opening, PU of <i>MWbase</i> (<i>Pmin</i>) (&gt; GovHydroDD.pmax). Typical value = 0. | |
| r [0..1] | [PU](#CIM17v40-PU) | Steady state droop (<i>R</i>). Typical value = 0,05. | |
| td [0..1] | [Seconds](#CIM17v40-Seconds) | Input filter time constant (<i>Td</i>) (&gt;= 0). If = 0, block is bypassed. Typical value = 0. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Washout time constant (<i>Tf</i>) (&gt;= 0). Typical value = 0,1. | |
| tp [0..1] | [Seconds](#CIM17v40-Seconds) | Gate servo time constant (<i>Tp</i>) (&gt;= 0). If = 0, block is bypassed. Typical value = 0,35. | |
| tt [0..1] | [Seconds](#CIM17v40-Seconds) | Power feedback time constant (<i>Tt</i>) (&gt;= 0). If = 0, block is bypassed. Typical value = 0,02. | |
| tturb [0..1] | [Seconds](#CIM17v40-Seconds) | Turbine time constant (<i>Tturb</i>) (&gt;= 0). See parameter detail 3. Typical value = 0,8. | |
| velcl [0..1] | [Float](#CIM17v40-Float) | Maximum gate closing velocity (<i>Velcl</i>). Unit = PU / s. Typical value = -0,14. | |
| velop [0..1] | [Float](#CIM17v40-Float) | Maximum gate opening velocity (<i>Velop</i>). Unit = PU / s. Typical value = 0,09. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovHydroFrancis}
### GovHydroFrancis

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovHydroFrancis {

+ am : PU [0..1]
+ av0 : Area [0..1]
+ av1 : Area [0..1]
+ bp : PU [0..1]
+ db1 : Frequency [0..1]
+ etamax : PU [0..1]
+ governorControl : enum:FrancisGovernorControlKind [0..1]
+ h1 : Length [0..1]
+ h2 : Length [0..1]
+ hn : Length [0..1]
+ kc : PU [0..1]
+ kg : PU [0..1]
+ kt : PU [0..1]
+ qc0 : PU [0..1]
+ qn : VolumeFlowRate [0..1]
+ ta : Seconds [0..1]
+ td : Seconds [0..1]
+ ts : Seconds [0..1]
+ twnc : Seconds [0..1]
+ twng : Seconds [0..1]
+ tx : Seconds [0..1]
+ va : Float [0..1]
+ valvmax : PU [0..1]
+ valvmin : PU [0..1]
+ vc : Float [0..1]
+ waterTunnelSurgeChamberSimulation : Boolean [0..1]
+ zsfc : Length [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovHydroFrancis : inherits from
```

Detailed hydro unit - Francis model. This model can be used to represent three types of governors.

A schematic of the hydraulic system of detailed hydro unit models, such as Francis and Pelton, is provided in the DetailedHydroModelHydraulicSystem diagram.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| am [0..1] | [PU](#CIM17v40-PU) | Opening section <i>S</i><i><sub>EFF</sub></i> at the maximum efficiency (<i>Am</i>). Typical value = 0,7. | |
| av0 [0..1] | [Area](#CIM17v40-Area) | Area of the surge tank (<i>A</i><i><sub>V0</sub></i>). Unit = m<sup>2</sup>. Typical value = 30. | |
| av1 [0..1] | [Area](#CIM17v40-Area) | Area of the compensation tank (<i>A</i><i><sub>V1</sub></i>). Unit = m<sup>2</sup>. Typical value = 700. | |
| bp [0..1] | [PU](#CIM17v40-PU) | Droop (<i>Bp</i>). Typical value = 0,05. | |
| db1 [0..1] | [Frequency](#CIM17v40-Frequency) | Intentional dead-band width (<i>DB1</i>). Unit = Hz. Typical value = 0. | |
| etamax [0..1] | [PU](#CIM17v40-PU) | Maximum efficiency (<i>EtaMax</i>). Typical value = 1,05. | |
| governorControl [0..1] | [FrancisGovernorControlKind](#CIM17v40-FrancisGovernorControlKind) | Governor control flag (<i>Cflag</i>). Typical value = mechanicHydrolicTachoAccelerator. | |
| h1 [0..1] | [Length](#CIM17v40-Length) | Head of compensation chamber water level with respect to the level of penstock (<i>H</i><i><sub>1</sub></i>). Unit = km. Typical value = 0,004. | |
| h2 [0..1] | [Length](#CIM17v40-Length) | Head of surge tank water level with respect to the level of penstock (<i>H</i><i><sub>2</sub></i>). Unit = km. Typical value = 0,040. | |
| hn [0..1] | [Length](#CIM17v40-Length) | Rated hydraulic head (<i>H</i><i><sub>n</sub></i>). Unit = km. Typical value = 0,250. | |
| kc [0..1] | [PU](#CIM17v40-PU) | Penstock loss coefficient (due to friction) (<i>Kc</i>). Typical value = 0,025. | |
| kg [0..1] | [PU](#CIM17v40-PU) | Water tunnel and surge chamber loss coefficient (due to friction) (<i>Kg</i>). Typical value = 0,025. | |
| kt [0..1] | [PU](#CIM17v40-PU) | Washout gain (<i>Kt</i>). Typical value = 0,25. | |
| qc0 [0..1] | [PU](#CIM17v40-PU) | No-load turbine flow at nominal head (<i>Qc0</i>). Typical value = 0,1. | |
| qn [0..1] | [VolumeFlowRate](#CIM17v40-VolumeFlowRate) | Rated flow (<i>Q</i><i><sub>n</sub></i>). Unit = m<sup>3</sup>/s. Typical value = 250. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Derivative gain (<i>Ta</i>) (&gt;= 0). Typical value = 3. | |
| td [0..1] | [Seconds](#CIM17v40-Seconds) | Washout time constant (<i>Td</i>) (&gt;= 0). Typical value = 6. | |
| ts [0..1] | [Seconds](#CIM17v40-Seconds) | Gate servo time constant (<i>Ts</i>) (&gt;= 0). Typical value = 0,5. | |
| twnc [0..1] | [Seconds](#CIM17v40-Seconds) | Water inertia time constant (<i>Twnc</i>) (&gt;= 0). Typical value = 1. | |
| twng [0..1] | [Seconds](#CIM17v40-Seconds) | Water tunnel and surge chamber inertia time constant (<i>Twng</i>) (&gt;= 0). Typical value = 3. | |
| tx [0..1] | [Seconds](#CIM17v40-Seconds) | Derivative feedback gain (<i>Tx</i>) (&gt;= 0). Typical value = 1. | |
| va [0..1] | [Float](#CIM17v40-Float) | Maximum gate opening velocity (<i>Va</i>). Unit = PU / s. Typical value = 0,06. | |
| valvmax [0..1] | [PU](#CIM17v40-PU) | Maximum gate opening (<i>ValvMax</i>) (&gt; GovHydroFrancis.valvmin). Typical value = 1,1. | |
| valvmin [0..1] | [PU](#CIM17v40-PU) | Minimum gate opening (<i>ValvMin</i>) (&lt; GovHydroFrancis.valvmax). Typical value = 0. | |
| vc [0..1] | [Float](#CIM17v40-Float) | Maximum gate closing velocity (<i>Vc</i>). Unit = PU / s. Typical value = -0,06. | |
| waterTunnelSurgeChamberSimulation [0..1] | [Boolean](#CIM17v40-Boolean) | Water tunnel and surge chamber simulation (<i>Tflag</i>).true = enable of water tunnel and surge chamber simulationfalse = inhibit of water tunnel and surge chamber simulation.Typical value = false. | |
| zsfc [0..1] | [Length](#CIM17v40-Length) | Head of upper water level with respect to the level of penstock (<i>Zsfc</i>). Unit = km. Typical value = 0,025. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovHydroIEEE0}
### GovHydroIEEE0

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovHydroIEEE0 {

+ k : PU [0..1]
+ mwbase : ActivePower [0..1]
+ pmax : PU [0..1]
+ pmin : PU [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovHydroIEEE0 : inherits from
```

IEEE simplified hydro governor-turbine model. Used for mechanical-hydraulic and electro-hydraulic turbine governors, with or without steam feedback. Typical values given are for mechanical-hydraulic turbine-governor.

Ref<font color="#0f0f0f">erence: IEEE Transactions on Power Apparatus and Systems, November/December 1973, Volume PAS-92, Number 6, <i><u>Dynamic Models for Steam and Hydro Turbines in Power System Studies</u></i>, page 1904.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| k [0..1] | [PU](#CIM17v40-PU) | Governor gain (<i>K)</i>. | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| pmax [0..1] | [PU](#CIM17v40-PU) | Gate maximum (<i>Pmax</i>) (&gt; GovHydroIEEE0.pmin). | |
| pmin [0..1] | [PU](#CIM17v40-PU) | Gate minimum (<i>Pmin</i>) (&lt; GovHydroIEEE.pmax). | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Governor lag time constant (<i>T1</i>) (&gt;= 0). Typical value = 0,25. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Governor lead time constant (<i>T2)</i> (&gt;= 0). Typical value = 0. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Gate actuator time constant (<i>T3</i>) (&gt;= 0). Typical value = 0,1. | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Water starting time (<i>T4</i>) (&gt;= 0). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovHydroIEEE2}
### GovHydroIEEE2

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovHydroIEEE2 {

+ aturb : PU [0..1]
+ bturb : PU [0..1]
+ gv1 : PU [0..1]
+ gv2 : PU [0..1]
+ gv3 : PU [0..1]
+ gv4 : PU [0..1]
+ gv5 : PU [0..1]
+ gv6 : PU [0..1]
+ kturb : PU [0..1]
+ mwbase : ActivePower [0..1]
+ pgv1 : PU [0..1]
+ pgv2 : PU [0..1]
+ pgv3 : PU [0..1]
+ pgv4 : PU [0..1]
+ pgv5 : PU [0..1]
+ pgv6 : PU [0..1]
+ pmax : PU [0..1]
+ pmin : PU [0..1]
+ rperm : PU [0..1]
+ rtemp : PU [0..1]
+ tg : Seconds [0..1]
+ tp : Seconds [0..1]
+ tr : Seconds [0..1]
+ tw : Seconds [0..1]
+ uc : Float [0..1]
+ uo : Float [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovHydroIEEE2 : inherits from
```

IEEE hydro turbine governor model represents plants with straightforward penstock configurations and hydraulic-dashpot governors.

Ref<font color="#0f0f0f">erence: IEEE Transactions on Power Apparatus and Systems, November/December 1973, Volume PAS-92, Number 6, <i><u>Dynamic Models for Steam and Hydro Turbines in Power System Studies</u></i>, page 1904.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aturb [0..1] | [PU](#CIM17v40-PU) | Turbine numerator multiplier (<i>Aturb</i>). Typical value = -1. | |
| bturb [0..1] | [PU](#CIM17v40-PU) | Turbine denominator multiplier (<i>Bturb</i>) (&gt; 0). Typical value = 0,5. | |
| gv1 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 1, PU gv (<i>Gv1</i>). Typical value = 0. | |
| gv2 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 2, PU gv (<i>Gv2</i>). Typical value = 0. | |
| gv3 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 3, PU gv (<i>Gv3</i>). Typical value = 0. | |
| gv4 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 4, PU gv (<i>Gv4</i>). Typical value = 0. | |
| gv5 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 5, PU gv (<i>Gv5</i>). Typical value = 0. | |
| gv6 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 6, PU gv (<i>Gv6</i>). Typical value = 0. | |
| kturb [0..1] | [PU](#CIM17v40-PU) | Turbine gain (<i>Kturb</i>). Typical value = 1. | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| pgv1 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 1, PU power (<i>Pgv1</i>). Typical value = 0. | |
| pgv2 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 2, PU power (<i>Pgv2</i>). Typical value = 0. | |
| pgv3 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 3, PU power (<i>Pgv3</i>). Typical value = 0. | |
| pgv4 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 4, PU power (<i>Pgv4</i>). Typical value = 0. | |
| pgv5 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 5, PU power (<i>Pgv5</i>). Typical value = 0. | |
| pgv6 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 6, PU power (<i>Pgv6</i>). Typical value = 0. | |
| pmax [0..1] | [PU](#CIM17v40-PU) | Maximum gate opening (<i>Pmax</i>) (&gt; GovHydroIEEE2.pmin). Typical value = 1. | |
| pmin [0..1] | [PU](#CIM17v40-PU) | Minimum gate opening (<i>Pmin</i>) (&lt;GovHydroIEEE2.pmax). Typical value = 0. | |
| rperm [0..1] | [PU](#CIM17v40-PU) | Permanent droop (<i>Rperm</i>). Typical value = 0,05. | |
| rtemp [0..1] | [PU](#CIM17v40-PU) | Temporary droop (<i>Rtemp</i>). Typical value = 0,5. | |
| tg [0..1] | [Seconds](#CIM17v40-Seconds) | Gate servo time constant (<i>Tg</i>) (&gt;= 0). Typical value = 0,5. | |
| tp [0..1] | [Seconds](#CIM17v40-Seconds) | Pilot servo valve time constant (<i>Tp</i>) (&gt;= 0). Typical value = 0,03. | |
| tr [0..1] | [Seconds](#CIM17v40-Seconds) | Dashpot time constant (<i>Tr</i>) (&gt;= 0). Typical value = 12. | |
| tw [0..1] | [Seconds](#CIM17v40-Seconds) | Water inertia time constant (<i>Tw</i>) (&gt;= 0). Typical value = 2. | |
| uc [0..1] | [Float](#CIM17v40-Float) | Maximum gate closing velocity (<i>Uc</i>) (&lt;0). Typical value = -0,1. | |
| uo [0..1] | [Float](#CIM17v40-Float) | Maximum gate opening velocity (<i>Uo</i>). Unit = PU / s. Typical value = 0,1. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovHydroPID}
### GovHydroPID

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovHydroPID {

+ aturb : PU [0..1]
+ bturb : PU [0..1]
+ db1 : Frequency [0..1]
+ db2 : ActivePower [0..1]
+ eps : Frequency [0..1]
+ gv1 : PU [0..1]
+ gv2 : PU [0..1]
+ gv3 : PU [0..1]
+ gv4 : PU [0..1]
+ gv5 : PU [0..1]
+ gv6 : PU [0..1]
+ inputSignal : Boolean [0..1]
+ kd : PU [0..1]
+ kg : PU [0..1]
+ ki : PU [0..1]
+ kp : PU [0..1]
+ mwbase : ActivePower [0..1]
+ pgv1 : PU [0..1]
+ pgv2 : PU [0..1]
+ pgv3 : PU [0..1]
+ pgv4 : PU [0..1]
+ pgv5 : PU [0..1]
+ pgv6 : PU [0..1]
+ pmax : PU [0..1]
+ pmin : PU [0..1]
+ r : PU [0..1]
+ td : Seconds [0..1]
+ tf : Seconds [0..1]
+ tp : Seconds [0..1]
+ tt : Seconds [0..1]
+ tturb : Seconds [0..1]
+ velcl : Float [0..1]
+ velop : Float [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovHydroPID : inherits from
```

PID governor and turbine.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aturb [0..1] | [PU](#CIM17v40-PU) | Turbine numerator multiplier (<i>Aturb</i>) (see parameter detail 3). Typical value -1. | |
| bturb [0..1] | [PU](#CIM17v40-PU) | Turbine denominator multiplier (<i>Bturb</i>) (see parameter detail 3). Typical value = 0,5. | |
| db1 [0..1] | [Frequency](#CIM17v40-Frequency) | Intentional dead-band width (<i>db1</i>). Unit = Hz. Typical value = 0. | |
| db2 [0..1] | [ActivePower](#CIM17v40-ActivePower) | Unintentional dead-band (<i>db2</i>). Unit = MW. Typical value = 0. | |
| eps [0..1] | [Frequency](#CIM17v40-Frequency) | Intentional db hysteresis (<i>eps</i>). Unit = Hz. Typical value = 0. | |
| gv1 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 1, PU gv (<i>Gv1</i>). Typical value = 0. | |
| gv2 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 2, PU gv (<i>Gv2</i>). Typical value = 0. | |
| gv3 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 3, PU gv (<i>Gv3</i>). Typical value = 0. | |
| gv4 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 4, PU gv (<i>Gv4</i>). Typical value = 0. | |
| gv5 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 5, PU gv (<i>Gv5</i>). Typical value = 0. | |
| gv6 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 6, PU gv (<i>Gv6</i>). Typical value = 0. | |
| inputSignal [0..1] | [Boolean](#CIM17v40-Boolean) | Input signal switch (<i>Flag</i>).true = <i>Pe</i> input is usedfalse = feedback is received from <i>CV</i>.<i>Flag</i> is normally dependent on <i>Tt</i>. If <i>Tt </i>is zero, <i>Flag</i> is set to false. If <i>Tt</i> is not zero, <i>Flag</i> is set to true.Typical value = true. | |
| kd [0..1] | [PU](#CIM17v40-PU) | Derivative gain (<i>Kd</i>). Typical value = 1,11. | |
| kg [0..1] | [PU](#CIM17v40-PU) | Gate servo gain (<i>Kg</i>). Typical value = 2,5. | |
| ki [0..1] | [PU](#CIM17v40-PU) | Integral gain (<i>Ki</i>). Typical value = 0,36. | |
| kp [0..1] | [PU](#CIM17v40-PU) | Proportional gain (<i>Kp</i>). Typical value = 0,1. | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| pgv1 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 1, PU power (<i>Pgv1</i>). Typical value = 0. | |
| pgv2 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 2, PU power (<i>Pgv2</i>). Typical value = 0. | |
| pgv3 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 3, PU power (<i>Pgv3</i>). Typical value = 0. | |
| pgv4 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 4, PU power (<i>Pgv4</i>). Typical value = 0. | |
| pgv5 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 5, PU power (<i>Pgv5</i>). Typical value = 0. | |
| pgv6 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 6, PU power (<i>Pgv6</i>). Typical value = 0. | |
| pmax [0..1] | [PU](#CIM17v40-PU) | Maximum gate opening, PU of MWbase (<i>Pmax</i>) (&gt; GovHydroPID.pmin). Typical value = 1. | |
| pmin [0..1] | [PU](#CIM17v40-PU) | Minimum gate opening, PU of MWbase (<i>Pmin</i>) (&lt; GovHydroPID.pmax). Typical value = 0. | |
| r [0..1] | [PU](#CIM17v40-PU) | Steady state droop (<i>R</i>). Typical value = 0,05. | |
| td [0..1] | [Seconds](#CIM17v40-Seconds) | Input filter time constant (<i>Td</i>) (&gt;= 0). If = 0, block is bypassed. Typical value = 0. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Washout time constant (<i>Tf</i>) (&gt;= 0). Typical value = 0,1. | |
| tp [0..1] | [Seconds](#CIM17v40-Seconds) | Gate servo time constant (<i>Tp</i>) (&gt;= 0). If = 0, block is bypassed. Typical value = 0,35. | |
| tt [0..1] | [Seconds](#CIM17v40-Seconds) | Power feedback time constant (<i>Tt</i>) (&gt;= 0). If = 0, block is bypassed. Typical value = 0,02. | |
| tturb [0..1] | [Seconds](#CIM17v40-Seconds) | Turbine time constant (<i>Tturb</i>) (&gt;= 0). See Parameter detail 3. Typical value = 0,8. | |
| velcl [0..1] | [Float](#CIM17v40-Float) | Maximum gate closing velocity (<i>Velcl</i>). Unit = PU / s. Typical value = -0,14. | |
| velop [0..1] | [Float](#CIM17v40-Float) | Maximum gate opening velocity (<i>Velop</i>). Unit = PU / s. Typical value = 0,09. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovHydroPID2}
### GovHydroPID2

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovHydroPID2 {

+ atw : PU [0..1]
+ d : PU [0..1]
+ feedbackSignal : Boolean [0..1]
+ g0 : PU [0..1]
+ g1 : PU [0..1]
+ g2 : PU [0..1]
+ gmax : PU [0..1]
+ gmin : PU [0..1]
+ kd : PU [0..1]
+ ki : Float [0..1]
+ kp : PU [0..1]
+ mwbase : ActivePower [0..1]
+ p1 : PU [0..1]
+ p2 : PU [0..1]
+ p3 : PU [0..1]
+ rperm : PU [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ treg : Seconds [0..1]
+ tw : Seconds [0..1]
+ velmax : Float [0..1]
+ velmin : Float [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovHydroPID2 : inherits from
```

Hydro turbine and governor. Represents plants with straightforward penstock configurations and "three term" electro-hydraulic governors (i.e. Woodward<sup>TM</sup> electronic).

[Footnote: Woodward electronic governors are an example of suitable products available commercially. This information is given for the convenience of users of this document and does not constitute an endorsement by IEC of these products.]


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| atw [0..1] | [PU](#CIM17v40-PU) | Factor multiplying <i>Tw</i> (<i>Atw</i>). Typical value = 0. | |
| d [0..1] | [PU](#CIM17v40-PU) | Turbine damping factor (<i>D</i>). Unit = delta P / delta speed. Typical value = 0. | |
| feedbackSignal [0..1] | [Boolean](#CIM17v40-Boolean) | Feedback signal type flag (<i>Flag</i>).true = use gate position feedback signalfalse = use Pe. | |
| g0 [0..1] | [PU](#CIM17v40-PU) | Gate opening at speed no load (<i>G0</i>). Typical value = 0. | |
| g1 [0..1] | [PU](#CIM17v40-PU) | Intermediate gate opening (<i>G1</i>). Typical value = 0. | |
| g2 [0..1] | [PU](#CIM17v40-PU) | Intermediate gate opening (<i>G2</i>). Typical value = 0. | |
| gmax [0..1] | [PU](#CIM17v40-PU) | Maximum gate opening (<i>Gmax</i>) (&gt; GovHydroPID2.gmin). Typical value = 0. | |
| gmin [0..1] | [PU](#CIM17v40-PU) | Minimum gate opening (<i>Gmin</i>) (&gt; GovHydroPID2.gmax). Typical value = 0. | |
| kd [0..1] | [PU](#CIM17v40-PU) | Derivative gain (<i>Kd</i>). Typical value = 0. | |
| ki [0..1] | [Float](#CIM17v40-Float) | Reset gain (<i>Ki</i>). Unit = PU/s. Typical value = 0. | |
| kp [0..1] | [PU](#CIM17v40-PU) | Proportional gain (<i>Kp</i>). Typical value = 0. | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt;0). Unit = MW. | |
| p1 [0..1] | [PU](#CIM17v40-PU) | Power at gate opening <i>G1</i> (<i>P1</i>). Typical value = 0. | |
| p2 [0..1] | [PU](#CIM17v40-PU) | Power at gate opening G2 (<i>P2</i>). Typical value = 0. | |
| p3 [0..1] | [PU](#CIM17v40-PU) | Power at full opened gate (<i>P3</i>). Typical value = 0. | |
| rperm [0..1] | [PU](#CIM17v40-PU) | Permanent drop (<i>Rperm</i>). Typical value = 0. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Controller time constant (<i>Ta</i>) (&gt;= 0). Typical value = 0. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Gate servo time constant (<i>Tb</i>) (&gt; 0). | |
| treg [0..1] | [Seconds](#CIM17v40-Seconds) | Speed detector time constant (<i>Treg</i>) (&gt;= 0). Typical value = 0. | |
| tw [0..1] | [Seconds](#CIM17v40-Seconds) | Water inertia time constant (<i>Tw</i>) (&gt;= 0). Typical value = 0. | |
| velmax [0..1] | [Float](#CIM17v40-Float) | Maximum gate opening velocity (<i>Velmax</i>) (&lt; GovHydroPID2.velmin). Unit = PU / s. Typical value = 0. | |
| velmin [0..1] | [Float](#CIM17v40-Float) | Maximum gate closing velocity (<i>Velmin</i>) (&gt; GovHydroPID2.velmax). Unit = PU / s. Typical value = 0. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovHydroPelton}
### GovHydroPelton

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovHydroPelton {

+ av0 : Area [0..1]
+ av1 : Area [0..1]
+ bp : PU [0..1]
+ db1 : Frequency [0..1]
+ db2 : Frequency [0..1]
+ h1 : Length [0..1]
+ h2 : Length [0..1]
+ hn : Length [0..1]
+ kc : PU [0..1]
+ kg : PU [0..1]
+ qc0 : PU [0..1]
+ qn : VolumeFlowRate [0..1]
+ simplifiedPelton : Boolean [0..1]
+ staticCompensating : Boolean [0..1]
+ ta : Seconds [0..1]
+ ts : Seconds [0..1]
+ tv : Seconds [0..1]
+ twnc : Seconds [0..1]
+ twng : Seconds [0..1]
+ tx : Seconds [0..1]
+ va : Float [0..1]
+ valvmax : PU [0..1]
+ valvmin : PU [0..1]
+ vav : PU [0..1]
+ vc : Float [0..1]
+ vcv : PU [0..1]
+ waterTunnelSurgeChamberSimulation : Boolean [0..1]
+ zsfc : Length [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovHydroPelton : inherits from
```

Detailed hydro unit - Pelton model. This model can be used to represent the dynamic related to water tunnel and surge chamber.

The DetailedHydroModelHydraulicSystem diagram, located under the GovHydroFrancis class, provides a schematic of the hydraulic system of detailed hydro unit models, such as Francis and Pelton.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| av0 [0..1] | [Area](#CIM17v40-Area) | Area of the surge tank (<i>A</i><i><sub>V0</sub></i>). Unit = m<sup>2</sup>. Typical value = 30. | |
| av1 [0..1] | [Area](#CIM17v40-Area) | Area of the compensation tank (<i>A</i><i><sub>V1</sub></i>). Unit = m<sup>2</sup>. Typical value = 700. | |
| bp [0..1] | [PU](#CIM17v40-PU) | Droop (<i>bp</i>). Typical value = 0,05. | |
| db1 [0..1] | [Frequency](#CIM17v40-Frequency) | Intentional dead-band width (<i>DB1</i>). Unit = Hz. Typical value = 0. | |
| db2 [0..1] | [Frequency](#CIM17v40-Frequency) | Intentional dead-band width of valve opening error (<i>DB2</i>). Unit = Hz. Typical value = 0,01. | |
| h1 [0..1] | [Length](#CIM17v40-Length) | Head of compensation chamber water level with respect to the level of penstock (<i>H</i><i><sub>1</sub></i>). Unit = km. Typical value = 0,004. | |
| h2 [0..1] | [Length](#CIM17v40-Length) | Head of surge tank water level with respect to the level of penstock (<i>H</i><i><sub>2</sub></i>). Unit = km. Typical value = 0,040. | |
| hn [0..1] | [Length](#CIM17v40-Length) | Rated hydraulic head (<i>H</i><i><sub>n</sub></i>). Unit = km. Typical value = 0,250. | |
| kc [0..1] | [PU](#CIM17v40-PU) | Penstock loss coefficient (due to friction) (<i>Kc</i>). Typical value = 0,025. | |
| kg [0..1] | [PU](#CIM17v40-PU) | Water tunnel and surge chamber loss coefficient (due to friction) (<i>Kg</i>). Typical value = 0,025. | |
| qc0 [0..1] | [PU](#CIM17v40-PU) | No-load turbine flow at nominal head (<i>Qc0</i>). Typical value = 0,05. | |
| qn [0..1] | [VolumeFlowRate](#CIM17v40-VolumeFlowRate) | Rated flow (<i>Q</i><i><sub>n</sub></i>). Unit = m<sup>3</sup>/s. Typical value = 250. | |
| simplifiedPelton [0..1] | [Boolean](#CIM17v40-Boolean) | Simplified Pelton model simulation (<i>Sflag</i>).true = enable of simplified Pelton model simulationfalse = enable of complete Pelton model simulation (non-linear gain).Typical value = true. | |
| staticCompensating [0..1] | [Boolean](#CIM17v40-Boolean) | Static compensating characteristic (<i>Cflag</i>). It should be true if simplifiedPelton = false.true = enable of static compensating characteristicfalse = inhibit of static compensating characteristic.Typical value = false. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Derivative gain (accelerometer time constant) (<i>Ta</i>) (&gt;= 0). Typical value = 3. | |
| ts [0..1] | [Seconds](#CIM17v40-Seconds) | Gate servo time constant (<i>Ts</i>) (&gt;= 0). Typical value = 0,15. | |
| tv [0..1] | [Seconds](#CIM17v40-Seconds) | Servomotor integrator time constant (<i>Tv</i>) (&gt;= 0). Typical value = 0,3. | |
| twnc [0..1] | [Seconds](#CIM17v40-Seconds) | Water inertia time constant (<i>Twnc</i>) (&gt;= 0). Typical value = 1. | |
| twng [0..1] | [Seconds](#CIM17v40-Seconds) | Water tunnel and surge chamber inertia time constant (<i>Twng</i>) (&gt;= 0). Typical value = 3. | |
| tx [0..1] | [Seconds](#CIM17v40-Seconds) | Electronic integrator time constant (<i>Tx</i>) (&gt;= 0). Typical value = 0,5. | |
| va [0..1] | [Float](#CIM17v40-Float) | Maximum gate opening velocity (<i>Va</i>). Unit = PU / s. Typical value = 0,06. | |
| valvmax [0..1] | [PU](#CIM17v40-PU) | Maximum gate opening (<i>ValvMax</i>) (&gt; GovHydroPelton.valvmin). Typical value = 1,1. | |
| valvmin [0..1] | [PU](#CIM17v40-PU) | Minimum gate opening (<i>ValvMin</i>) (&lt; GovHydroPelton.valvmax). Typical value = 0. | |
| vav [0..1] | [PU](#CIM17v40-PU) | Maximum servomotor valve opening velocity (<i>Vav</i>). Typical value = 0,1. | |
| vc [0..1] | [Float](#CIM17v40-Float) | Maximum gate closing velocity (<i>Vc</i>). Unit = PU / s. Typical value = -0,06. | |
| vcv [0..1] | [PU](#CIM17v40-PU) | Maximum servomotor valve closing velocity (<i>Vcv</i>). Typical value = -0,1. | |
| waterTunnelSurgeChamberSimulation [0..1] | [Boolean](#CIM17v40-Boolean) | Water tunnel and surge chamber simulation (<i>Tflag</i>).true = enable of water tunnel and surge chamber simulationfalse = inhibit of water tunnel and surge chamber simulation.Typical value = false. | |
| zsfc [0..1] | [Length](#CIM17v40-Length) | Head of upper water level with respect to the level of penstock (<i>Zsfc</i>). Unit = km. Typical value = 0,025. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovHydroR}
### GovHydroR

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovHydroR {

+ at : PU [0..1]
+ db1 : Frequency [0..1]
+ db2 : ActivePower [0..1]
+ dturb : PU [0..1]
+ eps : Frequency [0..1]
+ gmax : PU [0..1]
+ gmin : PU [0..1]
+ gv1 : PU [0..1]
+ gv2 : PU [0..1]
+ gv3 : PU [0..1]
+ gv4 : PU [0..1]
+ gv5 : PU [0..1]
+ gv6 : PU [0..1]
+ h0 : PU [0..1]
+ inputSignal : Boolean [0..1]
+ kg : PU [0..1]
+ ki : PU [0..1]
+ mwbase : ActivePower [0..1]
+ pgv1 : PU [0..1]
+ pgv2 : PU [0..1]
+ pgv3 : PU [0..1]
+ pgv4 : PU [0..1]
+ pgv5 : PU [0..1]
+ pgv6 : PU [0..1]
+ pmax : PU [0..1]
+ pmin : PU [0..1]
+ qnl : PU [0..1]
+ r : PU [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ t5 : Seconds [0..1]
+ t6 : Seconds [0..1]
+ t7 : Seconds [0..1]
+ t8 : Seconds [0..1]
+ td : Seconds [0..1]
+ tp : Seconds [0..1]
+ tt : Seconds [0..1]
+ tw : Seconds [0..1]
+ velcl : Float [0..1]
+ velop : Float [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovHydroR : inherits from
```

Fourth order lead-lag governor and hydro turbine.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| at [0..1] | [PU](#CIM17v40-PU) | Turbine gain (<i>At</i>). Typical value = 1,2. | |
| db1 [0..1] | [Frequency](#CIM17v40-Frequency) | Intentional dead-band width (<i>db1</i>). Unit = Hz. Typical value = 0. | |
| db2 [0..1] | [ActivePower](#CIM17v40-ActivePower) | Unintentional dead-band (<i>db2</i>). Unit = MW. Typical value = 0. | |
| dturb [0..1] | [PU](#CIM17v40-PU) | Turbine damping factor (<i>Dturb</i>). Typical value = 0,2. | |
| eps [0..1] | [Frequency](#CIM17v40-Frequency) | Intentional db hysteresis (<i>eps</i>). Unit = Hz. Typical value = 0. | |
| gmax [0..1] | [PU](#CIM17v40-PU) | Maximum governor output (<i>Gmax</i>) (&gt; GovHydroR.gmin). Typical value = 1,05. | |
| gmin [0..1] | [PU](#CIM17v40-PU) | Minimum governor output (<i>Gmin</i>) (&lt; GovHydroR.gmax). Typical value = -0,05. | |
| gv1 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 1, PU gv (<i>Gv1</i>). Typical value = 0. | |
| gv2 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 2, PU gv (<i>Gv2</i>). Typical value = 0. | |
| gv3 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 3, PU gv (<i>Gv3</i>). Typical value = 0. | |
| gv4 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 4, PU gv (<i>Gv4</i>). Typical value = 0. | |
| gv5 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 5, PU gv (<i>Gv5</i>). Typical value = 0. | |
| gv6 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 6, PU gv (<i>Gv6</i>). Typical value = 0. | |
| h0 [0..1] | [PU](#CIM17v40-PU) | Turbine nominal head (<i>H0</i>). Typical value = 1. | |
| inputSignal [0..1] | [Boolean](#CIM17v40-Boolean) | Input signal switch (<i>Flag</i>).true = <i>Pe</i> input is usedfalse = feedback is received from <i>CV</i>.<i>Flag</i> is normally dependent on <i>Tt</i>. If <i>Tt </i>is zero, <i>Flag</i> is set to false. If <i>Tt</i> is not zero, <i>Flag</i> is set to true.Typical value = true. | |
| kg [0..1] | [PU](#CIM17v40-PU) | Gate servo gain (<i>Kg</i>). Typical value = 2. | |
| ki [0..1] | [PU](#CIM17v40-PU) | Integral gain (<i>Ki</i>). Typical value = 0,5. | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| pgv1 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 1, PU power (<i>Pgv1</i>). Typical value = 0. | |
| pgv2 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 2, PU power (<i>Pgv2</i>). Typical value = 0. | |
| pgv3 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 3, PU power (<i>Pgv3</i>). Typical value = 0. | |
| pgv4 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 4, PU power (<i>Pgv4</i>). Typical value = 0. | |
| pgv5 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 5, PU power (<i>Pgv5</i>). Typical value = 0. | |
| pgv6 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain point 6, PU power (<i>Pgv6</i>). Typical value = 0. | |
| pmax [0..1] | [PU](#CIM17v40-PU) | Maximum gate opening, PU of <i>MWbase</i> (<i>Pmax</i>) (&gt; GovHydroR.pmin). Typical value = 1. | |
| pmin [0..1] | [PU](#CIM17v40-PU) | Minimum gate opening, PU of <i>MWbase</i> (<i>Pmin</i>) (&lt; GovHydroR.pmax). Typical value = 0. | |
| qnl [0..1] | [PU](#CIM17v40-PU) | No-load turbine flow at nominal head (<i>Qnl</i>). Typical value = 0,08. | |
| r [0..1] | [PU](#CIM17v40-PU) | Steady-state droop (<i>R</i>). Typical value = 0,05. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead time constant 1 (<i>T1</i>) (&gt;= 0). Typical value = 1,5. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Lag time constant 1 (<i>T2</i>) (&gt;= 0). Typical value = 0,1. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead time constant 2 (<i>T3</i>) (&gt;= 0). Typical value = 1,5. | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Lag time constant 2 (<i>T4</i>) (&gt;= 0). Typical value = 0,1. | |
| t5 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead time constant 3 (<i>T5</i>) (&gt;= 0). Typical value = 0. | |
| t6 [0..1] | [Seconds](#CIM17v40-Seconds) | Lag time constant 3 (<i>T6</i>) (&gt;= 0). Typical value = 0,05. | |
| t7 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead time constant 4 (<i>T7</i>) (&gt;= 0). Typical value = 0. | |
| t8 [0..1] | [Seconds](#CIM17v40-Seconds) | Lag time constant 4 (<i>T8</i>) (&gt;= 0). Typical value = 0,05. | |
| td [0..1] | [Seconds](#CIM17v40-Seconds) | Input filter time constant (<i>Td</i>) (&gt;= 0). Typical value = 0,05. | |
| tp [0..1] | [Seconds](#CIM17v40-Seconds) | Gate servo time constant (<i>Tp</i>) (&gt;= 0). Typical value = 0,05. | |
| tt [0..1] | [Seconds](#CIM17v40-Seconds) | Power feedback time constant (<i>Tt</i>) (&gt;= 0). Typical value = 0. | |
| tw [0..1] | [Seconds](#CIM17v40-Seconds) | Water inertia time constant (<i>Tw</i>) (&gt; 0). Typical value = 1. | |
| velcl [0..1] | [Float](#CIM17v40-Float) | Maximum gate closing velocity (<i>Velcl</i>). Unit = PU / s. Typical value = -0,2. | |
| velop [0..1] | [Float](#CIM17v40-Float) | Maximum gate opening velocity (<i>Velop</i>). Unit = PU / s. Typical value = 0,2. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovHydroWEH}
### GovHydroWEH

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovHydroWEH {

+ db : PU [0..1]
+ dicn : PU [0..1]
+ dpv : PU [0..1]
+ dturb : PU [0..1]
+ feedbackSignal : Boolean [0..1]
+ fl1 : PU [0..1]
+ fl2 : PU [0..1]
+ fl3 : PU [0..1]
+ fl4 : PU [0..1]
+ fl5 : PU [0..1]
+ fp1 : PU [0..1]
+ fp10 : PU [0..1]
+ fp2 : PU [0..1]
+ fp3 : PU [0..1]
+ fp4 : PU [0..1]
+ fp5 : PU [0..1]
+ fp6 : PU [0..1]
+ fp7 : PU [0..1]
+ fp8 : PU [0..1]
+ fp9 : PU [0..1]
+ gmax : PU [0..1]
+ gmin : PU [0..1]
+ gtmxcl : PU [0..1]
+ gtmxop : PU [0..1]
+ gv1 : PU [0..1]
+ gv2 : PU [0..1]
+ gv3 : PU [0..1]
+ gv4 : PU [0..1]
+ gv5 : PU [0..1]
+ kd : PU [0..1]
+ ki : PU [0..1]
+ kp : PU [0..1]
+ mwbase : ActivePower [0..1]
+ pmss1 : PU [0..1]
+ pmss10 : PU [0..1]
+ pmss2 : PU [0..1]
+ pmss3 : PU [0..1]
+ pmss4 : PU [0..1]
+ pmss5 : PU [0..1]
+ pmss6 : PU [0..1]
+ pmss7 : PU [0..1]
+ pmss8 : PU [0..1]
+ pmss9 : PU [0..1]
+ rpg : Float [0..1]
+ rpp : Float [0..1]
+ td : Seconds [0..1]
+ tdv : Seconds [0..1]
+ tg : Seconds [0..1]
+ tp : Seconds [0..1]
+ tpe : Seconds [0..1]
+ tw : Seconds [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovHydroWEH : inherits from
```

Woodward<sup>TM </sup>electric hydro governor.

[Footnote: Woodward electric hydro governors are an example of suitable products available commercially. This information is given for the convenience of users of this document and does not constitute an endorsement by IEC of these products.]


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| db [0..1] | [PU](#CIM17v40-PU) | Speed deadband (<i>db</i>). | |
| dicn [0..1] | [PU](#CIM17v40-PU) | Value to allow the integral controller to advance beyond the gate limits (<i>Dicn</i>). | |
| dpv [0..1] | [PU](#CIM17v40-PU) | Value to allow the pilot valve controller to advance beyond the gate limits (<i>Dpv</i>). | |
| dturb [0..1] | [PU](#CIM17v40-PU) | Turbine damping factor (<i>Dturb</i>). Unit = delta P (PU of <i>MWbase</i>) / delta speed (PU). | |
| feedbackSignal [0..1] | [Boolean](#CIM17v40-Boolean) | Feedback signal selection (<i>Sw</i>).true = PID output (if <i>R-Perm-Gate </i>= droop and <i>R-Perm-Pe </i>= 0)false = electrical power (if <i>R-Perm-Gate </i>= 0 and <i>R-Perm-Pe </i>= droop) orfalse = gate position (if R<i>-Perm-Gate </i>= droop and <i>R-Perm-Pe </i>= 0).Typical value = false. | |
| fl1 [0..1] | [PU](#CIM17v40-PU) | Flowgate 1 (<i>Fl1</i>). Flow value for gate position point 1 for lookup table representing water flow through the turbine as a function of gate position to produce steady state flow. | |
| fl2 [0..1] | [PU](#CIM17v40-PU) | Flowgate 2 (<i>Fl2</i>). Flow value for gate position point 2 for lookup table representing water flow through the turbine as a function of gate position to produce steady state flow. | |
| fl3 [0..1] | [PU](#CIM17v40-PU) | Flowgate 3 (<i>Fl3</i>). Flow value for gate position point 3 for lookup table representing water flow through the turbine as a function of gate position to produce steady state flow. | |
| fl4 [0..1] | [PU](#CIM17v40-PU) | Flowgate 4 (<i>Fl4</i>). Flow value for gate position point 4 for lookup table representing water flow through the turbine as a function of gate position to produce steady state flow. | |
| fl5 [0..1] | [PU](#CIM17v40-PU) | Flowgate 5 (<i>Fl5</i>). Flow value for gate position point 5 for lookup table representing water flow through the turbine as a function of gate position to produce steady state flow. | |
| fp1 [0..1] | [PU](#CIM17v40-PU) | Flow P1 (<i>Fp1</i>). Turbine flow value for point 1 for lookup table representing PU mechanical power on machine MVA rating as a function of turbine flow. | |
| fp10 [0..1] | [PU](#CIM17v40-PU) | Flow P10 (<i>Fp10</i>). Turbine flow value for point 10 for lookup table representing PU mechanical power on machine MVA rating as a function of turbine flow. | |
| fp2 [0..1] | [PU](#CIM17v40-PU) | Flow P2 (<i>Fp2</i>). Turbine flow value for point 2 for lookup table representing PU mechanical power on machine MVA rating as a function of turbine flow. | |
| fp3 [0..1] | [PU](#CIM17v40-PU) | Flow P3 (<i>Fp3</i>). Turbine flow value for point 3 for lookup table representing PU mechanical power on machine MVA rating as a function of turbine flow. | |
| fp4 [0..1] | [PU](#CIM17v40-PU) | Flow P4 (<i>Fp4</i>). Turbine flow value for point 4 for lookup table representing PU mechanical power on machine MVA rating as a function of turbine flow. | |
| fp5 [0..1] | [PU](#CIM17v40-PU) | Flow P5 (<i>Fp5</i>). Turbine flow value for point 5 for lookup table representing PU mechanical power on machine MVA rating as a function of turbine flow. | |
| fp6 [0..1] | [PU](#CIM17v40-PU) | Flow P6 (<i>Fp6</i>). Turbine flow value for point 6 for lookup table representing PU mechanical power on machine MVA rating as a function of turbine flow. | |
| fp7 [0..1] | [PU](#CIM17v40-PU) | Flow P7 (<i>Fp7</i>). Turbine flow value for point 7 for lookup table representing PU mechanical power on machine MVA rating as a function of turbine flow. | |
| fp8 [0..1] | [PU](#CIM17v40-PU) | Flow P8 (<i>Fp8</i>). Turbine flow value for point 8 for lookup table representing PU mechanical power on machine MVA rating as a function of turbine flow. | |
| fp9 [0..1] | [PU](#CIM17v40-PU) | Flow P9 (<i>Fp9</i>). Turbine flow value for point 9 for lookup table representing PU mechanical power on machine MVA rating as a function of turbine flow. | |
| gmax [0..1] | [PU](#CIM17v40-PU) | Maximum gate position (<i>Gmax</i>) (&gt; GovHydroWEH.gmin). | |
| gmin [0..1] | [PU](#CIM17v40-PU) | Minimum gate position (<i>Gmin</i>) (&lt; GovHydroWEH.gmax). | |
| gtmxcl [0..1] | [PU](#CIM17v40-PU) | Maximum gate closing rate (<i>Gtmxcl</i>). | |
| gtmxop [0..1] | [PU](#CIM17v40-PU) | Maximum gate opening rate (<i>Gtmxop</i>). | |
| gv1 [0..1] | [PU](#CIM17v40-PU) | Gate 1 (<i>Gv1</i>). Gate Position value for point 1 for lookup table representing water flow through the turbine as a function of gate position to produce steady state flow. | |
| gv2 [0..1] | [PU](#CIM17v40-PU) | Gate 2 (<i>Gv2</i>). Gate Position value for point 2 for lookup table representing water flow through the turbine as a function of gate position to produce steady state flow. | |
| gv3 [0..1] | [PU](#CIM17v40-PU) | Gate 3 (<i>Gv3</i>). Gate Position value for point 3 for lookup table representing water flow through the turbine as a function of gate position to produce steady state flow. | |
| gv4 [0..1] | [PU](#CIM17v40-PU) | Gate 4 (<i>Gv4</i>). Gate Position value for point 4 for lookup table representing water flow through the turbine as a function of gate position to produce steady state flow. | |
| gv5 [0..1] | [PU](#CIM17v40-PU) | Gate 5 (<i>Gv5</i>). Gate Position value for point 5 for lookup table representing water flow through the turbine as a function of gate position to produce steady state flow. | |
| kd [0..1] | [PU](#CIM17v40-PU) | Derivative controller derivative gain (<i>Kd</i>). | |
| ki [0..1] | [PU](#CIM17v40-PU) | Derivative controller Integral gain (<i>Ki</i>). | |
| kp [0..1] | [PU](#CIM17v40-PU) | Derivative control gain (<i>Kp</i>). | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| pmss1 [0..1] | [PU](#CIM17v40-PU) | Pmss flow P1 (<i>Pmss1</i>). Mechanical power output for turbine flow point 1 for lookup table representing PU mechanical power on machine MVA rating as a function of turbine flow. | |
| pmss10 [0..1] | [PU](#CIM17v40-PU) | Pmss flow P10 (<i>Pmss10</i>). Mechanical power output for turbine flow point 10 for lookup table representing PU mechanical power on machine MVA rating as a function of turbine flow. | |
| pmss2 [0..1] | [PU](#CIM17v40-PU) | Pmss flow P2 (<i>Pmss2</i>). Mechanical power output for turbine flow point 2 for lookup table representing PU mechanical power on machine MVA rating as a function of turbine flow. | |
| pmss3 [0..1] | [PU](#CIM17v40-PU) | Pmss flow P3 (<i>Pmss3</i>). Mechanical power output for turbine flow point 3 for lookup table representing PU mechanical power on machine MVA rating as a function of turbine flow. | |
| pmss4 [0..1] | [PU](#CIM17v40-PU) | Pmss flow P4 (<i>Pmss4</i>). Mechanical power output for turbine flow point 4 for lookup table representing PU mechanical power on machine MVA rating as a function of turbine flow. | |
| pmss5 [0..1] | [PU](#CIM17v40-PU) | Pmss flow P5 (<i>Pmss5</i>). Mechanical power output for turbine flow point 5 for lookup table representing PU mechanical power on machine MVA rating as a function of turbine flow. | |
| pmss6 [0..1] | [PU](#CIM17v40-PU) | Pmss flow P6 (<i>Pmss6</i>). Mechanical power output for turbine flow point 6 for lookup table representing PU mechanical power on machine MVA rating as a function of turbine flow. | |
| pmss7 [0..1] | [PU](#CIM17v40-PU) | Pmss flow P7 (<i>Pmss7</i>). Mechanical power output for turbine flow point 7 for lookup table representing PU mechanical power on machine MVA rating as a function of turbine flow. | |
| pmss8 [0..1] | [PU](#CIM17v40-PU) | Pmss flow P8 (<i>Pmss8</i>). Mechanical power output for turbine flow point 8 for lookup table representing PU mechanical power on machine MVA rating as a function of turbine flow. | |
| pmss9 [0..1] | [PU](#CIM17v40-PU) | Pmss flow P9 (<i>Pmss9</i>). Mechanical power output for turbine flow point 9 for lookup table representing PU mechanical power on machine MVA rating as a function of turbine flow. | |
| rpg [0..1] | [Float](#CIM17v40-Float) | Permanent droop for governor output feedback (<i>R-Perm-Gate</i>). | |
| rpp [0..1] | [Float](#CIM17v40-Float) | Permanent droop for electrical power feedback (<i>R-Perm-Pe</i>). | |
| td [0..1] | [Seconds](#CIM17v40-Seconds) | Derivative controller time constant (<i>Td</i>) (&gt;= 0). Limits the derivative characteristic beyond a breakdown frequency to avoid amplification of high-frequency noise. | |
| tdv [0..1] | [Seconds](#CIM17v40-Seconds) | Distributive valve time lag time constant (<i>Tdv</i>) (&gt;= 0). | |
| tg [0..1] | [Seconds](#CIM17v40-Seconds) | Value to allow the distribution valve controller to advance beyond the gate movement rate limit (<i>Tg</i>) (&gt;= 0). | |
| tp [0..1] | [Seconds](#CIM17v40-Seconds) | Pilot valve time lag time constant (<i>Tp</i>) (&gt;= 0). | |
| tpe [0..1] | [Seconds](#CIM17v40-Seconds) | Electrical power droop time constant (<i>Tpe</i>) (&gt;= 0). | |
| tw [0..1] | [Seconds](#CIM17v40-Seconds) | Water inertia time constant (<i>Tw</i>) (&gt; 0). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovHydroWPID}
### GovHydroWPID

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovHydroWPID {

+ d : PU [0..1]
+ gatmax : PU [0..1]
+ gatmin : PU [0..1]
+ gv1 : PU [0..1]
+ gv2 : PU [0..1]
+ gv3 : PU [0..1]
+ kd : PU [0..1]
+ ki : PU [0..1]
+ kp : PU [0..1]
+ mwbase : ActivePower [0..1]
+ pgv1 : PU [0..1]
+ pgv2 : PU [0..1]
+ pgv3 : PU [0..1]
+ pmax : PU [0..1]
+ pmin : PU [0..1]
+ reg : PU [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ treg : Seconds [0..1]
+ tw : Seconds [0..1]
+ velmax : PU [0..1]
+ velmin : PU [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovHydroWPID : inherits from
```

Woodward<sup>TM</sup> PID hydro governor.

[Footnote: Woodward PID hydro governors are an example of suitable products available commercially. This information is given for the convenience of users of this document and does not constitute an endorsement by IEC of these products.]


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| d [0..1] | [PU](#CIM17v40-PU) | Turbine damping factor (<i>D</i>). Unit = delta P / delta speed. | |
| gatmax [0..1] | [PU](#CIM17v40-PU) | Gate opening limit maximum (<i>Gatmax</i>) (&gt; GovHydroWPID.gatmin). | |
| gatmin [0..1] | [PU](#CIM17v40-PU) | Gate opening limit minimum (<i>Gatmin</i>) (&lt; GovHydroWPID.gatmax). | |
| gv1 [0..1] | [PU](#CIM17v40-PU) | Gate position 1 (<i>Gv1</i>). | |
| gv2 [0..1] | [PU](#CIM17v40-PU) | Gate position 2 (<i>Gv2</i>). | |
| gv3 [0..1] | [PU](#CIM17v40-PU) | Gate position 3 (<i>Gv3</i>) (= 1,0). | |
| kd [0..1] | [PU](#CIM17v40-PU) | Derivative gain (<i>Kd</i>). Typical value = 1,11. | |
| ki [0..1] | [PU](#CIM17v40-PU) | Reset gain (<i>Ki</i>). Typical value = 0,36. | |
| kp [0..1] | [PU](#CIM17v40-PU) | Proportional gain (<i>Kp</i>). Typical value = 0,1. | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| pgv1 [0..1] | [PU](#CIM17v40-PU) | Output at <i>Gv1</i> PU of <i>MWbase</i> (<i>Pgv1</i>). | |
| pgv2 [0..1] | [PU](#CIM17v40-PU) | Output at <i>Gv2</i> PU of <i>MWbase</i> (<i>Pgv2</i>). | |
| pgv3 [0..1] | [PU](#CIM17v40-PU) | Output at <i>Gv3</i> PU of <i>MWbase</i> (<i>Pgv3</i>). | |
| pmax [0..1] | [PU](#CIM17v40-PU) | Maximum power output (<i>Pmax</i>) (&gt; GovHydroWPID.pmin). | |
| pmin [0..1] | [PU](#CIM17v40-PU) | Minimum power output (<i>Pmin</i>) (&lt; GovHydroWPID.pmax). | |
| reg [0..1] | [PU](#CIM17v40-PU) | Permanent drop (<i>Reg</i>). | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Controller time constant (<i>Ta</i>) (&gt;= 0). Typical value = 0. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Gate servo time constant (<i>Tb</i>) (&gt;= 0). Typical value = 0. | |
| treg [0..1] | [Seconds](#CIM17v40-Seconds) | Speed detector time constant (<i>Treg</i>) (&gt;= 0). | |
| tw [0..1] | [Seconds](#CIM17v40-Seconds) | Water inertia time constant (<i>Tw</i>) (&gt;= 0). Typical value = 0. | |
| velmax [0..1] | [PU](#CIM17v40-PU) | Maximum gate opening velocity (<i>Velmax</i>) (&gt; GovHydroWPID.velmin). Unit = PU / s. Typical value = 0. | |
| velmin [0..1] | [PU](#CIM17v40-PU) | Maximum gate closing velocity (<i>Velmin</i>) (&lt; GovHydroWPID.velmax). Unit = PU / s. Typical value = 0. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovSteam0}
### GovSteam0

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovSteam0 {

+ dt : PU [0..1]
+ mwbase : ActivePower [0..1]
+ r : PU [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ vmax : PU [0..1]
+ vmin : PU [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovSteam0 : inherits from
```

A simplified steam turbine governor.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dt [0..1] | [PU](#CIM17v40-PU) | Turbine damping coefficient (<i>Dt</i>). Unit = delta P / delta speed. Typical value = 0. | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| r [0..1] | [PU](#CIM17v40-PU) | Permanent droop (<i>R</i>). Typical value = 0,05. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Steam bowl time constant (<i>T1</i>) (&gt; 0). Typical value = 0,5. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Numerator time constant of <i>T2</i>/<i>T3</i> block (<i>T2</i>) (&gt;= 0). Typical value = 3. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Reheater time constant (<i>T3</i>) (&gt; 0). Typical value = 10. | |
| vmax [0..1] | [PU](#CIM17v40-PU) | Maximum valve position, PU of <i>mwcap</i> (<i>Vmax</i>) (&gt; GovSteam0.vmin). Typical value = 1. | |
| vmin [0..1] | [PU](#CIM17v40-PU) | Minimum valve position, PU of <i>mwcap</i> (<i>Vmin</i>) (&lt; GovSteam0.vmax). Typical value = 0. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovSteam1}
### GovSteam1

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovSteam1 {

+ db1 : Frequency [0..1]
+ db2 : ActivePower [0..1]
+ eps : Frequency [0..1]
+ gv1 : PU [0..1]
+ gv2 : PU [0..1]
+ gv3 : PU [0..1]
+ gv4 : PU [0..1]
+ gv5 : PU [0..1]
+ gv6 : PU [0..1]
+ k : PU [0..1]
+ k1 : Float [0..1]
+ k2 : Float [0..1]
+ k3 : Float [0..1]
+ k4 : Float [0..1]
+ k5 : Float [0..1]
+ k6 : Float [0..1]
+ k7 : Float [0..1]
+ k8 : Float [0..1]
+ mwbase : ActivePower [0..1]
+ pgv1 : PU [0..1]
+ pgv2 : PU [0..1]
+ pgv3 : PU [0..1]
+ pgv4 : PU [0..1]
+ pgv5 : PU [0..1]
+ pgv6 : PU [0..1]
+ pmax : PU [0..1]
+ pmin : PU [0..1]
+ sdb1 : Boolean [0..1]
+ sdb2 : Boolean [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ t5 : Seconds [0..1]
+ t6 : Seconds [0..1]
+ t7 : Seconds [0..1]
+ uc : Float [0..1]
+ uo : Float [0..1]
+ valve : Boolean [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovSteam1 : inherits from
```

Steam turbine governor, based on the GovSteamIEEE1 (with optional deadband and nonlinear valve gain added).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| db1 [0..1] | [Frequency](#CIM17v40-Frequency) | Intentional deadband width (<i>db1</i>). Unit = Hz. Typical value = 0. | |
| db2 [0..1] | [ActivePower](#CIM17v40-ActivePower) | Unintentional deadband (<i>db2</i>). Unit = MW. Typical value = 0. | |
| eps [0..1] | [Frequency](#CIM17v40-Frequency) | Intentional db hysteresis (<i>eps</i>). Unit = Hz. Typical value = 0. | |
| gv1 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain valve position point 1 (<i>GV1</i>). Typical value = 0. | |
| gv2 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain valve position point 2 (<i>GV2</i>). Typical value = 0,4. | |
| gv3 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain valve position point 3 (<i>GV3</i>). Typical value = 0,5. | |
| gv4 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain valve position point 4 (<i>GV4</i>). Typical value = 0,6. | |
| gv5 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain valve position point 5 (<i>GV5</i>). Typical value = 1. | |
| gv6 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain valve position point 6 (<i>GV6</i>). Typical value = 0. | |
| k [0..1] | [PU](#CIM17v40-PU) | Governor gain (reciprocal of droop) (<i>K</i>) (&gt; 0). Typical value = 25. | |
| k1 [0..1] | [Float](#CIM17v40-Float) | Fraction of HP shaft power after first boiler pass (<i>K1</i>). Typical value = 0,2. | |
| k2 [0..1] | [Float](#CIM17v40-Float) | Fraction of LP shaft power after first boiler pass (<i>K2</i>). Typical value = 0. | |
| k3 [0..1] | [Float](#CIM17v40-Float) | Fraction of HP shaft power after second boiler pass (<i>K3</i>). Typical value = 0,3. | |
| k4 [0..1] | [Float](#CIM17v40-Float) | Fraction of LP shaft power after second boiler pass (<i>K4</i>). Typical value = 0. | |
| k5 [0..1] | [Float](#CIM17v40-Float) | Fraction of HP shaft power after third boiler pass (<i>K5</i>). Typical value = 0,5. | |
| k6 [0..1] | [Float](#CIM17v40-Float) | Fraction of LP shaft power after third boiler pass (<i>K6</i>). Typical value = 0. | |
| k7 [0..1] | [Float](#CIM17v40-Float) | Fraction of HP shaft power after fourth boiler pass (<i>K7</i>). Typical value = 0. | |
| k8 [0..1] | [Float](#CIM17v40-Float) | Fraction of LP shaft power after fourth boiler pass (<i>K8</i>). Typical value = 0. | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| pgv1 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain power value point 1 (<i>Pgv1</i>). Typical value = 0. | |
| pgv2 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain power value point 2 (<i>Pgv2</i>). Typical value = 0,75. | |
| pgv3 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain power value point 3 (<i>Pgv3</i>). Typical value = 0,91. | |
| pgv4 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain power value point 4 (<i>Pgv4</i>). Typical value = 0,98. | |
| pgv5 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain power value point 5 (<i>Pgv5</i>). Typical value = 1. | |
| pgv6 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain power value point 6 (<i>Pgv6</i>). Typical value = 0. | |
| pmax [0..1] | [PU](#CIM17v40-PU) | Maximum valve opening (<i>Pmax</i>) (&gt; GovSteam1.pmin). Typical value = 1. | |
| pmin [0..1] | [PU](#CIM17v40-PU) | Minimum valve opening (<i>Pmin</i>) (&gt;= 0 and &lt; GovSteam1.pmax). Typical value = 0. | |
| sdb1 [0..1] | [Boolean](#CIM17v40-Boolean) | Intentional deadband indicator.true = intentional deadband is appliedfalse = intentional deadband is not applied.Typical value = true. | |
| sdb2 [0..1] | [Boolean](#CIM17v40-Boolean) | Unintentional deadband location.true = intentional deadband is applied before point "A"false = intentional deadband is applied after point "A".Typical value = true. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Governor lag time constant (<i>T1</i>) (&gt;= 0). Typical value = 0. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Governor lead time constant (<i>T2</i>) (&gt;= 0). Typical value = 0. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Valve positioner time constant (<i>T3) </i>(&gt; 0). Typical value = 0,1. | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Inlet piping/steam bowl time constant (<i>T4</i>) (&gt;= 0). Typical value = 0,3. | |
| t5 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant of second boiler pass (<i>T5</i>) (&gt;= 0). Typical value = 5. | |
| t6 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant of third boiler pass (<i>T6</i>) (&gt;= 0). Typical value = 0,5. | |
| t7 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant of fourth boiler pass (<i>T7</i>) (&gt;= 0). Typical value = 0. | |
| uc [0..1] | [Float](#CIM17v40-Float) | Maximum valve closing velocity (<i>Uc</i>) (&lt; 0). Unit = PU / s. Typical value = -10. | |
| uo [0..1] | [Float](#CIM17v40-Float) | Maximum valve opening velocity (<i>Uo</i>) (&gt; 0). Unit = PU / s. Typical value = 1. | |
| valve [0..1] | [Boolean](#CIM17v40-Boolean) | Nonlinear valve characteristic.true = nonlinear valve characteristic is usedfalse = nonlinear valve characteristic is not used.Typical value = true. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovSteam2}
### GovSteam2

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovSteam2 {

+ dbf : PU [0..1]
+ k : Float [0..1]
+ mnef : PU [0..1]
+ mxef : PU [0..1]
+ pmax : PU [0..1]
+ pmin : PU [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovSteam2 : inherits from
```

Simplified governor.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dbf [0..1] | [PU](#CIM17v40-PU) | Frequency deadband (<i>DBF</i>). Typical value = 0. | |
| k [0..1] | [Float](#CIM17v40-Float) | Governor gain (reciprocal of droop) (<i>K</i>). Typical value = 20. | |
| mnef [0..1] | [PU](#CIM17v40-PU) | Fuel flow maximum negative error value (<i>MN</i><i><sub>EF</sub></i>). Typical value = -1. | |
| mxef [0..1] | [PU](#CIM17v40-PU) | Fuel flow maximum positive error value (<i>MX</i><i><sub>EF</sub></i>). Typical value = 1. | |
| pmax [0..1] | [PU](#CIM17v40-PU) | Maximum fuel flow (<i>P</i><i><sub>MAX</sub></i>) (&gt; GovSteam2.pmin). Typical value = 1. | |
| pmin [0..1] | [PU](#CIM17v40-PU) | Minimum fuel flow (<i>P</i><i><sub>MIN</sub></i>) (&lt; GovSteam2.pmax). Typical value = 0. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Governor lag time constant (<i>T</i><i><sub>1</sub></i>) (&gt; 0). Typical value = 0,45. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Governor lead time constant (<i>T</i><i><sub>2</sub></i>) (&gt;= 0). Typical value = 0. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovSteamBB}
### GovSteamBB

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovSteamBB {

+ fcut : PU [0..1]
+ k2 : PU [0..1]
+ k3 : PU [0..1]
+ kd : PU [0..1]
+ kg : PU [0..1]
+ kls : PU [0..1]
+ kp : PU [0..1]
+ ks : PU [0..1]
+ peflag : Boolean [0..1]
+ pmax : PU [0..1]
+ pmin : PU [0..1]
+ t1 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ t5 : Seconds [0..1]
+ t6 : Seconds [0..1]
+ td : Seconds [0..1]
+ tn : Seconds [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovSteamBB : inherits from
```

European governor model.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| fcut [0..1] | [PU](#CIM17v40-PU) | Frequency deadband (<i>f</i><i><sub>cut</sub></i>) (&gt;= 0). Typical value = 0,002. | |
| k2 [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K2</i>). Typical value = 0,75. | |
| k3 [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K3</i>). Typical value = 0,5. | |
| kd [0..1] | [PU](#CIM17v40-PU) | Gain (<i>Kd</i>). Typical value = 1,0. | |
| kg [0..1] | [PU](#CIM17v40-PU) | Gain (<i>Kg</i>). Typical value = 1,0. | |
| kls [0..1] | [PU](#CIM17v40-PU) | Gain (<i>Kls</i>) (&gt; 0). Typical value = 0,1. | |
| kp [0..1] | [PU](#CIM17v40-PU) | Gain (<i>Kp</i>). Typical value = 1,0. | |
| ks [0..1] | [PU](#CIM17v40-PU) | Gain (<i>Ks</i>). Typical value = 21,0. | |
| peflag [0..1] | [Boolean](#CIM17v40-Boolean) | Electric power input selection (Peflag).true = electric power inputfalse = feedback signal.Typical value = false. | |
| pmax [0..1] | [PU](#CIM17v40-PU) | High power limit (<i>Pmax</i>) (&gt; GovSteamBB.pmin). Typical value = 1,0. | |
| pmin [0..1] | [PU](#CIM17v40-PU) | Low power limit (<i>Pmin</i>) (&lt; GovSteamBB.pmax). Typical value = 0. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T1</i>). Typical value = 0,05. | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T4</i>). Typical value = 0,15. | |
| t5 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T5</i>). Typical value = 12,0. | |
| t6 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T6</i>). Typical value = 0,75. | |
| td [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Td</i>) (&gt; 0). Typical value = 1,0. | |
| tn [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Tn</i>) (&gt; 0). Typical value = 1,0. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovSteamCC}
### GovSteamCC

Inheritance path = [CrossCompoundTurbineGovernorDynamics](#CIM17v40-CrossCompoundTurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovSteamCC {

+ dhp : PU [0..1]
+ dlp : PU [0..1]
+ fhp : PU [0..1]
+ flp : PU [0..1]
+ mwbase : ActivePower [0..1]
+ pmaxhp : PU [0..1]
+ pmaxlp : PU [0..1]
+ rhp : PU [0..1]
+ rlp : PU [0..1]
+ t1hp : Seconds [0..1]
+ t1lp : Seconds [0..1]
+ t3hp : Seconds [0..1]
+ t3lp : Seconds [0..1]
+ t4hp : Seconds [0..1]
+ t4lp : Seconds [0..1]
+ t5hp : Seconds [0..1]
+ t5lp : Seconds [0..1]
}

class CrossCompoundTurbineGovernorDynamics {

}

CrossCompoundTurbineGovernorDynamics <|-- GovSteamCC : inherits from
```

Cross compound turbine governor. Unlike tandem compound units, cross compound units are not on the same shaft.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dhp [0..1] | [PU](#CIM17v40-PU) | HP damping factor (<i>Dhp</i>). Typical value = 0. | |
| dlp [0..1] | [PU](#CIM17v40-PU) | LP damping factor (<i>Dlp</i>). Typical value = 0. | |
| fhp [0..1] | [PU](#CIM17v40-PU) | Fraction of HP power ahead of reheater (<i>Fhp</i>). Typical value = 0,3. | |
| flp [0..1] | [PU](#CIM17v40-PU) | Fraction of LP power ahead of reheater (<i>Flp</i>). Typical value = 0,7. | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| pmaxhp [0..1] | [PU](#CIM17v40-PU) | Maximum HP value position (<i>Pmaxhp</i>). Typical value = 1. | |
| pmaxlp [0..1] | [PU](#CIM17v40-PU) | Maximum LP value position (<i>Pmaxlp</i>). Typical value = 1. | |
| rhp [0..1] | [PU](#CIM17v40-PU) | HP governor droop (<i>Rhp</i>) (&gt; 0). Typical value = 0,05. | |
| rlp [0..1] | [PU](#CIM17v40-PU) | LP governor droop (<i>Rlp</i>) (&gt; 0). Typical value = 0,05. | |
| t1hp [0..1] | [Seconds](#CIM17v40-Seconds) | HP governor time constant (<i>T1hp</i>) (&gt;= 0). Typical value = 0,1. | |
| t1lp [0..1] | [Seconds](#CIM17v40-Seconds) | LP governor time constant (<i>T1lp</i>) (&gt;= 0). Typical value = 0,1. | |
| t3hp [0..1] | [Seconds](#CIM17v40-Seconds) | HP turbine time constant (<i>T3hp</i>) (&gt;= 0). Typical value = 0,1. | |
| t3lp [0..1] | [Seconds](#CIM17v40-Seconds) | LP turbine time constant (<i>T3lp</i>) (&gt;= 0). Typical value = 0,1. | |
| t4hp [0..1] | [Seconds](#CIM17v40-Seconds) | HP turbine time constant (<i>T4hp</i>) (&gt;= 0). Typical value = 0,1. | |
| t4lp [0..1] | [Seconds](#CIM17v40-Seconds) | LP turbine time constant (<i>T4lp</i>) (&gt;= 0). Typical value = 0,1. | |
| t5hp [0..1] | [Seconds](#CIM17v40-Seconds) | HP reheater time constant (<i>T5hp</i>) (&gt;= 0). Typical value = 10. | |
| t5lp [0..1] | [Seconds](#CIM17v40-Seconds) | LP reheater time constant (<i>T5lp</i>) (&gt;= 0). Typical value = 10. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| HighPressureSynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [CrossCompoundTurbineGovernorDynamics](CIM17v40-CrossCompoundTurbineGovernorDynamics) | |
| LowPressureSynchronousMachineDynamics [1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [CrossCompoundTurbineGovernorDynamics](CIM17v40-CrossCompoundTurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovSteamEU}
### GovSteamEU

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovSteamEU {

+ chc : Float [0..1]
+ cho : Float [0..1]
+ cic : PU [0..1]
+ cio : PU [0..1]
+ db1 : PU [0..1]
+ db2 : PU [0..1]
+ hhpmax : PU [0..1]
+ ke : PU [0..1]
+ kfcor : PU [0..1]
+ khp : PU [0..1]
+ klp : PU [0..1]
+ komegacor : PU [0..1]
+ mwbase : ActivePower [0..1]
+ pmax : PU [0..1]
+ prhmax : PU [0..1]
+ simx : PU [0..1]
+ tb : Seconds [0..1]
+ tdp : Seconds [0..1]
+ ten : Seconds [0..1]
+ tf : Seconds [0..1]
+ tfp : Seconds [0..1]
+ thp : Seconds [0..1]
+ tip : Seconds [0..1]
+ tlp : Seconds [0..1]
+ tp : Seconds [0..1]
+ trh : Seconds [0..1]
+ tvhp : Seconds [0..1]
+ tvip : Seconds [0..1]
+ tw : Seconds [0..1]
+ wfmax : PU [0..1]
+ wfmin : PU [0..1]
+ wmax1 : PU [0..1]
+ wmax2 : PU [0..1]
+ wwmax : PU [0..1]
+ wwmin : PU [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovSteamEU : inherits from
```

Simplified boiler and steam turbine with PID governor.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| chc [0..1] | [Float](#CIM17v40-Float) | Control valves rate closing limit (<i>Chc</i>). Unit = PU / s. Typical value = -3,3. | |
| cho [0..1] | [Float](#CIM17v40-Float) | Control valves rate opening limit (<i>Cho</i>). Unit = PU / s. Typical value = 0,17. | |
| cic [0..1] | [PU](#CIM17v40-PU) | Intercept valves rate closing limit (<i>Cic</i>). Typical value = -2,2. | |
| cio [0..1] | [PU](#CIM17v40-PU) | Intercept valves rate opening limit (<i>Cio</i>). Typical value = 0,123. | |
| db1 [0..1] | [PU](#CIM17v40-PU) | Deadband of the frequency corrector (<i>db1</i>). Typical value = 0. | |
| db2 [0..1] | [PU](#CIM17v40-PU) | Deadband of the speed governor (<i>db2</i>). Typical value = 0,0004. | |
| hhpmax [0..1] | [PU](#CIM17v40-PU) | Maximum control valve position (<i>Hhpmax</i>). Typical value = 1. | |
| ke [0..1] | [PU](#CIM17v40-PU) | Gain of the power controller (<i>Ke</i>). Typical value = 0,65. | |
| kfcor [0..1] | [PU](#CIM17v40-PU) | Gain of the frequency corrector (<i>Kfcor</i>). Typical value = 20. | |
| khp [0..1] | [PU](#CIM17v40-PU) | Fraction of total turbine output generated by HP part (<i>Khp</i>). Typical value = 0,277. | |
| klp [0..1] | [PU](#CIM17v40-PU) | Fraction of total turbine output generated by HP part (<i>Klp</i>). Typical value = 0,723. | |
| komegacor [0..1] | [PU](#CIM17v40-PU) | Gain of the speed governor (<i>Kwcor</i>). Typical value = 20. | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| pmax [0..1] | [PU](#CIM17v40-PU) | Maximal active power of the turbine (<i>Pmax</i>). Typical value = 1. | |
| prhmax [0..1] | [PU](#CIM17v40-PU) | Maximum low pressure limit (<i>Prhmax</i>). Typical value = 1,4. | |
| simx [0..1] | [PU](#CIM17v40-PU) | Intercept valves transfer limit (<i>Simx</i>). Typical value = 0,425. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Boiler time constant (<i>Tb</i>) (&gt;= 0). Typical value = 100. | |
| tdp [0..1] | [Seconds](#CIM17v40-Seconds) | Derivative time constant of the power controller (<i>Tdp</i>) (&gt;= 0). Typical value = 0. | |
| ten [0..1] | [Seconds](#CIM17v40-Seconds) | Electro hydraulic transducer (<i>Ten</i>) (&gt;= 0). Typical value = 0,1. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Frequency transducer time constant (<i>Tf</i>) (&gt;= 0). Typical value = 0. | |
| tfp [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant of the power controller (<i>Tfp</i>) (&gt;= 0). Typical value = 0. | |
| thp [0..1] | [Seconds](#CIM17v40-Seconds) | High pressure (HP) time constant of the turbine (<i>Thp</i>) (&gt;= 0). Typical value = 0,31. | |
| tip [0..1] | [Seconds](#CIM17v40-Seconds) | Integral time constant of the power controller (<i>Tip</i>) (&gt;= 0). Typical value = 2. | |
| tlp [0..1] | [Seconds](#CIM17v40-Seconds) | Low pressure (LP) time constant of the turbine (<i>Tlp</i>) (&gt;= 0). Typical value = 0,45. | |
| tp [0..1] | [Seconds](#CIM17v40-Seconds) | Power transducer time constant (<i>Tp</i>) (&gt;= 0). Typical value = 0,07. | |
| trh [0..1] | [Seconds](#CIM17v40-Seconds) | Reheater time constant of the turbine (<i>Trh</i>) (&gt;= 0). Typical value = 8. | |
| tvhp [0..1] | [Seconds](#CIM17v40-Seconds) | Control valves servo time constant (<i>Tvhp</i>) (&gt;= 0). Typical value = 0,1. | |
| tvip [0..1] | [Seconds](#CIM17v40-Seconds) | Intercept valves servo time constant (<i>Tvip</i>) (&gt;= 0). Typical value = 0,15. | |
| tw [0..1] | [Seconds](#CIM17v40-Seconds) | Speed transducer time constant (<i>Tw</i>) (&gt;= 0). Typical value = 0,02. | |
| wfmax [0..1] | [PU](#CIM17v40-PU) | Upper limit for frequency correction (<i>Wfmax</i>) (&gt; GovSteamEU.wfmin). Typical value = 0,05. | |
| wfmin [0..1] | [PU](#CIM17v40-PU) | Lower limit for frequency correction (<i>Wfmin</i>) (&lt; GovSteamEU.wfmax). Typical value = -0,05. | |
| wmax1 [0..1] | [PU](#CIM17v40-PU) | Emergency speed control lower limit (<i>wmax1</i>). Typical value = 1,025. | |
| wmax2 [0..1] | [PU](#CIM17v40-PU) | Emergency speed control upper limit (<i>wmax2</i>). Typical value = 1,05. | |
| wwmax [0..1] | [PU](#CIM17v40-PU) | Upper limit for the speed governor (<i>Wwmax</i>) (&gt; GovSteamEU.wwmin). Typical value = 0,1. | |
| wwmin [0..1] | [PU](#CIM17v40-PU) | Lower limit for the speed governor frequency correction (<i>Wwmin</i>) (&lt; GovSteamEU.wwmax). Typical value = -1. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovSteamFV2}
### GovSteamFV2

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovSteamFV2 {

+ dt : PU [0..1]
+ k : PU [0..1]
+ mwbase : ActivePower [0..1]
+ r : PU [0..1]
+ t1 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ tt : Seconds [0..1]
+ vmax : PU [0..1]
+ vmin : PU [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovSteamFV2 : inherits from
```

Steam turbine governor with reheat time constants and modelling of the effects of fast valve closing to reduce mechanical power.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dt [0..1] | [PU](#CIM17v40-PU) | (<i>Dt</i>). | |
| k [0..1] | [PU](#CIM17v40-PU) | Fraction of the turbine power developed by turbine sections not involved in fast valving (<i>K</i>). | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Alternate base used instead of machine base in equipment model if necessary (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| r [0..1] | [PU](#CIM17v40-PU) | (<i>R</i>). | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Governor time constant (<i>T1</i>) (&gt;= 0). | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Reheater time constant (<i>T3</i>) (&gt;= 0). | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Time after initial time for valve to close (<i>Ta</i>) (&gt;= 0). | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Time after initial time for valve to begin opening (<i>Tb</i>) (&gt;= 0). | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Time after initial time for valve to become fully open (<i>Tc</i>) (&gt;= 0). | |
| tt [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant with which power falls off after intercept valve closure (<i>Tt</i>) (&gt;= 0). | |
| vmax [0..1] | [PU](#CIM17v40-PU) | (<i>Vmax</i>) (&gt; GovSteamFV2.vmin). | |
| vmin [0..1] | [PU](#CIM17v40-PU) | (<i>Vmin</i>) (&lt; GovSteamFV2.vmax). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovSteamFV3}
### GovSteamFV3

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovSteamFV3 {

+ gv1 : PU [0..1]
+ gv2 : PU [0..1]
+ gv3 : PU [0..1]
+ gv4 : PU [0..1]
+ gv5 : PU [0..1]
+ gv6 : PU [0..1]
+ k : PU [0..1]
+ k1 : PU [0..1]
+ k2 : PU [0..1]
+ k3 : PU [0..1]
+ mwbase : ActivePower [0..1]
+ pgv1 : PU [0..1]
+ pgv2 : PU [0..1]
+ pgv3 : PU [0..1]
+ pgv4 : PU [0..1]
+ pgv5 : PU [0..1]
+ pgv6 : PU [0..1]
+ pmax : PU [0..1]
+ pmin : PU [0..1]
+ prmax : PU [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ t5 : Seconds [0..1]
+ t6 : Seconds [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ uc : Float [0..1]
+ uo : Float [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovSteamFV3 : inherits from
```

Simplified GovSteamIEEE1 steam turbine governor with Prmax limit and fast valving.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| gv1 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain valve position point 1 (<i>GV1</i>). Typical value = 0. | |
| gv2 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain valve position point 2 (<i>GV2</i>). Typical value = 0,4. | |
| gv3 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain valve position point 3 (<i>GV3</i>). Typical value = 0,5. | |
| gv4 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain valve position point 4 (<i>GV4</i>). Typical value = 0,6. | |
| gv5 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain valve position point 5 (<i>GV5</i>). Typical value = 1. | |
| gv6 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain valve position point 6 (<i>GV6</i>). Typical value = 0. | |
| k [0..1] | [PU](#CIM17v40-PU) | Governor gain, (reciprocal of droop) (<i>K</i>). Typical value = 20. | |
| k1 [0..1] | [PU](#CIM17v40-PU) | Fraction of turbine power developed after first boiler pass (<i>K1</i>). Typical value = 0,2. | |
| k2 [0..1] | [PU](#CIM17v40-PU) | Fraction of turbine power developed after second boiler pass (<i>K2</i>). Typical value = 0,2. | |
| k3 [0..1] | [PU](#CIM17v40-PU) | Fraction of hp turbine power developed after crossover or third boiler pass (<i>K3</i>). Typical value = 0,6. | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| pgv1 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain power value point 1 (<i>Pgv1</i>). Typical value = 0. | |
| pgv2 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain power value point 2 (<i>Pgv2</i>). Typical value = 0,75. | |
| pgv3 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain power value point 3 (<i>Pgv3</i>). Typical value = 0,91. | |
| pgv4 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain power value point 4 (<i>Pgv4</i>). Typical value = 0,98. | |
| pgv5 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain power value point 5 (<i>Pgv5</i>). Typical value = 1. | |
| pgv6 [0..1] | [PU](#CIM17v40-PU) | Nonlinear gain power value point 6 (<i>Pgv6</i>). Typical value = 0. | |
| pmax [0..1] | [PU](#CIM17v40-PU) | Maximum valve opening, PU of <i>MWbase</i> (<i>Pmax</i>) (&gt; GovSteamFV3.pmin). Typical value = 1. | |
| pmin [0..1] | [PU](#CIM17v40-PU) | Minimum valve opening, PU of <i>MWbase</i> (<i>Pmin</i>) (&lt; GovSteamFV3.pmax). Typical value = 0. | |
| prmax [0..1] | [PU](#CIM17v40-PU) | Max. pressure in reheater (<i>Prmax</i>). Typical value = 1. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Governor lead time constant (<i>T1</i>) (&gt;= 0). Typical value = 0. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Governor lag time constant (<i>T2</i>) (&gt;= 0). Typical value = 0. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Valve positioner time constant (<i>T3</i>) (&gt; 0). Typical value = 0. | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Inlet piping/steam bowl time constant (<i>T4</i>) (&gt;= 0). Typical value = 0,2. | |
| t5 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant of second boiler pass (i.e. reheater) (<i>T5</i>) (&gt; 0 if fast valving is used, otherwise &gt;= 0). Typical value = 0,5. | |
| t6 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant of crossover or third boiler pass (<i>T6</i>) (&gt;= 0). Typical value = 10. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Time to close intercept valve (IV) (<i>Ta</i>) (&gt;= 0). Typical value = 0,97. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Time until IV starts to reopen (<i>Tb</i>) (&gt;= 0). Typical value = 0,98. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Time until IV is fully open (<i>Tc</i>) (&gt;= 0). Typical value = 0,99. | |
| uc [0..1] | [Float](#CIM17v40-Float) | Maximum valve closing velocity (<i>Uc</i>). Unit = PU / s. Typical value = -1. | |
| uo [0..1] | [Float](#CIM17v40-Float) | Maximum valve opening velocity (<i>Uo</i>). Unit = PU / s. Typical value = 0,1. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovSteamFV4}
### GovSteamFV4

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovSteamFV4 {

+ cpsmn : PU [0..1]
+ cpsmx : PU [0..1]
+ crmn : PU [0..1]
+ crmx : PU [0..1]
+ kdc : PU [0..1]
+ kf1 : PU [0..1]
+ kf3 : PU [0..1]
+ khp : PU [0..1]
+ kic : PU [0..1]
+ kip : PU [0..1]
+ kit : PU [0..1]
+ kmp1 : PU [0..1]
+ kmp2 : PU [0..1]
+ kpc : PU [0..1]
+ kpp : PU [0..1]
+ kpt : PU [0..1]
+ krc : PU [0..1]
+ ksh : PU [0..1]
+ lpi : PU [0..1]
+ lps : PU [0..1]
+ mnef : PU [0..1]
+ mxef : PU [0..1]
+ pr1 : PU [0..1]
+ pr2 : PU [0..1]
+ psmn : PU [0..1]
+ rsmimn : PU [0..1]
+ rsmimx : PU [0..1]
+ rvgmn : PU [0..1]
+ rvgmx : PU [0..1]
+ srmn : PU [0..1]
+ srmx : PU [0..1]
+ srsmp : PU [0..1]
+ svmn : Float [0..1]
+ svmx : Float [0..1]
+ ta : Seconds [0..1]
+ tam : Seconds [0..1]
+ tc : Seconds [0..1]
+ tcm : Seconds [0..1]
+ tdc : Seconds [0..1]
+ tf1 : Seconds [0..1]
+ tf2 : Seconds [0..1]
+ thp : Seconds [0..1]
+ tmp : Seconds [0..1]
+ trh : Seconds [0..1]
+ tv : Seconds [0..1]
+ ty : Seconds [0..1]
+ y : PU [0..1]
+ yhpmn : PU [0..1]
+ yhpmx : PU [0..1]
+ ympmn : PU [0..1]
+ ympmx : PU [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovSteamFV4 : inherits from
```

Detailed electro-hydraulic governor for steam unit.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| cpsmn [0..1] | [PU](#CIM17v40-PU) | Minimum value of pressure regulator output (<i>Cpsmn</i>). Typical value = -1. | |
| cpsmx [0..1] | [PU](#CIM17v40-PU) | Maximum value of pressure regulator output (<i>Cpsmx</i>). Typical value = 1. | |
| crmn [0..1] | [PU](#CIM17v40-PU) | Minimum value of regulator set-point (<i>Crmn</i>). Typical value = 0. | |
| crmx [0..1] | [PU](#CIM17v40-PU) | Maximum value of regulator set-point (<i>Crmx</i>). Typical value = 1,2. | |
| kdc [0..1] | [PU](#CIM17v40-PU) | Derivative gain of pressure regulator (<i>Kdc</i>). Typical value = 1. | |
| kf1 [0..1] | [PU](#CIM17v40-PU) | Frequency bias (reciprocal of droop) (<i>Kf1</i>). Typical value = 20. | |
| kf3 [0..1] | [PU](#CIM17v40-PU) | Frequency control (reciprocal of droop) (<i>Kf3</i>). Typical value = 20. | |
| khp [0..1] | [PU](#CIM17v40-PU) | Fraction of total turbine output generated by HP part (<i>Khp</i>). Typical value = 0,35. | |
| kic [0..1] | [PU](#CIM17v40-PU) | Integral gain of pressure regulator (<i>Kic</i>). Typical value = 0,0033. | |
| kip [0..1] | [PU](#CIM17v40-PU) | Integral gain of pressure feedback regulator (<i>Kip</i>). Typical value = 0,5. | |
| kit [0..1] | [PU](#CIM17v40-PU) | Integral gain of electro-hydraulic regulator (<i>Kit</i>). Typical value = 0,04. | |
| kmp1 [0..1] | [PU](#CIM17v40-PU) | First gain coefficient of intercept valves characteristic (<i>Kmp1</i>). Typical value = 0,5. | |
| kmp2 [0..1] | [PU](#CIM17v40-PU) | Second gain coefficient of intercept valves characteristic (<i>Kmp2</i>). Typical value = 3,5. | |
| kpc [0..1] | [PU](#CIM17v40-PU) | Proportional gain of pressure regulator (<i>Kpc</i>). Typical value = 0,5. | |
| kpp [0..1] | [PU](#CIM17v40-PU) | Proportional gain of pressure feedback regulator (<i>Kpp</i>). Typical value = 1. | |
| kpt [0..1] | [PU](#CIM17v40-PU) | Proportional gain of electro-hydraulic regulator (<i>Kpt</i>). Typical value = 0,3. | |
| krc [0..1] | [PU](#CIM17v40-PU) | Maximum variation of fuel flow (<i>Krc</i>). Typical value = 0,05. | |
| ksh [0..1] | [PU](#CIM17v40-PU) | Pressure loss due to flow friction in the boiler tubes (<i>Ksh</i>). Typical value = 0,08. | |
| lpi [0..1] | [PU](#CIM17v40-PU) | Maximum negative power error (<i>Lpi</i>). Typical value = -0,15. | |
| lps [0..1] | [PU](#CIM17v40-PU) | Maximum positive power error (<i>Lps</i>). Typical value = 0,03. | |
| mnef [0..1] | [PU](#CIM17v40-PU) | Lower limit for frequency correction (<i>MN</i><i><sub>EF</sub></i>). Typical value = -0,05. | |
| mxef [0..1] | [PU](#CIM17v40-PU) | Upper limit for frequency correction (<i>MX</i><i><sub>EF</sub></i>). Typical value = 0,05. | |
| pr1 [0..1] | [PU](#CIM17v40-PU) | First value of pressure set point static characteristic (<i>Pr1</i>). Typical value = 0,2. | |
| pr2 [0..1] | [PU](#CIM17v40-PU) | Second value of pressure set point static characteristic, corresponding to <i>Ps0</i> = 1,0 PU (<i>Pr2</i>). Typical value = 0,75. | |
| psmn [0..1] | [PU](#CIM17v40-PU) | Minimum value of pressure set point static characteristic (<i>Psmn</i>). Typical value = 1. | |
| rsmimn [0..1] | [PU](#CIM17v40-PU) | Minimum value of integral regulator (<i>Rsmimn</i>). Typical value = 0. | |
| rsmimx [0..1] | [PU](#CIM17v40-PU) | Maximum value of integral regulator (<i>Rsmimx</i>). Typical value = 1,1. | |
| rvgmn [0..1] | [PU](#CIM17v40-PU) | Minimum value of integral regulator (<i>Rvgmn</i>). Typical value = 0. | |
| rvgmx [0..1] | [PU](#CIM17v40-PU) | Maximum value of integral regulator (<i>Rvgmx</i>). Typical value = 1,2. | |
| srmn [0..1] | [PU](#CIM17v40-PU) | Minimum valve opening (<i>Srmn</i>). Typical value = 0. | |
| srmx [0..1] | [PU](#CIM17v40-PU) | Maximum valve opening (<i>Srmx</i>). Typical value = 1,1. | |
| srsmp [0..1] | [PU](#CIM17v40-PU) | Intercept valves characteristic discontinuity point (<i>Srsmp</i>). Typical value = 0,43. | |
| svmn [0..1] | [Float](#CIM17v40-Float) | Maximum regulator gate closing velocity (<i>Svmn</i>). Typical value = -0,0333. | |
| svmx [0..1] | [Float](#CIM17v40-Float) | Maximum regulator gate opening velocity (<i>Svmx</i>). Typical value = 0,0333. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Control valves rate opening time (<i>Ta</i>) (&gt;= 0). Typical value = 0,8. | |
| tam [0..1] | [Seconds](#CIM17v40-Seconds) | Intercept valves rate opening time (<i>Tam</i>) (&gt;= 0). Typical value = 0,8. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Control valves rate closing time (<i>Tc</i>) (&gt;= 0). Typical value = 0,5. | |
| tcm [0..1] | [Seconds](#CIM17v40-Seconds) | Intercept valves rate closing time (<i>Tcm</i>) (&gt;= 0). Typical value = 0,5. | |
| tdc [0..1] | [Seconds](#CIM17v40-Seconds) | Derivative time constant of pressure regulator (<i>Tdc</i>) (&gt;= 0). Typical value = 90. | |
| tf1 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant of fuel regulation (<i>Tf1</i>) (&gt;= 0). Typical value = 10. | |
| tf2 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant of steam chest (<i>Tf2</i>) (&gt;= 0). Typical value = 10. | |
| thp [0..1] | [Seconds](#CIM17v40-Seconds) | High pressure (HP) time constant of the turbine (<i>Thp</i>) (&gt;= 0). Typical value = 0,15. | |
| tmp [0..1] | [Seconds](#CIM17v40-Seconds) | Low pressure (LP) time constant of the turbine (<i>Tmp</i>) (&gt;= 0). Typical value = 0,4. | |
| trh [0..1] | [Seconds](#CIM17v40-Seconds) | Reheater time constant of the turbine (<i>Trh</i>) (&gt;= 0). Typical value = 10. | |
| tv [0..1] | [Seconds](#CIM17v40-Seconds) | Boiler time constant (<i>Tv</i>) (&gt;= 0). Typical value = 60. | |
| ty [0..1] | [Seconds](#CIM17v40-Seconds) | Control valves servo time constant (<i>Ty</i>) (&gt;= 0). Typical value = 0,1. | |
| y [0..1] | [PU](#CIM17v40-PU) | Coefficient of linearized equations of turbine (Stodola formulation) (<i>Y</i>). Typical value = 0,13. | |
| yhpmn [0..1] | [PU](#CIM17v40-PU) | Minimum control valve position (<i>Yhpmn</i>). Typical value = 0. | |
| yhpmx [0..1] | [PU](#CIM17v40-PU) | Maximum control valve position (<i>Yhpmx</i>). Typical value = 1,1. | |
| ympmn [0..1] | [PU](#CIM17v40-PU) | Minimum intercept valve position (<i>Ympmn</i>). Typical value = 0. | |
| ympmx [0..1] | [PU](#CIM17v40-PU) | Maximum intercept valve position (<i>Ympmx</i>). Typical value = 1,1. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovSteamIEEE1}
### GovSteamIEEE1

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovSteamIEEE1 {

+ k : PU [0..1]
+ k1 : Float [0..1]
+ k2 : Float [0..1]
+ k3 : Float [0..1]
+ k4 : Float [0..1]
+ k5 : Float [0..1]
+ k6 : Float [0..1]
+ k7 : Float [0..1]
+ k8 : Float [0..1]
+ mwbase : ActivePower [0..1]
+ pmax : PU [0..1]
+ pmin : PU [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ t5 : Seconds [0..1]
+ t6 : Seconds [0..1]
+ t7 : Seconds [0..1]
+ uc : Float [0..1]
+ uo : Float [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovSteamIEEE1 : inherits from
```

IEEE steam turbine governor model.

Ref<font color="#0f0f0f">erence: IEEE Transactions on Power Apparatus and Systems, November/December 1973, Volume PAS-92, Number 6, <i><u>Dynamic Models for Steam and Hydro Turbines in Power System Studies</u></i>, page 1904.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| k [0..1] | [PU](#CIM17v40-PU) | Governor gain (reciprocal of droop) (<i>K</i>) (&gt; 0). Typical value = 25. | |
| k1 [0..1] | [Float](#CIM17v40-Float) | Fraction of HP shaft power after first boiler pass (<i>K1</i>). Typical value = 0,2. | |
| k2 [0..1] | [Float](#CIM17v40-Float) | Fraction of LP shaft power after first boiler pass (<i>K2</i>). Typical value = 0. | |
| k3 [0..1] | [Float](#CIM17v40-Float) | Fraction of HP shaft power after second boiler pass (<i>K3</i>). Typical value = 0,3. | |
| k4 [0..1] | [Float](#CIM17v40-Float) | Fraction of LP shaft power after second boiler pass (<i>K4</i>). Typical value = 0. | |
| k5 [0..1] | [Float](#CIM17v40-Float) | Fraction of HP shaft power after third boiler pass (<i>K5</i>). Typical value = 0,5. | |
| k6 [0..1] | [Float](#CIM17v40-Float) | Fraction of LP shaft power after third boiler pass (<i>K6</i>). Typical value = 0. | |
| k7 [0..1] | [Float](#CIM17v40-Float) | Fraction of HP shaft power after fourth boiler pass (<i>K7</i>). Typical value = 0. | |
| k8 [0..1] | [Float](#CIM17v40-Float) | Fraction of LP shaft power after fourth boiler pass (<i>K8</i>). Typical value = 0. | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0)<i>. </i>Unit = MW. | |
| pmax [0..1] | [PU](#CIM17v40-PU) | Maximum valve opening (<i>Pmax</i>) (&gt; GovSteamIEEE1.pmin). Typical value = 1. | |
| pmin [0..1] | [PU](#CIM17v40-PU) | Minimum valve opening (<i>Pmin</i>) (&gt;= 0 and &lt; GovSteamIEEE1.pmax). Typical value = 0. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Governor lag time constant (<i>T1</i>) (&gt;= 0). Typical value = 0. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Governor lead time constant (<i>T2</i>) (&gt;= 0). Typical value = 0. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Valve positioner time constant (<i>T3</i>) (&gt; 0). Typical value = 0,1. | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Inlet piping/steam bowl time constant (<i>T4</i>) (&gt;= 0). Typical value = 0,3. | |
| t5 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant of second boiler pass (<i>T5</i>) (&gt;= 0). Typical value = 5. | |
| t6 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant of third boiler pass (<i>T6</i>) (&gt;= 0). Typical value = 0,5. | |
| t7 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant of fourth boiler pass (<i>T7</i>) (&gt;= 0). Typical value = 0. | |
| uc [0..1] | [Float](#CIM17v40-Float) | Maximum valve closing velocity (<i>Uc</i>) (&lt; 0). Unit = PU / s. Typical value = -10. | |
| uo [0..1] | [Float](#CIM17v40-Float) | Maximum valve opening velocity (<i>Uo</i>) (&gt; 0). Unit = PU / s. Typical value = 1. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GovSteamSGO}
### GovSteamSGO

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GovSteamSGO {

+ k1 : PU [0..1]
+ k2 : PU [0..1]
+ k3 : PU [0..1]
+ mwbase : ActivePower [0..1]
+ pmax : PU [0..1]
+ pmin : Seconds [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ t5 : Seconds [0..1]
+ t6 : Seconds [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- GovSteamSGO : inherits from
```

Simplified steam turbine governor.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| k1 [0..1] | [PU](#CIM17v40-PU) | One / PU regulation (<i>K1</i>). | |
| k2 [0..1] | [PU](#CIM17v40-PU) | Fraction (<i>K2</i>). | |
| k3 [0..1] | [PU](#CIM17v40-PU) | Fraction (<i>K3</i>). | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| pmax [0..1] | [PU](#CIM17v40-PU) | Upper power limit (<i>Pmax</i>) (&gt; GovSteamSGO.pmin). | |
| pmin [0..1] | [Seconds](#CIM17v40-Seconds) | Lower power limit (<i>Pmin</i>) (&gt;= 0 and &lt; GovSteamSGO.pmax). | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Controller lag (<i>T1</i>) (&gt;= 0). | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Controller lead compensation (<i>T2</i>) (&gt;= 0). | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Governor lag (<i>T3</i>) (&gt; 0). | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Delay due to steam inlet volumes associated with steam chest and inlet piping (<i>T4</i>) (&gt;= 0). | |
| t5 [0..1] | [Seconds](#CIM17v40-Seconds) | Reheater delay including hot and cold leads (<i>T5</i>) (&gt;= 0). | |
| t6 [0..1] | [Seconds](#CIM17v40-Seconds) | Delay due to IP-LP turbine, crossover pipes and LP end hoods (<i>T6</i>) (&gt;= 0). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GrossToNetActivePowerCurve}
### GrossToNetActivePowerCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GrossToNetActivePowerCurve {

}

class Curve {

}

Curve <|-- GrossToNetActivePowerCurve : inherits from
class GeneratingUnit {

}

GrossToNetActivePowerCurve --> "1" GeneratingUnit : GeneratingUnit
```

Relationship between the generating unit's gross active power output on the X-axis (measured at the terminals of the machine(s)) and the generating unit's net active power output on the Y-axis (based on utility-defined measurements at the power station). Station service loads, when modelled, should be treated as non-conforming bus loads. There may be more than one curve, depending on the auxiliary equipment that is in service.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `GeneratingUnit [1]` (OfAggregate) | [GeneratingUnit](#CIM17v40-GeneratingUnit) | A generating unit may have a gross active power to net active power curve, describing the losses and auxiliary power requirements of the unit. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Ground}
### Ground

Inheritance path = [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Ground {

}

class ConductingEquipment {

}

ConductingEquipment <|-- Ground : inherits from
class GroundAction {

}

Ground --> "0..1" GroundAction : GroundAction
```

A point where the system is grounded used for connecting conducting equipment to ground. The power system model can have any number of grounds.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| GroundAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | Action taken with this ground. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GroundAction}
### GroundAction

Inheritance path = [SwitchingAction](#CIM17v40-SwitchingAction) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GroundAction {

+ kind : enum:TempEquipActionKind [0..1]
}

class SwitchingAction {

}

SwitchingAction <|-- GroundAction : inherits from
class ACLineSegment {

}

GroundAction --> "0..1" ACLineSegment : AlongACLineSegment
class Ground {

}

GroundAction --> "0..1" Ground : Ground
class ConductingEquipment {

}

GroundAction --> "0..1" ConductingEquipment : GroundedEquipment
```

Action on ground as a switching step.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [TempEquipActionKind](#CIM17v40-TempEquipActionKind) | Switching action to perform. | |
| AlongACLineSegment [0..1] | [ACLineSegment](#CIM17v40-ACLineSegment) | The line segment that this ground action will affect. This is the only way to access relationship to clamp in case the ground needs to be placed along the line segment. | |
| Ground [0..1] | [Ground](#CIM17v40-Ground) | Ground on which this action is taken. | |
| GroundedEquipment [0..1] | [ConductingEquipment](#CIM17v40-ConductingEquipment) | Equipment being grounded with this operation. In case of placing a ground anywhere along a line segment, you must use the clamp (to get the distance from one terminal), so use the explicit relation with line segment. In all other cases (including placing the ground at a line segment terminal), reference to one or more conducting equipment is sufficient. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| executedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| issuedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| plannedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| Operator [0..1] | [Operator](#CIM17v40-Operator) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingEvent [0..1] | [SwitchingEvent](#CIM17v40-SwitchingEvent) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingStep [0..1] | [SwitchingStep](#CIM17v40-SwitchingStep) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GroundDisconnector}
### GroundDisconnector

Inheritance path = [Switch](#CIM17v40-Switch) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GroundDisconnector {

}

class Switch {

}

Switch <|-- GroundDisconnector : inherits from
```

A manually operated or motor operated mechanical switching device used for isolating a circuit or equipment from ground.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| locked [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| normalOpen [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| open [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [Switch](CIM17v40-Switch) | |
| retained [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| `switchOnCount [0..1]` (deprecated) | [Integer](#CIM17v40-Integer) | see [Switch](#CIM17v40-Switch) | |
| `switchOnDate [0..1]` (deprecated) | [DateTime](#CIM17v40-DateTime) | see [Switch](#CIM17v40-Switch) | |
| `CompositeSwitch [0..1]` (OfAggregate) | [CompositeSwitch](#CIM17v40-CompositeSwitch) | see [Switch](CIM17v40-Switch) | |
| SwitchAction [0..1] | [SwitchAction](#CIM17v40-SwitchAction) | see [Switch](CIM17v40-Switch) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-GroundingImpedance}
### GroundingImpedance

Inheritance path = [EarthFaultCompensator](#CIM17v40-EarthFaultCompensator) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class GroundingImpedance {

+ x : Reactance [0..1]
}

class EarthFaultCompensator {

}

EarthFaultCompensator <|-- GroundingImpedance : inherits from
```

A fixed impedance device used for grounding.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| x [0..1] | [Reactance](#CIM17v40-Reactance) | Reactance of device. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| r [0..1] | [Resistance](#CIM17v40-Resistance) | see [EarthFaultCompensator](CIM17v40-EarthFaultCompensator) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-HVDCDynamics}
### HVDCDynamics

Inheritance path = [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class HVDCDynamics {

}

class DynamicsFunctionBlock {

}

DynamicsFunctionBlock <|-- HVDCDynamics : inherits from
```

HVDC whose behaviour is described by reference to a standard model <font color="#0f0f0f">or by definition of a user-defined model.</font>


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-HVDCLookUpTable}
### HVDCLookUpTable


```mermaid
classDiagram
direction TB

class HVDCLookUpTable {

+ functionKind : enum:LookUpTableFunctionKind [0..1]
+ input : Float [0..1]
+ output : Float [0..1]
+ sequence : Integer [0..1]
}

class Qregulator {

}

HVDCLookUpTable --> "0..1" Qregulator : Qregulator
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| functionKind [0..1] | [LookUpTableFunctionKind](#CIM17v40-LookUpTableFunctionKind) | | |
| input [0..1] | [Float](#CIM17v40-Float) | | |
| output [0..1] | [Float](#CIM17v40-Float) | | |
| sequence [0..1] | [Integer](#CIM17v40-Integer) | | |
| `Qregulator [0..1]` (informative) | [Qregulator](#CIM17v40-Qregulator) | | |

{#CIM17v40-Hazard}
### Hazard

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Hazard {

+ type : String [0..1]
+ status : Status [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Hazard : inherits from
class Incident {

}

Hazard --> "0..1" Incident : Incident
class TroubleTicket {

}

Hazard --> "0..1" TroubleTicket : TroubleTicket
```

An object or a condition that is a danger for causing loss or perils to an asset and/or people.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| type [0..1] | [String](#CIM17v40-String) | Type of this hazard. | |
| Incident [0..1] | [Incident](#CIM17v40-Incident) | | |
| status [0..1] | [Status](#CIM17v40-Status) | Status of this hazard. | |
| TroubleTicket [0..1] | [TroubleTicket](#CIM17v40-TroubleTicket) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-HealthScore}
### HealthScore

Inheritance path = [AggregateScore](#CIM17v40-AggregateScore) => [AnalyticScore](#CIM17v40-AnalyticScore) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class HealthScore {

}

class AggregateScore {

}

AggregateScore <|-- HealthScore : inherits from
class RiskScore {

}

HealthScore --> "0..1" RiskScore : AssetRiskScore
```

Score that is indicative of the health of one or more assets.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetRiskScore [0..1] | [RiskScore](#CIM17v40-RiskScore) | Risk score with which this health score is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| calculationDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [AnalyticScore](#CIM17v40-AnalyticScore) | |
| effectiveDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [AnalyticScore](#CIM17v40-AnalyticScore) | |
| value [0..1] | [Float](#CIM17v40-Float) | see [AnalyticScore](#CIM17v40-AnalyticScore) | |
| Analytic [0..1] | [Analytic](#CIM17v40-Analytic) | see [AnalyticScore](CIM17v40-AnalyticScore) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [AnalyticScore](CIM17v40-AnalyticScore) | |
| AssetAggregateScore [0..1] | [AggregateScore](#CIM17v40-AggregateScore) | see [AnalyticScore](CIM17v40-AnalyticScore) | |
| AssetGroup [0..1] | [AssetGroup](#CIM17v40-AssetGroup) | see [AnalyticScore](CIM17v40-AnalyticScore) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-HeatInputCurve}
### HeatInputCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class HeatInputCurve {

+ auxPowerMult : PU [0..1]
+ auxPowerOffset : ActivePower [0..1]
+ heatInputEff : PU [0..1]
+ heatInputOffset : HeatRate [0..1]
+ isNetGrossP : Boolean [0..1]
}

class Curve {

}

Curve <|-- HeatInputCurve : inherits from
class ThermalGeneratingUnit {

}

HeatInputCurve --> "1" ThermalGeneratingUnit : ThermalGeneratingUnit
```

Relationship between unit heat input in energy per time for main fuel (Y1-axis) and supplemental fuel (Y2-axis) versus unit output in active power (X-axis). The quantity of main fuel used to sustain generation at this output level is prorated for throttling between definition points. The quantity of supplemental fuel used at this output level is fixed and not prorated.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| auxPowerMult [0..1] | [PU](#CIM17v40-PU) | Power output - auxiliary power multiplier adjustment factor. | |
| auxPowerOffset [0..1] | [ActivePower](#CIM17v40-ActivePower) | Power output - auxiliary power offset adjustment factor. | |
| heatInputEff [0..1] | [PU](#CIM17v40-PU) | Heat input - efficiency multiplier adjustment factor. | |
| heatInputOffset [0..1] | [HeatRate](#CIM17v40-HeatRate) | Heat input - offset adjustment factor. | |
| isNetGrossP [0..1] | [Boolean](#CIM17v40-Boolean) | Flag is set to true when output is expressed in net active power. | |
| `ThermalGeneratingUnit [1]` (OfAggregate) | [ThermalGeneratingUnit](#CIM17v40-ThermalGeneratingUnit) | A thermal generating unit may have a heat input curve. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-HeatRateCurve}
### HeatRateCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class HeatRateCurve {

+ isNetGrossP : Boolean [0..1]
}

class Curve {

}

Curve <|-- HeatRateCurve : inherits from
class ThermalGeneratingUnit {

}

HeatRateCurve --> "1" ThermalGeneratingUnit : ThermalGeneratingUnit
```

Relationship between unit heat rate per active power (Y-axis) and unit output (X-axis). The heat input is from all fuels.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| isNetGrossP [0..1] | [Boolean](#CIM17v40-Boolean) | Flag is set to true when output is expressed in net active power. | |
| `ThermalGeneratingUnit [1]` (OfAggregate) | [ThermalGeneratingUnit](#CIM17v40-ThermalGeneratingUnit) | A thermal generating unit may have a heat rate curve. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-HeatRecoveryBoiler}
### HeatRecoveryBoiler

Inheritance path = [FossilSteamSupply](#CIM17v40-FossilSteamSupply) => [SteamSupply](#CIM17v40-SteamSupply) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class HeatRecoveryBoiler {

+ steamSupplyRating2 : Float [0..1]
}

class FossilSteamSupply {

}

FossilSteamSupply <|-- HeatRecoveryBoiler : inherits from
```

The heat recovery system associated with combustion turbines in order to produce steam for combined cycle plants.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| steamSupplyRating2 [0..1] | [Float](#CIM17v40-Float) | The steam supply rating in kilopounds per hour, if dual pressure boiler. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| auxPowerVersusFrequency [0..1] | [PU](#CIM17v40-PU) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| auxPowerVersusVoltage [0..1] | [PU](#CIM17v40-PU) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| boilerControlMode [0..1] | [BoilerControlMode](#CIM17v40-BoilerControlMode) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| controlErrorBiasP [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| controlIC [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| controlPC [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| controlPEB [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| controlPED [0..1] | [PU](#CIM17v40-PU) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| controlTC [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| feedWaterIG [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| feedWaterPG [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| feedWaterTC [0..1] | [Seconds](#CIM17v40-Seconds) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| fuelDemandLimit [0..1] | [PU](#CIM17v40-PU) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| fuelSupplyDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| fuelSupplyTC [0..1] | [Seconds](#CIM17v40-Seconds) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| maxErrorRateP [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| mechPowerSensorLag [0..1] | [Seconds](#CIM17v40-Seconds) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| minErrorRateP [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| pressureCtrlDG [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| pressureCtrlIG [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| pressureCtrlPG [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| pressureFeedback [0..1] | [Integer](#CIM17v40-Integer) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| superHeater1Capacity [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| superHeater2Capacity [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| superHeaterPipePD [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| throttlePressureSP [0..1] | [PU](#CIM17v40-PU) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| steamSupplyRating [0..1] | [Float](#CIM17v40-Float) | see [SteamSupply](#CIM17v40-SteamSupply) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-HostControlArea}
### (informative) HostControlArea

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class HostControlArea {

+ areaControlMode : enum:AreaControlMode [0..1]
+ freqSetPoint : Frequency [0..1]
+ frequencyBiasFactor : Float [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- HostControlArea : inherits from
class AdjacentCASet {

}

HostControlArea --> "0..1" AdjacentCASet : AdjacentCASet
class ControlAreaOperator {

}

HostControlArea --> "1" ControlAreaOperator : Controls
class RTO {

}

HostControlArea --> "1" RTO : RTO
```

A HostControlArea has a set of tie points and a set of generator controls (i.e., AGC). It also has a total load, including transmission and distribution losses.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| areaControlMode [0..1] | [AreaControlMode](#CIM17v40-AreaControlMode) | The area's present control mode: (CF = constant frequency) or (CTL = constant tie-line) or (TLB = tie-line bias) or (OFF = off control) | |
| freqSetPoint [0..1] | [Frequency](#CIM17v40-Frequency) | The present power system frequency set point for automatic generation control | |
| frequencyBiasFactor [0..1] | [Float](#CIM17v40-Float) | The control area's frequency bias factor, in MW/0.1 Hz, for automatic generation control (AGC) | |
| AdjacentCASet [0..1] | [AdjacentCASet](#CIM17v40-AdjacentCASet) | | |
| `Controls [1]` (informative) | [ControlAreaOperator](#CIM17v40-ControlAreaOperator) | A ControlAreaCompany controls a ControlArea. | |
| RTO [1] | [RTO](#CIM17v40-RTO) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-HourlyPreDispatchSchedule}
### HourlyPreDispatchSchedule

Inheritance path = [BidHourlySchedule](#CIM17v40-BidHourlySchedule) => [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) => [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class HourlyPreDispatchSchedule {

+ value : Boolean [0..1]
}

class BidHourlySchedule {

}

BidHourlySchedule <|-- HourlyPreDispatchSchedule : inherits from
```

An indicator specifying that a resource shall have an Hourly Pre-Dispatch. The resource could be a RegisteredGenerator or a RegisteredInterTie.

This schedule is assocated with the hourly parameters in a resource bid.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| value [0..1] | [Boolean](#CIM17v40-Boolean) | Flag defining that for this hour in the resource bid the resource shall have an hourly pre-dispatch. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Bid [1] | [Bid](#CIM17v40-Bid) | see [BidHourlySchedule](CIM17v40-BidHourlySchedule) | |
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | see [RegularIntervalSchedule](CIM17v40-RegularIntervalSchedule) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Hurricane}
### Hurricane

Inheritance path = [Cyclone](#CIM17v40-Cyclone) => [AtmosphericPhenomenon](#CIM17v40-AtmosphericPhenomenon) => [EnvironmentalPhenomenon](#CIM17v40-EnvironmentalPhenomenon)

```mermaid
classDiagram
direction TB

class Hurricane {

+ category : Integer [0..1]
}

class Cyclone {

}

Cyclone <|-- Hurricane : inherits from
```

A hurricane, a subtype of cyclone occurring in the North Atlantic Ocean or North-eastern Pacific Ocean whose intensity is measured using the Saffir-Simpson Hurricane Scale.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| category [0..1] | [Integer](#CIM17v40-Integer) | The hurricane's category during the time interval, using Saffir-Simpson Hurricane Wind Scale, a 1 to 5 rating based on a hurricane's sustained wind speed. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| centralPressure [0..1] | [Pressure](#CIM17v40-Pressure) | see [Cyclone](CIM17v40-Cyclone) | |
| maxSurfaceWindSpeed [0..1] | [Speed](#CIM17v40-Speed) | see [Cyclone](CIM17v40-Cyclone) | |
| windForce [0..1] | [Integer](#CIM17v40-Integer) | see [Cyclone](#CIM17v40-Cyclone) | |
| direction [0..1] | [Bearing](#CIM17v40-Bearing) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| maxCoverage [0..1] | [PerCent](#CIM17v40-PerCent) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| minCoverage [0..1] | [PerCent](#CIM17v40-PerCent) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| speed [0..1] | [Speed](#CIM17v40-Speed) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| altitude [0..1] | [RelativeDisplacement](#CIM17v40-RelativeDisplacement) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| base [0..1] | [RelativeDisplacement](#CIM17v40-RelativeDisplacement) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| PhenomenonClassification [0..1] | [PhenomenonClassification](#CIM17v40-PhenomenonClassification) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| timeInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |

{#CIM17v40-HydroGeneratingEfficiencyCurve}
### HydroGeneratingEfficiencyCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class HydroGeneratingEfficiencyCurve {

}

class Curve {

}

Curve <|-- HydroGeneratingEfficiencyCurve : inherits from
class HydroGeneratingUnit {

}

HydroGeneratingEfficiencyCurve --> "1" HydroGeneratingUnit : HydroGeneratingUnit
```

Relationship between unit efficiency as percentage and unit output active power for a given net head in meters. The relationship between efficiency, discharge, head, and power output is expressed as follows: E =KP/HQ

where: E is the efficiency, as a percentage; P is the active power; H is the height; Q is the discharge, volume/time unit; K is a constant.

For example, a curve instance for a given net head could show efficiency (Y-axis) versus active power output (X-axis) or versus discharge on the X-axis.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `HydroGeneratingUnit [1]` (OfAggregate) | [HydroGeneratingUnit](#CIM17v40-HydroGeneratingUnit) | A hydro generating unit has an efficiency curve. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-HydroGeneratingUnit}
### HydroGeneratingUnit

Inheritance path = [GeneratingUnit](#CIM17v40-GeneratingUnit) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class HydroGeneratingUnit {

+ dropHeight : Length [0..1]
+ energyConversionCapability : enum:HydroEnergyConversionKind [0..1]
+ hydroUnitWaterCost : CostPerVolume [0..1]
+ turbineType : enum:HydroTurbineKind [0..1]
}

class GeneratingUnit {

}

GeneratingUnit <|-- HydroGeneratingUnit : inherits from
class HydroPowerPlant {

}

HydroGeneratingUnit --> "0..1" HydroPowerPlant : HydroPowerPlant
class PenstockLossCurve {

}

HydroGeneratingUnit --> "0..1" PenstockLossCurve : PenstockLossCurve
```

A generating unit whose prime mover is a hydraulic turbine (e.g., Francis, Pelton, Kaplan).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dropHeight [0..1] | [Length](#CIM17v40-Length) | The height water drops from the reservoir mid-point to the turbine. | |
| energyConversionCapability [0..1] | [HydroEnergyConversionKind](#CIM17v40-HydroEnergyConversionKind) | Energy conversion capability for generating. | |
| hydroUnitWaterCost [0..1] | [CostPerVolume](#CIM17v40-CostPerVolume) | The equivalent cost of water that drives the hydro turbine. | |
| turbineType [0..1] | [HydroTurbineKind](#CIM17v40-HydroTurbineKind) | Type of turbine. | |
| `HydroPowerPlant [0..1]` (OfAggregate) | [HydroPowerPlant](#CIM17v40-HydroPowerPlant) | The hydro generating unit belongs to a hydro power plant. | |
| `PenstockLossCurve [0..1]` (AggregateOf) | [PenstockLossCurve](#CIM17v40-PenstockLossCurve) | A hydro generating unit has a penstock loss curve. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| allocSpinResP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| autoCntrlMarginP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| baseP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlDeadband [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlPulseHigh [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlPulseLow [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlResponseRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| efficiency [0..1] | [PerCent](#CIM17v40-PerCent) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| genControlMode [0..1] | [GeneratorControlMode](#CIM17v40-GeneratorControlMode) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| genControlSource [0..1] | [GeneratorControlSource](#CIM17v40-GeneratorControlSource) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| governorMPL [0..1] | [PU](#CIM17v40-PU) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| governorSCD [0..1] | [PerCent](#CIM17v40-PerCent) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| highControlLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| initialP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| longPF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| lowControlLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| lowerRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| maxEconomicP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| maximumAllowableSpinningReserve [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| maxOperatingP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| minEconomicP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| minimumOffTime [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| minOperatingP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| modelDetail [0..1] | [Classification](#CIM17v40-Classification) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| nominalP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| normalPF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| penaltyFactor [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| raiseRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| ratedGrossMaxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| ratedGrossMinP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| ratedNetMaxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| shortPF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| startupCost [0..1] | [Money](#CIM17v40-Money) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| startupTime [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| tieLinePF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| totalEfficiency [0..1] | [PerCent](#CIM17v40-PerCent) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| variableCost [0..1] | [Money](#CIM17v40-Money) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| `GenUnitOpSchedule [0..1]` (AggregateOf) | [GenUnitOpSchedule](#CIM17v40-GenUnitOpSchedule) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-HydroPowerPlant}
### HydroPowerPlant

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class HydroPowerPlant {

+ dischargeTravelDelay : Seconds [0..1]
+ genRatedP : ActivePower [0..1]
+ hydroPlantStorageType : enum:HydroPlantStorageKind [0..1]
+ penstockType : String [0..1]
+ plantDischargeCapacity : VolumeFlowRate [0..1]
+ plantRatedHead : Length [0..1]
+ pumpRatedP : ActivePower [0..1]
+ surgeTankCode : String [0..1]
+ surgeTankCrestLevel : WaterLevel [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- HydroPowerPlant : inherits from
class Reservoir {

}

HydroPowerPlant --> "1" Reservoir : GenSourcePumpDischargeReservoir
class Reservoir {

}

HydroPowerPlant --> "0..1" Reservoir : Reservoir
```

A hydro power station which can generate or pump. When generating, the generator turbines receive water from an upper reservoir. When pumping, the pumps receive their water from a lower reservoir.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dischargeTravelDelay [0..1] | [Seconds](#CIM17v40-Seconds) | Water travel delay from tailbay to next downstream hydro power station. | |
| genRatedP [0..1] | [ActivePower](#CIM17v40-ActivePower) | The hydro plant's generating rating active power for rated head conditions.The attribute shall be a positive value. | |
| hydroPlantStorageType [0..1] | [HydroPlantStorageKind](#CIM17v40-HydroPlantStorageKind) | The type of hydro power plant water storage. | |
| penstockType [0..1] | [String](#CIM17v40-String) | Type and configuration of hydro plant penstock(s). | |
| plantDischargeCapacity [0..1] | [VolumeFlowRate](#CIM17v40-VolumeFlowRate) | Total plant discharge capacity. | |
| plantRatedHead [0..1] | [Length](#CIM17v40-Length) | The plant's rated gross head.The attribute shall be a positive value. | |
| pumpRatedP [0..1] | [ActivePower](#CIM17v40-ActivePower) | The hydro plant's pumping rating active power for rated head conditions.The attribute shall be a positive value. | |
| surgeTankCode [0..1] | [String](#CIM17v40-String) | A code describing the type (or absence) of surge tank that is associated with the hydro power plant. | |
| surgeTankCrestLevel [0..1] | [WaterLevel](#CIM17v40-WaterLevel) | The level at which the surge tank spills. | |
| GenSourcePumpDischargeReservoir [1] | [Reservoir](#CIM17v40-Reservoir) | Generators are supplied water from or pumps discharge water to an upstream reservoir. | |
| Reservoir [0..1] | [Reservoir](#CIM17v40-Reservoir) | Generators discharge water to or pumps are supplied water from a downstream reservoir. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-HydroPump}
### HydroPump

Inheritance path = [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class HydroPump {

+ pumpDischAtMaxHead : VolumeFlowRate [0..1]
+ pumpDischAtMinHead : VolumeFlowRate [0..1]
+ pumpPowerAtMaxHead : ActivePower [0..1]
+ pumpPowerAtMinHead : ActivePower [0..1]
}

class Equipment {

}

Equipment <|-- HydroPump : inherits from
class HydroPowerPlant {

}

HydroPump --> "0..1" HydroPowerPlant : HydroPowerPlant
class HydroPumpOpSchedule {

}

HydroPump --> "0..1" HydroPumpOpSchedule : HydroPumpOpSchedule
class RotatingMachine {

}

HydroPump --> "1" RotatingMachine : RotatingMachine
```

A synchronous motor-driven pump, typically associated with a pumped storage plant.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| pumpDischAtMaxHead [0..1] | [VolumeFlowRate](#CIM17v40-VolumeFlowRate) | The pumping discharge under maximum head conditions, usually at full gate. | |
| pumpDischAtMinHead [0..1] | [VolumeFlowRate](#CIM17v40-VolumeFlowRate) | The pumping discharge under minimum head conditions, usually at full gate. | |
| pumpPowerAtMaxHead [0..1] | [ActivePower](#CIM17v40-ActivePower) | The pumping power under maximum head conditions, usually at full gate. | |
| pumpPowerAtMinHead [0..1] | [ActivePower](#CIM17v40-ActivePower) | The pumping power under minimum head conditions, usually at full gate. | |
| `HydroPowerPlant [0..1]` (OfAggregate) | [HydroPowerPlant](#CIM17v40-HydroPowerPlant) | The hydro pump may be a member of a pumped storage plant or a pump for distributing water. | |
| `HydroPumpOpSchedule [0..1]` (AggregateOf) | [HydroPumpOpSchedule](#CIM17v40-HydroPumpOpSchedule) | The hydro pump has a pumping schedule over time, indicating when pumping is to occur. | |
| RotatingMachine [1] | [RotatingMachine](#CIM17v40-RotatingMachine) | The synchronous machine drives the turbine which moves the water from a low elevation to a higher elevation. The direction of machine rotation for pumping may or may not be the same as for generating. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-HydroPumpOpSchedule}
### HydroPumpOpSchedule

Inheritance path = [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) => [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class HydroPumpOpSchedule {

}

class RegularIntervalSchedule {

}

RegularIntervalSchedule <|-- HydroPumpOpSchedule : inherits from
class HydroPump {

}

HydroPumpOpSchedule --> "1" HydroPump : HydroPump
```

The hydro pump's Operator-approved current operating schedule (or plan), typically produced with the aid of unit commitment type analyses. The unit's operating schedule status is typically given as: (0=unavailable) (1=available to startup or shutdown) (2=must pump).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `HydroPump [1]` (OfAggregate) | [HydroPump](#CIM17v40-HydroPump) | The hydro pump has a pumping schedule over time, indicating when pumping is to occur. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | see [RegularIntervalSchedule](CIM17v40-RegularIntervalSchedule) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-HydroTurbine}
### HydroTurbine

Inheritance path = [PrimeMover](#CIM17v40-PrimeMover) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class HydroTurbine {

+ gateRateLimit : Float [0..1]
+ gateUpperLimit : PU [0..1]
+ maxHeadMaxP : ActivePower [0..1]
+ minHeadMaxP : ActivePower [0..1]
+ speedRating : RotationSpeed [0..1]
+ speedRegulation : PU [0..1]
+ transientDroopTime : Seconds [0..1]
+ transientRegulation : PU [0..1]
+ turbineRating : ActivePower [0..1]
+ turbineType : enum:HydroTurbineKind [0..1]
+ waterStartingTime : Seconds [0..1]
}

class PrimeMover {

}

PrimeMover <|-- HydroTurbine : inherits from
```

A water driven prime mover. Typical turbine types are: Francis, Kaplan, and Pelton.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| gateRateLimit [0..1] | [Float](#CIM17v40-Float) | Gate rate limit. | |
| gateUpperLimit [0..1] | [PU](#CIM17v40-PU) | Gate upper limit. | |
| maxHeadMaxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | Maximum efficiency active power at maximum head conditions. | |
| minHeadMaxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | Maximum efficiency active power at minimum head conditions. | |
| speedRating [0..1] | [RotationSpeed](#CIM17v40-RotationSpeed) | Rated speed in number of revolutions. The attribute shall be a positive value. | |
| speedRegulation [0..1] | [PU](#CIM17v40-PU) | Speed regulation. | |
| transientDroopTime [0..1] | [Seconds](#CIM17v40-Seconds) | Transient droop time constant. | |
| transientRegulation [0..1] | [PU](#CIM17v40-PU) | Transient regulation. | |
| turbineRating [0..1] | [ActivePower](#CIM17v40-ActivePower) | Rated turbine active power. The attribute shall be a positive value. | |
| turbineType [0..1] | [HydroTurbineKind](#CIM17v40-HydroTurbineKind) | Type of turbine. | |
| waterStartingTime [0..1] | [Seconds](#CIM17v40-Seconds) | Water starting time. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| primeMoverRating [0..1] | [Float](#CIM17v40-Float) | see [PrimeMover](#CIM17v40-PrimeMover) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-HydrosphericAnalog}
### HydrosphericAnalog

Inheritance path = [EnvironmentalAnalog](#CIM17v40-EnvironmentalAnalog) => [Analog](#CIM17v40-Analog) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class HydrosphericAnalog {

+ kind : enum:HydrosphericAnalogKind [0..1]
}

class EnvironmentalAnalog {

}

EnvironmentalAnalog <|-- HydrosphericAnalog : inherits from
```

Analog (float) measuring a hydrospheric condition.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [HydrosphericAnalogKind](#CIM17v40-HydrosphericAnalogKind) | Kind of hydrospheric analog. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ClassificationCondition [0..1] | [ClassificationCondition](#CIM17v40-ClassificationCondition) | see [EnvironmentalAnalog](CIM17v40-EnvironmentalAnalog) | |
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | see [EnvironmentalAnalog](CIM17v40-EnvironmentalAnalog) | |
| EnvironmentalMonitoringStation [0..1] | [EnvironmentalMonitoringStation](#CIM17v40-EnvironmentalMonitoringStation) | see [EnvironmentalAnalog](CIM17v40-EnvironmentalAnalog) | |
| ReportingCapability [0..1] | [ReportingCapability](#CIM17v40-ReportingCapability) | see [EnvironmentalAnalog](CIM17v40-EnvironmentalAnalog) | |
| maxValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| minValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| normalValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| positiveFlowIn [0..1] | [Boolean](#CIM17v40-Boolean) | see [Analog](#CIM17v40-Analog) | |
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-HydrosphericPhenomenon}
### HydrosphericPhenomenon

Inheritance path = [EnvironmentalPhenomenon](#CIM17v40-EnvironmentalPhenomenon)

```mermaid
classDiagram
direction TB

class HydrosphericPhenomenon {

}

class EnvironmentalPhenomenon {

}

EnvironmentalPhenomenon <|-- HydrosphericPhenomenon : inherits from
```

A hydrospheric phenomenon.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| PhenomenonClassification [0..1] | [PhenomenonClassification](#CIM17v40-PhenomenonClassification) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| timeInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |

{#CIM17v40-ICCPInformationMessage}
### ICCPInformationMessage

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ICCPInformationMessage {

+ localReference : String [0..1]
+ scope : enum:ICCPScopeKind [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ICCPInformationMessage : inherits from
```

This class represents the TASE.2 Information Message Object. The IdentifiedObject.name attribute must be non-null. The value of the attribute shall be used as the TASE.2 Information Reference, as specified by 60870-6-503.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| localReference [0..1] | [String](#CIM17v40-String) | The Local Reference attribute specifies a value agreed upon between sender and receiver of the Information Message. It further identifies the Information Message. | |
| scope [0..1] | [ICCPScopeKind](#CIM17v40-ICCPScopeKind) | Indicates if the Point is global scoped (e.g. VCC) or accessible only to the Bilateral table peer (e.g. ICC). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ICCPProvidedPoint}
### ICCPProvidedPoint

Inheritance path = [ProvidedBilateralPoint](#CIM17v40-ProvidedBilateralPoint) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ICCPProvidedPoint {

+ accessPriviledge : enum:ICCPAccessPrivilegeKind [0..1]
+ pointQuality : enum:ICCPQualityKind [0..1]
+ pointType : enum:ICCPPointKind [0..1]
+ scope : enum:ICCPScopeKind [0..1]
}

class ProvidedBilateralPoint {

}

ProvidedBilateralPoint <|-- ICCPProvidedPoint : inherits from
```

The IdentifiedObject.name attribute must have a value. The name attribute shall be used as the DataValue name used for the exchange.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| accessPriviledge [0..1] | [ICCPAccessPrivilegeKind](#CIM17v40-ICCPAccessPrivilegeKind) | Provides information regarding the access privileges allowed to the ICCP Point. | |
| pointQuality [0..1] | [ICCPQualityKind](#CIM17v40-ICCPQualityKind) | Specifies the type of ICCP quality that will be conveyed as part of the ICCP Point. | |
| pointType [0..1] | [ICCPPointKind](#CIM17v40-ICCPPointKind) | Indicates the ICCP Point type that is to be conveyed.A CIM AccumlatorValue shall be mapped to an ICCP real.A CIM AnalogValue shall be mapped to an ICCP real.A CIM DiscreteValue shall be mapped to either an ICCP real, state, stateSupplemental, or either protection event type.A CIM StringMeasurementValue does not have a standardized mapping. | |
| scope [0..1] | [ICCPScopeKind](#CIM17v40-ICCPScopeKind) | Indicates if the Point is global scoped (e.g. VCC) or accessible only to the Bilateral table peer (e.g. ICC). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BilateralExchangeActor [1] | [BilateralExchangeActor](#CIM17v40-BilateralExchangeActor) | see [ProvidedBilateralPoint](CIM17v40-ProvidedBilateralPoint) | |
| IOPoint [0..1] | [IOPoint](#CIM17v40-IOPoint) | see [ProvidedBilateralPoint](CIM17v40-ProvidedBilateralPoint) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ICCPVCC}
### ICCPVCC

Inheritance path = [BilateralExchangeActor](#CIM17v40-BilateralExchangeActor) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ICCPVCC {

}

class BilateralExchangeActor {

}

BilateralExchangeActor <|-- ICCPVCC : inherits from
```

Indicates that the ICCP information is global in nature and normally is available to all authorized peers.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ICCPVirtualControlCentre}
### ICCPVirtualControlCentre

Inheritance path = [BilateralExchangeActor](#CIM17v40-BilateralExchangeActor) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ICCPVirtualControlCentre {

+ applicationSecurityRequirement : enum:ApplicationSecurityKind [0..1]
+ calling : Boolean [0..1]
+ clientAndServer : Boolean [0..1]
+ minimumUpdateInterval : Integer [0..1]
+ nameOfLocalICC : String [0..1]
+ supportForBlock1 : Boolean [0..1]
+ supportForBlock2 : Boolean [0..1]
+ supportForBlock3 : Boolean [0..1]
+ supportForBlock4 : Boolean [0..1]
+ supportForBlock5 : Boolean [0..1]
+ supportForDepriciatedBlock8 : Boolean [0..1]
+ transportSecurityRequirement : Boolean [0..1]
}

class BilateralExchangeActor {

}

BilateralExchangeActor <|-- ICCPVirtualControlCentre : inherits from
```

This contains the information that a particular actor exposes for a particular agreed upon ICCP Bilateral Table.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| applicationSecurityRequirement [0..1] | [ApplicationSecurityKind](#CIM17v40-ApplicationSecurityKind) | Specifies the expected security mechanism, per IEC 62351-4, to be utilized. | |
| calling [0..1] | [Boolean](#CIM17v40-Boolean) | Used to indicate if the Provider is responsible for initiating the TASE.2 connection. If the value is TRUE, the provider is responsible for establishing the association. If the value is FALSE, the peer provider of the Bilateral Table will need to establish the association. | |
| clientAndServer [0..1] | [Boolean](#CIM17v40-Boolean) | If True the value indicates that the entity represented by the bilateral table is capable of issuing requests and responding to request (e.g. bidirectional support of ICCP requests).If False, this indicates that a calling entity (e.g. calling = True) will not be able to respond to ICCP requests. If False, and calling=False, this indicates that the entity will only respond to ICCP requests and not issue ICCP requests. | |
| minimumUpdateInterval [0..1] | [Integer](#CIM17v40-Integer) | Specifies the fastest update interval that can be provided for integrity information and Transfer Set creation. The value is in seconds. | |
| nameOfLocalICC [0..1] | [String](#CIM17v40-String) | Specifies the ICC scope name that the remote can use to access the information in the Bilateral Table if the information is not VCC scoped. This value may not be null. | |
| supportForBlock1 [0..1] | [Boolean](#CIM17v40-Boolean) | Per IEC 60870-6-702: If true indicates support for basic services. Must always be true. | |
| supportForBlock2 [0..1] | [Boolean](#CIM17v40-Boolean) | Per IEC 60870-6-702: If true indicates support for extended conditions. | |
| supportForBlock3 [0..1] | [Boolean](#CIM17v40-Boolean) | Per IEC 60870-6-702: If true indicates support for blocked transfers. | |
| supportForBlock4 [0..1] | [Boolean](#CIM17v40-Boolean) | Per IEC 60870-6-702: If true indicates support for information messages. | |
| supportForBlock5 [0..1] | [Boolean](#CIM17v40-Boolean) | Per IEC 60870-6-702: If true indicates support for device control. | |
| supportForDepriciatedBlock8 [0..1] | [Boolean](#CIM17v40-Boolean) | Per IEC 60870-6-702: If true indicates support for accounts. The use of this block was deprecated in Edition 3. | |
| transportSecurityRequirement [0..1] | [Boolean](#CIM17v40-Boolean) | If true, then transport level security as specified by IEC 62351-6 is required. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-IEC61968CIMVersion}
### IEC61968CIMVersion


```mermaid
classDiagram
direction TB

class IEC61968CIMVersion {

+ date : Date [0..1]
+ version : String [0..1]
}

```

IEC 61968 version number assigned to this UML model.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| date [0..1] | [Date](#CIM17v40-Date) | (const=2016-10-31) Form is YYYY-MM-DD for example for January 5, 2009 it is 2009-01-05. | |
| version [0..1] | [String](#CIM17v40-String) | (const=IEC61968CIM13v09) Form is IEC61968CIMXXvYY[a-z] where XX is the major CIM package version and the YY is the minor version. For example IEC61968CIM10v17a.The letter on the version number indicates the changes are due to National Committee comments. | |

{#CIM17v40-IEC61970CIMVersion}
### IEC61970CIMVersion


```mermaid
classDiagram
direction TB

class IEC61970CIMVersion {

+ date : Date [0..1]
+ version : String [0..1]
}

```

This is the IEC 61970 CIM version number assigned to this UML model.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| date [0..1] | [Date](#CIM17v40-Date) | Form is YYYY-MM-DD for example for January 5, 2009 it is 2009-01-05. | |
| version [0..1] | [String](#CIM17v40-String) | Form is IEC61970CIMXXvYY where XX is the major CIM package version and the YY is the minor version. For example IEC61970CIM13v18. | |

{#CIM17v40-IEC62325CIMVersion}
### IEC62325CIMVersion


```mermaid
classDiagram
direction TB

class IEC62325CIMVersion {

+ date : Date [0..1]
+ version : String [0..1]
}

```

IEC 62325 version number assigned to this UML model.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| date [0..1] | [Date](#CIM17v40-Date) | Form is YYYY-MM-DD for example for January 5, 2009 it is 2009-01-05. | |
| version [0..1] | [String](#CIM17v40-String) | Form is IEC62325CIMXXvYY where XX is the major CIM package version and the YY is the minor version. For example IEC62325CIM10v03. | |

{#CIM17v40-IOPoint}
### IOPoint

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class IOPoint {

}

class IdentifiedObject {

}

IdentifiedObject <|-- IOPoint : inherits from
class IOPointSource {

}

IOPoint --> "0..1" IOPointSource : IOPointSource
```

The class describe a measurement or control value. The purpose is to enable having attributes and associations common for measurement and control.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| IOPointSource [0..1] | [IOPointSource](#CIM17v40-IOPointSource) | Local merasurement value source for an ICCP point. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-IOPointSource}
### IOPointSource

Inheritance path = [MeasurementValueSource](#CIM17v40-MeasurementValueSource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class IOPointSource {

}

class MeasurementValueSource {

}

MeasurementValueSource <|-- IOPointSource : inherits from
```

Indicates the point source for an IO Point.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-IPAccessPoint}
### IPAccessPoint

Inheritance path = [CommunicationLink](#CIM17v40-CommunicationLink) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class IPAccessPoint {

+ address : String [0..1]
+ addressType : enum:IPAddressKind [0..1]
+ gateway : String [0..1]
+ subnet : String [0..1]
}

class CommunicationLink {

}

CommunicationLink <|-- IPAccessPoint : inherits from
```

Internet Protocol Access Point � used to represent an addressing structure is based upon an Internet Protocol (IP) address.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| address [0..1] | [String](#CIM17v40-String) | Is the dotted decimal IP Address resolve the IP address. The format is controlled by the value of the addressType. | |
| addressType [0..1] | [IPAddressKind](#CIM17v40-IPAddressKind) | IP address type. | |
| gateway [0..1] | [String](#CIM17v40-String) | Is the dotted decimal IPAddress of the first hop router. Format is controlled by the addressType. | |
| subnet [0..1] | [String](#CIM17v40-String) | This is the IP subnet mask which controls the local vs non-local routing. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BilateralExchangeActor [0..1] | [BilateralExchangeActor](#CIM17v40-BilateralExchangeActor) | see [CommunicationLink](CIM17v40-CommunicationLink) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ISOUpperLayer}
### ISOUpperLayer

Inheritance path = [TCPAccessPoint](#CIM17v40-TCPAccessPoint) => [IPAccessPoint](#CIM17v40-IPAccessPoint) => [CommunicationLink](#CIM17v40-CommunicationLink) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ISOUpperLayer {

+ aeInvoke : Integer [0..1]
+ aeQual : Integer [0..1]
+ apInvoke : Integer [0..1]
+ apTitle : String [0..1]
+ osiPsel : String [0..1]
+ osiSsel : String [0..1]
+ osiTsel : String [0..1]
}

class TCPAccessPoint {

}

TCPAccessPoint <|-- ISOUpperLayer : inherits from
```

Is a set of configure addressing information that is required since ICCP utilizes addressing other than a TCP port.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aeInvoke [0..1] | [Integer](#CIM17v40-Integer) | Is part of the Application Entity addressing as specified by ISO Addressing. | |
| aeQual [0..1] | [Integer](#CIM17v40-Integer) | Is the AE qualifier and represents further application level addressing information. | |
| apInvoke [0..1] | [Integer](#CIM17v40-Integer) | Is a further application level OSI addressing parameter. | |
| apTitle [0..1] | [String](#CIM17v40-String) | Is a sequence of integer strings separated by ".". The value, in conjunction with other application addressing attributes (e.g. other APs) are used to select a specific application (e.g. the ICCP application entity) per the OSI reference model. The sequence, and its values, represent a namespace whose values are governed by ISO/IEC 7498-3. | |
| osiPsel [0..1] | [String](#CIM17v40-String) | Is the addressing selector for OSI presentation addressing. | |
| osiSsel [0..1] | [String](#CIM17v40-String) | Is the OSI session layer addressing information. | |
| osiTsel [0..1] | [String](#CIM17v40-String) | Is the OSI Transport Layer addressing information. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| keepAliveTime [0..1] | [Integer](#CIM17v40-Integer) | see [TCPAccessPoint](#CIM17v40-TCPAccessPoint) | |
| port [0..1] | [Integer](#CIM17v40-Integer) | see [TCPAccessPoint](#CIM17v40-TCPAccessPoint) | |
| address [0..1] | [String](#CIM17v40-String) | see [IPAccessPoint](#CIM17v40-IPAccessPoint) | |
| addressType [0..1] | [IPAddressKind](#CIM17v40-IPAddressKind) | see [IPAccessPoint](CIM17v40-IPAccessPoint) | |
| gateway [0..1] | [String](#CIM17v40-String) | see [IPAccessPoint](#CIM17v40-IPAccessPoint) | |
| subnet [0..1] | [String](#CIM17v40-String) | see [IPAccessPoint](#CIM17v40-IPAccessPoint) | |
| BilateralExchangeActor [0..1] | [BilateralExchangeActor](#CIM17v40-BilateralExchangeActor) | see [CommunicationLink](CIM17v40-CommunicationLink) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-IdcInverterControl}
### IdcInverterControl


```mermaid
classDiagram
direction TB

class IdcInverterControl {

}

```


{#CIM17v40-IdentifiedObject}
### IdentifiedObject


```mermaid
classDiagram
direction TB

class IdentifiedObject {

+ mRID : String [0..1]
+ aliasName : String [0..1]
+ description : String [0..1]
+ name : String [0..1]
}

class InstanceSet {

}

IdentifiedObject --> "1" InstanceSet : InstanceSet
class ChangeSetMember {

}

IdentifiedObject --> "0..1" ChangeSetMember : PropertiesCIMDataObject
```

This is a root class to provide common identification for all classes needing identification and naming attributes.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | Master resource identifier issued by a model authority. The mRID is unique within an exchange context. Global uniqueness is easily achieved by using a UUID, as specified in RFC 4122, for the mRID. The use of UUID is strongly recommended.For CIMXML data files in RDF syntax conforming to IEC 61970-552, the mRID is mapped to rdf:ID or rdf:about attributes that identify CIM object elements. | |
| aliasName [0..1] | [String](#CIM17v40-String) | The aliasName is free text human readable name of the object alternative to IdentifiedObject.name. It may be non unique and may not correlate to a naming hierarchy.The attribute aliasName is retained because of backwards compatibility between CIM relases. It is however recommended to replace aliasName with the Name class as aliasName is planned for retirement at a future time. | |
| description [0..1] | [String](#CIM17v40-String) | The description is a free human readable text describing or naming the object. It may be non unique and may not correlate to a naming hierarchy. | |
| name [0..1] | [String](#CIM17v40-String) | The name is any free human readable and possibly non unique text naming the object. | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | Dataset containing the data objects. | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | The single CIM data object in the appropriate dataset context. | |

{#CIM17v40-IgnAngleContInverter}
### IgnAngleContInverter


```mermaid
classDiagram
direction TB

class IgnAngleContInverter {

}

```


{#CIM17v40-InadvertentAccount}
### InadvertentAccount


```mermaid
classDiagram
direction TB

class InadvertentAccount {

}

class SubControlArea {

}

InadvertentAccount --> "1" SubControlArea : SubControlArea
```

An account for tracking inadvertent interchange versus time for each control area. A control area may have more than one inadvertent account in order to track inadvertent over one or more specific tie points in addition to the usual overall net inadvertent. Separate accounts would also be used to track designated time periods, such as on-peak and off-peak.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `SubControlArea [1]` (OfAggregate, informative) | [SubControlArea](#CIM17v40-SubControlArea) | A control area can have one or more net inadvertent interchange accounts | |

{#CIM17v40-Incident}
### Incident

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Incident {

+ cause : String [0..1]
}

class Document {

}

Document <|-- Incident : inherits from
class Location {

}

Incident --> "0..1" Location : Location
class Outage {

}

Incident --> "0..1" Outage : Outage
class Operator {

}

Incident --> "0..1" Operator : Owner
class TroubleOrder {

}

Incident --> "0..1" TroubleOrder : TroubleOrder
class UnplannedOutage {

}

Incident --> "0..1" UnplannedOutage : UnplannedOutage
```

Description of a problem in the field that may be reported in a trouble ticket or come from another source. It may have to do with an outage.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| cause [0..1] | [String](#CIM17v40-String) | Cause of this incident. | |
| Location [0..1] | [Location](#CIM17v40-Location) | Location of this incident. | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | Outage for this incident. | |
| Owner [0..1] | [Operator](#CIM17v40-Operator) | Operator who owns this incident. | |
| TroubleOrder [0..1] | [TroubleOrder](#CIM17v40-TroubleOrder) | The trouble order that is associated to the incident | |
| UnplannedOutage [0..1] | [UnplannedOutage](#CIM17v40-UnplannedOutage) | The unplanned outage that may be associated with the incidents. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-IncidentHazard}
### IncidentHazard

Inheritance path = [Hazard](#CIM17v40-Hazard) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class IncidentHazard {

}

class Hazard {

}

Hazard <|-- IncidentHazard : inherits from
class Incident {

}

IncidentHazard --> "0..1" Incident : Incident
class TroubleTicket {

}

IncidentHazard --> "0..1" TroubleTicket : TroubleTicket
```

Hazardous situation associated with an incident. Examples are line down, gas leak, fire, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Incident [0..1] | [Incident](#CIM17v40-Incident) | Incident associated with this hazard. | |
| TroubleTicket [0..1] | [TroubleTicket](#CIM17v40-TroubleTicket) | Trouble ticket associated with this hazard. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| type [0..1] | [String](#CIM17v40-String) | see [Hazard](#CIM17v40-Hazard) | |
| Incident [0..1] | [Incident](#CIM17v40-Incident) | see [Hazard](CIM17v40-Hazard) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Hazard](CIM17v40-Hazard) | |
| TroubleTicket [0..1] | [TroubleTicket](#CIM17v40-TroubleTicket) | see [Hazard](CIM17v40-Hazard) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-IncrementalDatasetArg}
### IncrementalDatasetArg

Inheritance path = [ModelOperationArg](#CIM17v40-ModelOperationArg) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class IncrementalDatasetArg {

}

class ModelOperationArg {

}

ModelOperationArg <|-- IncrementalDatasetArg : inherits from
class ChangeSet {

}

IncrementalDatasetArg --> "1" ChangeSet : IncrementalDataset
class IncrementalDatasetArgDescription {

}

IncrementalDatasetArg --> "1" IncrementalDatasetArgDescription : IncrementalDatasetArgDescription
```

A generic model operation argument referencing an incremental change description.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `IncrementalDataset [1]` (informative) | [ChangeSet](#CIM17v40-ChangeSet) | | |
| `IncrementalDatasetArgDescription [1]` (informative) | [IncrementalDatasetArgDescription](#CIM17v40-IncrementalDatasetArgDescription) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | see [ModelOperationArg](#CIM17v40-ModelOperationArg) | |
| `ModelOperation [1]` (informative) | [ModelOperation](#CIM17v40-ModelOperation) | see [ModelOperationArg](CIM17v40-ModelOperationArg) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-IncrementalDatasetArgDescription}
### (informative) IncrementalDatasetArgDescription

Inheritance path = [ModelOperationArgDescription](#CIM17v40-ModelOperationArgDescription) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class IncrementalDatasetArgDescription {

}

class ModelOperationArgDescription {

}

ModelOperationArgDescription <|-- IncrementalDatasetArgDescription : inherits from
```


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| multiplicityMaximum [0..1] | [Integer](#CIM17v40-Integer) | see [ModelOperationArgDescription](#CIM17v40-ModelOperationArgDescription) | |
| multiplicityMinimum [0..1] | [Integer](#CIM17v40-Integer) | see [ModelOperationArgDescription](#CIM17v40-ModelOperationArgDescription) | |
| `ModelOperationDefinition [1]` (informative) | [ModelOperationDescription](#CIM17v40-ModelOperationDescription) | see [ModelOperationArgDescription](CIM17v40-ModelOperationArgDescription) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-IncrementalHeatRateCurve}
### IncrementalHeatRateCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class IncrementalHeatRateCurve {

+ isNetGrossP : Boolean [0..1]
}

class Curve {

}

Curve <|-- IncrementalHeatRateCurve : inherits from
class ThermalGeneratingUnit {

}

IncrementalHeatRateCurve --> "1" ThermalGeneratingUnit : ThermalGeneratingUnit
```

Relationship between unit incremental heat rate in (delta energy/time) per (delta active power) and unit output in active power. The IHR curve represents the slope of the HeatInputCurve. Note that the "incremental heat rate" and the "heat rate" have the same engineering units.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| isNetGrossP [0..1] | [Boolean](#CIM17v40-Boolean) | Flag is set to true when output is expressed in net active power. | |
| `ThermalGeneratingUnit [1]` (OfAggregate) | [ThermalGeneratingUnit](#CIM17v40-ThermalGeneratingUnit) | A thermal generating unit may have an incremental heat rate curve. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-IndividualPnode}
### IndividualPnode

Inheritance path = [Pnode](#CIM17v40-Pnode) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class IndividualPnode {

}

class Pnode {

}

Pnode <|-- IndividualPnode : inherits from
class GenDistributionFactor {

}

IndividualPnode --> "0..1" GenDistributionFactor : GenDistributionFactor
class LoadDistributionFactor {

}

IndividualPnode --> "0..1" LoadDistributionFactor : LoadDistributionFactor
class MktConnectivityNode {

}

IndividualPnode --> "1" MktConnectivityNode : MktConnectivityNode
```

Individual pricing node based on Pnode.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| GenDistributionFactor [0..1] | [GenDistributionFactor](#CIM17v40-GenDistributionFactor) | | |
| LoadDistributionFactor [0..1] | [LoadDistributionFactor](#CIM17v40-LoadDistributionFactor) | | |
| MktConnectivityNode [1] | [MktConnectivityNode](#CIM17v40-MktConnectivityNode) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| isPublic [0..1] | [Boolean](#CIM17v40-Boolean) | see [Pnode](#CIM17v40-Pnode) | |
| RTO [0..1] | [RTO](#CIM17v40-RTO) | see [Pnode](CIM17v40-Pnode) | |
| SubControlArea [0..1] | [SubControlArea](#CIM17v40-SubControlArea) | see [Pnode](CIM17v40-Pnode) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-InflowForecast}
### InflowForecast

Inheritance path = [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) => [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class InflowForecast {

}

class RegularIntervalSchedule {

}

RegularIntervalSchedule <|-- InflowForecast : inherits from
class Reservoir {

}

InflowForecast --> "1" Reservoir : Reservoir
```

Natural water inflow to a reservoir, usually forecasted from predicted rain and snowmelt. Typically in one hour increments for up to 10 days. The forecast is given in average cubic meters per second over the time increment.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Reservoir [1]` (OfAggregate) | [Reservoir](#CIM17v40-Reservoir) | A reservoir may have a "natural" inflow forecast. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | see [RegularIntervalSchedule](CIM17v40-RegularIntervalSchedule) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-InfoQuestion}
### InfoQuestion

Inheritance path = [WorkDocument](#CIM17v40-WorkDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class InfoQuestion {

+ answer : String [0..1]
+ answerDateTime : DateTime [0..1]
+ answerRemark : String [0..1]
+ questionCode : String [0..1]
+ questionRemark : String [0..1]
+ questionText : String [0..1]
+ questionType : String [0..1]
}

class WorkDocument {

}

WorkDocument <|-- InfoQuestion : inherits from
```

Questions and answers associated with a type of document for purposes of clarification. Questions may be predefined or ad hoc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| answer [0..1] | [String](#CIM17v40-String) | Answer to question. | |
| answerDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | The date and time the quesiton was answered. | |
| answerRemark [0..1] | [String](#CIM17v40-String) | Remarks to qualify the answer. | |
| questionCode [0..1] | [String](#CIM17v40-String) | The question code. If blank, refer to questionText. | |
| questionRemark [0..1] | [String](#CIM17v40-String) | Remarks to qualify the question in this situation. | |
| questionText [0..1] | [String](#CIM17v40-String) | For non-coded questions, the question is provided here. | |
| questionType [0..1] | [String](#CIM17v40-String) | The type of the question. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-InspectionAnalog}
### InspectionAnalog

Inheritance path = [AssetAnalog](#CIM17v40-AssetAnalog) => [Analog](#CIM17v40-Analog) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class InspectionAnalog {

+ kind : enum:InspectionAnalogKind [0..1]
}

class AssetAnalog {

}

AssetAnalog <|-- InspectionAnalog : inherits from
```

Asset inspection type of analog.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [InspectionAnalogKind](#CIM17v40-InspectionAnalogKind) | Kind of analog representing inspection result. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| detectionLimit [0..1] | [Float](#CIM17v40-Float) | see [AssetAnalog](#CIM17v40-AssetAnalog) | |
| precision [0..1] | [Float](#CIM17v40-Float) | see [AssetAnalog](#CIM17v40-AssetAnalog) | |
| reportingTemperature [0..1] | [Temperature](#CIM17v40-Temperature) | see [AssetAnalog](CIM17v40-AssetAnalog) | |
| TestStandard [0..1] | [TestStandard](#CIM17v40-TestStandard) | see [AssetAnalog](CIM17v40-AssetAnalog) | |
| maxValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| minValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| normalValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| positiveFlowIn [0..1] | [Boolean](#CIM17v40-Boolean) | see [Analog](#CIM17v40-Analog) | |
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-InspectionDataSet}
### (informative) InspectionDataSet

Inheritance path = [ProcedureDataSet](#CIM17v40-ProcedureDataSet) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class InspectionDataSet {

+ locationCondition : String [0..1]
}

class ProcedureDataSet {

}

ProcedureDataSet <|-- InspectionDataSet : inherits from
```

Documents the result of one inspection, for a given attribute of an asset.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| locationCondition [0..1] | [String](#CIM17v40-String) | Description of the conditions of the location where the asset resides. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| completedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [ProcedureDataSet](#CIM17v40-ProcedureDataSet) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [ProcedureDataSet](CIM17v40-ProcedureDataSet) | |
| Procedure [0..1] | [Procedure](#CIM17v40-Procedure) | see [ProcedureDataSet](CIM17v40-ProcedureDataSet) | |
| WorkTask [0..1] | [WorkTask](#CIM17v40-WorkTask) | see [ProcedureDataSet](CIM17v40-ProcedureDataSet) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-InspectionDiscrete}
### InspectionDiscrete

Inheritance path = [AssetDiscrete](#CIM17v40-AssetDiscrete) => [Discrete](#CIM17v40-Discrete) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class InspectionDiscrete {

+ kind : enum:InspectionDiscreteKind [0..1]
}

class AssetDiscrete {

}

AssetDiscrete <|-- InspectionDiscrete : inherits from
```

Asset inspection type of discrete.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [InspectionDiscreteKind](#CIM17v40-InspectionDiscreteKind) | Kind of discrete representing inspection result. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| TestStandard [0..1] | [TestStandard](#CIM17v40-TestStandard) | see [AssetDiscrete](CIM17v40-AssetDiscrete) | |
| maxValue [0..1] | [Integer](#CIM17v40-Integer) | see [Discrete](#CIM17v40-Discrete) | |
| minValue [0..1] | [Integer](#CIM17v40-Integer) | see [Discrete](#CIM17v40-Discrete) | |
| normalValue [0..1] | [Integer](#CIM17v40-Integer) | see [Discrete](#CIM17v40-Discrete) | |
| ValueAliasSet [0..1] | [ValueAliasSet](#CIM17v40-ValueAliasSet) | see [Discrete](CIM17v40-Discrete) | |
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-InstanceSet}
### (informative) InstanceSet

Inheritance path = [DataSet](#CIM17v40-DataSet)

```mermaid
classDiagram
direction TB

class InstanceSet {

}

class DataSet {

}

DataSet <|-- InstanceSet : inherits from
```

Instance of a version of a model part. This corresponds to a payload of instance data.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [DataSet](#CIM17v40-DataSet) | |
| description [0..1] | [String](#CIM17v40-String) | see [DataSet](#CIM17v40-DataSet) | |
| name [0..1] | [String](#CIM17v40-String) | see [DataSet](#CIM17v40-DataSet) | |
| `AlternateModel [0..1]` (informative) | [AlternateModel](#CIM17v40-AlternateModel) | see [DataSet](CIM17v40-DataSet) | |

{#CIM17v40-InstructionClearing}
### InstructionClearing

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class InstructionClearing {

}

class MarketFactors {

}

MarketFactors <|-- InstructionClearing : inherits from
class DistributedResourceActualEvent {

}

InstructionClearing --> "0..1" DistributedResourceActualEvent : ActualDemandResponseEvent
```

Model of market clearing, relating to commitment instructions. Identifies interval.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ActualDemandResponseEvent [0..1] | [DistributedResourceActualEvent](#CIM17v40-DistributedResourceActualEvent) | ActualDemandResponseEvents may exist that are not part of a cordinated MarketActualEvent associated to a Market. These ActualDemandResponseEvents can have many InstructionClearing Instructions for specified RegisteredResources or Distributed Energy Resource type of AggregateNodes. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-InstructionClearingDOP}
### InstructionClearingDOP

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class InstructionClearingDOP {

}

class MarketFactors {

}

MarketFactors <|-- InstructionClearingDOP : inherits from
```

Model of market clearing, related to Dispatch Operating Point. Identifies interval.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-InstructionClearingDOT}
### InstructionClearingDOT

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class InstructionClearingDOT {

+ contingencyActive : enum:YesNo [0..1]
+ dispatchMode : enum:AutomaticDispatchMode [0..1]
}

class MarketFactors {

}

MarketFactors <|-- InstructionClearingDOT : inherits from
class DistributedResourceActualEvent {

}

InstructionClearingDOT --> "0..1" DistributedResourceActualEvent : DemandResponseActualEvent
```

Model of market clearing, related to Dispatch Operating Target (model of anticipatory dispatch). Identifies interval.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| contingencyActive [0..1] | [YesNo](#CIM17v40-YesNo) | Indication that the system is currently operating in a contingency mode. | |
| dispatchMode [0..1] | [AutomaticDispatchMode](#CIM17v40-AutomaticDispatchMode) | | |
| `DemandResponseActualEvent [0..1]` (IRC-DR) | [DistributedResourceActualEvent](#CIM17v40-DistributedResourceActualEvent) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Instructions}
### Instructions


```mermaid
classDiagram
direction TB

class Instructions {

+ bindingDOD : Float [0..1]
+ bindingDOT : Float [0..1]
+ bindingInstruction : enum:YesNo [0..1]
+ instructionCost : Float [0..1]
+ instructionSource : enum:MQSInstructionSource [0..1]
+ instructionStartTime : DateTime [0..1]
+ instructionType : enum:AutomaticDispInstTypeCommitment [0..1]
+ manuallyBlocked : enum:YesNo [0..1]
+ minStatusChangeTime : Integer [0..1]
+ updateTimeStamp : DateTime [0..1]
+ updateType : enum:MQSCHGType [0..1]
+ updateUser : String [0..1]
}

class AggregateNode {

}

Instructions --> "0..1" AggregateNode : AggregateNode
class RegisteredResource {

}

Instructions --> "1" RegisteredResource : RegisteredResource
```

Provides the necessary information (on a resource basis) to capture the Startup/Shutdown instruction results. This information is relevant to the DA Market (RUC only) as well as the RT Market (HASP, Pre-dispatch, and Interval).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| bindingDOD [0..1] | [Float](#CIM17v40-Float) | Binding dispatch operating delta provides a relative delta to be applied. Typically used in demand response instructions. The binding<font color="#0f0f0f">DOD instructions are cumulative; in other words a second DOD instruction does not replace the previous DOD, instead the second DOD adds to the previous DODs.</font> | |
| bindingDOT [0..1] | [Float](#CIM17v40-Float) | | |
| bindingInstruction [0..1] | [YesNo](#CIM17v40-YesNo) | | |
| instructionCost [0..1] | [Float](#CIM17v40-Float) | Total cost associated with changing the status of the resource. | |
| instructionSource [0..1] | [MQSInstructionSource](#CIM17v40-MQSInstructionSource) | instruction source for market quality results (INS, ACT) | |
| instructionStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | Time the resource should be at Pmin (for start ups).Time the resource is off line. | |
| instructionType [0..1] | [AutomaticDispInstTypeCommitment](#CIM17v40-AutomaticDispInstTypeCommitment) | Indicator of either a Start-Up or a Shut-Down. | |
| manuallyBlocked [0..1] | [YesNo](#CIM17v40-YesNo) | Manually Blocked Indicator (Yes/No). The instruction has been blocked by an Operator. | |
| minStatusChangeTime [0..1] | [Integer](#CIM17v40-Integer) | Minimum start up time required to bring the unit online (minutes).SCUC commitment period start-up time. Calculated start up time based on the StartUpTimeCurve provided with the Bid.This is a combination of StartUp time bid and Unit down time.Units is minutes | |
| updateTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| updateType [0..1] | [MQSCHGType](#CIM17v40-MQSCHGType) | | |
| updateUser [0..1] | [String](#CIM17v40-String) | | |
| AggregateNode [0..1] | [AggregateNode](#CIM17v40-AggregateNode) | | |
| RegisteredResource [1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |

{#CIM17v40-IntSchedAgreement}
### IntSchedAgreement

Inheritance path = [Agreement](#CIM17v40-Agreement) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class IntSchedAgreement {

+ defaultIntegrationMethod : String [0..1]
}

class Agreement {

}

Agreement <|-- IntSchedAgreement : inherits from
```

A type of agreement that provides the default method by which interchange schedules are to be integrated to obtain hourly MWh schedules for accounting.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| defaultIntegrationMethod [0..1] | [String](#CIM17v40-String) | The default method by which interchange schedules are to be integrated to obtain hourly MWh schedules for accounting. Method #1 is to integrate the instantaneous schedule between the hourly boundaries. Method #2 compensates for any up/down ramping that occurs across the hourly boundary (this is called block accounting). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| signDate [0..1] | [Date](#CIM17v40-Date) | see [Agreement](#CIM17v40-Agreement) | |
| validityInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [Agreement](CIM17v40-Agreement) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-InterTieBid}
### InterTieBid

Inheritance path = [ResourceBid](#CIM17v40-ResourceBid) => [Bid](#CIM17v40-Bid) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class InterTieBid {

+ minHourlyBlock : Integer [0..1]
}

class ResourceBid {

}

ResourceBid <|-- InterTieBid : inherits from
class RegisteredInterTie {

}

InterTieBid --> "0..1" RegisteredInterTie : RegisteredInterTie
```

This class represents the inter tie bid.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| minHourlyBlock [0..1] | [Integer](#CIM17v40-Integer) | The minimum hourly block for an Inter-Tie Resource supplied within the bid. | |
| RegisteredInterTie [0..1] | [RegisteredInterTie](#CIM17v40-RegisteredInterTie) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aggregationFlag [0..1] | [Integer](#CIM17v40-Integer) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| bidStatus [0..1] | [String](#CIM17v40-String) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| commodityType [0..1] | [String](#CIM17v40-String) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| contingencyAvailFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [ResourceBid](CIM17v40-ResourceBid) | |
| createdISO [0..1] | [YesNo](#CIM17v40-YesNo) | see [ResourceBid](CIM17v40-ResourceBid) | |
| energyMaxDay [0..1] | [Float](#CIM17v40-Float) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| energyMinDay [0..1] | [Float](#CIM17v40-Float) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| marketSepFlag [0..1] | [String](#CIM17v40-String) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| minDispatchTime [0..1] | [Integer](#CIM17v40-Integer) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| resourceLoadingType [0..1] | [Integer](#CIM17v40-Integer) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| shutDownsMaxDay [0..1] | [Integer](#CIM17v40-Integer) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| shutDownsMaxWeek [0..1] | [Integer](#CIM17v40-Integer) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| startUpsMaxDay [0..1] | [Integer](#CIM17v40-Integer) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| startUpsMaxWeek [0..1] | [Integer](#CIM17v40-Integer) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| virtual [0..1] | [Boolean](#CIM17v40-Boolean) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| marketType [0..1] | [MarketType](#CIM17v40-MarketType) | see [Bid](CIM17v40-Bid) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Bid](#CIM17v40-Bid) | |
| stopTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Bid](#CIM17v40-Bid) | |
| ActionRequest [1] | [ActionRequest](#CIM17v40-ActionRequest) | see [Bid](CIM17v40-Bid) | |
| EnergyMarket [1] | [EnergyMarket](#CIM17v40-EnergyMarket) | see [Bid](CIM17v40-Bid) | |
| MarketParticipant [0..1] | [MarketParticipant](#CIM17v40-MarketParticipant) | see [Bid](CIM17v40-Bid) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-InterTieClearing}
### (informative) InterTieClearing

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class InterTieClearing {

}

class MarketFactors {

}

MarketFactors <|-- InterTieClearing : inherits from
```

Model of market clearing related to results at the inter-ties. Identifies interval


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-InterTieDispatchResponse}
### InterTieDispatchResponse


```mermaid
classDiagram
direction TB

class InterTieDispatchResponse {

+ acceptMW : Float [0..1]
+ acceptStatus : enum:DispatchResponseType [0..1]
+ clearedMW : Float [0..1]
+ passIndicator : enum:PassIndicatorType [0..1]
+ startTime : DateTime [0..1]
}

class RegisteredInterTie {

}

InterTieDispatchResponse --> "1" RegisteredInterTie : RegisteredInterTie
```

Response from an intertie resource acknowledging receipt of dispatch instructions.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| acceptMW [0..1] | [Float](#CIM17v40-Float) | The accepted mw amount by the responder. aka response mw. | |
| acceptStatus [0..1] | [DispatchResponseType](#CIM17v40-DispatchResponseType) | The accept status submitted by the responder. Valid values are NON-RESPONSE, ACCEPT, DECLINE, PARTIAL. | |
| clearedMW [0..1] | [Float](#CIM17v40-Float) | MW amount associated with instruction. For 5 minute binding dispatches, this is the Goto MW or DOT | |
| passIndicator [0..1] | [PassIndicatorType](#CIM17v40-PassIndicatorType) | Part of the Composite key that downstream app uses to match the instruction | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | Part of the Composite key that downstream app uses to match the instruction | |
| RegisteredInterTie [1] | [RegisteredInterTie](#CIM17v40-RegisteredInterTie) | | |

{#CIM17v40-InterTieResults}
### InterTieResults


```mermaid
classDiagram
direction TB

class InterTieResults {

+ baseMW : Float [0..1]
+ clearedValue : Float [0..1]
}

class Flowgate {

}

InterTieResults --> "1" Flowgate : Flowgate
class InterTieClearing {

}

InterTieResults --> "0..1" InterTieClearing : InterTieClearing
```

Provides the tie point specific output from the market applications. Currently, this is defined as the loop flow compensation MW value.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| baseMW [0..1] | [Float](#CIM17v40-Float) | Net Actual MW Flow | |
| clearedValue [0..1] | [Float](#CIM17v40-Float) | Net Dispatched MW | |
| `Flowgate [1]` (informative) | [Flowgate](#CIM17v40-Flowgate) | | |
| `InterTieClearing [0..1]` (informative) | [InterTieClearing](#CIM17v40-InterTieClearing) | | |

{#CIM17v40-InterchangeETCData}
### InterchangeETCData


```mermaid
classDiagram
direction TB

class InterchangeETCData {

+ contractNumber : String [0..1]
+ usageMW : Float [0..1]
}

class InterchangeSchedule {

}

InterchangeETCData --> "0..1" InterchangeSchedule : InterchangeSchedule
```

Existing Transmission Contract data for an interchange schedule.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| contractNumber [0..1] | [String](#CIM17v40-String) | Existing transmission contract number | |
| usageMW [0..1] | [Float](#CIM17v40-Float) | Existing transmission contract usage MW value | |
| `InterchangeSchedule [0..1]` (OfAggregate) | [InterchangeSchedule](#CIM17v40-InterchangeSchedule) | | |

{#CIM17v40-InterchangeSchedule}
### InterchangeSchedule

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class InterchangeSchedule {

+ checkOutType : enum:CheckOutType [0..1]
+ directionType : enum:InterTieDirection [0..1]
+ energyType : enum:MarketProductType [0..1]
+ intervalLength : Integer [0..1]
+ marketType : enum:MarketType [0..1]
+ operatingDate : DateTime [0..1]
+ outOfMarketType : Boolean [0..1]
+ scheduleType : enum:EnergyProductType [0..1]
+ wcrID : String [0..1]
}

class Curve {

}

Curve <|-- InterchangeSchedule : inherits from
class SchedulingPoint {

}

InterchangeSchedule --> "0..1" SchedulingPoint : InterTie
class RegisteredInterTie {

}

InterchangeSchedule --> "0..1" RegisteredInterTie : RegisteredInterTie
```

Interchange schedule class to hold information for interchange schedules such as import export type, energy type, and etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| checkOutType [0..1] | [CheckOutType](#CIM17v40-CheckOutType) | To indicate a check out type such as adjusted capacity or dispatch capacity. | |
| directionType [0..1] | [InterTieDirection](#CIM17v40-InterTieDirection) | Import or export. | |
| energyType [0..1] | [MarketProductType](#CIM17v40-MarketProductType) | Energy product type. | |
| intervalLength [0..1] | [Integer](#CIM17v40-Integer) | Interval length. | |
| marketType [0..1] | [MarketType](#CIM17v40-MarketType) | Market type. | |
| operatingDate [0..1] | [DateTime](#CIM17v40-DateTime) | Operating date, hour. | |
| outOfMarketType [0..1] | [Boolean](#CIM17v40-Boolean) | To indicate an out-of-market (OOM) schedule. | |
| scheduleType [0..1] | [EnergyProductType](#CIM17v40-EnergyProductType) | Schedule type. | |
| wcrID [0..1] | [String](#CIM17v40-String) | Wheeling Counter-Resource ID (required when Schedule Type=Wheel). | |
| InterTie [0..1] | [SchedulingPoint](#CIM17v40-SchedulingPoint) | | |
| RegisteredInterTie [0..1] | [RegisteredInterTie](#CIM17v40-RegisteredInterTie) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-IntermittentResourceEligibility}
### IntermittentResourceEligibility

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class IntermittentResourceEligibility {

+ eligibilityStatus : String [0..1]
}

class MarketFactors {

}

MarketFactors <|-- IntermittentResourceEligibility : inherits from
class RegisteredResource {

}

IntermittentResourceEligibility --> "1" RegisteredResource : RegisteredResource
```

Indicates whether unit is eligible for treatment as a intermittent variable renewable resource.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| eligibilityStatus [0..1] | [String](#CIM17v40-String) | Indicates whether a resource is eligible for PIRP program for a given hour | |
| RegisteredResource [1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-InternalControlArea}
### (informative) InternalControlArea

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class InternalControlArea {

}

class IdentifiedObject {

}

IdentifiedObject <|-- InternalControlArea : inherits from
class CurrentScheduledInterchange {

}

InternalControlArea --> "0..1" CurrentScheduledInterchange : CurrentScheduledInterchange
```

There is one internal control area in the system, which is the single control area in the primary network company. Real time generation control affects only the internal control area.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `CurrentScheduledInterchange [0..1]` (informative) | [CurrentScheduledInterchange](#CIM17v40-CurrentScheduledInterchange) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-InternalLocation}
### InternalLocation

Inheritance path = [WorkLocation](#CIM17v40-WorkLocation) => [Location](#CIM17v40-Location) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class InternalLocation {

+ buildingName : String [0..1]
+ buildingNumber : String [0..1]
+ floor : Integer [0..1]
+ roomNumber : String [0..1]
}

class WorkLocation {

}

WorkLocation <|-- InternalLocation : inherits from
```

Description of location internal to a building.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| buildingName [0..1] | [String](#CIM17v40-String) | Name of building where location is. | |
| buildingNumber [0..1] | [String](#CIM17v40-String) | Number of building where location is. | |
| floor [0..1] | [Integer](#CIM17v40-Integer) | Floor of location. | |
| roomNumber [0..1] | [String](#CIM17v40-String) | Room number of location. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `OneCallRequest [0..1]` (informative) | [OneCallRequest](#CIM17v40-OneCallRequest) | see [WorkLocation](CIM17v40-WorkLocation) | |
| direction [0..1] | [String](#CIM17v40-String) | see [Location](#CIM17v40-Location) | |
| geoInfoReference [0..1] | [String](#CIM17v40-String) | see [Location](#CIM17v40-Location) | |
| type [0..1] | [String](#CIM17v40-String) | see [Location](#CIM17v40-Location) | |
| CoordinateSystem [0..1] | [CoordinateSystem](#CIM17v40-CoordinateSystem) | see [Location](CIM17v40-Location) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Location](CIM17v40-Location) | |
| Incident [0..1] | [Incident](#CIM17v40-Incident) | see [Location](CIM17v40-Location) | |
| mainAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Location](CIM17v40-Location) | |
| OutageOrder [0..1] | [OutageOrder](#CIM17v40-OutageOrder) | see [Location](CIM17v40-Location) | |
| phone1 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Location](CIM17v40-Location) | |
| phone2 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Location](CIM17v40-Location) | |
| secondaryAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Location](CIM17v40-Location) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Location](CIM17v40-Location) | |
| SwitchingOrder [0..1] | [SwitchingOrder](#CIM17v40-SwitchingOrder) | see [Location](CIM17v40-Location) | |
| TroubleOrder [0..1] | [TroubleOrder](#CIM17v40-TroubleOrder) | see [Location](CIM17v40-Location) | |
| TroubleTicket [0..1] | [TroubleTicket](#CIM17v40-TroubleTicket) | see [Location](CIM17v40-Location) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-InterrupterUnit}
### InterrupterUnit

Inheritance path = [Asset](#CIM17v40-Asset) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class InterrupterUnit {

}

class Asset {

}

Asset <|-- InterrupterUnit : inherits from
class OperatingMechanism {

}

InterrupterUnit --> "0..1" OperatingMechanism : OperatingMechanism
```

Breaker interrupter.

Some interrupters have one fixed and one moving contact, some have 2 fixed contacts, some 2 moving contacts. An interrupter will have relationships with 2 bushings and those relationships may be any combination of the FixedContact and MovingContact associations.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| OperatingMechanism [0..1] | [OperatingMechanism](#CIM17v40-OperatingMechanism) | Breaker mechanism controlling this interrupter. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | see [Asset](#CIM17v40-Asset) | |
| initialCondition [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | see [Asset](CIM17v40-Asset) | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | see [Asset](CIM17v40-Asset) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [Asset](CIM17v40-Asset) | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | see [Asset](CIM17v40-Asset) | |
| lotNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| position [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | see [Asset](CIM17v40-Asset) | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | see [Asset](CIM17v40-Asset) | |
| serialNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| type [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| utcNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | see [Asset](CIM17v40-Asset) | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | see [Asset](CIM17v40-Asset) | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | see [Asset](CIM17v40-Asset) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [Asset](CIM17v40-Asset) | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | see [Asset](CIM17v40-Asset) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Asset](CIM17v40-Asset) | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | see [Asset](CIM17v40-Asset) | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | see [Asset](CIM17v40-Asset) | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | see [Asset](CIM17v40-Asset) | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | see [Asset](CIM17v40-Asset) | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | see [Asset](CIM17v40-Asset) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Asset](CIM17v40-Asset) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [Asset](CIM17v40-Asset) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [Asset](CIM17v40-Asset) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Asset](CIM17v40-Asset) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-InterrupterUnitInfo}
### InterrupterUnitInfo

Inheritance path = [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class InterrupterUnitInfo {

+ interruptingMedium : enum:InterruptingMediumKind [0..1]
}

class AssetInfo {

}

AssetInfo <|-- InterrupterUnitInfo : inherits from
```

Interrupter datasheet information.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| interruptingMedium [0..1] | [InterruptingMediumKind](#CIM17v40-InterruptingMediumKind) | Interrupting medium. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-IntervalBlock}
### IntervalBlock


```mermaid
classDiagram
direction TB

class IntervalBlock {

}

class MeterReading {

}

IntervalBlock --> "0..1" MeterReading : MeterReading
class PendingCalculation {

}

IntervalBlock --> "0..1" PendingCalculation : PendingCalculation
class ReadingType {

}

IntervalBlock --> "0..1" ReadingType : ReadingType
```

Time sequence of readings of the same reading type. Contained interval readings may need conversion through the application of an offset and a scalar defined in associated pending.

Table 548 shows all association ends of IntervalBlock with other classes.

Table 548 � Association ends of Metering::IntervalBlock with other classes

Associations

name

mult to

type

description

0..*

PendingCalculation

0..1

PendingCalculation

Pending calculation to apply to interval reading values contained by this block (after which the resulting reading type is different than the original because it reflects the conversion result).

0..*

IntervalReadings

0..*

IntervalReading

Interval reading contained in this block.

0..*

ReadingType

0..1

ReadingType

Type information for interval reading values contained in this block.

0..*

MeterReading

0..1

MeterReading

Meter reading containing this interval block.

IntervalReading

Data captured at regular intervals of time. Interval data could be captured as incremental data, absolute data, or relative data. The source for the data is usually a tariff quantity or an engineering quantity. Data is typically captured in time-tagged, uniform, fixed-length intervals of 5 min, 10 min, 15 min, 30 min, or 60 min.

Note: Interval Data is sometimes also called "Interval Data Readings" (IDR).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| MeterReading [0..1] | [MeterReading](#CIM17v40-MeterReading) | Meter reading containing this interval block. | |
| PendingCalculation [0..1] | [PendingCalculation](#CIM17v40-PendingCalculation) | Pending calculation to apply to interval reading values contained by this block (after which the resulting reading type is different than the original because it reflects the conversion result). | |
| ReadingType [0..1] | [ReadingType](#CIM17v40-ReadingType) | Type information for interval reading values contained in this block. | |

{#CIM17v40-IntervalReading}
### IntervalReading

Inheritance path = [BaseReading](#CIM17v40-BaseReading) => [MeasurementValue](#CIM17v40-MeasurementValue) => [IOPoint](#CIM17v40-IOPoint) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class IntervalReading {

}

class BaseReading {

}

BaseReading <|-- IntervalReading : inherits from
```

Data captured at regular intervals of time. Interval data could be captured as incremental data, absolute data, or relative data. The source for the data is usually a tariff quantity or an engineering quantity. Data is typically captured in time-tagged, uniform, fixed-length intervals of 5 min, 10 min, 15 min, 30 min, or 60 min.

Note: Interval Data is sometimes also called "Interval Data Readings" (IDR).


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| reportedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BaseReading](#CIM17v40-BaseReading) | |
| source [0..1] | [String](#CIM17v40-String) | see [BaseReading](#CIM17v40-BaseReading) | |
| value [0..1] | [String](#CIM17v40-String) | see [BaseReading](#CIM17v40-BaseReading) | |
| timePeriod [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [BaseReading](CIM17v40-BaseReading) | |
| sensorAccuracy [0..1] | [PerCent](#CIM17v40-PerCent) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| timeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | see [MeasurementValue](#CIM17v40-MeasurementValue) | |
| `CalculationMethodHierarchy [0..1]` (harmonization) | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| `ErpPerson [0..1]` (informative) | [OldPerson](#CIM17v40-OldPerson) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| `MeasurementValueQuality [0..1]` (AggregateOf) | [MeasurementValueQuality](#CIM17v40-MeasurementValueQuality) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| MeasurementValueSource [1] | [MeasurementValueSource](#CIM17v40-MeasurementValueSource) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| RemoteSource [0..1] | [RemoteSource](#CIM17v40-RemoteSource) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| IOPointSource [0..1] | [IOPointSource](#CIM17v40-IOPointSource) | see [IOPoint](CIM17v40-IOPoint) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-IrregularIntervalSchedule}
### IrregularIntervalSchedule

Inheritance path = [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class IrregularIntervalSchedule {

}

class BasicIntervalSchedule {

}

BasicIntervalSchedule <|-- IrregularIntervalSchedule : inherits from
```

The schedule has time points where the time between them varies.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-IrregularTimePoint}
### IrregularTimePoint


```mermaid
classDiagram
direction TB

class IrregularTimePoint {

+ time : Seconds [0..1]
+ value1 : Float [0..1]
+ value2 : Float [0..1]
}

class IrregularIntervalSchedule {

}

IrregularTimePoint --> "1" IrregularIntervalSchedule : IntervalSchedule
```

TimePoints for a schedule where the time between the points varies.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| time [0..1] | [Seconds](#CIM17v40-Seconds) | The time is relative to the schedule starting time. | |
| value1 [0..1] | [Float](#CIM17v40-Float) | The first value at the time. The meaning of the value is defined by the derived type of the associated schedule. | |
| value2 [0..1] | [Float](#CIM17v40-Float) | The second value at the time. The meaning of the value is defined by the derived type of the associated schedule. | |
| `IntervalSchedule [1]` (OfAggregate) | [IrregularIntervalSchedule](#CIM17v40-IrregularIntervalSchedule) | An IrregularTimePoint belongs to an IrregularIntervalSchedule. | |

{#CIM17v40-Issuer}
### Issuer

Inheritance path = [DocumentPersonRole](#CIM17v40-DocumentPersonRole) => [PersonRole](#CIM17v40-PersonRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Issuer {

}

class DocumentPersonRole {

}

DocumentPersonRole <|-- Issuer : inherits from
```

Person who issued the document and is responsible for its content.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Person [0..1] | [Person](#CIM17v40-Person) | see [PersonRole](CIM17v40-PersonRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Joint}
### Joint

Inheritance path = [Asset](#CIM17v40-Asset) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Joint {

+ configurationKind : enum:JointConfigurationKind [0..1]
+ fillKind : enum:JointFillKind [0..1]
+ insulation : String [0..1]
}

class Asset {

}

Asset <|-- Joint : inherits from
```

Joint connects two or more cables. It includes the portion of cable under wipes, welds, or other seals.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| configurationKind [0..1] | [JointConfigurationKind](#CIM17v40-JointConfigurationKind) | Configuration of joint. | |
| fillKind [0..1] | [JointFillKind](#CIM17v40-JointFillKind) | Material used to fill the joint. | |
| insulation [0..1] | [String](#CIM17v40-String) | The type of insulation around the joint, classified according to the utility's asset management standards and practices. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | see [Asset](#CIM17v40-Asset) | |
| initialCondition [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | see [Asset](CIM17v40-Asset) | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | see [Asset](CIM17v40-Asset) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [Asset](CIM17v40-Asset) | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | see [Asset](CIM17v40-Asset) | |
| lotNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| position [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | see [Asset](CIM17v40-Asset) | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | see [Asset](CIM17v40-Asset) | |
| serialNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| type [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| utcNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | see [Asset](CIM17v40-Asset) | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | see [Asset](CIM17v40-Asset) | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | see [Asset](CIM17v40-Asset) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [Asset](CIM17v40-Asset) | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | see [Asset](CIM17v40-Asset) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Asset](CIM17v40-Asset) | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | see [Asset](CIM17v40-Asset) | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | see [Asset](CIM17v40-Asset) | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | see [Asset](CIM17v40-Asset) | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | see [Asset](CIM17v40-Asset) | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | see [Asset](CIM17v40-Asset) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Asset](CIM17v40-Asset) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [Asset](CIM17v40-Asset) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [Asset](CIM17v40-Asset) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Asset](CIM17v40-Asset) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Jumper}
### Jumper

Inheritance path = [Switch](#CIM17v40-Switch) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Jumper {

}

class Switch {

}

Switch <|-- Jumper : inherits from
class JumperAction {

}

Jumper --> "0..1" JumperAction : JumperAction
```

A short section of conductor with negligible impedance which can be manually removed and replaced if the circuit is de-energized. Note that zero-impedance branches can potentially be modelled by other equipment types.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| JumperAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | Action taken with this jumper. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| locked [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| normalOpen [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| open [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [Switch](CIM17v40-Switch) | |
| retained [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| `switchOnCount [0..1]` (deprecated) | [Integer](#CIM17v40-Integer) | see [Switch](#CIM17v40-Switch) | |
| `switchOnDate [0..1]` (deprecated) | [DateTime](#CIM17v40-DateTime) | see [Switch](#CIM17v40-Switch) | |
| `CompositeSwitch [0..1]` (OfAggregate) | [CompositeSwitch](#CIM17v40-CompositeSwitch) | see [Switch](CIM17v40-Switch) | |
| SwitchAction [0..1] | [SwitchAction](#CIM17v40-SwitchAction) | see [Switch](CIM17v40-Switch) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-JumperAction}
### JumperAction

Inheritance path = [SwitchingAction](#CIM17v40-SwitchingAction) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class JumperAction {

+ kind : enum:TempEquipActionKind [0..1]
}

class SwitchingAction {

}

SwitchingAction <|-- JumperAction : inherits from
class Clamp {

}

JumperAction --> "0..1" Clamp : Clamp
class Jumper {

}

JumperAction --> "0..1" Jumper : Jumper
```

Action on jumper as a switching step.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [TempEquipActionKind](#CIM17v40-TempEquipActionKind) | Switching action to perform. | |
| Clamp [0..1] | [Clamp](#CIM17v40-Clamp) | Clamp on which this action is taken. | |
| Jumper [0..1] | [Jumper](#CIM17v40-Jumper) | Jumper on which this action is taken. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| executedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| issuedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| plannedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| Operator [0..1] | [Operator](#CIM17v40-Operator) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingEvent [0..1] | [SwitchingEvent](#CIM17v40-SwitchingEvent) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingStep [0..1] | [SwitchingStep](#CIM17v40-SwitchingStep) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Junction}
### Junction

Inheritance path = [Connector](#CIM17v40-Connector) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Junction {

}

class Connector {

}

Connector <|-- Junction : inherits from
```

A point where one or more conducting equipments are connected with zero resistance.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LabTestDataSet}
### LabTestDataSet

Inheritance path = [ProcedureDataSet](#CIM17v40-ProcedureDataSet) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LabTestDataSet {

+ conclusion : String [0..1]
+ conclusionConfidence : String [0..1]
+ reasonForTest : enum:TestReason [0..1]
+ testEquipmentID : String [0..1]
}

class ProcedureDataSet {

}

ProcedureDataSet <|-- LabTestDataSet : inherits from
class AssetTestLab {

}

LabTestDataSet --> "0..1" AssetTestLab : AssetTestLab
class Specimen {

}

LabTestDataSet --> "0..1" Specimen : Specimen
```

Results of testing done by a lab.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| conclusion [0..1] | [String](#CIM17v40-String) | Conclusion drawn from test results. | |
| conclusionConfidence [0..1] | [String](#CIM17v40-String) | Description of confidence in conclusion. | |
| reasonForTest [0..1] | [TestReason](#CIM17v40-TestReason) | Reason for performing test. | |
| testEquipmentID [0..1] | [String](#CIM17v40-String) | Identity of lab equipment used to perform test. | |
| AssetTestLab [0..1] | [AssetTestLab](#CIM17v40-AssetTestLab) | Test lab which produced this set of lab test results. | |
| Specimen [0..1] | [Specimen](#CIM17v40-Specimen) | Specimen on which lab testing done in determining results. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| completedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [ProcedureDataSet](#CIM17v40-ProcedureDataSet) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [ProcedureDataSet](CIM17v40-ProcedureDataSet) | |
| Procedure [0..1] | [Procedure](#CIM17v40-Procedure) | see [ProcedureDataSet](CIM17v40-ProcedureDataSet) | |
| WorkTask [0..1] | [WorkTask](#CIM17v40-WorkTask) | see [ProcedureDataSet](CIM17v40-ProcedureDataSet) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LaborItem}
### LaborItem

Inheritance path = [WorkIdentifiedObject](#CIM17v40-WorkIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LaborItem {

+ activityCode : String [0..1]
+ cost : Money [0..1]
+ laborDuration : Hours [0..1]
+ laborRate : CostRate [0..1]
+ status : Status [0..1]
}

class WorkIdentifiedObject {

}

WorkIdentifiedObject <|-- LaborItem : inherits from
class WorkCostDetail {

}

LaborItem --> "1" WorkCostDetail : WorkCostDetail
class OldWorkTask {

}

LaborItem --> "0..1" OldWorkTask : WorkTask
```

Labor used for work order.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| activityCode [0..1] | [String](#CIM17v40-String) | Activity code identifies a specific and distinguishable unit of work. | |
| cost [0..1] | [Money](#CIM17v40-Money) | Total cost for labor. Note that this may not be able to be derived from labor rate and time charged. | |
| laborDuration [0..1] | [Hours](#CIM17v40-Hours) | Time required to perform work. | |
| laborRate [0..1] | [CostRate](#CIM17v40-CostRate) | The labor rate applied for work. | |
| status [0..1] | [Status](#CIM17v40-Status) | | |
| `WorkCostDetail [1]` (informative) | [WorkCostDetail](#CIM17v40-WorkCostDetail) | | |
| `WorkTask [0..1]` (informative) | [OldWorkTask](#CIM17v40-OldWorkTask) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LandProperty}
### (informative) LandProperty

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LandProperty {

+ demographicKind : enum:DemographicKind [0..1]
+ externalRecordReference : String [0..1]
+ kind : enum:LandPropertyKind [0..1]
+ status : Status [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- LandProperty : inherits from
```

Information about a particular piece of (land) property such as its use. Ownership of the property may be determined through associations to Organisations and/or ErpPersons.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| demographicKind [0..1] | [DemographicKind](#CIM17v40-DemographicKind) | Demographics around the site. | |
| externalRecordReference [0..1] | [String](#CIM17v40-String) | Reference allocated by the governing organisation (such as municipality) to this piece of land that has a formal reference to Surveyor General's records. The governing organisation is specified in associated Organisation. | |
| kind [0..1] | [LandPropertyKind](#CIM17v40-LandPropertyKind) | Kind of (land) property, categorised according to its main functional use from the utility's perspective. | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Landslide}
### Landslide

Inheritance path = [GeosphericPhenomenon](#CIM17v40-GeosphericPhenomenon) => [EnvironmentalPhenomenon](#CIM17v40-EnvironmentalPhenomenon)

```mermaid
classDiagram
direction TB

class Landslide {

}

class GeosphericPhenomenon {

}

GeosphericPhenomenon <|-- Landslide : inherits from
```

A landslide, a large mass of rocks and earth that suddenly and quickly moves down the side of a mountain or hill.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| PhenomenonClassification [0..1] | [PhenomenonClassification](#CIM17v40-PhenomenonClassification) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| timeInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |

{#CIM17v40-LevelVsVolumeCurve}
### LevelVsVolumeCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LevelVsVolumeCurve {

}

class Curve {

}

Curve <|-- LevelVsVolumeCurve : inherits from
class Reservoir {

}

LevelVsVolumeCurve --> "1" Reservoir : Reservoir
```

Relationship between reservoir volume and reservoir level. The volume is at the Y-axis and the reservoir level at the X-axis.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Reservoir [1]` (OfAggregate) | [Reservoir](#CIM17v40-Reservoir) | A reservoir may have a level versus volume relationship. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LightningStrike}
### LightningStrike

Inheritance path = [GeosphericPhenomenon](#CIM17v40-GeosphericPhenomenon) => [EnvironmentalPhenomenon](#CIM17v40-EnvironmentalPhenomenon)

```mermaid
classDiagram
direction TB

class LightningStrike {

+ errorEllipseConfidence : PerCent [0..1]
+ errorEllipseMajorSemiAxis : Length [0..1]
+ errorEllipseMinorSemiAxis : Length [0..1]
+ errorEllipseOrientation : Bearing [0..1]
+ negativePolarity : Boolean [0..1]
+ peakAmplitude : CurrentFlow [0..1]
}

class GeosphericPhenomenon {

}

GeosphericPhenomenon <|-- LightningStrike : inherits from
```

A cloud-to-ground lightning strike at a particular location.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| errorEllipseConfidence [0..1] | [PerCent](#CIM17v40-PerCent) | Likelihood that strike fell within errorEllipse. | |
| errorEllipseMajorSemiAxis [0..1] | [Length](#CIM17v40-Length) | Length of major semi-axis (longest radius) of the error ellipse. | |
| errorEllipseMinorSemiAxis [0..1] | [Length](#CIM17v40-Length) | Length of minor semi-axis (shortest radius) of the error ellipse. | |
| errorEllipseOrientation [0..1] | [Bearing](#CIM17v40-Bearing) | The orientation of the major semi- axis in degrees from True North. | |
| negativePolarity [0..1] | [Boolean](#CIM17v40-Boolean) | The polarity of the strike, with T meaning negative. About 90% of all lightning strokes are negative strokes, meaning that they were initiated by a large concentration of negative charge in the cloud-base; this tends to induce an area of positive charge on the ground. | |
| peakAmplitude [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Peak current of strike. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| PhenomenonClassification [0..1] | [PhenomenonClassification](#CIM17v40-PhenomenonClassification) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| timeInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |

{#CIM17v40-Limit}
### Limit

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Limit {

}

class IdentifiedObject {

}

IdentifiedObject <|-- Limit : inherits from
```

Specifies one limit value for a Measurement. A Measurement typically has several limits that are kept together by the LimitSet class. The actual meaning and use of a Limit instance (i.e., if it is an alarm or warning limit or if it is a high or low limit) is not captured in the Limit class. However the name of a Limit instance may indicate both meaning and use.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LimitDependency}
### LimitDependency

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LimitDependency {

}

class IdentifiedObject {

}

IdentifiedObject <|-- LimitDependency : inherits from
class Equipment {

}

LimitDependency --> "0..1" Equipment : Equipment
```

A limit calculation model used to compute an operational limit based on external input such as temperature. These are intended to be shared among operational limits with the same calculation form that apply to a piece of equipment..


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Equipment [0..1]` (OfAggregate, informative) | [Equipment](#CIM17v40-Equipment) | The equipment for which this limit dependency model is organized under. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LimitScalingLimit}
### LimitScalingLimit

Inheritance path = [LimitDependency](#CIM17v40-LimitDependency) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LimitScalingLimit {

+ limitScalingPercent : PerCent [0..1]
}

class LimitDependency {

}

LimitDependency <|-- LimitScalingLimit : inherits from
class OperationalLimit {

}

LimitScalingLimit --> "1" OperationalLimit : SourceOperationalLimit
```

Specifies an operational limit is calculated by scaling another operational limit.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| limitScalingPercent [0..1] | [PerCent](#CIM17v40-PerCent) | The associated source limit is scaled by this value to compute the limit of the dependency model. | |
| `SourceOperationalLimit [1]` (informative) | [OperationalLimit](#CIM17v40-OperationalLimit) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Equipment [0..1]` (OfAggregate, informative) | [Equipment](#CIM17v40-Equipment) | see [LimitDependency](CIM17v40-LimitDependency) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LimitSet}
### LimitSet

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LimitSet {

+ isPercentageLimits : Boolean [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- LimitSet : inherits from
```

Specifies a set of Limits that are associated with a Measurement. A Measurement may have several LimitSets corresponding to seasonal or other changing conditions. The condition is captured in the name and description attributes. The same LimitSet may be used for several Measurements. In particular percentage limits are used this way.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| isPercentageLimits [0..1] | [Boolean](#CIM17v40-Boolean) | Tells if the limit values are in percentage of normalValue or the specified Unit for Measurements and Controls. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Line}
### Line

Inheritance path = [EquipmentContainer](#CIM17v40-EquipmentContainer) => [ConnectivityNodeContainer](#CIM17v40-ConnectivityNodeContainer) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Line {

}

class EquipmentContainer {

}

EquipmentContainer <|-- Line : inherits from
class SubGeographicalRegion {

}

Line --> "0..1" SubGeographicalRegion : Region
```

Contains equipment beyond a substation belonging to a power transmission line.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Region [0..1]` (OfAggregate) | [SubGeographicalRegion](#CIM17v40-SubGeographicalRegion) | The sub-geographical region of the line. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LineFault}
### LineFault

Inheritance path = [Fault](#CIM17v40-Fault) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LineFault {

+ lengthFromTerminal1 : Length [0..1]
}

class Fault {

}

Fault <|-- LineFault : inherits from
class ACLineSegment {

}

LineFault --> "0..1" ACLineSegment : ACLineSegment
```

A fault that occurs on an AC line segment at some point along the length.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| lengthFromTerminal1 [0..1] | [Length](#CIM17v40-Length) | The length to the place where the fault is located starting from terminal with sequence number 1 of the faulted line segment. | |
| ACLineSegment [0..1] | [ACLineSegment](#CIM17v40-ACLineSegment) | The line segment of this line fault. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [PhaseConnectedFaultKind](#CIM17v40-PhaseConnectedFaultKind) | see [Fault](CIM17v40-Fault) | |
| occurredDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Fault](#CIM17v40-Fault) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Fault](CIM17v40-Fault) | |
| FaultyEquipment [0..1] | [Equipment](#CIM17v40-Equipment) | see [Fault](CIM17v40-Fault) | |
| impedance [0..1] | [FaultImpedance](#CIM17v40-FaultImpedance) | see [Fault](CIM17v40-Fault) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Fault](CIM17v40-Fault) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [Fault](CIM17v40-Fault) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LinearShuntCompensator}
### LinearShuntCompensator

Inheritance path = [ShuntCompensator](#CIM17v40-ShuntCompensator) => [RegulatingCondEq](#CIM17v40-RegulatingCondEq) => [EnergyConnection](#CIM17v40-EnergyConnection) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LinearShuntCompensator {

+ b0PerSection : Susceptance [0..1]
+ bPerSection : Susceptance [0..1]
+ g0PerSection : Conductance [0..1]
+ gPerSection : Conductance [0..1]
}

class ShuntCompensator {

}

ShuntCompensator <|-- LinearShuntCompensator : inherits from
```

A linear shunt compensator has banks or sections with equal admittance values.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| b0PerSection [0..1] | [Susceptance](#CIM17v40-Susceptance) | Zero sequence shunt (charging) susceptance per section. | |
| bPerSection [0..1] | [Susceptance](#CIM17v40-Susceptance) | Positive sequence shunt (charging) susceptance per section. | |
| g0PerSection [0..1] | [Conductance](#CIM17v40-Conductance) | Zero sequence shunt (charging) conductance per section. | |
| gPerSection [0..1] | [Conductance](#CIM17v40-Conductance) | Positive sequence shunt (charging) conductance per section. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aVRDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [ShuntCompensator](CIM17v40-ShuntCompensator) | |
| grounded [0..1] | [Boolean](#CIM17v40-Boolean) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| maximumSections [0..1] | [Integer](#CIM17v40-Integer) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| nomU [0..1] | [Voltage](#CIM17v40-Voltage) | see [ShuntCompensator](CIM17v40-ShuntCompensator) | |
| normalSections [0..1] | [Integer](#CIM17v40-Integer) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| phaseConnection [0..1] | [PhaseShuntConnectionKind](#CIM17v40-PhaseShuntConnectionKind) | see [ShuntCompensator](CIM17v40-ShuntCompensator) | |
| sections [0..1] | [Float](#CIM17v40-Float) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| `switchOnCount [0..1]` (deprecated) | [Integer](#CIM17v40-Integer) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| `switchOnDate [0..1]` (deprecated) | [DateTime](#CIM17v40-DateTime) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| voltageSensitivity [0..1] | [VoltagePerReactivePower](#CIM17v40-VoltagePerReactivePower) | see [ShuntCompensator](CIM17v40-ShuntCompensator) | |
| ShuntCompensatorAction [0..1] | [ShuntCompensatorAction](#CIM17v40-ShuntCompensatorAction) | see [ShuntCompensator](CIM17v40-ShuntCompensator) | |
| controlEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [RegulatingCondEq](#CIM17v40-RegulatingCondEq) | |
| RegulatingControl [0..1] | [RegulatingControl](#CIM17v40-RegulatingControl) | see [RegulatingCondEq](CIM17v40-RegulatingCondEq) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LinearShuntCompensatorPhase}
### LinearShuntCompensatorPhase

Inheritance path = [ShuntCompensatorPhase](#CIM17v40-ShuntCompensatorPhase) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LinearShuntCompensatorPhase {

+ bPerSection : Susceptance [0..1]
+ gPerSection : Conductance [0..1]
}

class ShuntCompensatorPhase {

}

ShuntCompensatorPhase <|-- LinearShuntCompensatorPhase : inherits from
```

A per phase linear shunt compensator has banks or sections with equal admittance values.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| bPerSection [0..1] | [Susceptance](#CIM17v40-Susceptance) | Susceptance per section of the phase if shunt compensator is wye connected. Susceptance per section phase to phase if shunt compensator is delta connected. | |
| gPerSection [0..1] | [Conductance](#CIM17v40-Conductance) | Conductance per section for this phase if shunt compensator is wye connected. Conductance per section phase to phase if shunt compensator is delta connected. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maximumSections [0..1] | [Integer](#CIM17v40-Integer) | see [ShuntCompensatorPhase](#CIM17v40-ShuntCompensatorPhase) | |
| normalSections [0..1] | [Integer](#CIM17v40-Integer) | see [ShuntCompensatorPhase](#CIM17v40-ShuntCompensatorPhase) | |
| phase [0..1] | [SinglePhaseKind](#CIM17v40-SinglePhaseKind) | see [ShuntCompensatorPhase](CIM17v40-ShuntCompensatorPhase) | |
| sections [0..1] | [Float](#CIM17v40-Float) | see [ShuntCompensatorPhase](#CIM17v40-ShuntCompensatorPhase) | |
| ShuntCompensator [1] | [ShuntCompensator](#CIM17v40-ShuntCompensator) | see [ShuntCompensatorPhase](CIM17v40-ShuntCompensatorPhase) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LoadAggregate}
### LoadAggregate

Inheritance path = [LoadDynamics](#CIM17v40-LoadDynamics) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LoadAggregate {

}

class LoadDynamics {

}

LoadDynamics <|-- LoadAggregate : inherits from
class LoadMotor {

}

LoadAggregate --> "0..1" LoadMotor : LoadMotor
class LoadStatic {

}

LoadAggregate --> "0..1" LoadStatic : LoadStatic
```

Aggregate loads are used to represent all or part of the real and reactive load from one or more loads in the static (power flow) data. This load is usually the aggregation of many individual load devices and the load model is an approximate representation of the aggregate response of the load devices to system disturbances.

Standard aggregate load model comprised of static and/or dynamic components. A static load model represents the sensitivity of the real and reactive power consumed by the load to the amplitude and frequency of the bus voltage. A dynamic load model can be used to represent the aggregate response of the motor components of the load.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| LoadMotor [0..1] | [LoadMotor](#CIM17v40-LoadMotor) | Aggregate motor (dynamic) load associated with this aggregate load. | |
| LoadStatic [0..1] | [LoadStatic](#CIM17v40-LoadStatic) | Aggregate static load associated with this aggregate load. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LoadAggregationPoint}
### LoadAggregationPoint

Inheritance path = [AggregateNode](#CIM17v40-AggregateNode) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LoadAggregationPoint {

}

class AggregateNode {

}

AggregateNode <|-- LoadAggregationPoint : inherits from
```

A specialized class of type AggregatedNode type. Defines Load Aggregation Points.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| anodeType [0..1] | [AnodeType](#CIM17v40-AnodeType) | see [AggregateNode](CIM17v40-AggregateNode) | |
| qualifASOrder [0..1] | [Integer](#CIM17v40-Integer) | see [AggregateNode](#CIM17v40-AggregateNode) | |
| RTO [1] | [RTO](#CIM17v40-RTO) | see [AggregateNode](CIM17v40-AggregateNode) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LoadArea}
### LoadArea

Inheritance path = [EnergyArea](#CIM17v40-EnergyArea) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LoadArea {

}

class EnergyArea {

}

EnergyArea <|-- LoadArea : inherits from
```

The class is the root or first level in a hierarchical structure for grouping of loads for the purpose of load flow load scaling.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ControlArea [0..1] | [ControlArea](#CIM17v40-ControlArea) | see [EnergyArea](CIM17v40-EnergyArea) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LoadBid}
### LoadBid

Inheritance path = [ResourceBid](#CIM17v40-ResourceBid) => [Bid](#CIM17v40-Bid) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LoadBid {

+ dropRampRate : ActivePowerChangeRate [0..1]
+ loadRedInitiationCost : Money [0..1]
+ loadRedInitiationTime : Float [0..1]
+ marketDate : DateTime [0..1]
+ meteredValue : Boolean [0..1]
+ minLoad : ActivePower [0..1]
+ minLoadReduction : ActivePower [0..1]
+ minLoadReductionCost : Money [0..1]
+ minLoadReductionInterval : Float [0..1]
+ minTimeBetLoadRed : Float [0..1]
+ pickUpRampRate : ActivePowerChangeRate [0..1]
+ priceSetting : Boolean [0..1]
+ reqNoticeTime : Float [0..1]
+ shutdownCost : Money [0..1]
}

class ResourceBid {

}

ResourceBid <|-- LoadBid : inherits from
class AreaLoadBid {

}

LoadBid --> "0..1" AreaLoadBid : AreaLoadBid
class RegisteredLoad {

}

LoadBid --> "0..1" RegisteredLoad : RegisteredLoad
```

Offer to supply energy/ancillary services from a load resource (participating load reduces consumption).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dropRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | Maximum rate that load can be reduced (MW/minute) | |
| loadRedInitiationCost [0..1] | [Money](#CIM17v40-Money) | load reduction initiation cost | |
| loadRedInitiationTime [0..1] | [Float](#CIM17v40-Float) | load reduction initiation time | |
| marketDate [0..1] | [DateTime](#CIM17v40-DateTime) | The date represents the NextMarketDate for which the load response bids apply to. | |
| meteredValue [0..1] | [Boolean](#CIM17v40-Boolean) | Flag indicated that the load reduction is metered. (See above)If priceSetting and meteredValue both equal 1, then the facility is eligible to set LMP in the real time market. | |
| minLoad [0..1] | [ActivePower](#CIM17v40-ActivePower) | Minimum MW load below which it may not be reduced. | |
| minLoadReduction [0..1] | [ActivePower](#CIM17v40-ActivePower) | Minimum MW for a load reduction (e.g. MW rating of a discrete pump. | |
| minLoadReductionCost [0..1] | [Money](#CIM17v40-Money) | Cost in $ at the minimum reduced load | |
| minLoadReductionInterval [0..1] | [Float](#CIM17v40-Float) | Shortest period load reduction shall be maintained before load can be restored to normal levels. | |
| minTimeBetLoadRed [0..1] | [Float](#CIM17v40-Float) | Shortest time that load shall be left at normal levels before a new load reduction. | |
| pickUpRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | Maximum rate load may be restored (MW/minute) | |
| priceSetting [0..1] | [Boolean](#CIM17v40-Boolean) | Flag to indicate that the facility can set LMP Works in tandem with Metered Value. Greater chance of this being dynamic than the Metered Value, however, it is requested that Price Setting and Metered Value stay at the same source. Currently no customers have implemented the metering capability, but if this option is implemented, then Price Setting could become dynamic. However, Metered Value will remain static. | |
| reqNoticeTime [0..1] | [Float](#CIM17v40-Float) | Time period that is required from an order to reduce a load to the time that it takes to get to the minimum load reduction. | |
| shutdownCost [0..1] | [Money](#CIM17v40-Money) | The fixed cost associated with committing a load reduction. | |
| AreaLoadBid [0..1] | [AreaLoadBid](#CIM17v40-AreaLoadBid) | | |
| RegisteredLoad [0..1] | [RegisteredLoad](#CIM17v40-RegisteredLoad) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aggregationFlag [0..1] | [Integer](#CIM17v40-Integer) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| bidStatus [0..1] | [String](#CIM17v40-String) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| commodityType [0..1] | [String](#CIM17v40-String) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| contingencyAvailFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [ResourceBid](CIM17v40-ResourceBid) | |
| createdISO [0..1] | [YesNo](#CIM17v40-YesNo) | see [ResourceBid](CIM17v40-ResourceBid) | |
| energyMaxDay [0..1] | [Float](#CIM17v40-Float) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| energyMinDay [0..1] | [Float](#CIM17v40-Float) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| marketSepFlag [0..1] | [String](#CIM17v40-String) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| minDispatchTime [0..1] | [Integer](#CIM17v40-Integer) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| resourceLoadingType [0..1] | [Integer](#CIM17v40-Integer) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| shutDownsMaxDay [0..1] | [Integer](#CIM17v40-Integer) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| shutDownsMaxWeek [0..1] | [Integer](#CIM17v40-Integer) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| startUpsMaxDay [0..1] | [Integer](#CIM17v40-Integer) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| startUpsMaxWeek [0..1] | [Integer](#CIM17v40-Integer) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| virtual [0..1] | [Boolean](#CIM17v40-Boolean) | see [ResourceBid](#CIM17v40-ResourceBid) | |
| marketType [0..1] | [MarketType](#CIM17v40-MarketType) | see [Bid](CIM17v40-Bid) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Bid](#CIM17v40-Bid) | |
| stopTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Bid](#CIM17v40-Bid) | |
| ActionRequest [1] | [ActionRequest](#CIM17v40-ActionRequest) | see [Bid](CIM17v40-Bid) | |
| EnergyMarket [1] | [EnergyMarket](#CIM17v40-EnergyMarket) | see [Bid](CIM17v40-Bid) | |
| MarketParticipant [0..1] | [MarketParticipant](#CIM17v40-MarketParticipant) | see [Bid](CIM17v40-Bid) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LoadBreakSwitch}
### LoadBreakSwitch

Inheritance path = [ProtectedSwitch](#CIM17v40-ProtectedSwitch) => [Switch](#CIM17v40-Switch) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LoadBreakSwitch {

}

class ProtectedSwitch {

}

ProtectedSwitch <|-- LoadBreakSwitch : inherits from
```

A mechanical switching device capable of making, carrying, and breaking currents under normal operating conditions.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| breakingCapacity [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [ProtectedSwitch](CIM17v40-ProtectedSwitch) | |
| locked [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| normalOpen [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| open [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [Switch](CIM17v40-Switch) | |
| retained [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| `switchOnCount [0..1]` (deprecated) | [Integer](#CIM17v40-Integer) | see [Switch](#CIM17v40-Switch) | |
| `switchOnDate [0..1]` (deprecated) | [DateTime](#CIM17v40-DateTime) | see [Switch](#CIM17v40-Switch) | |
| `CompositeSwitch [0..1]` (OfAggregate) | [CompositeSwitch](#CIM17v40-CompositeSwitch) | see [Switch](CIM17v40-Switch) | |
| SwitchAction [0..1] | [SwitchAction](#CIM17v40-SwitchAction) | see [Switch](CIM17v40-Switch) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LoadComposite}
### LoadComposite

Inheritance path = [LoadDynamics](#CIM17v40-LoadDynamics) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LoadComposite {

+ epfd : Float [0..1]
+ epfs : Float [0..1]
+ epvd : Float [0..1]
+ epvs : Float [0..1]
+ eqfd : Float [0..1]
+ eqfs : Float [0..1]
+ eqvd : Float [0..1]
+ eqvs : Float [0..1]
+ h : Seconds [0..1]
+ lfac : Float [0..1]
+ pfrac : Float [0..1]
}

class LoadDynamics {

}

LoadDynamics <|-- LoadComposite : inherits from
```

Combined static load and induction motor load effects.

The dynamics of the motor are simplified by linearizing the induction machine equations.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| epfd [0..1] | [Float](#CIM17v40-Float) | Active load-frequency dependence index (dynamic) (<i>Epfd</i>). Typical value = 1,5. | |
| epfs [0..1] | [Float](#CIM17v40-Float) | Active load-frequency dependence index (static) (<i>Epfs</i>). Typical value = 1,5. | |
| epvd [0..1] | [Float](#CIM17v40-Float) | Active load-voltage dependence index (dynamic) (<i>Epvd</i>). Typical value = 0,7. | |
| epvs [0..1] | [Float](#CIM17v40-Float) | Active load-voltage dependence index (static) (<i>Epvs</i>). Typical value = 0,7. | |
| eqfd [0..1] | [Float](#CIM17v40-Float) | Reactive load-frequency dependence index (dynamic) (<i>Eqfd</i>). Typical value = 0. | |
| eqfs [0..1] | [Float](#CIM17v40-Float) | Reactive load-frequency dependence index (static) (<i>Eqfs</i>). Typical value = 0. | |
| eqvd [0..1] | [Float](#CIM17v40-Float) | Reactive load-voltage dependence index (dynamic) (<i>Eqvd</i>). Typical value = 2. | |
| eqvs [0..1] | [Float](#CIM17v40-Float) | Reactive load-voltage dependence index (static) (<i>Eqvs</i>). Typical value = 2. | |
| h [0..1] | [Seconds](#CIM17v40-Seconds) | Inertia constant (<i>H</i>) (&gt;= 0). Typical value = 2,5. | |
| lfac [0..1] | [Float](#CIM17v40-Float) | Loading factor (<i>L</i><i><sub>fac</sub></i>). The ratio of initial <i>P</i> to motor MVA base. Typical value = 0,8. | |
| pfrac [0..1] | [Float](#CIM17v40-Float) | Fraction of constant-power load to be represented by this motor model (<i>P</i><i><sub>FRAC</sub></i>) (&gt;= 0,0 and &lt;= 1,0). Typical value = 0,5. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LoadDistributionFactor}
### LoadDistributionFactor


```mermaid
classDiagram
direction TB

class LoadDistributionFactor {

+ pDistFactor : Float [0..1]
+ qDistFactor : Float [0..1]
}

class AggregatedPnode {

}

LoadDistributionFactor --> "0..1" AggregatedPnode : AggregatedPnode
class IndividualPnode {

}

LoadDistributionFactor --> "0..1" IndividualPnode : IndividualPnode
```

This class models the load distribution factors. This class should be used in one of two ways:

Use it along with the AggregatedPnode and the IndividualPnode to show the distriubtion of each individual party

OR

Use it with Mkt_EnergyConsumer to represent the current MW/Mvar distribution within it's parnet load group.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| pDistFactor [0..1] | [Float](#CIM17v40-Float) | Real power (MW) load distribution factor | |
| qDistFactor [0..1] | [Float](#CIM17v40-Float) | Reactive power (MVAr) load distribution factor | |
| AggregatedPnode [0..1] | [AggregatedPnode](#CIM17v40-AggregatedPnode) | | |
| IndividualPnode [0..1] | [IndividualPnode](#CIM17v40-IndividualPnode) | | |

{#CIM17v40-LoadDynamics}
### LoadDynamics

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LoadDynamics {

}

class IdentifiedObject {

}

IdentifiedObject <|-- LoadDynamics : inherits from
```

Load whose behaviour is described by reference to a standard model <font color="#0f0f0f">or by definition of a user-defined model.</font>

A standard feature of dynamic load behaviour modelling is the ability to associate the same behaviour to multiple energy consumers by means of a single load definition. The load model is always applied to individual bus loads (energy consumers).


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LoadFollowingInst}
### LoadFollowingInst


```mermaid
classDiagram
direction TB

class LoadFollowingInst {

+ endTime : DateTime [0..1]
+ loadFollowingMW : Float [0..1]
+ mssInstructionID : String [0..1]
+ startTime : DateTime [0..1]
}

class RegisteredResource {

}

LoadFollowingInst --> "1" RegisteredResource : RegisteredResource
```

Metered SubSystem Load Following Instruction.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | Instruction End Time | |
| loadFollowingMW [0..1] | [Float](#CIM17v40-Float) | Load Following MW Positive for follow-up and negative for follow-down | |
| mssInstructionID [0..1] | [String](#CIM17v40-String) | Unique instruction id per instruction, assigned by the SC and provided to ADS. ADS passes through. | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | Instruction Start Time | |
| RegisteredResource [1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |

{#CIM17v40-LoadFollowingOperatorInput}
### LoadFollowingOperatorInput


```mermaid
classDiagram
direction TB

class LoadFollowingOperatorInput {

+ dataEntryTimeStamp : DateTime [0..1]
+ tempLoadFollowingDownManualCap : Float [0..1]
+ tempLoadFollowingUpManualCap : Float [0..1]
+ updateTimeStamp : DateTime [0..1]
+ updateType : enum:MQSCHGType [0..1]
+ updateUser : String [0..1]
}

class RegisteredResource {

}

LoadFollowingOperatorInput --> "0..1" RegisteredResource : RegisteredResource
```

Model of load following capabilities that are entered by operators on a temporary basis. Related to Registered Resources in Metered Subsystems.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dataEntryTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | Time the data entry was performed | |
| tempLoadFollowingDownManualCap [0..1] | [Float](#CIM17v40-Float) | temporarily manually entered LFD capacity | |
| tempLoadFollowingUpManualCap [0..1] | [Float](#CIM17v40-Float) | temporarily manually entered LFU capacity. | |
| updateTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| updateType [0..1] | [MQSCHGType](#CIM17v40-MQSCHGType) | | |
| updateUser [0..1] | [String](#CIM17v40-String) | | |
| RegisteredResource [0..1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |

{#CIM17v40-LoadGenericNonLinear}
### LoadGenericNonLinear

Inheritance path = [LoadDynamics](#CIM17v40-LoadDynamics) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LoadGenericNonLinear {

+ bs : Float [0..1]
+ bt : Float [0..1]
+ genericNonLinearLoadModelType : enum:GenericNonLinearLoadModelKind [0..1]
+ ls : Float [0..1]
+ lt : Float [0..1]
+ tp : Seconds [0..1]
+ tq : Seconds [0..1]
}

class LoadDynamics {

}

LoadDynamics <|-- LoadGenericNonLinear : inherits from
```

Generic non-linear dynamic (GNLD) load. This model can be used in mid-term and long-term voltage stability simulations (i.e., to study voltage collapse), as it can replace a more detailed representation of aggregate load, including induction motors, thermostatically controlled and static loads.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| bs [0..1] | [Float](#CIM17v40-Float) | Steady state voltage index for reactive power (<i>BS</i>). | |
| bt [0..1] | [Float](#CIM17v40-Float) | Transient voltage index for reactive power (<i>BT</i>). | |
| genericNonLinearLoadModelType [0..1] | [GenericNonLinearLoadModelKind](#CIM17v40-GenericNonLinearLoadModelKind) | Type of generic non-linear load model. | |
| ls [0..1] | [Float](#CIM17v40-Float) | Steady state voltage index for active power (<i>LS</i>). | |
| lt [0..1] | [Float](#CIM17v40-Float) | Transient voltage index for active power (<i>LT</i>). | |
| tp [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant of lag function of active power (<i>T</i><i><sub>P</sub></i>) (&gt; 0). | |
| tq [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant of lag function of reactive power (<i>T</i><i><sub>Q</sub></i>) (&gt; 0). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LoadGroup}
### LoadGroup

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LoadGroup {

}

class IdentifiedObject {

}

IdentifiedObject <|-- LoadGroup : inherits from
class SubLoadArea {

}

LoadGroup --> "1" SubLoadArea : SubLoadArea
```

The class is the third level in a hierarchical structure for grouping of loads for the purpose of load flow load scaling.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `SubLoadArea [1]` (OfAggregate) | [SubLoadArea](#CIM17v40-SubLoadArea) | The SubLoadArea where the Loadgroup belongs. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LoadModelPartVersion}
### LoadModelPartVersion


```mermaid
classDiagram
direction TB

class LoadModelPartVersion {

}

```

Load a model part version.


{#CIM17v40-LoadMotor}
### LoadMotor

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LoadMotor {

+ d : Float [0..1]
+ h : Seconds [0..1]
+ lfac : Float [0..1]
+ lp : PU [0..1]
+ lpp : PU [0..1]
+ ls : PU [0..1]
+ pfrac : Float [0..1]
+ ra : PU [0..1]
+ tbkr : Seconds [0..1]
+ tpo : Seconds [0..1]
+ tppo : Seconds [0..1]
+ tv : Seconds [0..1]
+ vt : PU [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- LoadMotor : inherits from
class LoadAggregate {

}

LoadMotor --> "1" LoadAggregate : LoadAggregate
```

Aggregate induction motor load. This model is used to represent a fraction of an ordinary load as "induction motor load". It allows a load that is treated as an ordinary constant power in power flow analysis to be represented by an induction motor in dynamic simulation. This model is intended for representation of aggregations of many motors dispersed through a load represented at a high voltage bus but where there is no information on the characteristics of individual motors.

Either a "one-cage" or "two-cage" model of the induction machine can be modelled. Magnetic saturation is not modelled.

This model treats a fraction of the constant power part of a load as a motor. During initialisation, the initial power drawn by the motor is set equal to <i>Pfrac</i> times the constant <i>P</i> part of the static load. The remainder of the load is left as a static load.

The reactive power demand of the motor is calculated during initialisation as a function of voltage at the load bus. This reactive power demand can be less than or greater than the constant <i>Q</i> component of the load. If the motor's reactive demand is greater than the constant <i>Q</i> component of the load, the model inserts a shunt capacitor at the terminal of the motor to bring its reactive demand down to equal the constant <i>Q</i> reactive load.

If an induction motor load model and a static load model are both present for a load, the motor <i>Pfrac</i> is assumed to be subtracted from the power flow constant <i>P</i> load before the static load model is applied. The remainder of the load, if any, is then represented by the static load model.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| d [0..1] | [Float](#CIM17v40-Float) | Damping factor (<i>D</i>). Unit = delta <i>P</i>/delta speed. Typical value = 2. | |
| h [0..1] | [Seconds](#CIM17v40-Seconds) | Inertia constant (<i>H</i>) (&gt;= 0). Typical value = 0,4. | |
| lfac [0..1] | [Float](#CIM17v40-Float) | Loading factor (<i>Lfac</i>). The ratio of initial <i>P</i> to motor MVA base. Typical value = 0,8. | |
| lp [0..1] | [PU](#CIM17v40-PU) | Transient reactance (<i>Lp</i>). Typical value = 0,15. | |
| lpp [0..1] | [PU](#CIM17v40-PU) | Subtransient reactance (<i>Lpp</i>). Typical value = 0,15. | |
| ls [0..1] | [PU](#CIM17v40-PU) | Synchronous reactance (<i>Ls</i>). Typical value = 3,2. | |
| pfrac [0..1] | [Float](#CIM17v40-Float) | Fraction of constant-power load to be represented by this motor model (<i>Pfrac</i>) (&gt;= 0,0 and &lt;= 1,0). Typical value = 0,3. | |
| ra [0..1] | [PU](#CIM17v40-PU) | Stator resistance (<i>Ra</i>). Typical value = 0. | |
| tbkr [0..1] | [Seconds](#CIM17v40-Seconds) | Circuit breaker operating time (<i>Tbkr</i>) (&gt;= 0). Typical value = 0,08. | |
| tpo [0..1] | [Seconds](#CIM17v40-Seconds) | Transient rotor time constant (<i>Tpo</i>) (&gt;= 0). Typical value = 1. | |
| tppo [0..1] | [Seconds](#CIM17v40-Seconds) | Subtransient rotor time constant (<i>Tppo</i>) (&gt;= 0). Typical value = 0,02. | |
| tv [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage trip pickup time (<i>Tv</i>) (&gt;= 0). Typical value = 0,1. | |
| vt [0..1] | [PU](#CIM17v40-PU) | Voltage threshold for tripping (<i>Vt</i>). Typical value = 0,7. | |
| LoadAggregate [1] | [LoadAggregate](#CIM17v40-LoadAggregate) | Aggregate load to which this aggregate motor (dynamic) load belongs. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LoadRatio}
### LoadRatio


```mermaid
classDiagram
direction TB

class LoadRatio {

+ intervalEndTime : DateTime [0..1]
+ intervalStartTime : DateTime [0..1]
+ share : PerCent [0..1]
}

class SchedulingCoordinator {

}

LoadRatio --> "0..1" SchedulingCoordinator : SchedulingCoordinator
```

Representing the ratio of the load share for the associated SC.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | Interval End Time | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | Interval Start Time | |
| share [0..1] | [PerCent](#CIM17v40-PerCent) | Share in percentage of total Market load for the selected time interval. | |
| SchedulingCoordinator [0..1] | [SchedulingCoordinator](#CIM17v40-SchedulingCoordinator) | | |

{#CIM17v40-LoadReductionPriceCurve}
### LoadReductionPriceCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LoadReductionPriceCurve {

}

class Curve {

}

Curve <|-- LoadReductionPriceCurve : inherits from
class LoadBid {

}

LoadReductionPriceCurve --> "1" LoadBid : LoadBid
```

This is the price sensitivity that bidder expresses for allowing market load interruption. Relationship between price (Y1-axis) vs. MW (X-axis).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| LoadBid [1] | [LoadBid](#CIM17v40-LoadBid) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LoadReductionTimeCurve}
### LoadReductionTimeCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LoadReductionTimeCurve {

+ loadReductionTimeCurveType : String [0..1]
}

class Curve {

}

Curve <|-- LoadReductionTimeCurve : inherits from
```

This is the cureve that describes the load reduction time. Relationship between time (Y1-axis) vs. MW (X-axis).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| loadReductionTimeCurveType [0..1] | [String](#CIM17v40-String) | type of the curve: Possible values are but not limited to:Max, Min, | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LoadResponseCharacteristic}
### LoadResponseCharacteristic

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LoadResponseCharacteristic {

+ exponentModel : Boolean [0..1]
+ pConstantCurrent : Float [0..1]
+ pConstantImpedance : Float [0..1]
+ pConstantPower : Float [0..1]
+ pFrequencyExponent : Float [0..1]
+ pVoltageExponent : Float [0..1]
+ qConstantCurrent : Float [0..1]
+ qConstantImpedance : Float [0..1]
+ qConstantPower : Float [0..1]
+ qFrequencyExponent : Float [0..1]
+ qVoltageExponent : Float [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- LoadResponseCharacteristic : inherits from
```

Models the characteristic response of the load demand due to changes in system conditions such as voltage and frequency. It is not related to demand response.

If LoadResponseCharacteristic.exponentModel is True, the exponential voltage or frequency dependent models are specified and used as to calculate active and reactive power components of the load model.

The equations to calculate active and reactive power components of the load model are internal to the power flow calculation, hence they use different quantities depending on the use case of the data exchange.

The equations for exponential voltage dependent load model injected power are:

pInjection= Pnominal* (Voltage/cim:BaseVoltage.nominalVoltage) ** cim:LoadResponseCharacteristic.pVoltageExponent

qInjection= Qnominal* (Voltage/cim:BaseVoltage.nominalVoltage) ** cim:LoadResponseCharacteristic.qVoltageExponent

Where:

1) * means "multiply" and ** is "raised to power of";

2) Pnominal and Qnominal represent the active power and reactive power at nominal voltage as any load described by the voltage exponential model shall be given at nominal voltage. This means that EnergyConsumer.p and EnergyConsumer.q are at nominal voltage.

3) After power flow is solved:

-pInjection and qInjection correspond to SvPowerflow.p and SvPowerflow.q respectively.

- Voltage corresponds to SvVoltage.v at the TopologicalNode where the load is connected.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| exponentModel [0..1] | [Boolean](#CIM17v40-Boolean) | Indicates the exponential voltage dependency model is to be used. If false, the coefficient model is to be used.The exponential voltage dependency model consist of the attributes:- pVoltageExponent- qVoltageExponent- pFrequencyExponent- qFrequencyExponent.The coefficient model consist of the attributes:- pConstantImpedance- pConstantCurrent- pConstantPower- qConstantImpedance- qConstantCurrent- qConstantPower.The sum of pConstantImpedance, pConstantCurrent and pConstantPower shall equal 1.The sum of qConstantImpedance, qConstantCurrent and qConstantPower shall equal 1. | |
| pConstantCurrent [0..1] | [Float](#CIM17v40-Float) | Portion of active power load modelled as constant current. | |
| pConstantImpedance [0..1] | [Float](#CIM17v40-Float) | Portion of active power load modelled as constant impedance. | |
| pConstantPower [0..1] | [Float](#CIM17v40-Float) | Portion of active power load modelled as constant power. | |
| pFrequencyExponent [0..1] | [Float](#CIM17v40-Float) | Exponent of per unit frequency effecting active power. | |
| pVoltageExponent [0..1] | [Float](#CIM17v40-Float) | Exponent of per unit voltage effecting real power. | |
| qConstantCurrent [0..1] | [Float](#CIM17v40-Float) | Portion of reactive power load modelled as constant current. | |
| qConstantImpedance [0..1] | [Float](#CIM17v40-Float) | Portion of reactive power load modelled as constant impedance. | |
| qConstantPower [0..1] | [Float](#CIM17v40-Float) | Portion of reactive power load modelled as constant power. | |
| qFrequencyExponent [0..1] | [Float](#CIM17v40-Float) | Exponent of per unit frequency effecting reactive power. | |
| qVoltageExponent [0..1] | [Float](#CIM17v40-Float) | Exponent of per unit voltage effecting reactive power. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LoadStatic}
### LoadStatic

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LoadStatic {

+ ep1 : Float [0..1]
+ ep2 : Float [0..1]
+ ep3 : Float [0..1]
+ eq1 : Float [0..1]
+ eq2 : Float [0..1]
+ eq3 : Float [0..1]
+ kp1 : Float [0..1]
+ kp2 : Float [0..1]
+ kp3 : Float [0..1]
+ kp4 : Float [0..1]
+ kpf : Float [0..1]
+ kq1 : Float [0..1]
+ kq2 : Float [0..1]
+ kq3 : Float [0..1]
+ kq4 : Float [0..1]
+ kqf : Float [0..1]
+ staticLoadModelType : enum:StaticLoadModelKind [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- LoadStatic : inherits from
class LoadAggregate {

}

LoadStatic --> "1" LoadAggregate : LoadAggregate
```

General static load. This model represents the sensitivity of the real and reactive power consumed by the load to the amplitude and frequency of the bus voltage.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ep1 [0..1] | [Float](#CIM17v40-Float) | First term voltage exponent for active power (<i>Ep1</i>). Used only when .staticLoadModelType = exponential. | |
| ep2 [0..1] | [Float](#CIM17v40-Float) | Second term voltage exponent for active power (<i>Ep2</i>). Used only when .staticLoadModelType = exponential. | |
| ep3 [0..1] | [Float](#CIM17v40-Float) | Third term voltage exponent for active power (<i>Ep3</i>). Used only when .staticLoadModelType = exponential. | |
| eq1 [0..1] | [Float](#CIM17v40-Float) | First term voltage exponent for reactive power (<i>Eq1</i>). Used only when .staticLoadModelType = exponential. | |
| eq2 [0..1] | [Float](#CIM17v40-Float) | Second term voltage exponent for reactive power (<i>Eq2</i>). Used only when .staticLoadModelType = exponential. | |
| eq3 [0..1] | [Float](#CIM17v40-Float) | Third term voltage exponent for reactive power (<i>Eq3</i>). Used only when .staticLoadModelType = exponential. | |
| kp1 [0..1] | [Float](#CIM17v40-Float) | First term voltage coefficient for active power (<i>K</i><i><sub>p1</sub></i>). Not used when .staticLoadModelType = constantZ. | |
| kp2 [0..1] | [Float](#CIM17v40-Float) | Second term voltage coefficient for active power (<i>K</i><i><sub>p2</sub></i>). Not used when .staticLoadModelType = constantZ. | |
| kp3 [0..1] | [Float](#CIM17v40-Float) | Third term voltage coefficient for active power (<i>K</i><i><sub>p3</sub></i>). Not used when .staticLoadModelType = constantZ. | |
| kp4 [0..1] | [Float](#CIM17v40-Float) | Frequency coefficient for active power (<i>K</i><i><sub>p4</sub></i>) (not = 0 if .staticLoadModelType = zIP2). Used only when .staticLoadModelType = zIP2. | |
| kpf [0..1] | [Float](#CIM17v40-Float) | Frequency deviation coefficient for active power (<i>K</i><i><sub>pf</sub></i>). Not used when .staticLoadModelType = constantZ. | |
| kq1 [0..1] | [Float](#CIM17v40-Float) | First term voltage coefficient for reactive power (<i>K</i><i><sub>q1</sub></i>). Not used when .staticLoadModelType = constantZ. | |
| kq2 [0..1] | [Float](#CIM17v40-Float) | Second term voltage coefficient for reactive power (<i>K</i><i><sub>q2</sub></i>). Not used when .staticLoadModelType = constantZ. | |
| kq3 [0..1] | [Float](#CIM17v40-Float) | Third term voltage coefficient for reactive power (<i>K</i><i><sub>q3</sub></i>). Not used when .staticLoadModelType = constantZ. | |
| kq4 [0..1] | [Float](#CIM17v40-Float) | Frequency coefficient for reactive power (<i>K</i><i><sub>q4</sub></i>) (not = 0 when .staticLoadModelType = zIP2). Used only when .staticLoadModelType - zIP2. | |
| kqf [0..1] | [Float](#CIM17v40-Float) | Frequency deviation coefficient for reactive power (<i>K</i><i><sub>qf</sub></i>). Not used when .staticLoadModelType = constantZ. | |
| staticLoadModelType [0..1] | [StaticLoadModelKind](#CIM17v40-StaticLoadModelKind) | Type of static load model. Typical value = constantZ. | |
| LoadAggregate [1] | [LoadAggregate](#CIM17v40-LoadAggregate) | Aggregate load to which this aggregate static load belongs. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LoadUserDefined}
### LoadUserDefined

Inheritance path = [LoadDynamics](#CIM17v40-LoadDynamics) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LoadUserDefined {

+ proprietary : Boolean [0..1]
}

class LoadDynamics {

}

LoadDynamics <|-- LoadUserDefined : inherits from
```

Load whose dynamic behaviour is described by a user-defined model.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| proprietary [0..1] | [Boolean](#CIM17v40-Boolean) | Behaviour is based on a proprietary model as opposed to a detailed model.true = user-defined model is proprietary with behaviour mutually understood by sending and receiving applications and parameters passed as general attributesfalse = user-defined model is explicitly defined in terms of control blocks and their input and output signals. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LocalReliabilityArea}
### LocalReliabilityArea

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LocalReliabilityArea {

}

class IdentifiedObject {

}

IdentifiedObject <|-- LocalReliabilityArea : inherits from
class RTO {

}

LocalReliabilityArea --> "1" RTO : RTO
```

Allows definition of reliability areas (e.g.. load pockets) within the ISO/RTO.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| RTO [1] | [RTO](#CIM17v40-RTO) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Location}
### Location

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Location {

+ direction : String [0..1]
+ geoInfoReference : String [0..1]
+ type : String [0..1]
+ electronicAddress : ElectronicAddress [0..1]
+ mainAddress : StreetAddress [0..1]
+ phone1 : TelephoneNumber [0..1]
+ phone2 : TelephoneNumber [0..1]
+ secondaryAddress : StreetAddress [0..1]
+ status : Status [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Location : inherits from
class CoordinateSystem {

}

Location --> "0..1" CoordinateSystem : CoordinateSystem
class Incident {

}

Location --> "0..1" Incident : Incident
class OutageOrder {

}

Location --> "0..1" OutageOrder : OutageOrder
class SwitchingOrder {

}

Location --> "0..1" SwitchingOrder : SwitchingOrder
class TroubleOrder {

}

Location --> "0..1" TroubleOrder : TroubleOrder
class TroubleTicket {

}

Location --> "0..1" TroubleTicket : TroubleTicket
```

The place, scene, or point of something where someone or something has been, is, and/or will be at a given moment in time. It can be defined with one or more position points (coordinates) in a given coordinate system.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| direction [0..1] | [String](#CIM17v40-String) | (if applicable) Direction that allows field crews to quickly find a given asset. For a given location, such as a street address, this is the relative direction in which to find the asset. For example, a streetlight may be located at the 'NW' (northwest) corner of the customer's site, or a usage point may be located on the second floor of an apartment building. | |
| geoInfoReference [0..1] | [String](#CIM17v40-String) | (if applicable) Reference to geographical information source, often external to the utility. | |
| type [0..1] | [String](#CIM17v40-String) | Classification by utility's corporate standards and practices, relative to the location itself (e.g., geographical, functional accounting, etc., not a given property that happens to exist at that location). | |
| CoordinateSystem [0..1] | [CoordinateSystem](#CIM17v40-CoordinateSystem) | Coordinate system used to describe position points of this location. | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | Electronic address. | |
| Incident [0..1] | [Incident](#CIM17v40-Incident) | Incident at this location. | |
| mainAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | Main address of the location. | |
| OutageOrder [0..1] | [OutageOrder](#CIM17v40-OutageOrder) | The outage order at this location. | |
| phone1 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | Phone number. | |
| phone2 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | Additional phone number. | |
| secondaryAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | Secondary address of the location. For example, PO Box address may have different ZIP code than that in the 'mainAddress'. | |
| status [0..1] | [Status](#CIM17v40-Status) | Status of this location. | |
| SwitchingOrder [0..1] | [SwitchingOrder](#CIM17v40-SwitchingOrder) | The switching order at this location. | |
| TroubleOrder [0..1] | [TroubleOrder](#CIM17v40-TroubleOrder) | The trouble order at this location | |
| TroubleTicket [0..1] | [TroubleTicket](#CIM17v40-TroubleTicket) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LocationGrant}
### LocationGrant

Inheritance path = [Agreement](#CIM17v40-Agreement) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LocationGrant {

+ propertyData : String [0..1]
}

class Agreement {

}

Agreement <|-- LocationGrant : inherits from
class LandProperty {

}

LocationGrant --> "0..1" LandProperty : LandProperty
```

A grant provides a right, as defined by type, for a parcel of land. Note that the association to Location, Asset, Organisation, etc. for the Grant is inherited from Agreement, a type of Document.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| propertyData [0..1] | [String](#CIM17v40-String) | Property related information that describes the Grant's land parcel. For example, it may be a deed book number, deed book page number, and parcel number. | |
| `LandProperty [0..1]` (informative) | [LandProperty](#CIM17v40-LandProperty) | Land property this location grant applies to. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| signDate [0..1] | [Date](#CIM17v40-Date) | see [Agreement](#CIM17v40-Agreement) | |
| validityInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [Agreement](CIM17v40-Agreement) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LossClearing}
### LossClearing

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LossClearing {

}

class MarketFactors {

}

MarketFactors <|-- LossClearing : inherits from
```

RT only and is published on 5 minute intervals for the previous RT time interval results.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LossClearingResults}
### LossClearingResults


```mermaid
classDiagram
direction TB

class LossClearingResults {

+ lossMW : Float [0..1]
}

class HostControlArea {

}

LossClearingResults --> "0..1" HostControlArea : HostControlArea
class LossClearing {

}

LossClearingResults --> "0..1" LossClearing : LossClearing
class RUCZone {

}

LossClearingResults --> "0..1" RUCZone : RUCZone
class SubControlArea {

}

LossClearingResults --> "0..1" SubControlArea : SubControlArea
```

Provides the MW loss for RUC Zones, subcontrol areas, and the total loss.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| lossMW [0..1] | [Float](#CIM17v40-Float) | | |
| HostControlArea [0..1] | [HostControlArea](#CIM17v40-HostControlArea) | | |
| LossClearing [0..1] | [LossClearing](#CIM17v40-LossClearing) | | |
| RUCZone [0..1] | [RUCZone](#CIM17v40-RUCZone) | | |
| SubControlArea [0..1] | [SubControlArea](#CIM17v40-SubControlArea) | | |

{#CIM17v40-LossProfile}
### LossProfile

Inheritance path = [Profile](#CIM17v40-Profile) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LossProfile {

}

class Profile {

}

Profile <|-- LossProfile : inherits from
class EnergyTransaction {

}

LossProfile --> "1" EnergyTransaction : EnergyTransaction
class TransmissionProvider {

}

LossProfile --> "0..1" TransmissionProvider : HasLoss_
```

LossProfile is associated with an EnerrgyTransaction and must be completely contained within the time frame of the EnergyProfile associated with this EnergyTransaction.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `EnergyTransaction [1]` (OfAggregate, informative) | [EnergyTransaction](#CIM17v40-EnergyTransaction) | An EnergyTransaction may have a LossProfile. | |
| `HasLoss_ [0..1]` (informative) | [TransmissionProvider](#CIM17v40-TransmissionProvider) | Part of the LossProfile for an EnergyTransaction may be a loss for a TransmissionProvider. If so, the TransmissionProvider must be one of the participating entities in the EnergyTransaction. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-LossSensitivity}
### LossSensitivity

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class LossSensitivity {

+ lossFactor : Float [0..1]
}

class MarketFactors {

}

MarketFactors <|-- LossSensitivity : inherits from
class MktConnectivityNode {

}

LossSensitivity --> "1" MktConnectivityNode : MktConnectivityNode
```

Loss sensitivity applied to a ConnectivityNode for a given time interval.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| lossFactor [0..1] | [Float](#CIM17v40-Float) | Loss penalty factor.Defined as: 1 / ( 1 - Incremental Transmission Loss); with the Incremental Transmission Loss expressed as a plus or minus value. The typical range of penalty factors is (0,9 to 1,1). | |
| MktConnectivityNode [1] | [MktConnectivityNode](#CIM17v40-MktConnectivityNode) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MPMClearing}
### MPMClearing

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MPMClearing {

+ LMPMFinalFlag : enum:YesNo [0..1]
+ mitigationOccuredFlag : enum:YesNo [0..1]
+ SMPMFinalFlag : enum:YesNo [0..1]
}

class MarketFactors {

}

MarketFactors <|-- MPMClearing : inherits from
```

Model of results of Market Power tests, and possible mitigation. Interval based.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| LMPMFinalFlag [0..1] | [YesNo](#CIM17v40-YesNo) | | |
| mitigationOccuredFlag [0..1] | [YesNo](#CIM17v40-YesNo) | | |
| SMPMFinalFlag [0..1] | [YesNo](#CIM17v40-YesNo) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MPMResourceStatus}
### MPMResourceStatus


```mermaid
classDiagram
direction TB

class MPMResourceStatus {

+ resourceStatus : String [0..1]
}

class MPMTestCategory {

}

MPMResourceStatus --> "1" MPMTestCategory : MPMTestCategory
class RegisteredResource {

}

MPMResourceStatus --> "0..1" RegisteredResource : RegisteredResource
```

Model of results of Market Power tests, gives status of resource for the associated interval.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| resourceStatus [0..1] | [String](#CIM17v40-String) | Interval Test Status'N' - not applicable | |
| MPMTestCategory [1] | [MPMTestCategory](#CIM17v40-MPMTestCategory) | | |
| RegisteredResource [0..1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |

{#CIM17v40-MPMTestCategory}
### MPMTestCategory

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MPMTestCategory {

+ purposeFlag : enum:PurposeFlagType [0..1]
+ testIdentifier : enum:MPMTestIdentifierType [0..1]
+ testMethod : enum:MPMTestMethodType [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- MPMTestCategory : inherits from
```

Provides a reference to the Market Power Mitigation test identifiers and methods for the results of the DA or RT markets. Specific data is the test identifier (Price, Conduct, or Impact) and the test method (System MPM, Local MPM, Alternate System MPM, or Alternate Local MPM).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| purposeFlag [0..1] | [PurposeFlagType](#CIM17v40-PurposeFlagType) | Nature of threshold data:'M' - Mitigation threshold'R' - Reporting threshold | |
| testIdentifier [0..1] | [MPMTestIdentifierType](#CIM17v40-MPMTestIdentifierType) | 1 - Global Price Test2 - Global Conduct Test3 - Global Impact Test4 - Local Price Test5 - Local Conduct Test6 - Local Impact Test | |
| testMethod [0..1] | [MPMTestMethodType](#CIM17v40-MPMTestMethodType) | The method of performing the market power monitoring. Examples are Normal (default) thresholds or Alternate thresholds. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MPMTestResults}
### MPMTestResults


```mermaid
classDiagram
direction TB

class MPMTestResults {

+ marginPercent : PerCent [0..1]
+ outcome : enum:MPMTestOutcome [0..1]
}

class AggregatedPnode {

}

MPMTestResults --> "1" AggregatedPnode : AggregatedPnode
class MPMClearing {

}

MPMTestResults --> "0..1" MPMClearing : MPMClearing
class MPMTestCategory {

}

MPMTestResults --> "1" MPMTestCategory : MPMTestCategory
```

Provides the outcome and margin percent (as appropriate) result data for the MPM tests. There are relationships to Zone for Designated Congestion Area Tests, CurveSchedData for bid segment tests, to the SubControlArea for the system wide level tests, and Pnodes for the LMPM impact tests.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| marginPercent [0..1] | [PerCent](#CIM17v40-PerCent) | Used to show the Margin % result of the Impact test | |
| outcome [0..1] | [MPMTestOutcome](#CIM17v40-MPMTestOutcome) | The results of the test. For the Price, Impact, and Conduct tests, typical values are NA, Pass, Fail, Disable, or Skip. | |
| AggregatedPnode [1] | [AggregatedPnode](#CIM17v40-AggregatedPnode) | | |
| MPMClearing [0..1] | [MPMClearing](#CIM17v40-MPMClearing) | | |
| MPMTestCategory [1] | [MPMTestCategory](#CIM17v40-MPMTestCategory) | | |

{#CIM17v40-MPMTestThreshold}
### MPMTestThreshold


```mermaid
classDiagram
direction TB

class MPMTestThreshold {

+ marketType : enum:MarketType [0..1]
+ percent : PerCent [0..1]
+ price : CostPerEnergyUnit [0..1]
}

class MPMTestCategory {

}

MPMTestThreshold --> "1" MPMTestCategory : MPMTestCategory
```

Market Power Mitigation (MPM) test thresholds for resource as well as designated congestion areas (DCAs).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| marketType [0..1] | [MarketType](#CIM17v40-MarketType) | Market Type (DAM, RTM) | |
| percent [0..1] | [PerCent](#CIM17v40-PerCent) | Price Threshold in % | |
| price [0..1] | [CostPerEnergyUnit](#CIM17v40-CostPerEnergyUnit) | Price Threshold in $/MW | |
| MPMTestCategory [1] | [MPMTestCategory](#CIM17v40-MPMTestCategory) | | |

{#CIM17v40-MSSAggregation}
### MSSAggregation

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MSSAggregation {

+ costRecovery : enum:YesNo [0..1]
+ grossSettlement : enum:YesNo [0..1]
+ ignoreLosses : enum:YesNo [0..1]
+ ignoreMarginalLosses : enum:YesNo [0..1]
+ loadFollowing : enum:YesNo [0..1]
+ rucProcurement : enum:YesNo [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- MSSAggregation : inherits from
class RTO {

}

MSSAggregation --> "1" RTO : RTO
```

Metered Sub-System aggregation of MSS Zones.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| costRecovery [0..1] | [YesNo](#CIM17v40-YesNo) | Charge for Emission Costs, Start Up Costs, or Minimum Load Costs. | |
| grossSettlement [0..1] | [YesNo](#CIM17v40-YesNo) | MSS Load Following may select Net vs. Gross settlement. Net Settlement requires the net Demand settled at the MSS LAP and Net Supply needs to settle at the equivalent to the weighted average price of the MSS generation. Gross load will be settled at the System LAP and the Gross supply will be settled at the LMP. MSS Aggregation that elects gross settlement shall have to identify if its resources are Load Following or not. | |
| ignoreLosses [0..1] | [YesNo](#CIM17v40-YesNo) | Provides an indication if losses are to be ignored for this zone. Also refered to as Exclude Marginal Losses. | |
| ignoreMarginalLosses [0..1] | [YesNo](#CIM17v40-YesNo) | Provides an indication if marginal losses are to be ignored for this zone. | |
| loadFollowing [0..1] | [YesNo](#CIM17v40-YesNo) | Indication that this particular MSSA participates in the Load Following function. | |
| rucProcurement [0..1] | [YesNo](#CIM17v40-YesNo) | Indicates that RUC will be procured by the ISO or self provided. | |
| RTO [1] | [RTO](#CIM17v40-RTO) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MSSZone}
### MSSZone

Inheritance path = [AggregateNode](#CIM17v40-AggregateNode) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MSSZone {

+ ignoreLosses : enum:YesNo [0..1]
+ lossFactor : Float [0..1]
+ rucGrossSettlement : enum:YesNo [0..1]
}

class AggregateNode {

}

AggregateNode <|-- MSSZone : inherits from
class MeteredSubSystem {

}

MSSZone --> "0..1" MeteredSubSystem : MeteredSubSystem
```

Model to define a zone within a Metered Sub System.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ignoreLosses [0..1] | [YesNo](#CIM17v40-YesNo) | Provides an indication if losses are to be ignored for this metered subsystem zone. | |
| lossFactor [0..1] | [Float](#CIM17v40-Float) | This is the default loss factor for the Metered Sub-System (MSS) zone. The actual losses are calculated during the RT market. | |
| rucGrossSettlement [0..1] | [YesNo](#CIM17v40-YesNo) | Metered Sub-System (MSS) Load Following may select Net vs. Gross settlement. Net Settlement requires the net Demand settled at the Metered Sub-Sustem (MSS) Load Aggregation Point (LAP) and Net Supply needs to settle at the equivalent to the weighted average price of the MSS generation. Gross load will be settled at the System LAP and the Gross supply will be settled at the LMP. MSS Aggregation that elects gross settlement shall have to identify if its resources are Load Following or not. | |
| MeteredSubSystem [0..1] | [MeteredSubSystem](#CIM17v40-MeteredSubSystem) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| anodeType [0..1] | [AnodeType](#CIM17v40-AnodeType) | see [AggregateNode](CIM17v40-AggregateNode) | |
| qualifASOrder [0..1] | [Integer](#CIM17v40-Integer) | see [AggregateNode](#CIM17v40-AggregateNode) | |
| RTO [1] | [RTO](#CIM17v40-RTO) | see [AggregateNode](CIM17v40-AggregateNode) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MWLimitSchedule}
### MWLimitSchedule


```mermaid
classDiagram
direction TB

class MWLimitSchedule {

}

class ContingencyConstraintLimit {

}

MWLimitSchedule --> "1" ContingencyConstraintLimit : SecurityConstraintLimit
```

Maximum MW and optionally Minimum MW (Y1 and Y2, respectively).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| SecurityConstraintLimit [1] | [ContingencyConstraintLimit](#CIM17v40-ContingencyConstraintLimit) | | |

{#CIM17v40-MagneticStorm}
### MagneticStorm

Inheritance path = [SpacePhenomenon](#CIM17v40-SpacePhenomenon) => [EnvironmentalPhenomenon](#CIM17v40-EnvironmentalPhenomenon)

```mermaid
classDiagram
direction TB

class MagneticStorm {

+ changeDst : MagneticField [0..1]
}

class SpacePhenomenon {

}

SpacePhenomenon <|-- MagneticStorm : inherits from
```

A magnetic storm, a temporary disturbance of the earth's magnetic field, induced by radiation and streams of charged particles from the sun.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| changeDst [0..1] | [MagneticField](#CIM17v40-MagneticField) | Change in the disturbance - storm time (Dst) index. The size of a geomagnetic storm is classified as:- moderate ( -50 nT &gt;minimum of Dst &gt; -100 nT)- intense (-100 nT &gt; minimum Dst &gt; -250 nT) or- super-storm ( minimum of Dst &lt; -250 nT). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| PhenomenonClassification [0..1] | [PhenomenonClassification](#CIM17v40-PhenomenonClassification) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| timeInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |

{#CIM17v40-Maintainer}
### Maintainer

Inheritance path = [AssetOrganisationRole](#CIM17v40-AssetOrganisationRole) => [OrganisationRole](#CIM17v40-OrganisationRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Maintainer {

}

class AssetOrganisationRole {

}

AssetOrganisationRole <|-- Maintainer : inherits from
```

Organisation that maintains assets.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Organisation [0..1] | [Organisation](#CIM17v40-Organisation) | see [OrganisationRole](CIM17v40-OrganisationRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MaintenanceDataSet}
### MaintenanceDataSet

Inheritance path = [ProcedureDataSet](#CIM17v40-ProcedureDataSet) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MaintenanceDataSet {

+ conditionAfter : String [0..1]
+ conditionBefore : String [0..1]
+ maintCode : String [0..1]
}

class ProcedureDataSet {

}

ProcedureDataSet <|-- MaintenanceDataSet : inherits from
```

The result of a maintenance activity, a type of Procedure, for a given attribute of an asset.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| conditionAfter [0..1] | [String](#CIM17v40-String) | Condition of asset just following maintenance procedure. | |
| conditionBefore [0..1] | [String](#CIM17v40-String) | Description of the condition of the asset just prior to maintenance being performed. | |
| maintCode [0..1] | [String](#CIM17v40-String) | Code for the type of maintenance performed. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| completedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [ProcedureDataSet](#CIM17v40-ProcedureDataSet) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [ProcedureDataSet](CIM17v40-ProcedureDataSet) | |
| Procedure [0..1] | [Procedure](#CIM17v40-Procedure) | see [ProcedureDataSet](CIM17v40-ProcedureDataSet) | |
| WorkTask [0..1] | [WorkTask](#CIM17v40-WorkTask) | see [ProcedureDataSet](CIM17v40-ProcedureDataSet) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MaintenanceLocation}
### MaintenanceLocation

Inheritance path = [WorkLocation](#CIM17v40-WorkLocation) => [Location](#CIM17v40-Location) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MaintenanceLocation {

+ block : String [0..1]
+ lot : String [0..1]
+ nearestIntersection : String [0..1]
+ subdivision : String [0..1]
}

class WorkLocation {

}

WorkLocation <|-- MaintenanceLocation : inherits from
```

Location where to perform maintenance work.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| block [0..1] | [String](#CIM17v40-String) | (if applicable) Name, identifier, or description of the block in which work is to occur. | |
| lot [0..1] | [String](#CIM17v40-String) | (if applicable) Name, identifier, or description of the lot in which work is to occur. | |
| nearestIntersection [0..1] | [String](#CIM17v40-String) | The names of streets at the nearest intersection to work area. | |
| subdivision [0..1] | [String](#CIM17v40-String) | (if applicable) Name, identifier, or description of the subdivision in which work is to occur. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `OneCallRequest [0..1]` (informative) | [OneCallRequest](#CIM17v40-OneCallRequest) | see [WorkLocation](CIM17v40-WorkLocation) | |
| direction [0..1] | [String](#CIM17v40-String) | see [Location](#CIM17v40-Location) | |
| geoInfoReference [0..1] | [String](#CIM17v40-String) | see [Location](#CIM17v40-Location) | |
| type [0..1] | [String](#CIM17v40-String) | see [Location](#CIM17v40-Location) | |
| CoordinateSystem [0..1] | [CoordinateSystem](#CIM17v40-CoordinateSystem) | see [Location](CIM17v40-Location) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Location](CIM17v40-Location) | |
| Incident [0..1] | [Incident](#CIM17v40-Incident) | see [Location](CIM17v40-Location) | |
| mainAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Location](CIM17v40-Location) | |
| OutageOrder [0..1] | [OutageOrder](#CIM17v40-OutageOrder) | see [Location](CIM17v40-Location) | |
| phone1 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Location](CIM17v40-Location) | |
| phone2 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Location](CIM17v40-Location) | |
| secondaryAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Location](CIM17v40-Location) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Location](CIM17v40-Location) | |
| SwitchingOrder [0..1] | [SwitchingOrder](#CIM17v40-SwitchingOrder) | see [Location](CIM17v40-Location) | |
| TroubleOrder [0..1] | [TroubleOrder](#CIM17v40-TroubleOrder) | see [Location](CIM17v40-Location) | |
| TroubleTicket [0..1] | [TroubleTicket](#CIM17v40-TroubleTicket) | see [Location](CIM17v40-Location) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MaintenanceOrder}
### MaintenanceOrder

Inheritance path = [WorkOrder](#CIM17v40-WorkOrder) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MaintenanceOrder {

}

class WorkOrder {

}

WorkOrder <|-- MaintenanceOrder : inherits from
```


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MaintenanceWorkTask}
### MaintenanceWorkTask

Inheritance path = [WorkTask](#CIM17v40-WorkTask) => [BaseWork](#CIM17v40-BaseWork) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MaintenanceWorkTask {

+ breakerMaintenanceKind : enum:BreakerMaintenanceKind [0..1]
+ transformerMaintenanceKind : enum:TransformerMaintenanceKind [0..1]
}

class WorkTask {

}

WorkTask <|-- MaintenanceWorkTask : inherits from
```

Maintenance work task. Costs associated with this are considered preventive maintenance (PM) costs.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| breakerMaintenanceKind [0..1] | [BreakerMaintenanceKind](#CIM17v40-BreakerMaintenanceKind) | Kind of breaker maintenance performed by this maintenance work task. | |
| transformerMaintenanceKind [0..1] | [TransformerMaintenanceKind](#CIM17v40-TransformerMaintenanceKind) | Kind of transformer maintenance performed by this maintenance work task. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| completedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [WorkTask](#CIM17v40-WorkTask) | |
| contractorCost [0..1] | [Money](#CIM17v40-Money) | see [WorkTask](CIM17v40-WorkTask) | |
| crewETA [0..1] | [DateTime](#CIM17v40-DateTime) | see [WorkTask](#CIM17v40-WorkTask) | |
| estimatedCompletionTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [WorkTask](#CIM17v40-WorkTask) | |
| instruction [0..1] | [String](#CIM17v40-String) | see [WorkTask](#CIM17v40-WorkTask) | |
| laborCost [0..1] | [Money](#CIM17v40-Money) | see [WorkTask](CIM17v40-WorkTask) | |
| laborHours [0..1] | [Hours](#CIM17v40-Hours) | see [WorkTask](CIM17v40-WorkTask) | |
| materiallCost [0..1] | [Money](#CIM17v40-Money) | see [WorkTask](CIM17v40-WorkTask) | |
| schedOverride [0..1] | [String](#CIM17v40-String) | see [WorkTask](#CIM17v40-WorkTask) | |
| startedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [WorkTask](#CIM17v40-WorkTask) | |
| taskKind [0..1] | [WorkTaskKind](#CIM17v40-WorkTaskKind) | see [WorkTask](CIM17v40-WorkTask) | |
| toolCost [0..1] | [Money](#CIM17v40-Money) | see [WorkTask](CIM17v40-WorkTask) | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | see [WorkTask](CIM17v40-WorkTask) | |
| TroubleOrder [0..1] | [TroubleOrder](#CIM17v40-TroubleOrder) | see [WorkTask](CIM17v40-WorkTask) | |
| Work [1] | [Work](#CIM17v40-Work) | see [WorkTask](CIM17v40-WorkTask) | |
| kind [0..1] | [ServiceRequestKind](#CIM17v40-ServiceRequestKind) | see [BaseWork](CIM17v40-BaseWork) | |
| statusKind [0..1] | [WorkStatusKind](#CIM17v40-WorkStatusKind) | see [BaseWork](CIM17v40-BaseWork) | |
| priority [0..1] | [Priority](#CIM17v40-Priority) | see [BaseWork](CIM17v40-BaseWork) | |
| WorkLocation [0..1] | [WorkLocation](#CIM17v40-WorkLocation) | see [BaseWork](CIM17v40-BaseWork) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MajorChargeGroup}
### MajorChargeGroup

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MajorChargeGroup {

+ effectiveDate : DateTime [0..1]
+ frequencyType : String [0..1]
+ invoiceType : String [0..1]
+ requireAutorun : String [0..1]
+ revisionNumber : String [0..1]
+ runType : String [0..1]
+ runVersion : String [0..1]
+ terminationDate : DateTime [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- MajorChargeGroup : inherits from
```

A Major Charge Group is the same as Invoice Type which provides the highest level of grouping for charge types configuration. Examples: Market, FERC, RMR.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| effectiveDate [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| frequencyType [0..1] | [String](#CIM17v40-String) | | |
| invoiceType [0..1] | [String](#CIM17v40-String) | | |
| requireAutorun [0..1] | [String](#CIM17v40-String) | | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | Revision number for the major charge group | |
| runType [0..1] | [String](#CIM17v40-String) | | |
| runVersion [0..1] | [String](#CIM17v40-String) | | |
| terminationDate [0..1] | [DateTime](#CIM17v40-DateTime) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Manufacturer}
### Manufacturer

Inheritance path = [OrganisationRole](#CIM17v40-OrganisationRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Manufacturer {

}

class OrganisationRole {

}

OrganisationRole <|-- Manufacturer : inherits from
```

Organisation that manufactures asset products.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Organisation [0..1] | [Organisation](#CIM17v40-Organisation) | see [OrganisationRole](CIM17v40-OrganisationRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Market}
### Market

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Market {

+ actualEnd : DateTime [0..1]
+ actualStart : DateTime [0..1]
+ dst : Boolean [0..1]
+ end : DateTime [0..1]
+ localTimeZone : String [0..1]
+ start : DateTime [0..1]
+ status : String [0..1]
+ timeIntervalLength : Float [0..1]
+ tradingDay : DateTime [0..1]
+ tradingPeriod : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Market : inherits from
```

Market (e.g. Day Ahead Market, Real Time Market) with a description of the Market operation control parameters.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| actualEnd [0..1] | [DateTime](#CIM17v40-DateTime) | Market ending time - actual market end | |
| actualStart [0..1] | [DateTime](#CIM17v40-DateTime) | Market starting time - actual market start | |
| dst [0..1] | [Boolean](#CIM17v40-Boolean) | True if daylight savings time (DST) is in effect. | |
| end [0..1] | [DateTime](#CIM17v40-DateTime) | Market end time. | |
| localTimeZone [0..1] | [String](#CIM17v40-String) | Local time zone. | |
| start [0..1] | [DateTime](#CIM17v40-DateTime) | Market start time. | |
| status [0..1] | [String](#CIM17v40-String) | Market Status'OPEN', 'CLOSED', 'CLEARED', 'BLOCKED' | |
| timeIntervalLength [0..1] | [Float](#CIM17v40-Float) | Trading time interval length. | |
| tradingDay [0..1] | [DateTime](#CIM17v40-DateTime) | Market trading date | |
| tradingPeriod [0..1] | [String](#CIM17v40-String) | Trading period that describes the market, possibilities could be for an Energy Market:DayHourFor a CRR Market:YearMonthSeason | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MarketActualEvent}
### MarketActualEvent

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MarketActualEvent {

+ eventComments : String [0..1]
+ eventEndTime : DateTime [0..1]
+ eventStartTime : DateTime [0..1]
+ eventStatus : enum:MarketEventStatusKind [1]
+ eventType : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- MarketActualEvent : inherits from
class MarketRun {

}

MarketActualEvent --> "0..1" MarketRun : MarketRun
class PlannedMarketEvent {

}

MarketActualEvent --> "0..1" PlannedMarketEvent : PlannedMarketEvent
```

This class represents the actual instance of an event.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| eventComments [0..1] | [String](#CIM17v40-String) | Free format comments for the event, for any purpose needed. | |
| eventEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | End time of the event. | |
| eventStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | Start time of the event. | |
| eventStatus [1] | [MarketEventStatusKind](#CIM17v40-MarketEventStatusKind) | Event status, e.g. active, canceled, expired, etc. | |
| eventType [0..1] | [String](#CIM17v40-String) | Actual event type. | |
| MarketRun [0..1] | [MarketRun](#CIM17v40-MarketRun) | Market run triggered by this actual event. For example, the DA market run is triggered by the actual open bid submission event and terminated by the actual execution and completion of the DA market run captured by the runState of the MarketRun. | |
| PlannedMarketEvent [0..1] | [PlannedMarketEvent](#CIM17v40-PlannedMarketEvent) | Planned event executed by this actual event. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MarketAgreement}
### MarketAgreement

Inheritance path = [MarketDocument](#CIM17v40-MarketDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MarketAgreement {

}

class MarketDocument {

}

MarketDocument <|-- MarketAgreement : inherits from
```

An identification or eventually the contents of an agreement between two or more parties.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MarketCaseClearing}
### (informative) MarketCaseClearing

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MarketCaseClearing {

+ caseType : String [0..1]
+ modifiedDate : DateTime [0..1]
+ postedDate : DateTime [0..1]
}

class MarketFactors {

}

MarketFactors <|-- MarketCaseClearing : inherits from
```

Market case clearing results are posted for a given settlement period.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| caseType [0..1] | [String](#CIM17v40-String) | Settlement period:'DA - Bid-in''DA - Reliability''DA - Amp1''DA - Amp2''RT - Ex-Ante''RT - Ex-Post''RT - Amp1''RT - Amp2' | |
| modifiedDate [0..1] | [DateTime](#CIM17v40-DateTime) | Last time and date clearing results were manually modified. | |
| postedDate [0..1] | [DateTime](#CIM17v40-DateTime) | Bid clearing results posted time and date. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MarketDocument}
### MarketDocument

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MarketDocument {

}

class Document {

}

Document <|-- MarketDocument : inherits from
```

Electronic document containing the information necessary to satisfy a given business process set of requirements.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MarketEvaluationPoint}
### MarketEvaluationPoint

Inheritance path = [UsagePoint](#CIM17v40-UsagePoint) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MarketEvaluationPoint {

}

class UsagePoint {

}

UsagePoint <|-- MarketEvaluationPoint : inherits from
```

The identification of an entity where energy products are measured or computed.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| amiBillingReady [0..1] | [AmiBillingReadyKind](#CIM17v40-AmiBillingReadyKind) | see [UsagePoint](CIM17v40-UsagePoint) | |
| checkBilling [0..1] | [Boolean](#CIM17v40-Boolean) | see [UsagePoint](#CIM17v40-UsagePoint) | |
| connectionCategory [0..1] | [String](#CIM17v40-String) | see [UsagePoint](#CIM17v40-UsagePoint) | |
| connectionState [0..1] | [UsagePointConnectedKind](#CIM17v40-UsagePointConnectedKind) | see [UsagePoint](CIM17v40-UsagePoint) | |
| disconnectionMethod [0..1] | [String](#CIM17v40-String) | see [UsagePoint](#CIM17v40-UsagePoint) | |
| estimatedLoad [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [UsagePoint](CIM17v40-UsagePoint) | |
| grounded [0..1] | [Boolean](#CIM17v40-Boolean) | see [UsagePoint](#CIM17v40-UsagePoint) | |
| isSdp [0..1] | [Boolean](#CIM17v40-Boolean) | see [UsagePoint](#CIM17v40-UsagePoint) | |
| isVirtual [0..1] | [Boolean](#CIM17v40-Boolean) | see [UsagePoint](#CIM17v40-UsagePoint) | |
| minimalUsageExpected [0..1] | [Boolean](#CIM17v40-Boolean) | see [UsagePoint](#CIM17v40-UsagePoint) | |
| nominalServiceVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | see [UsagePoint](CIM17v40-UsagePoint) | |
| outageRegion [0..1] | [String](#CIM17v40-String) | see [UsagePoint](#CIM17v40-UsagePoint) | |
| phaseCode [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [UsagePoint](CIM17v40-UsagePoint) | |
| phaseCount [0..1] | [Integer](#CIM17v40-Integer) | see [UsagePoint](#CIM17v40-UsagePoint) | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [UsagePoint](CIM17v40-UsagePoint) | |
| ratedPower [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [UsagePoint](CIM17v40-UsagePoint) | |
| readCycle [0..1] | [String](#CIM17v40-String) | see [UsagePoint](#CIM17v40-UsagePoint) | |
| readRoute [0..1] | [String](#CIM17v40-String) | see [UsagePoint](#CIM17v40-UsagePoint) | |
| serviceDeliveryRemark [0..1] | [String](#CIM17v40-String) | see [UsagePoint](#CIM17v40-UsagePoint) | |
| servicePriority [0..1] | [String](#CIM17v40-String) | see [UsagePoint](#CIM17v40-UsagePoint) | |
| CustomerAgreement [0..1] | [CustomerAgreement](#CIM17v40-CustomerAgreement) | see [UsagePoint](CIM17v40-UsagePoint) | |
| EnvironmentalMonitoringStation [0..1] | [EnvironmentalMonitoringStation](#CIM17v40-EnvironmentalMonitoringStation) | see [UsagePoint](CIM17v40-UsagePoint) | |
| MeterReadSchedule [0..1] | [MeterReadSchedule](#CIM17v40-MeterReadSchedule) | see [UsagePoint](CIM17v40-UsagePoint) | |
| physicalConnectionCapacity [0..1] | [DecimalQuantity](#CIM17v40-DecimalQuantity) | see [UsagePoint](CIM17v40-UsagePoint) | |
| ServiceCategory [0..1] | [ServiceCategory](#CIM17v40-ServiceCategory) | see [UsagePoint](CIM17v40-UsagePoint) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [UsagePoint](CIM17v40-UsagePoint) | |
| ServiceSupplier [0..1] | [ServiceSupplier](#CIM17v40-ServiceSupplier) | see [UsagePoint](CIM17v40-UsagePoint) | |
| UsagePointLocation [0..1] | [UsagePointLocation](#CIM17v40-UsagePointLocation) | see [UsagePoint](CIM17v40-UsagePoint) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MarketFactors}
### MarketFactors

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MarketFactors {

+ intervalEndTime : DateTime [0..1]
+ intervalStartTime : DateTime [0..1]
}

class Document {

}

Document <|-- MarketFactors : inherits from
class Market {

}

MarketFactors --> "0..1" Market : Market
```

Aggregation of market information relative for a specific time interval.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | The end of the time interval for which requirement is defined. | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | The start of the time interval for which requirement is defined. | |
| Market [0..1] | [Market](#CIM17v40-Market) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MarketInvoice}
### MarketInvoice


```mermaid
classDiagram
direction TB

class MarketInvoice {

+ amount : Money [0..1]
+ billMediaKind : enum:MktBillMediaKind [0..1]
+ dueDate : Date [0..1]
+ kind : enum:MktAccountKind [0..1]
+ mailedDate : Date [0..1]
+ proForma : Boolean [0..1]
+ referenceNumber : String [0..1]
+ transactionDateTime : DateTime [0..1]
+ transferType : String [0..1]
}

```

A roll up of invoice line items. The whole invoice has a due date and amount to be paid, with information such as customer, banks etc. being obtained through associations. The invoice roll up is based on individual line items that each contain amounts and descriptions for specific services or products.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| amount [0..1] | [Money](#CIM17v40-Money) | Total amount due on this invoice based on line items and applicable adjustments. | |
| billMediaKind [0..1] | [MktBillMediaKind](#CIM17v40-MktBillMediaKind) | Kind of media by which the CustomerBillingInfo was delivered. | |
| dueDate [0..1] | [Date](#CIM17v40-Date) | Calculated date upon which the Invoice amount is due. | |
| kind [0..1] | [MktAccountKind](#CIM17v40-MktAccountKind) | Kind of invoice (default is 'sales'). | |
| mailedDate [0..1] | [Date](#CIM17v40-Date) | Date on which the customer billing statement/invoice was printed/mailed. | |
| proForma [0..1] | [Boolean](#CIM17v40-Boolean) | True if payment is to be paid by a Customer to accept a particular ErpQuote (with associated Design) and have work initiated, at which time an associated ErpInvoice should automatically be generated. EprPayment.subjectStatus satisfies terms specificed in the ErpQuote. | |
| referenceNumber [0..1] | [String](#CIM17v40-String) | Number of an invoice to be reference by this invoice. | |
| transactionDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time when the invoice is issued. | |
| transferType [0..1] | [String](#CIM17v40-String) | Type of invoice transfer. | |

{#CIM17v40-MarketInvoiceLineItem}
### MarketInvoiceLineItem


```mermaid
classDiagram
direction TB

class MarketInvoiceLineItem {

+ glAccount : String [0..1]
+ glDateTime : DateTime [0..1]
+ kind : enum:MktInvoiceLineItemKind [0..1]
+ lineAmount : Float [0..1]
+ lineNumber : String [0..1]
+ lineVersion : String [0..1]
+ netAmount : Float [0..1]
+ previousAmount : Float [0..1]
+ billPeriod : DateTimeInterval [0..1]
}

class MarketInvoiceLineItem {

}

MarketInvoiceLineItem --> "0..1" MarketInvoiceLineItem : ContainerMarketInvoiceLineItem
class MarketInvoice {

}

MarketInvoiceLineItem --> "1" MarketInvoice : MarketInvoice
```

An individual line item on an invoice.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| glAccount [0..1] | [String](#CIM17v40-String) | General Ledger account code, shall be a valid combination. | |
| glDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time line item will be posted to the General Ledger. | |
| kind [0..1] | [MktInvoiceLineItemKind](#CIM17v40-MktInvoiceLineItemKind) | Kind of line item. | |
| lineAmount [0..1] | [Float](#CIM17v40-Float) | Amount due for this line item. | |
| lineNumber [0..1] | [String](#CIM17v40-String) | Line item number on invoice statement. | |
| lineVersion [0..1] | [String](#CIM17v40-String) | Version number of the bill run. | |
| netAmount [0..1] | [Float](#CIM17v40-Float) | Net line item charge amount. | |
| previousAmount [0..1] | [Float](#CIM17v40-Float) | Previous line item charge amount. | |
| billPeriod [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Bill period for the line item. | |
| ContainerMarketInvoiceLineItem [0..1] | [MarketInvoiceLineItem](#CIM17v40-MarketInvoiceLineItem) | | |
| MarketInvoice [1] | [MarketInvoice](#CIM17v40-MarketInvoice) | | |

{#CIM17v40-MarketLedger}
### MarketLedger


```mermaid
classDiagram
direction TB

class MarketLedger {

}

```

In accounting transactions, a ledger is a book containing accounts to which debits and credits are posted from journals, where transactions are initially recorded. Journal entries are periodically posted to the ledger. Ledger actual represents actual amounts by account within ledger within company or within business area. Actual amounts may be generated in a source application and then loaded to a specific ledger within the enterprise general ledger or budget application.


{#CIM17v40-MarketLedgerEntry}
### MarketLedgerEntry


```mermaid
classDiagram
direction TB

class MarketLedgerEntry {

+ accountID : String [0..1]
+ accountKind : enum:MktAccountKind [0..1]
+ amount : Money [0..1]
+ postedDateTime : DateTime [0..1]
+ transactionDateTime : DateTime [0..1]
+ status : Status [0..1]
}

class MarketLedger {

}

MarketLedgerEntry --> "1" MarketLedger : MarketLedger
```

Details of an individual entry in a ledger, which was posted from a journal on the posted date.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| accountID [0..1] | [String](#CIM17v40-String) | Account identifier for this entry. | |
| accountKind [0..1] | [MktAccountKind](#CIM17v40-MktAccountKind) | Kind of account for this entry. | |
| amount [0..1] | [Money](#CIM17v40-Money) | The amount of the debit or credit for this account. | |
| postedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time this entry was posted to the ledger. | |
| transactionDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time journal entry was recorded. | |
| MarketLedger [1] | [MarketLedger](#CIM17v40-MarketLedger) | | |
| status [0..1] | [Status](#CIM17v40-Status) | Status of ledger entry. | |

{#CIM17v40-MarketObjectStatus}
### MarketObjectStatus


```mermaid
classDiagram
direction TB

class MarketObjectStatus {

+ status : String [0..1]
}

```

The condition or position of an object with regard to its standing.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| status [0..1] | [String](#CIM17v40-String) | The coded condition or position of an object with regard to its standing. | |

{#CIM17v40-MarketParticipant}
### MarketParticipant

Inheritance path = [Organisation](#CIM17v40-Organisation) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MarketParticipant {

}

class Organisation {

}

Organisation <|-- MarketParticipant : inherits from
```

An identification of a party acting in a electricity market business process. This class is used to identify organizations that can participate in market management and/or market operations.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Organisation](CIM17v40-Organisation) | |
| ParentOrganisation [0..1] | [ParentOrganization](#CIM17v40-ParentOrganization) | see [Organisation](CIM17v40-Organisation) | |
| phone1 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Organisation](CIM17v40-Organisation) | |
| phone2 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Organisation](CIM17v40-Organisation) | |
| postalAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Organisation](CIM17v40-Organisation) | |
| streetAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Organisation](CIM17v40-Organisation) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MarketPerson}
### MarketPerson

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MarketPerson {

+ category : String [0..1]
+ firstName : String [0..1]
+ governmentID : String [0..1]
+ lastName : String [0..1]
+ mName : String [0..1]
+ prefix : String [0..1]
+ specialNeed : String [0..1]
+ suffix : String [0..1]
+ userID : String [0..1]
+ electronicAddressAlternate : ElectronicAddress [0..1]
+ electronicAddressPrimary : ElectronicAddress [0..1]
+ landlinePhone : TelephoneNumber [0..1]
+ mobilePhone : TelephoneNumber [0..1]
+ status : Status [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- MarketPerson : inherits from
```

General purpose information for name and other information to contact people.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| category [0..1] | [String](#CIM17v40-String) | Category of this person relative to utility operations, classified according to the utility's corporate standards and practices. Examples include employee, contractor, agent, not affiliated, etc.This field is not used to indicate whether this person is a customer of the utility. Often an employee or contractor is also a customer. Customer information is gained with relationship to Organisation and CustomerData. In similar fashion, this field does not indicate the various roles this person may fill as part of utility operations. | |
| firstName [0..1] | [String](#CIM17v40-String) | Person's first name. | |
| governmentID [0..1] | [String](#CIM17v40-String) | Unique identifier for person relative to its governing authority, for example a federal tax identifier (such as a Social Security number in the United States). | |
| lastName [0..1] | [String](#CIM17v40-String) | Person's last (family, sir) name. | |
| mName [0..1] | [String](#CIM17v40-String) | Middle name(s) or initial(s). | |
| prefix [0..1] | [String](#CIM17v40-String) | A prefix or title for the person's name, such as Miss, Mister, Doctor, etc. | |
| specialNeed [0..1] | [String](#CIM17v40-String) | Special service needs for the person (contact) are described; examples include life support, etc. | |
| suffix [0..1] | [String](#CIM17v40-String) | A suffix for the person's name, such as II, III, etc. | |
| userID [0..1] | [String](#CIM17v40-String) | The user name for the person; required to log in. | |
| electronicAddressAlternate [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | Alternate Electronic address. | |
| electronicAddressPrimary [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | Primary Electronic address. | |
| landlinePhone [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | Landline phone number. | |
| mobilePhone [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | Mobile phone number. | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MarketPlan}
### MarketPlan

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MarketPlan {

+ tradingDay : DateTime [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- MarketPlan : inherits from
```

This class identifies a set of planned markets.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| tradingDay [0..1] | [DateTime](#CIM17v40-DateTime) | Planned market trading day. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MarketProduct}
### (informative) MarketProduct

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MarketProduct {

+ marketProductType : enum:MarketProductType [0..1]
+ rampInterval : Float [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- MarketProduct : inherits from
class Market {

}

MarketProduct --> "0..1" Market : Market
class MarketRegionResults {

}

MarketProduct --> "0..1" MarketRegionResults : MarketRegionResults
```

A product traded by an RTO (e.g. energy, 10 minute spinning reserve). Ancillary service product examples include: Regulation, Regulation Up, Regulation Down, Spinning Reserve, Non-Spinning Reserve, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| marketProductType [0..1] | [MarketProductType](#CIM17v40-MarketProductType) | Market product type examples:EN (Energy)RU (Regulation Up)RD (Regulation Dn)SR (Spinning Reserve)NR (Non-Spinning Reserve)RC (RUC) | |
| rampInterval [0..1] | [Float](#CIM17v40-Float) | Ramping time interval for the specific market product type specified by marketProductType attribute. For example, if marketProductType = EN (from enumeration MarketProductType), then the rampInterval is the ramping time interval for Energy. | |
| Market [0..1] | [Market](#CIM17v40-Market) | | |
| MarketRegionResults [0..1] | [MarketRegionResults](#CIM17v40-MarketRegionResults) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MarketQualificationRequirement}
### MarketQualificationRequirement

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MarketQualificationRequirement {

+ effectiveDate : DateTime [0..1]
+ expirationDate : DateTime [0..1]
+ qualificationID : String [0..1]
+ status : Integer [0..1]
+ statusType : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- MarketQualificationRequirement : inherits from
```

Certain skills are required and shall be certified in order for a person (typically a member of a crew) to be qualified to work on types of equipment.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| effectiveDate [0..1] | [DateTime](#CIM17v40-DateTime) | Effective date of the privilege, terminate date of the privilege, or effective date of the application for the organization | |
| expirationDate [0..1] | [DateTime](#CIM17v40-DateTime) | This is the terminate date of the application for the organizationThe specific organization can no longer access the application as of the terminate date | |
| qualificationID [0..1] | [String](#CIM17v40-String) | Qualification identifier. | |
| status [0..1] | [Integer](#CIM17v40-Integer) | The status of the privilege. Shows the status of the user�s qualification.The current statuses are: 1=New, 2=Active, 3=Refused, 4=Terminated, 5=Withdrawnand it is subject to update. | |
| statusType [0..1] | [String](#CIM17v40-String) | This is the name of the status of the qualification and is used to display the status of the user's or organization's status. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MarketRegion}
### MarketRegion

Inheritance path = [AggregateNode](#CIM17v40-AggregateNode) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MarketRegion {

}

class AggregateNode {

}

AggregateNode <|-- MarketRegion : inherits from
```

A specialized class of AggregatedNode type. Defines the MarketRegions. Regions could be system Market Regions, Energy Regions or Ancillary Service Regions.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| anodeType [0..1] | [AnodeType](#CIM17v40-AnodeType) | see [AggregateNode](CIM17v40-AggregateNode) | |
| qualifASOrder [0..1] | [Integer](#CIM17v40-Integer) | see [AggregateNode](#CIM17v40-AggregateNode) | |
| RTO [1] | [RTO](#CIM17v40-RTO) | see [AggregateNode](CIM17v40-AggregateNode) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MarketRegionResults}
### MarketRegionResults


```mermaid
classDiagram
direction TB

class MarketRegionResults {

+ clearedMW : Float [0..1]
+ clearedPrice : Float [0..1]
+ dispatchCtMW : Float [0..1]
+ dispatchHydroMW : Float [0..1]
+ dispatchRate : Float [0..1]
+ dispatchSteamMW : Float [0..1]
+ imbalanceEnergyBias : Float [0..1]
+ limitFlag : enum:ResourceLimitIndicator [0..1]
+ lumpyIndicator : enum:YesNo [0..1]
+ maxSufficiencyIndex : Float [0..1]
+ minSufficiencyIndex : Float [0..1]
+ reqMaxMW : Float [0..1]
+ reqMinMW : Float [0..1]
+ selfScheduleMW : Float [0..1]
}

class AncillaryServiceClearing {

}

MarketRegionResults --> "0..1" AncillaryServiceClearing : AncillaryServiceClearing
class MarketProduct {

}

MarketRegionResults --> "0..1" MarketProduct : MarketProduct
class MarketRegion {

}

MarketRegionResults --> "1" MarketRegion : MarketRegion
```

Provides all Region Ancillary Service results for the DA and RT markets. The specific data is commodity type (Regulation Up, Regulation Down, Spinning Reserve, Non-spinning Reserve, or Total Up reserves) based for the cleared MW, cleared price, and total capacity required for the region.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| clearedMW [0..1] | [Float](#CIM17v40-Float) | Cleared generation Value in MW. For AS, this value is clearedMW = AS Total. For AS, clearedMW - selfScheduleMW = AS Procured | |
| clearedPrice [0..1] | [Float](#CIM17v40-Float) | Marginal Price ($/MW) for the commodity (Energy, Regulation Up, Regulation Down, Spinning Reserve, or Non-spinning reserve) based on the pricing run. | |
| dispatchCtMW [0..1] | [Float](#CIM17v40-Float) | Dispatchable MW for Combustion units. | |
| dispatchHydroMW [0..1] | [Float](#CIM17v40-Float) | Dispatchable MW for Hydro units. | |
| dispatchRate [0..1] | [Float](#CIM17v40-Float) | Dispatch rate in MW/minutes. | |
| dispatchSteamMW [0..1] | [Float](#CIM17v40-Float) | Dispatchable MW for Steam units. | |
| imbalanceEnergyBias [0..1] | [Float](#CIM17v40-Float) | Imbalance Energy Bias (MW) by Time Period (5' only) | |
| limitFlag [0..1] | [ResourceLimitIndicator](#CIM17v40-ResourceLimitIndicator) | Locational AS Flags indicating whether the Upper or Lower Bound limit of the AS regional procurment is binding | |
| lumpyIndicator [0..1] | [YesNo](#CIM17v40-YesNo) | The "Lumpy Flag"(Y/N) indicates whether the resource that sets the price is a lumpy generator by hour over the time horizon.Only applicable for the Day Ahead Market | |
| maxSufficiencyIndex [0..1] | [Float](#CIM17v40-Float) | Region requirement maximum limit | |
| minSufficiencyIndex [0..1] | [Float](#CIM17v40-Float) | Region requirement minimum limit | |
| reqMaxMW [0..1] | [Float](#CIM17v40-Float) | Region requirement maximum limit | |
| reqMinMW [0..1] | [Float](#CIM17v40-Float) | Region requirement minimum limit | |
| selfScheduleMW [0..1] | [Float](#CIM17v40-Float) | Aof AS, selfScheduleMW = AS Self-Provided | |
| AncillaryServiceClearing [0..1] | [AncillaryServiceClearing](#CIM17v40-AncillaryServiceClearing) | | |
| MarketProduct [0..1] | [MarketProduct](#CIM17v40-MarketProduct) | | |
| MarketRegion [1] | [MarketRegion](#CIM17v40-MarketRegion) | | |

{#CIM17v40-MarketResults}
### MarketResults


```mermaid
classDiagram
direction TB

class MarketResults {

+ ancillarySvcCost : Float [0..1]
+ contingentOperatingResAvail : enum:YesNo [0..1]
+ energyCost : Float [0..1]
+ minimumLoadCost : Float [0..1]
+ startUpCost : Float [0..1]
+ totalCost : Float [0..1]
+ totalRucCost : Float [0..1]
}

class EnergyMarket {

}

MarketResults --> "1" EnergyMarket : EnergyMarket
```

This class holds elements that are single values for the entire market time horizon. That is, for the Day Ahead market, there is 1 value for each element, not hourly based. Is a summary of the market run.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ancillarySvcCost [0..1] | [Float](#CIM17v40-Float) | Total AS Cost (i.e., payment) ($) over the time horizon | |
| contingentOperatingResAvail [0..1] | [YesNo](#CIM17v40-YesNo) | Global Contingent Operating Reserve Availability Indicator (Yes/No) | |
| energyCost [0..1] | [Float](#CIM17v40-Float) | Total Energy Cost ($) over the time horizon | |
| minimumLoadCost [0..1] | [Float](#CIM17v40-Float) | Total Minimum Load Cost ($) over the time horizon | |
| startUpCost [0..1] | [Float](#CIM17v40-Float) | Total Start-up Cost ($) over the time horizon | |
| totalCost [0..1] | [Float](#CIM17v40-Float) | Total Cost (Energy + AS) cost ($) by over the time horizon | |
| totalRucCost [0..1] | [Float](#CIM17v40-Float) | The total RUC capacity cost for this interval | |
| EnergyMarket [1] | [EnergyMarket](#CIM17v40-EnergyMarket) | | |

{#CIM17v40-MarketRole}
### MarketRole

Inheritance path = [OrganisationRole](#CIM17v40-OrganisationRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MarketRole {

+ type : String [0..1]
}

class OrganisationRole {

}

OrganisationRole <|-- MarketRole : inherits from
```

The external intended behavior played by a party within the electricity market.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| type [0..1] | [String](#CIM17v40-String) | The kind of market roles that can be played by parties for given domains within the electricity market. Types are flexible using dataType of string for free-entry of role types. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Organisation [0..1] | [Organisation](#CIM17v40-Organisation) | see [OrganisationRole](CIM17v40-OrganisationRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MarketRun}
### MarketRun

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MarketRun {

+ executionType : enum:ExecutionType [0..1]
+ marketApprovalTime : DateTime [0..1]
+ marketApprovedStatus : Boolean [0..1]
+ marketEndTime : DateTime [0..1]
+ marketStartTime : DateTime [0..1]
+ marketType : enum:MarketType [0..1]
+ reportedState : String [0..1]
+ runState : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- MarketRun : inherits from
class Market {

}

MarketRun --> "1" Market : Market
class PlannedMarket {

}

MarketRun --> "1" PlannedMarket : PlannedMarket
```

This class represents an actual instance of a planned market. For example, a Day Ahead market opens with the Bid Submission, ends with the closing of the Bid Submission. The market run represent the whole process. MarketRuns can be defined for markets such as Day Ahead Market, Real Time Market, Hour Ahead Market, Week Ahead Market, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| executionType [0..1] | [ExecutionType](#CIM17v40-ExecutionType) | The execution type; Day Ahead, Intra Day, Real Time Pre-Dispatch, Real Time Dispatch | |
| marketApprovalTime [0..1] | [DateTime](#CIM17v40-DateTime) | Approved time for case. Identifies the time that the dispatcher approved a specific real time unit dispatch case | |
| marketApprovedStatus [0..1] | [Boolean](#CIM17v40-Boolean) | Set to true when the plan is approved by authority and becomes the official plan for the day ahead market. Identifies the approved case for the market for the specified time interval. | |
| marketEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | The end time defined as the end of the market, market end time. | |
| marketStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | The start time defined as the beginning of the market, market start time. | |
| marketType [0..1] | [MarketType](#CIM17v40-MarketType) | The market type, Day Ahead Market or Real Time Market. | |
| reportedState [0..1] | [String](#CIM17v40-String) | This is the state of market run activity as reported by market systems to the market definition services. | |
| runState [0..1] | [String](#CIM17v40-String) | This is the state controlled by market defintion service.Possible values could be but not limited by: Open, Close. | |
| Market [1] | [Market](#CIM17v40-Market) | | |
| PlannedMarket [1] | [PlannedMarket](#CIM17v40-PlannedMarket) | A planned market could have multiple market runs for the reason that a planned market could have a rerun. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MarketScheduledEvent}
### MarketScheduledEvent

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MarketScheduledEvent {

+ category : String [0..1]
+ duration : Seconds [0..1]
+ status : Status [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- MarketScheduledEvent : inherits from
class MajorChargeGroup {

}

MarketScheduledEvent --> "0..1" MajorChargeGroup : MajorChargeGroup
```

Signifies an event to trigger one or more activities, such as reading a meter, recalculating a bill, requesting work, when generating units shall be scheduled for maintenance, when a transformer is scheduled to be refurbished, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| category [0..1] | [String](#CIM17v40-String) | Category of scheduled event. | |
| duration [0..1] | [Seconds](#CIM17v40-Seconds) | Duration of the scheduled event, for example, the time to ramp between values. | |
| MajorChargeGroup [0..1] | [MajorChargeGroup](#CIM17v40-MajorChargeGroup) | | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MarketSkill}
### MarketSkill

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MarketSkill {

+ effectiveDateTime : DateTime [0..1]
+ level : String [0..1]
+ certificationPeriod : DateTimeInterval [0..1]
}

class Document {

}

Document <|-- MarketSkill : inherits from
class MarketPerson {

}

MarketSkill --> "0..1" MarketPerson : MarketPerson
```

Proficiency level of a craft, which is required to operate or maintain a particular type of asset and/or perform certain types of work.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| effectiveDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time the skill became effective. | |
| level [0..1] | [String](#CIM17v40-String) | Level of skill for a Craft. | |
| certificationPeriod [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Interval between the certification and its expiry. | |
| MarketPerson [0..1] | [MarketPerson](#CIM17v40-MarketPerson) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MarketStatement}
### MarketStatement

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MarketStatement {

+ end : DateTime [0..1]
+ referenceNumber : String [0..1]
+ start : DateTime [0..1]
+ tradeDate : DateTime [0..1]
+ transactionDate : DateTime [0..1]
}

class Document {

}

Document <|-- MarketStatement : inherits from
```

A statement is a roll up of statement line items. Each statement along with its line items provide the details of specific charges at any given time. Used by Billing and Settlement.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| end [0..1] | [DateTime](#CIM17v40-DateTime) | The end of a bill period. | |
| referenceNumber [0..1] | [String](#CIM17v40-String) | The version number of previous statement (in the case of true up). | |
| start [0..1] | [DateTime](#CIM17v40-DateTime) | The start of a bill period. | |
| tradeDate [0..1] | [DateTime](#CIM17v40-DateTime) | The date of which Settlement is run. | |
| transactionDate [0..1] | [DateTime](#CIM17v40-DateTime) | The date of which this statement is issued. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MarketStatementLineItem}
### MarketStatementLineItem

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MarketStatementLineItem {

+ currentAmount : Float [0..1]
+ currentISOAmount : Float [0..1]
+ currentISOQuantity : Float [0..1]
+ currentPrice : Float [0..1]
+ currentQuantity : Float [0..1]
+ intervalDate : DateTime [0..1]
+ intervalNumber : String [0..1]
+ netAmount : Float [0..1]
+ netISOAmount : Float [0..1]
+ netISOQuantity : Float [0..1]
+ netPrice : Float [0..1]
+ netQuantity : Float [0..1]
+ previousAmount : Float [0..1]
+ previousISOAmount : Float [0..1]
+ previousISOQuantity : Float [0..1]
+ previousPrice : Float [0..1]
+ previousQuantity : Float [0..1]
+ quantityUOM : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- MarketStatementLineItem : inherits from
class MarketStatementLineItem {

}

MarketStatementLineItem --> "0..1" MarketStatementLineItem : ContainerMarketStatementLineItem
class MarketStatement {

}

MarketStatementLineItem --> "1" MarketStatement : MarketStatement
class PassThroughBill {

}

MarketStatementLineItem --> "0..1" PassThroughBill : PassThroughBill
```

An individual line item on an ISO settlement statement.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| currentAmount [0..1] | [Float](#CIM17v40-Float) | Current settlement amount. | |
| currentISOAmount [0..1] | [Float](#CIM17v40-Float) | Current ISO settlement amount. | |
| currentISOQuantity [0..1] | [Float](#CIM17v40-Float) | Current ISO settlement quantity. | |
| currentPrice [0..1] | [Float](#CIM17v40-Float) | Current settlement price. | |
| currentQuantity [0..1] | [Float](#CIM17v40-Float) | Current settlement quantity, subject to the UOM. | |
| intervalDate [0..1] | [DateTime](#CIM17v40-DateTime) | The date of which the settlement is run. | |
| intervalNumber [0..1] | [String](#CIM17v40-String) | The number of intervals. | |
| netAmount [0..1] | [Float](#CIM17v40-Float) | Net settlement amount. | |
| netISOAmount [0..1] | [Float](#CIM17v40-Float) | Net ISO settlement amount. | |
| netISOQuantity [0..1] | [Float](#CIM17v40-Float) | Net ISO settlement quantity. | |
| netPrice [0..1] | [Float](#CIM17v40-Float) | Net settlement price. | |
| netQuantity [0..1] | [Float](#CIM17v40-Float) | Net settlement quantity, subject to the UOM. | |
| previousAmount [0..1] | [Float](#CIM17v40-Float) | Previous settlement amount. | |
| previousISOAmount [0..1] | [Float](#CIM17v40-Float) | Previous ISO settlement amount. | |
| previousISOQuantity [0..1] | [Float](#CIM17v40-Float) | Previous ISO settlement quantity. | |
| previousPrice [0..1] | [Float](#CIM17v40-Float) | Previous settlement price. | |
| previousQuantity [0..1] | [Float](#CIM17v40-Float) | Previous settlement quantity, subject to the UOM. | |
| quantityUOM [0..1] | [String](#CIM17v40-String) | The unit of measure for the quantity element of the line item. | |
| ContainerMarketStatementLineItem [0..1] | [MarketStatementLineItem](#CIM17v40-MarketStatementLineItem) | | |
| MarketStatement [1] | [MarketStatement](#CIM17v40-MarketStatement) | | |
| PassThroughBill [0..1] | [PassThroughBill](#CIM17v40-PassThroughBill) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Marketer}
### (informative) Marketer

Inheritance path = [Organisation](#CIM17v40-Organisation) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Marketer {

}

class Organisation {

}

Organisation <|-- Marketer : inherits from
```

Matches buyers and sellers, and secures transmission (and other ancillary services) needed to complete the energy transaction.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Organisation](CIM17v40-Organisation) | |
| ParentOrganisation [0..1] | [ParentOrganization](#CIM17v40-ParentOrganization) | see [Organisation](CIM17v40-Organisation) | |
| phone1 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Organisation](CIM17v40-Organisation) | |
| phone2 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Organisation](CIM17v40-Organisation) | |
| postalAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Organisation](CIM17v40-Organisation) | |
| streetAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Organisation](CIM17v40-Organisation) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MaterialItem}
### MaterialItem

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MaterialItem {

+ quantity : IntegerQuantity [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- MaterialItem : inherits from
class TypeMaterial {

}

MaterialItem --> "0..1" TypeMaterial : TypeMaterial
class WorkTask {

}

MaterialItem --> "0..1" WorkTask : WorkTask
```

The physical consumable supply used for work and other purposes. It includes items such as nuts, bolts, brackets, glue, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| quantity [0..1] | [IntegerQuantity](#CIM17v40-IntegerQuantity) | Quantity of material used. | |
| `TypeMaterial [0..1]` (informative) | [TypeMaterial](#CIM17v40-TypeMaterial) | | |
| WorkTask [0..1] | [WorkTask](#CIM17v40-WorkTask) | The work task that uses the material items | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MaxStartUpCostCurve}
### MaxStartUpCostCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MaxStartUpCostCurve {

}

class Curve {

}

Curve <|-- MaxStartUpCostCurve : inherits from
```

The maximum Startup costs and time as a function of down time. Relationship between unit startup cost (Y1-axis) vs. unit elapsed down time (X-axis). This is used to validate the information provided in the Bid.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Measurement}
### (informative) Measurement

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Measurement {

+ measurementType : String [0..1]
+ phases : enum:PhaseCode [0..1]
+ unitMultiplier : enum:UnitMultiplier [0..1]
+ unitSymbol : enum:UnitSymbol [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Measurement : inherits from
class Asset {

}

Measurement --> "0..1" Asset : Asset
class CalculationMethodHierarchy {

}

Measurement --> "0..1" CalculationMethodHierarchy : CalculationMethodHierarchy
class MeasurementAction {

}

Measurement --> "0..1" MeasurementAction : MeasurementAction
class PowerSystemResource {

}

Measurement --> "0..1" PowerSystemResource : PowerSystemResource
class ACDCTerminal {

}

Measurement --> "0..1" ACDCTerminal : Terminal
```

A Measurement represents any measured, calculated or non-measured non-calculated quantity. Any piece of equipment may contain Measurements, e.g. a substation may have temperature measurements and door open indications, a transformer may have oil temperature and tank pressure measurements, a bay may contain a number of power flow measurements and a Breaker may contain a switch status measurement.

The PSR - Measurement association is intended to capture this use of Measurement and is included in the naming hierarchy based on EquipmentContainer. The naming hierarchy typically has Measurements as leaves, e.g. Substation-VoltageLevel-Bay-Switch-Measurement.

Some Measurements represent quantities related to a particular sensor location in the network, e.g. a voltage transformer (VT) or potential transformer (PT) at a busbar or a current transformer (CT) at the bar between a breaker and an isolator. The sensing position is not captured in the PSR - Measurement association. Instead it is captured by the Measurement - Terminal association that is used to define the sensing location in the network topology. The location is defined by the connection of the Terminal to ConductingEquipment.

If both a Terminal and PSR are associated, and the PSR is of type ConductingEquipment, the associated Terminal should belong to that ConductingEquipment instance.

When the sensor location is needed both Measurement-PSR and Measurement-Terminal are used. The Measurement-Terminal association is never used alone.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| measurementType [0..1] | [String](#CIM17v40-String) | Specifies the type of measurement. For example, this specifies if the measurement represents an indoor temperature, outdoor temperature, bus voltage, line flow, etc.When the measurementType is set to "Specialization", the type of Measurement is defined in more detail by the specialized class which inherits from Measurement. | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | Indicates to which phases the measurement applies and avoids the need to use 'measurementType' to also encode phase information (which would explode the types). The phase information in Measurement, along with 'measurementType' and 'phases' uniquely defines a Measurement for a device, based on normal network phase. Their meaning will not change when the computed energizing phasing is changed due to jumpers or other reasons.If the attribute is missing three phases (ABC) shall be assumed. | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | The unit multiplier of the measured quantity. | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | The unit of measure of the measured quantity. | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | Asset that has a measurement | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | Calculation method hierarchy which applies to this analog. | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | The measurement action that is performed on the measurement | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | The power system resource that contains the measurement. | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | One or more measurements may be associated with a terminal in the network. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MeasurementAction}
### MeasurementAction

Inheritance path = [SwitchingAction](#CIM17v40-SwitchingAction) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MeasurementAction {

}

class SwitchingAction {

}

SwitchingAction <|-- MeasurementAction : inherits from
class Measurement {

}

MeasurementAction --> "0..1" Measurement : Measurement
```

Measurement taken as a switching step.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Measurement [0..1] | [Measurement](#CIM17v40-Measurement) | The measurement that the measurement action is performed on | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| executedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| issuedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| plannedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| Operator [0..1] | [Operator](#CIM17v40-Operator) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingEvent [0..1] | [SwitchingEvent](#CIM17v40-SwitchingEvent) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingStep [0..1] | [SwitchingStep](#CIM17v40-SwitchingStep) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MeasurementCalculator}
### (informative) MeasurementCalculator

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MeasurementCalculator {

+ kind : enum:CalculationKind [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- MeasurementCalculator : inherits from
```

Result of a calculation of one or more measurement.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [CalculationKind](#CIM17v40-CalculationKind) | Calculation operation executed on the operants. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MeasurementCalculatorInput}
### MeasurementCalculatorInput

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MeasurementCalculatorInput {

+ absoluteValue : Boolean [0..1]
+ order : Integer [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- MeasurementCalculatorInput : inherits from
class Measurement {

}

MeasurementCalculatorInput --> "1" Measurement : Measurement
class MeasurementCalculator {

}

MeasurementCalculatorInput --> "1" MeasurementCalculator : MeasurementCalculator
```

Input to measurement calculation. Support Analog, Discrete and Accumulator.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| absoluteValue [0..1] | [Boolean](#CIM17v40-Boolean) | If true, use the absolute value for the calculation. | |
| order [0..1] | [Integer](#CIM17v40-Integer) | Positive number that defines the order of the operant in the calculation. 0 = default. The order is not relevant (e.g. summation). | |
| `Measurement [1]` (informative) | [Measurement](#CIM17v40-Measurement) | Measurement used as input to a calculation. | |
| `MeasurementCalculator [1]` (OfAggregate, informative) | [MeasurementCalculator](#CIM17v40-MeasurementCalculator) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MeasurementValue}
### (harmonization) MeasurementValue

Inheritance path = [IOPoint](#CIM17v40-IOPoint) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MeasurementValue {

+ sensorAccuracy : PerCent [0..1]
+ timeStamp : DateTime [0..1]
}

class IOPoint {

}

IOPoint <|-- MeasurementValue : inherits from
class CalculationMethodHierarchy {

}

MeasurementValue --> "0..1" CalculationMethodHierarchy : CalculationMethodHierarchy
class OldPerson {

}

MeasurementValue --> "0..1" OldPerson : ErpPerson
class MeasurementValueQuality {

}

MeasurementValue --> "0..1" MeasurementValueQuality : MeasurementValueQuality
class MeasurementValueSource {

}

MeasurementValue --> "1" MeasurementValueSource : MeasurementValueSource
class RemoteSource {

}

MeasurementValue --> "0..1" RemoteSource : RemoteSource
```

The current state for a measurement. A state value is an instance of a measurement from a specific source. Measurements can be associated with many state values, each representing a different source for the measurement.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| sensorAccuracy [0..1] | [PerCent](#CIM17v40-PerCent) | The limit, expressed as a percentage of the sensor maximum, that errors will not exceed when the sensor is used under reference conditions. | |
| timeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | The time when the value was last updated. | |
| `CalculationMethodHierarchy [0..1]` (harmonization) | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | | |
| `ErpPerson [0..1]` (informative) | [OldPerson](#CIM17v40-OldPerson) | | |
| `MeasurementValueQuality [0..1]` (AggregateOf) | [MeasurementValueQuality](#CIM17v40-MeasurementValueQuality) | A MeasurementValue has a MeasurementValueQuality associated with it. | |
| MeasurementValueSource [1] | [MeasurementValueSource](#CIM17v40-MeasurementValueSource) | A reference to the type of source that updates the MeasurementValue, e.g. SCADA, CCLink, manual, etc. User conventions for the names of sources are contained in the introduction to IEC 61970-301. | |
| RemoteSource [0..1] | [RemoteSource](#CIM17v40-RemoteSource) | Link to the physical telemetered point associated with this measurement. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| IOPointSource [0..1] | [IOPointSource](#CIM17v40-IOPointSource) | see [IOPoint](CIM17v40-IOPoint) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MeasurementValueQuality}
### MeasurementValueQuality

Inheritance path = [Quality61850](#CIM17v40-Quality61850)

```mermaid
classDiagram
direction TB

class MeasurementValueQuality {

}

class Quality61850 {

}

Quality61850 <|-- MeasurementValueQuality : inherits from
class MeasurementValue {

}

MeasurementValueQuality --> "1" MeasurementValue : MeasurementValue
```

Measurement quality flags. Bits 0-10 are defined for substation automation in IEC 61850-7-3. Bits 11-15 are reserved for future expansion by that document. Bits 16-31 are reserved for EMS applications.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `MeasurementValue [1]` (OfAggregate) | [MeasurementValue](#CIM17v40-MeasurementValue) | A MeasurementValue has a MeasurementValueQuality associated with it. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| badReference [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| estimatorReplaced [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| failure [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| oldData [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| operatorBlocked [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| oscillatory [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| outOfRange [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| overFlow [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| source [0..1] | [Source](#CIM17v40-Source) | see [Quality61850](CIM17v40-Quality61850) | |
| suspect [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| test [0..1] | [Boolean](#CIM17v40-Boolean) | see [Quality61850](#CIM17v40-Quality61850) | |
| validity [0..1] | [Validity](#CIM17v40-Validity) | see [Quality61850](CIM17v40-Quality61850) | |

{#CIM17v40-MeasurementValueSource}
### MeasurementValueSource

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MeasurementValueSource {

}

class IdentifiedObject {

}

IdentifiedObject <|-- MeasurementValueSource : inherits from
```

MeasurementValueSource describes the alternative sources updating a MeasurementValue. User conventions for how to use the MeasurementValueSource attributes are defined in IEC 61970-301.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MechLoad1}
### MechLoad1

Inheritance path = [MechanicalLoadDynamics](#CIM17v40-MechanicalLoadDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MechLoad1 {

+ a : Float [0..1]
+ b : Float [0..1]
+ d : Float [0..1]
+ e : Float [0..1]
}

class MechanicalLoadDynamics {

}

MechanicalLoadDynamics <|-- MechLoad1 : inherits from
```

Mechanical load model type 1.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| a [0..1] | [Float](#CIM17v40-Float) | Speed squared coefficient (<i>a</i>). | |
| b [0..1] | [Float](#CIM17v40-Float) | Speed coefficient (<i>b</i>). | |
| d [0..1] | [Float](#CIM17v40-Float) | Speed to the exponent coefficient (<i>d</i>). | |
| e [0..1] | [Float](#CIM17v40-Float) | Exponent (<i>e</i>). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [MechanicalLoadDynamics](CIM17v40-MechanicalLoadDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [MechanicalLoadDynamics](CIM17v40-MechanicalLoadDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MechanicalLoadDynamics}
### MechanicalLoadDynamics

Inheritance path = [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MechanicalLoadDynamics {

}

class DynamicsFunctionBlock {

}

DynamicsFunctionBlock <|-- MechanicalLoadDynamics : inherits from
class AsynchronousMachineDynamics {

}

MechanicalLoadDynamics --> "0..1" AsynchronousMachineDynamics : AsynchronousMachineDynamics
class SynchronousMachineDynamics {

}

MechanicalLoadDynamics --> "0..1" SynchronousMachineDynamics : SynchronousMachineDynamics
```

Mechanical load function block whose behaviour is described by reference to a standard model <font color="#0f0f0f">or by definition of a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | Asynchronous machine model with which this mechanical load model is associated. MechanicalLoadDynamics shall have either an association to SynchronousMachineDynamics or to AsynchronousMachineDynamics. | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | Synchronous machine model with which this mechanical load model is associated. MechanicalLoadDynamics shall have either an association to SynchronousMachineDynamics or AsynchronousMachineDyanmics. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MechanicalLoadUserDefined}
### MechanicalLoadUserDefined

Inheritance path = [MechanicalLoadDynamics](#CIM17v40-MechanicalLoadDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MechanicalLoadUserDefined {

+ proprietary : Boolean [0..1]
}

class MechanicalLoadDynamics {

}

MechanicalLoadDynamics <|-- MechanicalLoadUserDefined : inherits from
```

Mechanical load function block whose dynamic behaviour is described by <font color="#0f0f0f">a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| proprietary [0..1] | [Boolean](#CIM17v40-Boolean) | Behaviour is based on a proprietary model as opposed to a detailed model.true = user-defined model is proprietary with behaviour mutually understood by sending and receiving applications and parameters passed as general attributesfalse = user-defined model is explicitly defined in terms of control blocks and their input and output signals. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [MechanicalLoadDynamics](CIM17v40-MechanicalLoadDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [MechanicalLoadDynamics](CIM17v40-MechanicalLoadDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Medium}
### Medium

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Medium {

+ kind : enum:MediumKind [0..1]
+ volumeSpec : Volume [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Medium : inherits from
class Specification {

}

Medium --> "0..1" Specification : Specification
```

A substance that either (1) provides the means of transmission of a force or effect, such as hydraulic fluid, or (2) is used for a surrounding or enveloping substance, such as oil in a transformer or circuit breaker.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [MediumKind](#CIM17v40-MediumKind) | Kind of this medium. | |
| volumeSpec [0..1] | [Volume](#CIM17v40-Volume) | The volume of the medium specified for this application. Note that the actual volume is a type of measurement associated witht the asset. | |
| `Specification [0..1]` (informative) | [Specification](#CIM17v40-Specification) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MerchantAccount}
### MerchantAccount

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MerchantAccount {

+ currentBalance : Money [0..1]
+ provisionalBalance : Money [0..1]
}

class Document {

}

Document <|-- MerchantAccount : inherits from
class MerchantAgreement {

}

MerchantAccount --> "0..1" MerchantAgreement : MerchantAgreement
```

The operating account controlled by merchant agreement, against which the vendor may vend tokens or receipt payments. Transactions via vendor shift debit the account and bank deposits via bank statement credit the account.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| currentBalance [0..1] | [Money](#CIM17v40-Money) | The current operating balance of this account. | |
| provisionalBalance [0..1] | [Money](#CIM17v40-Money) | The balance of this account after taking into account any pending debits from VendorShift.merchantDebitAmount and pending credits from BankStatement.merchantCreditAmount or credits (see also BankStatement attributes and VendorShift attributes). | |
| MerchantAgreement [0..1] | [MerchantAgreement](#CIM17v40-MerchantAgreement) | Merchant agreement that instantiated this merchant account. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MerchantAgreement}
### MerchantAgreement

Inheritance path = [Agreement](#CIM17v40-Agreement) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MerchantAgreement {

}

class Agreement {

}

Agreement <|-- MerchantAgreement : inherits from
```

A formal controlling contractual agreement between supplier and merchant, in terms of which the merchant is authorised to vend tokens and receipt payments on behalf of the supplier. The merchant is accountable to the supplier for revenue collected at point of sale.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| signDate [0..1] | [Date](#CIM17v40-Date) | see [Agreement](#CIM17v40-Agreement) | |
| validityInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [Agreement](CIM17v40-Agreement) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Meter}
### Meter

Inheritance path = [EndDevice](#CIM17v40-EndDevice) => [AssetContainer](#CIM17v40-AssetContainer) => [Asset](#CIM17v40-Asset) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Meter {

+ connectionCategory : String [0..1]
+ formNumber : String [0..1]
}

class EndDevice {

}

EndDevice <|-- Meter : inherits from
```

Physical asset that performs the metering role of the usage point. Used for measuring consumption and detection of events.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| connectionCategory [0..1] | [String](#CIM17v40-String) | A code used to specify the connection category, e.g. low voltage, where the meter operates. | |
| formNumber [0..1] | [String](#CIM17v40-String) | Meter form designation per ANSI C12.10 or other applicable standard. An alphanumeric designation denoting the circuit arrangement for which the meter is applicable and its specific terminal arrangement. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| amrSystem [0..1] | [String](#CIM17v40-String) | see [EndDevice](#CIM17v40-EndDevice) | |
| installCode [0..1] | [String](#CIM17v40-String) | see [EndDevice](#CIM17v40-EndDevice) | |
| isPan [0..1] | [Boolean](#CIM17v40-Boolean) | see [EndDevice](#CIM17v40-EndDevice) | |
| isSmartInverter [0..1] | [Boolean](#CIM17v40-Boolean) | see [EndDevice](#CIM17v40-EndDevice) | |
| isVirtual [0..1] | [Boolean](#CIM17v40-Boolean) | see [EndDevice](#CIM17v40-EndDevice) | |
| timeZoneOffset [0..1] | [Minutes](#CIM17v40-Minutes) | see [EndDevice](CIM17v40-EndDevice) | |
| Customer [0..1] | [Customer](#CIM17v40-Customer) | see [EndDevice](CIM17v40-EndDevice) | |
| EndDeviceInfo [0..1] | [EndDeviceInfo](#CIM17v40-EndDeviceInfo) | see [EndDevice](CIM17v40-EndDevice) | |
| MeterReadSchedule [0..1] | [MeterReadSchedule](#CIM17v40-MeterReadSchedule) | see [EndDevice](CIM17v40-EndDevice) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [EndDevice](CIM17v40-EndDevice) | |
| UsagePoint [0..1] | [UsagePoint](#CIM17v40-UsagePoint) | see [EndDevice](CIM17v40-EndDevice) | |
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | see [Asset](#CIM17v40-Asset) | |
| initialCondition [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | see [Asset](CIM17v40-Asset) | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | see [Asset](CIM17v40-Asset) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [Asset](CIM17v40-Asset) | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | see [Asset](CIM17v40-Asset) | |
| lotNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| position [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | see [Asset](CIM17v40-Asset) | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | see [Asset](CIM17v40-Asset) | |
| serialNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| type [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| utcNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | see [Asset](CIM17v40-Asset) | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | see [Asset](CIM17v40-Asset) | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | see [Asset](CIM17v40-Asset) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [Asset](CIM17v40-Asset) | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | see [Asset](CIM17v40-Asset) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Asset](CIM17v40-Asset) | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | see [Asset](CIM17v40-Asset) | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | see [Asset](CIM17v40-Asset) | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | see [Asset](CIM17v40-Asset) | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | see [Asset](CIM17v40-Asset) | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | see [Asset](CIM17v40-Asset) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Asset](CIM17v40-Asset) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [Asset](CIM17v40-Asset) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [Asset](CIM17v40-Asset) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Asset](CIM17v40-Asset) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MeterMultiplier}
### MeterMultiplier

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MeterMultiplier {

+ kind : enum:MeterMultiplierKind [0..1]
+ value : Float [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- MeterMultiplier : inherits from
class Meter {

}

MeterMultiplier --> "0..1" Meter : Meter
```

Multiplier applied at the meter.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [MeterMultiplierKind](#CIM17v40-MeterMultiplierKind) | Kind of multiplier. | |
| value [0..1] | [Float](#CIM17v40-Float) | Multiplier value. | |
| Meter [0..1] | [Meter](#CIM17v40-Meter) | Meter applying this multiplier. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MeterReadSchedule}
### MeterReadSchedule

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MeterReadSchedule {

}

class Document {

}

Document <|-- MeterReadSchedule : inherits from
```


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MeterReading}
### MeterReading

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MeterReading {

+ isCoincidentTrigger : Boolean [0..1]
+ valuesInterval : DateTimeInterval [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- MeterReading : inherits from
class CustomerAgreement {

}

MeterReading --> "0..1" CustomerAgreement : CustomerAgreement
class Meter {

}

MeterReading --> "0..1" Meter : Meter
class UsagePoint {

}

MeterReading --> "0..1" UsagePoint : UsagePoint
```

Set of values obtained from the meter.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| isCoincidentTrigger [0..1] | [Boolean](#CIM17v40-Boolean) | If true, this meter reading is the meter reading for which other coincident meter readings are requested or provided. | |
| CustomerAgreement [0..1] | [CustomerAgreement](#CIM17v40-CustomerAgreement) | (could be deprecated in the future) Customer agreement for this meter reading. | |
| Meter [0..1] | [Meter](#CIM17v40-Meter) | Meter providing this reading. | |
| UsagePoint [0..1] | [UsagePoint](#CIM17v40-UsagePoint) | Usage point from which this meter reading (set of values) has been obtained. | |
| valuesInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Date and time interval of the data items contained within this meter reading. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MeterWorkTask}
### MeterWorkTask

Inheritance path = [WorkTask](#CIM17v40-WorkTask) => [BaseWork](#CIM17v40-BaseWork) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MeterWorkTask {

}

class WorkTask {

}

WorkTask <|-- MeterWorkTask : inherits from
class Meter {

}

MeterWorkTask --> "0..1" Meter : Meter
class Meter {

}

MeterWorkTask --> "0..1" Meter : OldMeter
class UsagePoint {

}

MeterWorkTask --> "0..1" UsagePoint : UsagePoint
```

Work task involving meters.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Meter [0..1] | [Meter](#CIM17v40-Meter) | Meter on which this non-replacement work task is performed. | |
| OldMeter [0..1] | [Meter](#CIM17v40-Meter) | Old meter replaced by this work task. | |
| UsagePoint [0..1] | [UsagePoint](#CIM17v40-UsagePoint) | Usage point to which this meter service work task applies. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| completedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [WorkTask](#CIM17v40-WorkTask) | |
| contractorCost [0..1] | [Money](#CIM17v40-Money) | see [WorkTask](CIM17v40-WorkTask) | |
| crewETA [0..1] | [DateTime](#CIM17v40-DateTime) | see [WorkTask](#CIM17v40-WorkTask) | |
| estimatedCompletionTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [WorkTask](#CIM17v40-WorkTask) | |
| instruction [0..1] | [String](#CIM17v40-String) | see [WorkTask](#CIM17v40-WorkTask) | |
| laborCost [0..1] | [Money](#CIM17v40-Money) | see [WorkTask](CIM17v40-WorkTask) | |
| laborHours [0..1] | [Hours](#CIM17v40-Hours) | see [WorkTask](CIM17v40-WorkTask) | |
| materiallCost [0..1] | [Money](#CIM17v40-Money) | see [WorkTask](CIM17v40-WorkTask) | |
| schedOverride [0..1] | [String](#CIM17v40-String) | see [WorkTask](#CIM17v40-WorkTask) | |
| startedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [WorkTask](#CIM17v40-WorkTask) | |
| taskKind [0..1] | [WorkTaskKind](#CIM17v40-WorkTaskKind) | see [WorkTask](CIM17v40-WorkTask) | |
| toolCost [0..1] | [Money](#CIM17v40-Money) | see [WorkTask](CIM17v40-WorkTask) | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | see [WorkTask](CIM17v40-WorkTask) | |
| TroubleOrder [0..1] | [TroubleOrder](#CIM17v40-TroubleOrder) | see [WorkTask](CIM17v40-WorkTask) | |
| Work [1] | [Work](#CIM17v40-Work) | see [WorkTask](CIM17v40-WorkTask) | |
| kind [0..1] | [ServiceRequestKind](#CIM17v40-ServiceRequestKind) | see [BaseWork](CIM17v40-BaseWork) | |
| statusKind [0..1] | [WorkStatusKind](#CIM17v40-WorkStatusKind) | see [BaseWork](CIM17v40-BaseWork) | |
| priority [0..1] | [Priority](#CIM17v40-Priority) | see [BaseWork](CIM17v40-BaseWork) | |
| WorkLocation [0..1] | [WorkLocation](#CIM17v40-WorkLocation) | see [BaseWork](CIM17v40-BaseWork) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MeteredSubSystem}
### MeteredSubSystem

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MeteredSubSystem {

}

class IdentifiedObject {

}

IdentifiedObject <|-- MeteredSubSystem : inherits from
class MSSAggregation {

}

MeteredSubSystem --> "0..1" MSSAggregation : MSSAggregation
```

A metered subsystem.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| MSSAggregation [0..1] | [MSSAggregation](#CIM17v40-MSSAggregation) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MetrologyRequirement}
### MetrologyRequirement

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MetrologyRequirement {

+ reason : enum:ReadingReasonKind [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- MetrologyRequirement : inherits from
```

A specification of the metering requirements for a particular point within a network.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| reason [0..1] | [ReadingReasonKind](#CIM17v40-ReadingReasonKind) | Reason for this metrology requirement being specified. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MiscCostItem}
### MiscCostItem

Inheritance path = [WorkIdentifiedObject](#CIM17v40-WorkIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MiscCostItem {

+ account : String [0..1]
+ costPerUnit : Money [0..1]
+ costType : String [0..1]
+ externalRefID : String [0..1]
+ quantity : IntegerQuantity [0..1]
+ status : Status [0..1]
}

class WorkIdentifiedObject {

}

WorkIdentifiedObject <|-- MiscCostItem : inherits from
class DesignLocation {

}

MiscCostItem --> "0..1" DesignLocation : DesignLocation
class WorkCostDetail {

}

MiscCostItem --> "0..1" WorkCostDetail : WorkCostDetail
class OldWorkTask {

}

MiscCostItem --> "0..1" OldWorkTask : WorkTask
```

Various cost items that are not associated with compatible units. Examples include rental equipment, labor, materials, contractor costs, permits - anything not covered in a CU.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| account [0..1] | [String](#CIM17v40-String) | This drives the accounting treatment for this misc. item. | |
| costPerUnit [0..1] | [Money](#CIM17v40-Money) | The cost per unit for this misc. item. | |
| costType [0..1] | [String](#CIM17v40-String) | The cost type for accounting, such as material, labor, vehicle, contractor, equipment, overhead. | |
| externalRefID [0..1] | [String](#CIM17v40-String) | External reference identifier (e.g. purchase order number, serial number) . | |
| `DesignLocation [0..1]` (informative) | [DesignLocation](#CIM17v40-DesignLocation) | | |
| quantity [0..1] | [IntegerQuantity](#CIM17v40-IntegerQuantity) | The quantity of the misc. item being assigned to this location. | |
| status [0..1] | [Status](#CIM17v40-Status) | | |
| `WorkCostDetail [0..1]` (informative) | [WorkCostDetail](#CIM17v40-WorkCostDetail) | | |
| `WorkTask [0..1]` (informative) | [OldWorkTask](#CIM17v40-OldWorkTask) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MitigatedBid}
### MitigatedBid

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MitigatedBid {

}

class IdentifiedObject {

}

IdentifiedObject <|-- MitigatedBid : inherits from
class Bid {

}

MitigatedBid --> "0..1" Bid : Bid
```

Mitigated bid results posted for a given settlement period.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Bid [0..1] | [Bid](#CIM17v40-Bid) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MitigatedBidClearing}
### MitigatedBidClearing

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MitigatedBidClearing {

}

class MarketFactors {

}

MarketFactors <|-- MitigatedBidClearing : inherits from
```

Model of market power mitigation through reference or mitigated bids. Interval based.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MitigatedBidSegment}
### MitigatedBidSegment


```mermaid
classDiagram
direction TB

class MitigatedBidSegment {

+ intervalStartTime : DateTime [0..1]
+ segmentMW : Float [0..1]
+ segmentNumber : Integer [0..1]
+ thresholdType : String [0..1]
}

class Bid {

}

MitigatedBidSegment --> "1" Bid : Bid
```

Model of mitigated bid. Indicates segment of piece-wise linear bid, that has been mitigated.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| segmentMW [0..1] | [Float](#CIM17v40-Float) | Mitigated bid segment MW value | |
| segmentNumber [0..1] | [Integer](#CIM17v40-Integer) | Mitigated Bid Segment Number | |
| thresholdType [0..1] | [String](#CIM17v40-String) | | |
| Bid [1] | [Bid](#CIM17v40-Bid) | | |

{#CIM17v40-MktACLineSegment}
### MktACLineSegment

Inheritance path = [ACLineSegment](#CIM17v40-ACLineSegment) => [Conductor](#CIM17v40-Conductor) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MktACLineSegment {

}

class ACLineSegment {

}

ACLineSegment <|-- MktACLineSegment : inherits from
class BranchEndFlow {

}

MktACLineSegment --> "0..1" BranchEndFlow : EndAFlow
class BranchEndFlow {

}

MktACLineSegment --> "0..1" BranchEndFlow : EndBFlow
```

Subclass of IEC 61970:Wires:ACLineSegment.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| EndAFlow [0..1] | [BranchEndFlow](#CIM17v40-BranchEndFlow) | | |
| EndBFlow [0..1] | [BranchEndFlow](#CIM17v40-BranchEndFlow) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| b0ch [0..1] | [Susceptance](#CIM17v40-Susceptance) | see [ACLineSegment](CIM17v40-ACLineSegment) | |
| bch [0..1] | [Susceptance](#CIM17v40-Susceptance) | see [ACLineSegment](CIM17v40-ACLineSegment) | |
| g0ch [0..1] | [Conductance](#CIM17v40-Conductance) | see [ACLineSegment](CIM17v40-ACLineSegment) | |
| gch [0..1] | [Conductance](#CIM17v40-Conductance) | see [ACLineSegment](CIM17v40-ACLineSegment) | |
| r [0..1] | [Resistance](#CIM17v40-Resistance) | see [ACLineSegment](CIM17v40-ACLineSegment) | |
| r0 [0..1] | [Resistance](#CIM17v40-Resistance) | see [ACLineSegment](CIM17v40-ACLineSegment) | |
| shortCircuitEndTemperature [0..1] | [Temperature](#CIM17v40-Temperature) | see [ACLineSegment](CIM17v40-ACLineSegment) | |
| x [0..1] | [Reactance](#CIM17v40-Reactance) | see [ACLineSegment](CIM17v40-ACLineSegment) | |
| x0 [0..1] | [Reactance](#CIM17v40-Reactance) | see [ACLineSegment](CIM17v40-ACLineSegment) | |
| LineGroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ACLineSegment](CIM17v40-ACLineSegment) | |
| LineJumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ACLineSegment](CIM17v40-ACLineSegment) | |
| PerLengthImpedance [0..1] | [PerLengthImpedance](#CIM17v40-PerLengthImpedance) | see [ACLineSegment](CIM17v40-ACLineSegment) | |
| WireSpacingInfo [0..1] | [WireSpacingInfo](#CIM17v40-WireSpacingInfo) | see [ACLineSegment](CIM17v40-ACLineSegment) | |
| length [0..1] | [Length](#CIM17v40-Length) | see [Conductor](CIM17v40-Conductor) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MktActivityRecord}
### MktActivityRecord

Inheritance path = [ActivityRecord](#CIM17v40-ActivityRecord) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MktActivityRecord {

}

class ActivityRecord {

}

ActivityRecord <|-- MktActivityRecord : inherits from
```

Subclass of IEC61968: Common:ActivityRecord.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| reason [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| severity [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| type [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| Document [0..1] | [Document](#CIM17v40-Document) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MktAnalogLimit}
### MktAnalogLimit

Inheritance path = [AnalogLimit](#CIM17v40-AnalogLimit) => [Limit](#CIM17v40-Limit) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MktAnalogLimit {

+ exceededLimit : Boolean [0..1]
+ limitType : enum:AnalogLimitType [0..1]
}

class AnalogLimit {

}

AnalogLimit <|-- MktAnalogLimit : inherits from
```

Subclass of IEC 61970:Meas:AnalogLimit.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| exceededLimit [0..1] | [Boolean](#CIM17v40-Boolean) | true if limit exceeded | |
| limitType [0..1] | [AnalogLimitType](#CIM17v40-AnalogLimitType) | The type of limit the value representsBranch Limit Types:Short TermMedium TermLong TermVoltage Limits:HighLow | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| value [0..1] | [Float](#CIM17v40-Float) | see [AnalogLimit](#CIM17v40-AnalogLimit) | |
| `LimitSet [1]` (OfAggregate) | [AnalogLimitSet](#CIM17v40-AnalogLimitSet) | see [AnalogLimit](CIM17v40-AnalogLimit) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MktAnalogLimitSet}
### MktAnalogLimitSet

Inheritance path = [AnalogLimitSet](#CIM17v40-AnalogLimitSet) => [LimitSet](#CIM17v40-LimitSet) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MktAnalogLimitSet {

+ ratingSet : Integer [0..1]
}

class AnalogLimitSet {

}

AnalogLimitSet <|-- MktAnalogLimitSet : inherits from
```

Subclass of IEC 61970:Meas:AnalogLimitSet.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ratingSet [0..1] | [Integer](#CIM17v40-Integer) | Rating set numbers | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| isPercentageLimits [0..1] | [Boolean](#CIM17v40-Boolean) | see [LimitSet](#CIM17v40-LimitSet) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MktCombinedCyclePlant}
### MktCombinedCyclePlant

Inheritance path = [CombinedCyclePlant](#CIM17v40-CombinedCyclePlant) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MktCombinedCyclePlant {

}

class CombinedCyclePlant {

}

CombinedCyclePlant <|-- MktCombinedCyclePlant : inherits from
class AggregatedPnode {

}

MktCombinedCyclePlant --> "0..1" AggregatedPnode : AggregatedPnode
```

Subclass of Production: CombinedCyclePlant from IEC 61970 package.

A set of combustion turbines and steam turbines where the exhaust heat from the combustion turbines is recovered to make steam for the steam turbines, resulting in greater overall plant efficiency.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AggregatedPnode [0..1] | [AggregatedPnode](#CIM17v40-AggregatedPnode) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| combCyclePlantRating [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [CombinedCyclePlant](CIM17v40-CombinedCyclePlant) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MktConductingEquipment}
### MktConductingEquipment

Inheritance path = [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MktConductingEquipment {

}

class ConductingEquipment {

}

ConductingEquipment <|-- MktConductingEquipment : inherits from
```

Subclass of IEC 61970:Core:ConductingEquipment.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MktConnectivityNode}
### MktConnectivityNode

Inheritance path = [ConnectivityNode](#CIM17v40-ConnectivityNode) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MktConnectivityNode {

}

class ConnectivityNode {

}

ConnectivityNode <|-- MktConnectivityNode : inherits from
class IndividualPnode {

}

MktConnectivityNode --> "0..1" IndividualPnode : IndividualPnode
class RTO {

}

MktConnectivityNode --> "1" RTO : RTO
class SysLoadDistributionFactor {

}

MktConnectivityNode --> "0..1" SysLoadDistributionFactor : SysLoadDistribuFactor
```

Subclass of IEC61970:Topology:ConnectivityNode.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| IndividualPnode [0..1] | [IndividualPnode](#CIM17v40-IndividualPnode) | | |
| RTO [1] | [RTO](#CIM17v40-RTO) | | |
| SysLoadDistribuFactor [0..1] | [SysLoadDistributionFactor](#CIM17v40-SysLoadDistributionFactor) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ConnectivityNodeContainer [1] | [ConnectivityNodeContainer](#CIM17v40-ConnectivityNodeContainer) | see [ConnectivityNode](CIM17v40-ConnectivityNode) | |
| `TopologicalNode [0..1]` (OfAggregate) | [TopologicalNode](#CIM17v40-TopologicalNode) | see [ConnectivityNode](CIM17v40-ConnectivityNode) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MktContingency}
### MktContingency

Inheritance path = [Contingency](#CIM17v40-Contingency) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MktContingency {

+ loadRolloverFlag : Boolean [0..1]
+ ltcControlFlag : Boolean [0..1]
+ participationFactorSet : String [0..1]
+ screeningFlag : Boolean [0..1]
}

class Contingency {

}

Contingency <|-- MktContingency : inherits from
class TransferInterfaceSolution {

}

MktContingency --> "0..1" TransferInterfaceSolution : TransferInterfaceSolutionA
class TransferInterfaceSolution {

}

MktContingency --> "0..1" TransferInterfaceSolution : TransferInterfaceSolutionB
```

Subclass of IEC 61970:Contingency.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| loadRolloverFlag [0..1] | [Boolean](#CIM17v40-Boolean) | load change flagFlag that indicates whether load rollover and load pickup should be processed for this contingency | |
| ltcControlFlag [0..1] | [Boolean](#CIM17v40-Boolean) | ltc enable flagFlag that indicates if LTCs regulate voltage during the solution of the contingency | |
| participationFactorSet [0..1] | [String](#CIM17v40-String) | Participation Factor flagAn indication which set of generator participation factors should be used to re-allocate generation in this contingency | |
| screeningFlag [0..1] | [Boolean](#CIM17v40-Boolean) | sceening flag for outageFlag that indicated whether screening is bypassed for the contingency | |
| TransferInterfaceSolutionA [0..1] | [TransferInterfaceSolution](#CIM17v40-TransferInterfaceSolution) | | |
| TransferInterfaceSolutionB [0..1] | [TransferInterfaceSolution](#CIM17v40-TransferInterfaceSolution) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mustStudy [0..1] | [Boolean](#CIM17v40-Boolean) | see [Contingency](#CIM17v40-Contingency) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MktControlArea}
### MktControlArea

Inheritance path = [ControlArea](#CIM17v40-ControlArea) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MktControlArea {

}

class ControlArea {

}

ControlArea <|-- MktControlArea : inherits from
```

Market subclass of IEC 61970:ControlArea.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| netInterchange [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [ControlArea](CIM17v40-ControlArea) | |
| pTolerance [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [ControlArea](CIM17v40-ControlArea) | |
| type [0..1] | [ControlAreaTypeKind](#CIM17v40-ControlAreaTypeKind) | see [ControlArea](CIM17v40-ControlArea) | |
| EnergyArea [0..1] | [EnergyArea](#CIM17v40-EnergyArea) | see [ControlArea](CIM17v40-ControlArea) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MktGeneratingUnit}
### MktGeneratingUnit

Inheritance path = [GeneratingUnit](#CIM17v40-GeneratingUnit) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MktGeneratingUnit {

}

class GeneratingUnit {

}

GeneratingUnit <|-- MktGeneratingUnit : inherits from
```

Subclass of IEC61970:Production:GeneratingUnit.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| allocSpinResP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| autoCntrlMarginP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| baseP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlDeadband [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlPulseHigh [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlPulseLow [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlResponseRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| efficiency [0..1] | [PerCent](#CIM17v40-PerCent) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| genControlMode [0..1] | [GeneratorControlMode](#CIM17v40-GeneratorControlMode) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| genControlSource [0..1] | [GeneratorControlSource](#CIM17v40-GeneratorControlSource) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| governorMPL [0..1] | [PU](#CIM17v40-PU) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| governorSCD [0..1] | [PerCent](#CIM17v40-PerCent) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| highControlLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| initialP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| longPF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| lowControlLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| lowerRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| maxEconomicP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| maximumAllowableSpinningReserve [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| maxOperatingP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| minEconomicP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| minimumOffTime [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| minOperatingP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| modelDetail [0..1] | [Classification](#CIM17v40-Classification) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| nominalP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| normalPF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| penaltyFactor [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| raiseRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| ratedGrossMaxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| ratedGrossMinP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| ratedNetMaxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| shortPF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| startupCost [0..1] | [Money](#CIM17v40-Money) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| startupTime [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| tieLinePF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| totalEfficiency [0..1] | [PerCent](#CIM17v40-PerCent) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| variableCost [0..1] | [Money](#CIM17v40-Money) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| `GenUnitOpSchedule [0..1]` (AggregateOf) | [GenUnitOpSchedule](#CIM17v40-GenUnitOpSchedule) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MktHeatRateCurve}
### MktHeatRateCurve

Inheritance path = [HeatRateCurve](#CIM17v40-HeatRateCurve) => [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MktHeatRateCurve {

}

class HeatRateCurve {

}

HeatRateCurve <|-- MktHeatRateCurve : inherits from
class RegisteredGenerator {

}

MktHeatRateCurve --> "0..1" RegisteredGenerator : RegisteredGenerator
class ResourceVerifiableCosts {

}

MktHeatRateCurve --> "0..1" ResourceVerifiableCosts : ResourceVerifiableCosts
```

Subclass of IEC 61970: Generation: Production:HeatRateCurve.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| RegisteredGenerator [0..1] | [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | | |
| ResourceVerifiableCosts [0..1] | [ResourceVerifiableCosts](#CIM17v40-ResourceVerifiableCosts) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| isNetGrossP [0..1] | [Boolean](#CIM17v40-Boolean) | see [HeatRateCurve](#CIM17v40-HeatRateCurve) | |
| `ThermalGeneratingUnit [1]` (OfAggregate) | [ThermalGeneratingUnit](#CIM17v40-ThermalGeneratingUnit) | see [HeatRateCurve](CIM17v40-HeatRateCurve) | |
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MktLine}
### MktLine

Inheritance path = [Line](#CIM17v40-Line) => [EquipmentContainer](#CIM17v40-EquipmentContainer) => [ConnectivityNodeContainer](#CIM17v40-ConnectivityNodeContainer) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MktLine {

}

class Line {

}

Line <|-- MktLine : inherits from
class TransmissionRightOfWay {

}

MktLine --> "0..1" TransmissionRightOfWay : TransmissionRightOfWay
```

Subclass for IEC61970:Wires:Line.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `TransmissionRightOfWay [0..1]` (informative) | [TransmissionRightOfWay](#CIM17v40-TransmissionRightOfWay) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Region [0..1]` (OfAggregate) | [SubGeographicalRegion](#CIM17v40-SubGeographicalRegion) | see [Line](CIM17v40-Line) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MktMeasurement}
### (informative) MktMeasurement

Inheritance path = [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MktMeasurement {

}

class Measurement {

}

Measurement <|-- MktMeasurement : inherits from
class TiePoint {

}

MktMeasurement --> "1" TiePoint : ByTiePoint
class TiePoint {

}

MktMeasurement --> "1" TiePoint : ForTiePoint
class Pnode {

}

MktMeasurement --> "0..1" Pnode : Pnode
```

Subclass of IEC61970:Meas:Measurement.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ByTiePoint [1]` (informative) | [TiePoint](#CIM17v40-TiePoint) | A measurement is made on the B side of a tie point | |
| `ForTiePoint [1]` (informative) | [TiePoint](#CIM17v40-TiePoint) | A measurement is made on the A side of a tie point | |
| Pnode [0..1] | [Pnode](#CIM17v40-Pnode) | Allows Pnode an association to aggregated resources external DC ties or psuedo tie measurements. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MktPSRType}
### MktPSRType

Inheritance path = [PSRType](#CIM17v40-PSRType) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MktPSRType {

+ psrType : String [0..1]
}

class PSRType {

}

PSRType <|-- MktPSRType : inherits from
```

The type of a power system resource.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| psrType [0..1] | [String](#CIM17v40-String) | The coded type of a power system resource. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MktPowerTransformer}
### MktPowerTransformer

Inheritance path = [PowerTransformer](#CIM17v40-PowerTransformer) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MktPowerTransformer {

}

class PowerTransformer {

}

PowerTransformer <|-- MktPowerTransformer : inherits from
class BranchEndFlow {

}

MktPowerTransformer --> "0..1" BranchEndFlow : EndAFlow
class BranchEndFlow {

}

MktPowerTransformer --> "0..1" BranchEndFlow : EndBFlow
```

Subclass of IEC61970:Wires:PowerTransformer.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| EndAFlow [0..1] | [BranchEndFlow](#CIM17v40-BranchEndFlow) | | |
| EndBFlow [0..1] | [BranchEndFlow](#CIM17v40-BranchEndFlow) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| beforeShCircuitHighestOperatingCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [PowerTransformer](CIM17v40-PowerTransformer) | |
| beforeShCircuitHighestOperatingVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | see [PowerTransformer](CIM17v40-PowerTransformer) | |
| beforeShortCircuitAnglePf [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | see [PowerTransformer](CIM17v40-PowerTransformer) | |
| highSideMinOperatingU [0..1] | [Voltage](#CIM17v40-Voltage) | see [PowerTransformer](CIM17v40-PowerTransformer) | |
| isPartOfGeneratorUnit [0..1] | [Boolean](#CIM17v40-Boolean) | see [PowerTransformer](#CIM17v40-PowerTransformer) | |
| operationalValuesConsidered [0..1] | [Boolean](#CIM17v40-Boolean) | see [PowerTransformer](#CIM17v40-PowerTransformer) | |
| vectorGroup [0..1] | [String](#CIM17v40-String) | see [PowerTransformer](#CIM17v40-PowerTransformer) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MktSeriesCompensator}
### MktSeriesCompensator

Inheritance path = [SeriesCompensator](#CIM17v40-SeriesCompensator) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MktSeriesCompensator {

}

class SeriesCompensator {

}

SeriesCompensator <|-- MktSeriesCompensator : inherits from
class BranchEndFlow {

}

MktSeriesCompensator --> "0..1" BranchEndFlow : EndAFlow
class BranchEndFlow {

}

MktSeriesCompensator --> "0..1" BranchEndFlow : EndBFlow
```

Subclass of IEC 61970:Wires:SeriesCompensator.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| EndAFlow [0..1] | [BranchEndFlow](#CIM17v40-BranchEndFlow) | | |
| EndBFlow [0..1] | [BranchEndFlow](#CIM17v40-BranchEndFlow) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| r [0..1] | [Resistance](#CIM17v40-Resistance) | see [SeriesCompensator](CIM17v40-SeriesCompensator) | |
| r0 [0..1] | [Resistance](#CIM17v40-Resistance) | see [SeriesCompensator](CIM17v40-SeriesCompensator) | |
| varistorPresent [0..1] | [Boolean](#CIM17v40-Boolean) | see [SeriesCompensator](#CIM17v40-SeriesCompensator) | |
| varistorRatedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [SeriesCompensator](CIM17v40-SeriesCompensator) | |
| varistorVoltageThreshold [0..1] | [Voltage](#CIM17v40-Voltage) | see [SeriesCompensator](CIM17v40-SeriesCompensator) | |
| x [0..1] | [Reactance](#CIM17v40-Reactance) | see [SeriesCompensator](CIM17v40-SeriesCompensator) | |
| x0 [0..1] | [Reactance](#CIM17v40-Reactance) | see [SeriesCompensator](CIM17v40-SeriesCompensator) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MktShuntCompensator}
### MktShuntCompensator

Inheritance path = [ShuntCompensator](#CIM17v40-ShuntCompensator) => [RegulatingCondEq](#CIM17v40-RegulatingCondEq) => [EnergyConnection](#CIM17v40-EnergyConnection) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MktShuntCompensator {

}

class ShuntCompensator {

}

ShuntCompensator <|-- MktShuntCompensator : inherits from
```

Subclass of IEC 61970:Wires:ShuntCompensator.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aVRDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [ShuntCompensator](CIM17v40-ShuntCompensator) | |
| grounded [0..1] | [Boolean](#CIM17v40-Boolean) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| maximumSections [0..1] | [Integer](#CIM17v40-Integer) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| nomU [0..1] | [Voltage](#CIM17v40-Voltage) | see [ShuntCompensator](CIM17v40-ShuntCompensator) | |
| normalSections [0..1] | [Integer](#CIM17v40-Integer) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| phaseConnection [0..1] | [PhaseShuntConnectionKind](#CIM17v40-PhaseShuntConnectionKind) | see [ShuntCompensator](CIM17v40-ShuntCompensator) | |
| sections [0..1] | [Float](#CIM17v40-Float) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| `switchOnCount [0..1]` (deprecated) | [Integer](#CIM17v40-Integer) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| `switchOnDate [0..1]` (deprecated) | [DateTime](#CIM17v40-DateTime) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| voltageSensitivity [0..1] | [VoltagePerReactivePower](#CIM17v40-VoltagePerReactivePower) | see [ShuntCompensator](CIM17v40-ShuntCompensator) | |
| ShuntCompensatorAction [0..1] | [ShuntCompensatorAction](#CIM17v40-ShuntCompensatorAction) | see [ShuntCompensator](CIM17v40-ShuntCompensator) | |
| controlEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [RegulatingCondEq](#CIM17v40-RegulatingCondEq) | |
| RegulatingControl [0..1] | [RegulatingControl](#CIM17v40-RegulatingControl) | see [RegulatingCondEq](CIM17v40-RegulatingCondEq) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MktSwitch}
### MktSwitch

Inheritance path = [Switch](#CIM17v40-Switch) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MktSwitch {

}

class Switch {

}

Switch <|-- MktSwitch : inherits from
```

Subclass of IEC 61970:Wires:Switch.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| locked [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| normalOpen [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| open [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [Switch](CIM17v40-Switch) | |
| retained [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| `switchOnCount [0..1]` (deprecated) | [Integer](#CIM17v40-Integer) | see [Switch](#CIM17v40-Switch) | |
| `switchOnDate [0..1]` (deprecated) | [DateTime](#CIM17v40-DateTime) | see [Switch](#CIM17v40-Switch) | |
| `CompositeSwitch [0..1]` (OfAggregate) | [CompositeSwitch](#CIM17v40-CompositeSwitch) | see [Switch](CIM17v40-Switch) | |
| SwitchAction [0..1] | [SwitchAction](#CIM17v40-SwitchAction) | see [Switch](CIM17v40-Switch) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MktTapChanger}
### MktTapChanger

Inheritance path = [TapChanger](#CIM17v40-TapChanger) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MktTapChanger {

}

class TapChanger {

}

TapChanger <|-- MktTapChanger : inherits from
```

Subclass of IEC 61970:Wires:TapChanger.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| controlEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [TapChanger](#CIM17v40-TapChanger) | |
| highStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| initialDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [TapChanger](CIM17v40-TapChanger) | |
| lowStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| ltcFlag [0..1] | [Boolean](#CIM17v40-Boolean) | see [TapChanger](#CIM17v40-TapChanger) | |
| neutralStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| neutralU [0..1] | [Voltage](#CIM17v40-Voltage) | see [TapChanger](CIM17v40-TapChanger) | |
| normalStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| step [0..1] | [Float](#CIM17v40-Float) | see [TapChanger](#CIM17v40-TapChanger) | |
| subsequentDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [TapChanger](CIM17v40-TapChanger) | |
| SvTapStep [0..1] | [SvTapStep](#CIM17v40-SvTapStep) | see [TapChanger](CIM17v40-TapChanger) | |
| TapChangerControl [0..1] | [TapChangerControl](#CIM17v40-TapChangerControl) | see [TapChanger](CIM17v40-TapChanger) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MktTerminal}
### MktTerminal

Inheritance path = [Terminal](#CIM17v40-Terminal) => [ACDCTerminal](#CIM17v40-ACDCTerminal) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MktTerminal {

}

class Terminal {

}

Terminal <|-- MktTerminal : inherits from
class Flowgate {

}

MktTerminal --> "0..1" Flowgate : Flowgate
```

Subclass of IEC61970:Core:Terminal.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Flowgate [0..1] | [Flowgate](#CIM17v40-Flowgate) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Terminal](CIM17v40-Terminal) | |
| Bushing [0..1] | [Bushing](#CIM17v40-Bushing) | see [Terminal](CIM17v40-Terminal) | |
| `Circuit [0..1]` (informative) | [Circuit](#CIM17v40-Circuit) | see [Terminal](CIM17v40-Terminal) | |
| ConductingEquipment [1] | [ConductingEquipment](#CIM17v40-ConductingEquipment) | see [Terminal](CIM17v40-Terminal) | |
| ConnectivityNode [0..1] | [ConnectivityNode](#CIM17v40-ConnectivityNode) | see [Terminal](CIM17v40-Terminal) | |
| NormalHeadFeeder [0..1] | [Feeder](#CIM17v40-Feeder) | see [Terminal](CIM17v40-Terminal) | |
| `TopologicalNode [0..1]` (OfAggregate) | [TopologicalNode](#CIM17v40-TopologicalNode) | see [Terminal](CIM17v40-Terminal) | |
| connected [0..1] | [Boolean](#CIM17v40-Boolean) | see [ACDCTerminal](#CIM17v40-ACDCTerminal) | |
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | see [ACDCTerminal](#CIM17v40-ACDCTerminal) | |
| BusNameMarker [0..1] | [BusNameMarker](#CIM17v40-BusNameMarker) | see [ACDCTerminal](CIM17v40-ACDCTerminal) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MktThermalGeneratingUnit}
### MktThermalGeneratingUnit

Inheritance path = [ThermalGeneratingUnit](#CIM17v40-ThermalGeneratingUnit) => [GeneratingUnit](#CIM17v40-GeneratingUnit) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MktThermalGeneratingUnit {

}

class ThermalGeneratingUnit {

}

ThermalGeneratingUnit <|-- MktThermalGeneratingUnit : inherits from
```

Subclass of ThermalGeneratingUnit from Production Package in IEC 61970.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| oMCost [0..1] | [CostPerHeatUnit](#CIM17v40-CostPerHeatUnit) | see [ThermalGeneratingUnit](CIM17v40-ThermalGeneratingUnit) | |
| CAESPlant [0..1] | [CAESPlant](#CIM17v40-CAESPlant) | see [ThermalGeneratingUnit](CIM17v40-ThermalGeneratingUnit) | |
| CogenerationPlant [0..1] | [CogenerationPlant](#CIM17v40-CogenerationPlant) | see [ThermalGeneratingUnit](CIM17v40-ThermalGeneratingUnit) | |
| CombinedCyclePlant [0..1] | [CombinedCyclePlant](#CIM17v40-CombinedCyclePlant) | see [ThermalGeneratingUnit](CIM17v40-ThermalGeneratingUnit) | |
| `HeatInputCurve [0..1]` (AggregateOf) | [HeatInputCurve](#CIM17v40-HeatInputCurve) | see [ThermalGeneratingUnit](CIM17v40-ThermalGeneratingUnit) | |
| `HeatRateCurve [0..1]` (AggregateOf) | [HeatRateCurve](#CIM17v40-HeatRateCurve) | see [ThermalGeneratingUnit](CIM17v40-ThermalGeneratingUnit) | |
| `IncrementalHeatRateCurve [0..1]` (AggregateOf) | [IncrementalHeatRateCurve](#CIM17v40-IncrementalHeatRateCurve) | see [ThermalGeneratingUnit](CIM17v40-ThermalGeneratingUnit) | |
| `ShutdownCurve [0..1]` (AggregateOf) | [ShutdownCurve](#CIM17v40-ShutdownCurve) | see [ThermalGeneratingUnit](CIM17v40-ThermalGeneratingUnit) | |
| `StartupModel [0..1]` (AggregateOf) | [StartupModel](#CIM17v40-StartupModel) | see [ThermalGeneratingUnit](CIM17v40-ThermalGeneratingUnit) | |
| allocSpinResP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| autoCntrlMarginP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| baseP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlDeadband [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlPulseHigh [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlPulseLow [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlResponseRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| efficiency [0..1] | [PerCent](#CIM17v40-PerCent) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| genControlMode [0..1] | [GeneratorControlMode](#CIM17v40-GeneratorControlMode) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| genControlSource [0..1] | [GeneratorControlSource](#CIM17v40-GeneratorControlSource) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| governorMPL [0..1] | [PU](#CIM17v40-PU) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| governorSCD [0..1] | [PerCent](#CIM17v40-PerCent) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| highControlLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| initialP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| longPF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| lowControlLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| lowerRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| maxEconomicP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| maximumAllowableSpinningReserve [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| maxOperatingP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| minEconomicP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| minimumOffTime [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| minOperatingP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| modelDetail [0..1] | [Classification](#CIM17v40-Classification) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| nominalP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| normalPF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| penaltyFactor [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| raiseRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| ratedGrossMaxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| ratedGrossMinP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| ratedNetMaxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| shortPF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| startupCost [0..1] | [Money](#CIM17v40-Money) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| startupTime [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| tieLinePF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| totalEfficiency [0..1] | [PerCent](#CIM17v40-PerCent) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| variableCost [0..1] | [Money](#CIM17v40-Money) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| `GenUnitOpSchedule [0..1]` (AggregateOf) | [GenUnitOpSchedule](#CIM17v40-GenUnitOpSchedule) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MktUserAttribute}
### MktUserAttribute

Inheritance path = [UserAttribute](#CIM17v40-UserAttribute)

```mermaid
classDiagram
direction TB

class MktUserAttribute {

}

class UserAttribute {

}

UserAttribute <|-- MktUserAttribute : inherits from
```

Subclass of IEC61968:Domain2:UserAttribute.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| name [0..1] | [String](#CIM17v40-String) | see [UserAttribute](#CIM17v40-UserAttribute) | |
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | see [UserAttribute](#CIM17v40-UserAttribute) | |
| `PropertySpecification [0..1]` (informative) | [Specification](#CIM17v40-Specification) | see [UserAttribute](CIM17v40-UserAttribute) | |
| `RatingSpecification [0..1]` (informative) | [Specification](#CIM17v40-Specification) | see [UserAttribute](CIM17v40-UserAttribute) | |
| Transaction [0..1] | [Transaction](#CIM17v40-Transaction) | see [UserAttribute](CIM17v40-UserAttribute) | |
| value [0..1] | [StringQuantity](#CIM17v40-StringQuantity) | see [UserAttribute](CIM17v40-UserAttribute) | |

{#CIM17v40-ModelAuthority}
### (informative) ModelAuthority

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ModelAuthority {

}

class IdentifiedObject {

}

IdentifiedObject <|-- ModelAuthority : inherits from
```

A Modeling Authority is an entity responsible for supplying and maintaining the data defining a specific set of objects in a network model.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ModelAuthoritySet}
### (informative) ModelAuthoritySet

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ModelAuthoritySet {

}

class IdentifiedObject {

}

IdentifiedObject <|-- ModelAuthoritySet : inherits from
class ModelAuthority {

}

ModelAuthoritySet --> "1" ModelAuthority : ModelingAuthority
```

A Modeling Authority Set is a group of objects in a network model where the data is supplied and maintained by the same Modeling Authority.

This class is typically not included in instance data exchange as this information is tracked by other mechanisms in the exchange.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ModelingAuthority [1]` (informative) | [ModelAuthority](#CIM17v40-ModelAuthority) | Modeling Authority suppliying and maintaining the data for the objects in this Modeling Authority Set. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ModelFrameType}
### (informative) ModelFrameType

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ModelFrameType {

}

class IdentifiedObject {

}

IdentifiedObject <|-- ModelFrameType : inherits from
```

Examples would be "Boundary" or "Region" type of frame.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ModelOperation}
### (informative) ModelOperation

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ModelOperation {

+ sequenceNumber : Integer [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ModelOperation : inherits from
class ModelOperationDescription {

}

ModelOperation --> "1" ModelOperationDescription : ModelOperationDescription
class ModelOperationSequence {

}

ModelOperation --> "1" ModelOperationSequence : OperationSequence
```

An operation performed on models.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | Sequence number within a operation sequence, lower is first. Normally starts with 1. | |
| `ModelOperationDescription [1]` (informative) | [ModelOperationDescription](#CIM17v40-ModelOperationDescription) | The type of the model operation. | |
| `OperationSequence [1]` (informative) | [ModelOperationSequence](#CIM17v40-ModelOperationSequence) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ModelOperationArg}
### ModelOperationArg

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ModelOperationArg {

+ sequenceNumber : Integer [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ModelOperationArg : inherits from
class ModelOperation {

}

ModelOperationArg --> "1" ModelOperation : ModelOperation
```

Describes the role a dataset plays in a model operation. The role is applicable only in the context of a single operation.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | The sequence number of the argument in an operation. Argument entries are considered in numerical order where the operation requires an ordering. | |
| `ModelOperation [1]` (informative) | [ModelOperation](#CIM17v40-ModelOperation) | The opeation for the operation argument. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ModelOperationArgDescription}
### ModelOperationArgDescription

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ModelOperationArgDescription {

+ multiplicityMaximum : Integer [0..1]
+ multiplicityMinimum : Integer [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ModelOperationArgDescription : inherits from
class ModelOperationDescription {

}

ModelOperationArgDescription --> "1" ModelOperationDescription : ModelOperationDefinition
```

The type of custom operation dataset role for an operation description.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| multiplicityMaximum [0..1] | [Integer](#CIM17v40-Integer) | The maximum multiplicity of the instance arguments that should be supplied for a single operation. Use -1 to indicate unlimited. | |
| multiplicityMinimum [0..1] | [Integer](#CIM17v40-Integer) | The minimum multiplicity of the instance arguments that should be supplied for a single operation. Use zero to indicate optional. | |
| `ModelOperationDefinition [1]` (informative) | [ModelOperationDescription](#CIM17v40-ModelOperationDescription) | The type of operation for this type of dataset role. Operations referencing the dataset role type should only belong to operations that reference the operation type. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ModelOperationDescription}
### (informative) ModelOperationDescription

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ModelOperationDescription {

}

class IdentifiedObject {

}

IdentifiedObject <|-- ModelOperationDescription : inherits from
```

The type of model operation. This class is referenced by model operations and defines the kind of operation.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ModelOperationSequence}
### (informative) ModelOperationSequence

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ModelOperationSequence {

}

class IdentifiedObject {

}

IdentifiedObject <|-- ModelOperationSequence : inherits from
```

A concrete sequence of operations. For example, this may be used to describe a specific audit trail, a script or other specific set of actions on specific datasets.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ModelPartSpecification}
### (informative) ModelPartSpecification

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ModelPartSpecification {

}

class IdentifiedObject {

}

IdentifiedObject <|-- ModelPartSpecification : inherits from
class ModelAuthoritySet {

}

ModelPartSpecification --> "0..1" ModelAuthoritySet : FrameworkPart
```

The type of model. For example, state estimator, planning, planning dynamics, short circuit, or real-time dynamics etc. The model must conform to a profile.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `FrameworkPart [0..1]` (informative) | [ModelAuthoritySet](#CIM17v40-ModelAuthoritySet) | Model frame of the model part. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ModelPartVersion}
### ModelPartVersion

Inheritance path = [ModelToBeDeleted](#CIM17v40-ModelToBeDeleted) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ModelPartVersion {

}

class ModelToBeDeleted {

}

ModelToBeDeleted <|-- ModelPartVersion : inherits from
class ModelPartSpecification {

}

ModelPartVersion --> "1" ModelPartSpecification : ModelSpecification
```

This is a version of a part of a model. New instances of this class with new identity are instantiated upon changes to the content of this class or changes to the associated data set. Instances of this class are considered immutable. The case audit trail can reference this immutable data to exactly reproduce a case.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ModelSpecification [1]` (informative) | [ModelPartSpecification](#CIM17v40-ModelPartSpecification) | Model specification of the modelt. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ModelToBeDeleted}
### ModelToBeDeleted

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ModelToBeDeleted {

}

class IdentifiedObject {

}

IdentifiedObject <|-- ModelToBeDeleted : inherits from
```

A Model is a collection of Datasets.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-MutualCoupling}
### MutualCoupling

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class MutualCoupling {

+ b0ch : Susceptance [0..1]
+ distance11 : Length [0..1]
+ distance12 : Length [0..1]
+ distance21 : Length [0..1]
+ distance22 : Length [0..1]
+ g0ch : Conductance [0..1]
+ r0 : Resistance [0..1]
+ x0 : Reactance [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- MutualCoupling : inherits from
class Terminal {

}

MutualCoupling --> "1" Terminal : First_Terminal
class Terminal {

}

MutualCoupling --> "1" Terminal : Second_Terminal
```

This class represents the zero sequence line mutual coupling.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| b0ch [0..1] | [Susceptance](#CIM17v40-Susceptance) | Zero sequence mutual coupling shunt (charging) susceptance, uniformly distributed, of the entire line section. | |
| distance11 [0..1] | [Length](#CIM17v40-Length) | Distance to the start of the coupled region from the first line's terminal having sequence number equal to 1. | |
| distance12 [0..1] | [Length](#CIM17v40-Length) | Distance to the end of the coupled region from the first line's terminal with sequence number equal to 1. | |
| distance21 [0..1] | [Length](#CIM17v40-Length) | Distance to the start of coupled region from the second line's terminal with sequence number equal to 1. | |
| distance22 [0..1] | [Length](#CIM17v40-Length) | Distance to the end of coupled region from the second line's terminal with sequence number equal to 1. | |
| g0ch [0..1] | [Conductance](#CIM17v40-Conductance) | Zero sequence mutual coupling shunt (charging) conductance, uniformly distributed, of the entire line section. | |
| r0 [0..1] | [Resistance](#CIM17v40-Resistance) | Zero sequence branch-to-branch mutual impedance coupling, resistance. | |
| x0 [0..1] | [Reactance](#CIM17v40-Reactance) | Zero sequence branch-to-branch mutual impedance coupling, reactance. | |
| First_Terminal [1] | [Terminal](#CIM17v40-Terminal) | The starting terminal for the calculation of distances along the first branch of the mutual coupling. Normally MutualCoupling would only be used for terminals of AC line segments. The first and second terminals of a mutual coupling should point to different AC line segments. | |
| Second_Terminal [1] | [Terminal](#CIM17v40-Terminal) | The starting terminal for the calculation of distances along the second branch of the mutual coupling. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Name}
### Name


```mermaid
classDiagram
direction TB

class Name {

+ name : String [0..1]
}

class IdentifiedObject {

}

Name --> "1" IdentifiedObject : IdentifiedObject
class NameType {

}

Name --> "1" NameType : NameType
```

The Name class provides the means to define any number of human readable names for an object. A name is <b>not</b> to be used for defining inter-object relationships. For inter-object relationships instead use the object identification 'mRID'.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| name [0..1] | [String](#CIM17v40-String) | Any free text that name the object. | |
| IdentifiedObject [1] | [IdentifiedObject](#CIM17v40-IdentifiedObject) | Identified object that this name designates. | |
| NameType [1] | [NameType](#CIM17v40-NameType) | Type of this name. | |

{#CIM17v40-NameType}
### NameType


```mermaid
classDiagram
direction TB

class NameType {

+ description : String [0..1]
+ name : String [0..1]
}

class NameTypeAuthority {

}

NameType --> "0..1" NameTypeAuthority : NameTypeAuthority
```

Type of name. Possible values for attribute 'name' are implementation dependent but standard profiles may specify types. An enterprise may have multiple IT systems each having its own local name for the same object, e.g. a planning system may have different names from an EMS. An object may also have different names within the same IT system, e.g. localName as defined in CIM version 14. The definition from CIM14 is:

The localName is a human readable name of the object. It is a free text name local to a node in a naming hierarchy similar to a file directory structure. A power system related naming hierarchy may be: Substation, VoltageLevel, Equipment etc. Children of the same parent in such a hierarchy have names that typically are unique among them.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| description [0..1] | [String](#CIM17v40-String) | Description of the name type. | |
| name [0..1] | [String](#CIM17v40-String) | Name of the name type. | |
| NameTypeAuthority [0..1] | [NameTypeAuthority](#CIM17v40-NameTypeAuthority) | Authority responsible for managing names of this type. | |

{#CIM17v40-NameTypeAuthority}
### NameTypeAuthority


```mermaid
classDiagram
direction TB

class NameTypeAuthority {

+ description : String [0..1]
+ name : String [0..1]
}

```

Authority responsible for creation and management of names of a given type; typically an organization or an enterprise system.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| description [0..1] | [String](#CIM17v40-String) | Description of the name type authority. | |
| name [0..1] | [String](#CIM17v40-String) | Name of the name type authority. | |

{#CIM17v40-NetworkBoundary}
### NetworkBoundary

Inheritance path = [FrameworkPart](#CIM17v40-FrameworkPart) => [ModelAuthoritySet](#CIM17v40-ModelAuthoritySet) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class NetworkBoundary {

}

class FrameworkPart {

}

FrameworkPart <|-- NetworkBoundary : inherits from
```

A framework part that is a boundary between 2 frames.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Frame [0..1]` (informative) | [NetworkFrame](#CIM17v40-NetworkFrame) | see [FrameworkPart](CIM17v40-FrameworkPart) | |
| `ModelFrameType [1]` (informative) | [ModelFrameType](#CIM17v40-ModelFrameType) | see [FrameworkPart](CIM17v40-FrameworkPart) | |
| `ModelingAuthority [1]` (informative) | [ModelAuthority](#CIM17v40-ModelAuthority) | see [ModelAuthoritySet](CIM17v40-ModelAuthoritySet) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-NetworkFrame}
### (informative) NetworkFrame

Inheritance path = [FrameworkPart](#CIM17v40-FrameworkPart) => [ModelAuthoritySet](#CIM17v40-ModelAuthoritySet) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class NetworkFrame {

}

class FrameworkPart {

}

FrameworkPart <|-- NetworkFrame : inherits from
```

A region isolated by boundaries.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Frame [0..1]` (informative) | [NetworkFrame](#CIM17v40-NetworkFrame) | see [FrameworkPart](CIM17v40-FrameworkPart) | |
| `ModelFrameType [1]` (informative) | [ModelFrameType](#CIM17v40-ModelFrameType) | see [FrameworkPart](CIM17v40-FrameworkPart) | |
| `ModelingAuthority [1]` (informative) | [ModelAuthority](#CIM17v40-ModelAuthority) | see [ModelAuthoritySet](CIM17v40-ModelAuthoritySet) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-NetworkModelCaseDefinition}
### NetworkModelCaseDefinition


```mermaid
classDiagram
direction TB

class NetworkModelCaseDefinition {

}

```

Instructions to build a network model case, including when appropriate the results.


{#CIM17v40-NetworkModelProject}
### (informative) NetworkModelProject

Inheritance path = [NetworkModelProjectComponent](#CIM17v40-NetworkModelProjectComponent) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class NetworkModelProject {

}

class NetworkModelProjectComponent {

}

NetworkModelProjectComponent <|-- NetworkModelProject : inherits from
```

A grouping of network model change descriptions. Primarily used to organize the phases of an overall project.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ContainingProject [1]` (informative) | [NetworkModelProject](#CIM17v40-NetworkModelProject) | see [NetworkModelProjectComponent](CIM17v40-NetworkModelProjectComponent) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-NetworkModelProject2}
### (informative) NetworkModelProject2

Inheritance path = [NetworkModelProjectComponent2](#CIM17v40-NetworkModelProjectComponent2) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class NetworkModelProject2 {

}

class NetworkModelProjectComponent2 {

}

NetworkModelProjectComponent2 <|-- NetworkModelProject2 : inherits from
```


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| closed [0..1] | [DateTime](#CIM17v40-DateTime) | see [NetworkModelProjectComponent2](#CIM17v40-NetworkModelProjectComponent2) | |
| created [0..1] | [DateTime](#CIM17v40-DateTime) | see [NetworkModelProjectComponent2](#CIM17v40-NetworkModelProjectComponent2) | |
| updated [0..1] | [DateTime](#CIM17v40-DateTime) | see [NetworkModelProjectComponent2](#CIM17v40-NetworkModelProjectComponent2) | |
| version [0..1] | [Integer](#CIM17v40-Integer) | see [NetworkModelProjectComponent2](#CIM17v40-NetworkModelProjectComponent2) | |
| `Parent [0..1]` (informative) | [NetworkModelProject2](#CIM17v40-NetworkModelProject2) | see [NetworkModelProjectComponent2](CIM17v40-NetworkModelProjectComponent2) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-NetworkModelProjectChange}
### (informative) NetworkModelProjectChange

Inheritance path = [NetworkModelProjectComponent](#CIM17v40-NetworkModelProjectComponent) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class NetworkModelProjectChange {

}

class NetworkModelProjectComponent {

}

NetworkModelProjectComponent <|-- NetworkModelProjectChange : inherits from
```

Network model project change described by versions of an associated change set. Has persistent identity over multiple versions of the associated change set.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ContainingProject [1]` (informative) | [NetworkModelProject](#CIM17v40-NetworkModelProject) | see [NetworkModelProjectComponent](CIM17v40-NetworkModelProjectComponent) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-NetworkModelProjectChangeVersion}
### (informative) NetworkModelProjectChangeVersion

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class NetworkModelProjectChangeVersion {

+ comment : String [0..1]
+ effectiveDateTime : DateTime [0..1]
+ timeStamp : DateTime [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- NetworkModelProjectChangeVersion : inherits from
class ChangeSet {

}

NetworkModelProjectChangeVersion --> "0..1" ChangeSet : ChangeSet
class NetworkModelProjectChange {

}

NetworkModelProjectChangeVersion --> "1" NetworkModelProjectChange : NetworkModelProjectChange
class NetworkModelProjectState {

}

NetworkModelProjectChangeVersion --> "0..1" NetworkModelProjectState : NetworkModelProjectState
class NetworkModelProjectChangeVersion {

}

NetworkModelProjectChangeVersion --> "0..1" NetworkModelProjectChangeVersion : SupercededBy
class NetworkModelProjectChangeVersion {

}

NetworkModelProjectChangeVersion --> "0..1" NetworkModelProjectChangeVersion : Supercedes
```

Describes the status and the planned implementation of the associated change set into the as-built model. New instances of this class with new identity are instantiated upon changes to the content of this class or changes to the associated change set. Instances of this class are considered immutable. The case audit trail can reference this immutable data to exactly reproduce a case.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| comment [0..1] | [String](#CIM17v40-String) | A user provided comment describing the changes in this version from the previous version. | |
| effectiveDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | The date/time the change set is included in the model. | |
| timeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | The date/time this version was finalized and thus made immutable. | |
| `ChangeSet [0..1]` (informative) | [ChangeSet](#CIM17v40-ChangeSet) | The details of model changes for this project. The change set should have a new identifier if it changes. | |
| `NetworkModelProjectChange [1]` (informative) | [NetworkModelProjectChange](#CIM17v40-NetworkModelProjectChange) | The persistent network model project change to which this version applies. | |
| `NetworkModelProjectState [0..1]` (informative) | [NetworkModelProjectState](#CIM17v40-NetworkModelProjectState) | The state of this network model project version. | |
| `SupercededBy [0..1]` (informative) | [NetworkModelProjectChangeVersion](#CIM17v40-NetworkModelProjectChangeVersion) | The project version that will supercede this project version. | |
| `Supercedes [0..1]` (informative) | [NetworkModelProjectChangeVersion](#CIM17v40-NetworkModelProjectChangeVersion) | Project version that is being superceded. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-NetworkModelProjectCollection}
### NetworkModelProjectCollection


```mermaid
classDiagram
direction TB

class NetworkModelProjectCollection {

}

```


{#CIM17v40-NetworkModelProjectComponent}
### (informative) NetworkModelProjectComponent

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class NetworkModelProjectComponent {

}

class IdentifiedObject {

}

IdentifiedObject <|-- NetworkModelProjectComponent : inherits from
class NetworkModelProject {

}

NetworkModelProjectComponent --> "1" NetworkModelProject : ContainingProject
```

Abstract class for both a network model project and network model change.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ContainingProject [1]` (informative) | [NetworkModelProject](#CIM17v40-NetworkModelProject) | The parent project of this project. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-NetworkModelProjectComponent2}
### NetworkModelProjectComponent2

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class NetworkModelProjectComponent2 {

+ closed : DateTime [0..1]
+ created : DateTime [0..1]
+ updated : DateTime [0..1]
+ version : Integer [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- NetworkModelProjectComponent2 : inherits from
class NetworkModelProject2 {

}

NetworkModelProjectComponent2 --> "0..1" NetworkModelProject2 : Parent
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| closed [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| created [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| updated [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| version [0..1] | [Integer](#CIM17v40-Integer) | | |
| `Parent [0..1]` (informative) | [NetworkModelProject2](#CIM17v40-NetworkModelProject2) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-NetworkModelProjectDocument}
### NetworkModelProjectDocument


```mermaid
classDiagram
direction TB

class NetworkModelProjectDocument {

}

```


{#CIM17v40-NetworkModelProjectRelationship}
### NetworkModelProjectRelationship

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class NetworkModelProjectRelationship {

}

class IdentifiedObject {

}

IdentifiedObject <|-- NetworkModelProjectRelationship : inherits from
class NetworkModelProjectComponent {

}

NetworkModelProjectRelationship --> "1" NetworkModelProjectComponent : ProjectA
class NetworkModelProjectComponent {

}

NetworkModelProjectRelationship --> "1" NetworkModelProjectComponent : ProjectB
```

A relationship that assists humans and software building cases by assembling project changes in the correct sequence. This class may be specialized to create specific types of relationships.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ProjectA [1]` (informative) | [NetworkModelProjectComponent](#CIM17v40-NetworkModelProjectComponent) | | |
| `ProjectB [1]` (informative) | [NetworkModelProjectComponent](#CIM17v40-NetworkModelProjectComponent) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-NetworkModelProjectStage}
### (informative) NetworkModelProjectStage

Inheritance path = [NetworkModelProjectComponent2](#CIM17v40-NetworkModelProjectComponent2) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class NetworkModelProjectStage {

+ changesetVersion : Integer [0..1]
+ commissionedDate : DateTime [0..1]
+ plannedCommissionedDate : DateTime [0..1]
}

class NetworkModelProjectComponent2 {

}

NetworkModelProjectComponent2 <|-- NetworkModelProjectStage : inherits from
class AnnotatedProjectDependency {

}

NetworkModelProjectStage --> "0..1" AnnotatedProjectDependency : DependencyDependentOnStage
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| changesetVersion [0..1] | [Integer](#CIM17v40-Integer) | | |
| commissionedDate [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| plannedCommissionedDate [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| `DependencyDependentOnStage [0..1]` (informative) | [AnnotatedProjectDependency](#CIM17v40-AnnotatedProjectDependency) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| closed [0..1] | [DateTime](#CIM17v40-DateTime) | see [NetworkModelProjectComponent2](#CIM17v40-NetworkModelProjectComponent2) | |
| created [0..1] | [DateTime](#CIM17v40-DateTime) | see [NetworkModelProjectComponent2](#CIM17v40-NetworkModelProjectComponent2) | |
| updated [0..1] | [DateTime](#CIM17v40-DateTime) | see [NetworkModelProjectComponent2](#CIM17v40-NetworkModelProjectComponent2) | |
| version [0..1] | [Integer](#CIM17v40-Integer) | see [NetworkModelProjectComponent2](#CIM17v40-NetworkModelProjectComponent2) | |
| `Parent [0..1]` (informative) | [NetworkModelProject2](#CIM17v40-NetworkModelProject2) | see [NetworkModelProjectComponent2](CIM17v40-NetworkModelProjectComponent2) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-NetworkModelProjectState}
### (informative) NetworkModelProjectState

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class NetworkModelProjectState {

}

class IdentifiedObject {

}

IdentifiedObject <|-- NetworkModelProjectState : inherits from
```

A network model project version state. States are agreed upon by the exchange community. Examples are "approved", "proposed", "withdrawn", "committed" etc.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-NoLoadTest}
### NoLoadTest

Inheritance path = [TransformerTest](#CIM17v40-TransformerTest) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class NoLoadTest {

+ energisedEndVoltage : Voltage [0..1]
+ excitingCurrent : PerCent [0..1]
+ excitingCurrentZero : PerCent [0..1]
+ loss : KiloActivePower [0..1]
+ lossZero : KiloActivePower [0..1]
}

class TransformerTest {

}

TransformerTest <|-- NoLoadTest : inherits from
class TransformerEndInfo {

}

NoLoadTest --> "0..1" TransformerEndInfo : EnergisedEnd
```

No-load test results determine core admittance parameters. They include exciting current and core loss measurements from applying voltage to one winding. The excitation may be positive sequence or zero sequence. The test may be repeated at different voltages to measure saturation.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| energisedEndVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Voltage applied to the winding (end) during test. | |
| excitingCurrent [0..1] | [PerCent](#CIM17v40-PerCent) | Exciting current measured from a positive-sequence or single-phase excitation test. | |
| excitingCurrentZero [0..1] | [PerCent](#CIM17v40-PerCent) | Exciting current measured from a zero-sequence open-circuit excitation test. | |
| loss [0..1] | [KiloActivePower](#CIM17v40-KiloActivePower) | Losses measured from a positive-sequence or single-phase excitation test. | |
| lossZero [0..1] | [KiloActivePower](#CIM17v40-KiloActivePower) | Losses measured from a zero-sequence excitation test. | |
| EnergisedEnd [0..1] | [TransformerEndInfo](#CIM17v40-TransformerEndInfo) | Transformer end that current is applied to in this no-load test. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| basePower [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | see [TransformerTest](CIM17v40-TransformerTest) | |
| temperature [0..1] | [Temperature](#CIM17v40-Temperature) | see [TransformerTest](CIM17v40-TransformerTest) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-NodeConstraintTerm}
### NodeConstraintTerm

Inheritance path = [ConstraintTerm](#CIM17v40-ConstraintTerm) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class NodeConstraintTerm {

}

class ConstraintTerm {

}

ConstraintTerm <|-- NodeConstraintTerm : inherits from
class MktConnectivityNode {

}

NodeConstraintTerm --> "1" MktConnectivityNode : MktConnectivityNode
```

To be used only to constrain a quantity that cannot be associated with a terminal. For example, a registered generating unit that is not electrically connected to the network.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| MktConnectivityNode [1] | [MktConnectivityNode](#CIM17v40-MktConnectivityNode) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| factor [0..1] | [String](#CIM17v40-String) | see [ConstraintTerm](#CIM17v40-ConstraintTerm) | |
| function [0..1] | [String](#CIM17v40-String) | see [ConstraintTerm](#CIM17v40-ConstraintTerm) | |
| SecurityConstraintSum [1] | [SecurityConstraintSum](#CIM17v40-SecurityConstraintSum) | see [ConstraintTerm](CIM17v40-ConstraintTerm) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-NonConformLoad}
### NonConformLoad

Inheritance path = [EnergyConsumer](#CIM17v40-EnergyConsumer) => [EnergyConnection](#CIM17v40-EnergyConnection) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class NonConformLoad {

}

class EnergyConsumer {

}

EnergyConsumer <|-- NonConformLoad : inherits from
class NonConformLoadGroup {

}

NonConformLoad --> "0..1" NonConformLoadGroup : LoadGroup
```

NonConformLoad represents loads that do not follow a daily load change pattern and whose changes are not correlated with the daily load change pattern.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| LoadGroup [0..1] | [NonConformLoadGroup](#CIM17v40-NonConformLoadGroup) | Group of this ConformLoad. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| customerCount [0..1] | [Integer](#CIM17v40-Integer) | see [EnergyConsumer](#CIM17v40-EnergyConsumer) | |
| grounded [0..1] | [Boolean](#CIM17v40-Boolean) | see [EnergyConsumer](#CIM17v40-EnergyConsumer) | |
| p [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| pfixed [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| pfixedPct [0..1] | [PerCent](#CIM17v40-PerCent) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| phaseConnection [0..1] | [PhaseShuntConnectionKind](#CIM17v40-PhaseShuntConnectionKind) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| q [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| qfixed [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| qfixedPct [0..1] | [PerCent](#CIM17v40-PerCent) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| EnergyConsumerAction [0..1] | [EnergyConsumerAction](#CIM17v40-EnergyConsumerAction) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| LoadDynamics [0..1] | [LoadDynamics](#CIM17v40-LoadDynamics) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| LoadResponse [0..1] | [LoadResponseCharacteristic](#CIM17v40-LoadResponseCharacteristic) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| `PowerCutZone [0..1]` (OfAggregate) | [PowerCutZone](#CIM17v40-PowerCutZone) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-NonConformLoadGroup}
### NonConformLoadGroup

Inheritance path = [LoadGroup](#CIM17v40-LoadGroup) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class NonConformLoadGroup {

}

class LoadGroup {

}

LoadGroup <|-- NonConformLoadGroup : inherits from
```

Loads that do not follow a daily and seasonal load variation pattern.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `SubLoadArea [1]` (OfAggregate) | [SubLoadArea](#CIM17v40-SubLoadArea) | see [LoadGroup](CIM17v40-LoadGroup) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-NonConformLoadSchedule}
### NonConformLoadSchedule

Inheritance path = [SeasonDayTypeSchedule](#CIM17v40-SeasonDayTypeSchedule) => [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) => [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class NonConformLoadSchedule {

}

class SeasonDayTypeSchedule {

}

SeasonDayTypeSchedule <|-- NonConformLoadSchedule : inherits from
class NonConformLoadGroup {

}

NonConformLoadSchedule --> "1" NonConformLoadGroup : NonConformLoadGroup
```

An active power (Y1-axis) and reactive power (Y2-axis) schedule (curves) versus time (X-axis) for non-conforming loads, e.g., large industrial load or power station service (where modelled).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `NonConformLoadGroup [1]` (OfAggregate) | [NonConformLoadGroup](#CIM17v40-NonConformLoadGroup) | The NonConformLoadGroup where the NonConformLoadSchedule belongs. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DayType [0..1] | [DayType](#CIM17v40-DayType) | see [SeasonDayTypeSchedule](CIM17v40-SeasonDayTypeSchedule) | |
| Season [0..1] | [Season](#CIM17v40-Season) | see [SeasonDayTypeSchedule](CIM17v40-SeasonDayTypeSchedule) | |
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | see [RegularIntervalSchedule](CIM17v40-RegularIntervalSchedule) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-NonStandardItem}
### NonStandardItem

Inheritance path = [WorkDocument](#CIM17v40-WorkDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class NonStandardItem {

+ amount : Money [0..1]
}

class WorkDocument {

}

WorkDocument <|-- NonStandardItem : inherits from
```

This document provides information for non-standard items like customer contributions (e.g., customer digs trench), vouchers (e.g., credit), and contractor bids.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| amount [0..1] | [Money](#CIM17v40-Money) | The projected cost for this item. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-NonlinearShuntCompensator}
### NonlinearShuntCompensator

Inheritance path = [ShuntCompensator](#CIM17v40-ShuntCompensator) => [RegulatingCondEq](#CIM17v40-RegulatingCondEq) => [EnergyConnection](#CIM17v40-EnergyConnection) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class NonlinearShuntCompensator {

}

class ShuntCompensator {

}

ShuntCompensator <|-- NonlinearShuntCompensator : inherits from
```

A non linear shunt compensator has bank or section admittance values that differ. The attributes g, b, g0 and b0 of the associated NonlinearShuntCompensatorPoint describe the total conductance and admittance of a NonlinearShuntCompensatorPoint at a section number specified by NonlinearShuntCompensatorPoint.sectionNumber.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aVRDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [ShuntCompensator](CIM17v40-ShuntCompensator) | |
| grounded [0..1] | [Boolean](#CIM17v40-Boolean) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| maximumSections [0..1] | [Integer](#CIM17v40-Integer) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| nomU [0..1] | [Voltage](#CIM17v40-Voltage) | see [ShuntCompensator](CIM17v40-ShuntCompensator) | |
| normalSections [0..1] | [Integer](#CIM17v40-Integer) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| phaseConnection [0..1] | [PhaseShuntConnectionKind](#CIM17v40-PhaseShuntConnectionKind) | see [ShuntCompensator](CIM17v40-ShuntCompensator) | |
| sections [0..1] | [Float](#CIM17v40-Float) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| `switchOnCount [0..1]` (deprecated) | [Integer](#CIM17v40-Integer) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| `switchOnDate [0..1]` (deprecated) | [DateTime](#CIM17v40-DateTime) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| voltageSensitivity [0..1] | [VoltagePerReactivePower](#CIM17v40-VoltagePerReactivePower) | see [ShuntCompensator](CIM17v40-ShuntCompensator) | |
| ShuntCompensatorAction [0..1] | [ShuntCompensatorAction](#CIM17v40-ShuntCompensatorAction) | see [ShuntCompensator](CIM17v40-ShuntCompensator) | |
| controlEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [RegulatingCondEq](#CIM17v40-RegulatingCondEq) | |
| RegulatingControl [0..1] | [RegulatingControl](#CIM17v40-RegulatingControl) | see [RegulatingCondEq](CIM17v40-RegulatingCondEq) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-NonlinearShuntCompensatorPhase}
### NonlinearShuntCompensatorPhase

Inheritance path = [ShuntCompensatorPhase](#CIM17v40-ShuntCompensatorPhase) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class NonlinearShuntCompensatorPhase {

}

class ShuntCompensatorPhase {

}

ShuntCompensatorPhase <|-- NonlinearShuntCompensatorPhase : inherits from
```

A per phase non linear shunt compensator has bank or section admittance values that differ. The attributes g and b of the associated NonlinearShuntCompensatorPhasePoint describe the total conductance and admittance of a NonlinearShuntCompensatorPhasePoint at a section number specified by NonlinearShuntCompensatorPhasePoint.sectionNumber.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maximumSections [0..1] | [Integer](#CIM17v40-Integer) | see [ShuntCompensatorPhase](#CIM17v40-ShuntCompensatorPhase) | |
| normalSections [0..1] | [Integer](#CIM17v40-Integer) | see [ShuntCompensatorPhase](#CIM17v40-ShuntCompensatorPhase) | |
| phase [0..1] | [SinglePhaseKind](#CIM17v40-SinglePhaseKind) | see [ShuntCompensatorPhase](CIM17v40-ShuntCompensatorPhase) | |
| sections [0..1] | [Float](#CIM17v40-Float) | see [ShuntCompensatorPhase](#CIM17v40-ShuntCompensatorPhase) | |
| ShuntCompensator [1] | [ShuntCompensator](#CIM17v40-ShuntCompensator) | see [ShuntCompensatorPhase](CIM17v40-ShuntCompensatorPhase) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-NonlinearShuntCompensatorPhasePoint}
### NonlinearShuntCompensatorPhasePoint


```mermaid
classDiagram
direction TB

class NonlinearShuntCompensatorPhasePoint {

+ b : Susceptance [0..1]
+ g : Conductance [0..1]
+ sectionNumber : Integer [0..1]
}

class NonlinearShuntCompensatorPhase {

}

NonlinearShuntCompensatorPhasePoint --> "1" NonlinearShuntCompensatorPhase : NonlinearShuntCompensatorPhase
```

A per phase non linear shunt compensator bank or section admittance value. The number of NonlinearShuntCompenstorPhasePoint instances associated with a NonlinearShuntCompensatorPhase shall be equal to ShuntCompensatorPhase.maximumSections. ShuntCompensator.sections shall only be set to one of the NonlinearShuntCompenstorPhasePoint.sectionNumber. There is no interpolation between NonlinearShuntCompenstorPhasePoint-s.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| b [0..1] | [Susceptance](#CIM17v40-Susceptance) | Positive sequence shunt (charging) susceptance per section. | |
| g [0..1] | [Conductance](#CIM17v40-Conductance) | Positive sequence shunt (charging) conductance per section. | |
| sectionNumber [0..1] | [Integer](#CIM17v40-Integer) | The number of the section. | |
| `NonlinearShuntCompensatorPhase [1]` (OfAggregate) | [NonlinearShuntCompensatorPhase](#CIM17v40-NonlinearShuntCompensatorPhase) | Non-linear shunt compensator phase owning this point. | |

{#CIM17v40-NonlinearShuntCompensatorPoint}
### NonlinearShuntCompensatorPoint


```mermaid
classDiagram
direction TB

class NonlinearShuntCompensatorPoint {

+ b : Susceptance [0..1]
+ b0 : Susceptance [0..1]
+ g : Conductance [0..1]
+ g0 : Conductance [0..1]
+ sectionNumber : Integer [0..1]
}

class NonlinearShuntCompensator {

}

NonlinearShuntCompensatorPoint --> "1" NonlinearShuntCompensator : NonlinearShuntCompensator
```

A non linear shunt compensator bank or section admittance value. The number of NonlinearShuntCompenstorPoint instances associated with a NonlinearShuntCompensator shall be equal to ShuntCompensator.maximumSections. ShuntCompensator.sections shall only be set to one of the NonlinearShuntCompenstorPoint.sectionNumber. There is no interpolation between NonlinearShuntCompenstorPoint-s.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| b [0..1] | [Susceptance](#CIM17v40-Susceptance) | Positive sequence shunt (charging) susceptance per section. | |
| b0 [0..1] | [Susceptance](#CIM17v40-Susceptance) | Zero sequence shunt (charging) susceptance per section. | |
| g [0..1] | [Conductance](#CIM17v40-Conductance) | Positive sequence shunt (charging) conductance per section. | |
| g0 [0..1] | [Conductance](#CIM17v40-Conductance) | Zero sequence shunt (charging) conductance per section. | |
| sectionNumber [0..1] | [Integer](#CIM17v40-Integer) | The number of the section. | |
| `NonlinearShuntCompensator [1]` (OfAggregate) | [NonlinearShuntCompensator](#CIM17v40-NonlinearShuntCompensator) | Non-linear shunt compensator owning this point. | |

{#CIM17v40-NotificationTimeCurve}
### NotificationTimeCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class NotificationTimeCurve {

}

class Curve {

}

Curve <|-- NotificationTimeCurve : inherits from
```

Notification time curve as a function of down time. Relationship between crew notification time (Y1-axis) and unit startup time (Y2-axis) vs. unit elapsed down time (X-axis).


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-NuclearGeneratingUnit}
### NuclearGeneratingUnit

Inheritance path = [GeneratingUnit](#CIM17v40-GeneratingUnit) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class NuclearGeneratingUnit {

}

class GeneratingUnit {

}

GeneratingUnit <|-- NuclearGeneratingUnit : inherits from
```

A nuclear generating unit.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| allocSpinResP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| autoCntrlMarginP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| baseP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlDeadband [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlPulseHigh [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlPulseLow [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlResponseRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| efficiency [0..1] | [PerCent](#CIM17v40-PerCent) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| genControlMode [0..1] | [GeneratorControlMode](#CIM17v40-GeneratorControlMode) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| genControlSource [0..1] | [GeneratorControlSource](#CIM17v40-GeneratorControlSource) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| governorMPL [0..1] | [PU](#CIM17v40-PU) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| governorSCD [0..1] | [PerCent](#CIM17v40-PerCent) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| highControlLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| initialP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| longPF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| lowControlLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| lowerRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| maxEconomicP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| maximumAllowableSpinningReserve [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| maxOperatingP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| minEconomicP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| minimumOffTime [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| minOperatingP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| modelDetail [0..1] | [Classification](#CIM17v40-Classification) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| nominalP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| normalPF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| penaltyFactor [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| raiseRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| ratedGrossMaxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| ratedGrossMinP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| ratedNetMaxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| shortPF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| startupCost [0..1] | [Money](#CIM17v40-Money) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| startupTime [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| tieLinePF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| totalEfficiency [0..1] | [PerCent](#CIM17v40-PerCent) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| variableCost [0..1] | [Money](#CIM17v40-Money) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| `GenUnitOpSchedule [0..1]` (AggregateOf) | [GenUnitOpSchedule](#CIM17v40-GenUnitOpSchedule) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ObjectCreation}
### ObjectCreation

Inheritance path = [ChangeSetMember](#CIM17v40-ChangeSetMember)

```mermaid
classDiagram
direction TB

class ObjectCreation {

}

class ChangeSetMember {

}

ChangeSetMember <|-- ObjectCreation : inherits from
```

An object is to be created in the context.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Changeset [0..1] | [ChangeSet](#CIM17v40-ChangeSet) | see [ChangeSetMember](CIM17v40-ChangeSetMember) | |
| PropertiesObject [0..1] | [IdentifiedObject](#CIM17v40-IdentifiedObject) | see [ChangeSetMember](CIM17v40-ChangeSetMember) | |
| TargetObject [1] | [IdentifiedObject](#CIM17v40-IdentifiedObject) | see [ChangeSetMember](CIM17v40-ChangeSetMember) | |

{#CIM17v40-ObjectDeletion}
### ObjectDeletion

Inheritance path = [ChangeSetMember](#CIM17v40-ChangeSetMember)

```mermaid
classDiagram
direction TB

class ObjectDeletion {

}

class ChangeSetMember {

}

ChangeSetMember <|-- ObjectDeletion : inherits from
```

An object is to be deleted in the context.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Changeset [0..1] | [ChangeSet](#CIM17v40-ChangeSet) | see [ChangeSetMember](CIM17v40-ChangeSetMember) | |
| PropertiesObject [0..1] | [IdentifiedObject](#CIM17v40-IdentifiedObject) | see [ChangeSetMember](CIM17v40-ChangeSetMember) | |
| TargetObject [1] | [IdentifiedObject](#CIM17v40-IdentifiedObject) | see [ChangeSetMember](CIM17v40-ChangeSetMember) | |

{#CIM17v40-ObjectModification}
### ObjectModification

Inheritance path = [ChangeSetMember](#CIM17v40-ChangeSetMember)

```mermaid
classDiagram
direction TB

class ObjectModification {

}

class ChangeSetMember {

}

ChangeSetMember <|-- ObjectModification : inherits from
class ObjectReverseModification {

}

ObjectModification --> "0..1" ObjectReverseModification : ObjectReverseModification
```

The object already exists and is to be modified.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ObjectReverseModification [0..1] | [ObjectReverseModification](#CIM17v40-ObjectReverseModification) | The data object holding preconditions of updates. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Changeset [0..1] | [ChangeSet](#CIM17v40-ChangeSet) | see [ChangeSetMember](CIM17v40-ChangeSetMember) | |
| PropertiesObject [0..1] | [IdentifiedObject](#CIM17v40-IdentifiedObject) | see [ChangeSetMember](CIM17v40-ChangeSetMember) | |
| TargetObject [1] | [IdentifiedObject](#CIM17v40-IdentifiedObject) | see [ChangeSetMember](CIM17v40-ChangeSetMember) | |

{#CIM17v40-ObjectReverseModification}
### ObjectReverseModification

Inheritance path = [ChangeSetMember](#CIM17v40-ChangeSetMember)

```mermaid
classDiagram
direction TB

class ObjectReverseModification {

}

class ChangeSetMember {

}

ChangeSetMember <|-- ObjectReverseModification : inherits from
class ObjectModification {

}

ObjectReverseModification --> "0..1" ObjectModification : ObjectModification
```

Used to specify precondition properties for a preconditioned update.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ObjectModification [0..1] | [ObjectModification](#CIM17v40-ObjectModification) | The associated data object representing the update. Normally the associaiton is specifed, but in the case of a proxy object where the association is removed, we might not reference any data object as it would only reference a proxy data object with no associations. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Changeset [0..1] | [ChangeSet](#CIM17v40-ChangeSet) | see [ChangeSetMember](CIM17v40-ChangeSetMember) | |
| PropertiesObject [0..1] | [IdentifiedObject](#CIM17v40-IdentifiedObject) | see [ChangeSetMember](CIM17v40-ChangeSetMember) | |
| TargetObject [1] | [IdentifiedObject](#CIM17v40-IdentifiedObject) | see [ChangeSetMember](CIM17v40-ChangeSetMember) | |

{#CIM17v40-Observation}
### Observation

Inheritance path = [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Observation {

}

class EnvironmentalInformation {

}

EnvironmentalInformation <|-- Observation : inherits from
```

Observed (actual non-forecast) values sets and/or phenomena characteristics.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| created [0..1] | [DateTime](#CIM17v40-DateTime) | see [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | |
| EnvironmentalDataProvider [0..1] | [EnvironmentalDataProvider](#CIM17v40-EnvironmentalDataProvider) | see [EnvironmentalInformation](CIM17v40-EnvironmentalInformation) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OilAnalysisFluidAnalog}
### OilAnalysisFluidAnalog

Inheritance path = [AssetAnalog](#CIM17v40-AssetAnalog) => [Analog](#CIM17v40-Analog) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OilAnalysisFluidAnalog {

+ kind : enum:OilAnalysisFluidAnalogKind [0..1]
}

class AssetAnalog {

}

AssetAnalog <|-- OilAnalysisFluidAnalog : inherits from
```

Asset oil analysis fluid test type of analog.

.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [OilAnalysisFluidAnalogKind](#CIM17v40-OilAnalysisFluidAnalogKind) | Kind of analog representing oil fluid test analysis result. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| detectionLimit [0..1] | [Float](#CIM17v40-Float) | see [AssetAnalog](#CIM17v40-AssetAnalog) | |
| precision [0..1] | [Float](#CIM17v40-Float) | see [AssetAnalog](#CIM17v40-AssetAnalog) | |
| reportingTemperature [0..1] | [Temperature](#CIM17v40-Temperature) | see [AssetAnalog](CIM17v40-AssetAnalog) | |
| TestStandard [0..1] | [TestStandard](#CIM17v40-TestStandard) | see [AssetAnalog](CIM17v40-AssetAnalog) | |
| maxValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| minValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| normalValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| positiveFlowIn [0..1] | [Boolean](#CIM17v40-Boolean) | see [Analog](#CIM17v40-Analog) | |
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OilAnalysisFluidDiscrete}
### OilAnalysisFluidDiscrete

Inheritance path = [AssetDiscrete](#CIM17v40-AssetDiscrete) => [Discrete](#CIM17v40-Discrete) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OilAnalysisFluidDiscrete {

+ kind : enum:OilAnalysisFluidDiscreteKind [0..1]
}

class AssetDiscrete {

}

AssetDiscrete <|-- OilAnalysisFluidDiscrete : inherits from
```

Asset oil analysis fluid type of discrete.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [OilAnalysisFluidDiscreteKind](#CIM17v40-OilAnalysisFluidDiscreteKind) | Kind of discrete representing oil fluid test analysis result. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| TestStandard [0..1] | [TestStandard](#CIM17v40-TestStandard) | see [AssetDiscrete](CIM17v40-AssetDiscrete) | |
| maxValue [0..1] | [Integer](#CIM17v40-Integer) | see [Discrete](#CIM17v40-Discrete) | |
| minValue [0..1] | [Integer](#CIM17v40-Integer) | see [Discrete](#CIM17v40-Discrete) | |
| normalValue [0..1] | [Integer](#CIM17v40-Integer) | see [Discrete](#CIM17v40-Discrete) | |
| ValueAliasSet [0..1] | [ValueAliasSet](#CIM17v40-ValueAliasSet) | see [Discrete](CIM17v40-Discrete) | |
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OilAnalysisGasAnalog}
### OilAnalysisGasAnalog

Inheritance path = [AssetAnalog](#CIM17v40-AssetAnalog) => [Analog](#CIM17v40-Analog) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OilAnalysisGasAnalog {

+ kind : enum:OilAnalysisGasAnalogKind [0..1]
}

class AssetAnalog {

}

AssetAnalog <|-- OilAnalysisGasAnalog : inherits from
```

Asset oil analysis gas type of analog.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [OilAnalysisGasAnalogKind](#CIM17v40-OilAnalysisGasAnalogKind) | Kind of analog representing oil dissolved gases analysis result. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| detectionLimit [0..1] | [Float](#CIM17v40-Float) | see [AssetAnalog](#CIM17v40-AssetAnalog) | |
| precision [0..1] | [Float](#CIM17v40-Float) | see [AssetAnalog](#CIM17v40-AssetAnalog) | |
| reportingTemperature [0..1] | [Temperature](#CIM17v40-Temperature) | see [AssetAnalog](CIM17v40-AssetAnalog) | |
| TestStandard [0..1] | [TestStandard](#CIM17v40-TestStandard) | see [AssetAnalog](CIM17v40-AssetAnalog) | |
| maxValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| minValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| normalValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| positiveFlowIn [0..1] | [Boolean](#CIM17v40-Boolean) | see [Analog](#CIM17v40-Analog) | |
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OilAnalysisMetalsAnalog}
### OilAnalysisMetalsAnalog

Inheritance path = [AssetAnalog](#CIM17v40-AssetAnalog) => [Analog](#CIM17v40-Analog) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OilAnalysisMetalsAnalog {

+ kind : enum:OilAnalysisMetalsAnalogKind [0..1]
}

class AssetAnalog {

}

AssetAnalog <|-- OilAnalysisMetalsAnalog : inherits from
```

Asset oil analysis metals type of analog.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [OilAnalysisMetalsAnalogKind](#CIM17v40-OilAnalysisMetalsAnalogKind) | Kind of analog representing oil metals elements analysis result. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| detectionLimit [0..1] | [Float](#CIM17v40-Float) | see [AssetAnalog](#CIM17v40-AssetAnalog) | |
| precision [0..1] | [Float](#CIM17v40-Float) | see [AssetAnalog](#CIM17v40-AssetAnalog) | |
| reportingTemperature [0..1] | [Temperature](#CIM17v40-Temperature) | see [AssetAnalog](CIM17v40-AssetAnalog) | |
| TestStandard [0..1] | [TestStandard](#CIM17v40-TestStandard) | see [AssetAnalog](CIM17v40-AssetAnalog) | |
| maxValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| minValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| normalValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| positiveFlowIn [0..1] | [Boolean](#CIM17v40-Boolean) | see [Analog](#CIM17v40-Analog) | |
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OilAnalysisMoistureAnalog}
### OilAnalysisMoistureAnalog

Inheritance path = [AssetAnalog](#CIM17v40-AssetAnalog) => [Analog](#CIM17v40-Analog) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OilAnalysisMoistureAnalog {

+ kind : enum:OilAnalysisMoistureAnalogKind [0..1]
}

class AssetAnalog {

}

AssetAnalog <|-- OilAnalysisMoistureAnalog : inherits from
```

Asset oil analysis moisture type of analog.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [OilAnalysisMoistureAnalogKind](#CIM17v40-OilAnalysisMoistureAnalogKind) | Kind of analog representing oil moisture analysis result. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| detectionLimit [0..1] | [Float](#CIM17v40-Float) | see [AssetAnalog](#CIM17v40-AssetAnalog) | |
| precision [0..1] | [Float](#CIM17v40-Float) | see [AssetAnalog](#CIM17v40-AssetAnalog) | |
| reportingTemperature [0..1] | [Temperature](#CIM17v40-Temperature) | see [AssetAnalog](CIM17v40-AssetAnalog) | |
| TestStandard [0..1] | [TestStandard](#CIM17v40-TestStandard) | see [AssetAnalog](CIM17v40-AssetAnalog) | |
| maxValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| minValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| normalValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| positiveFlowIn [0..1] | [Boolean](#CIM17v40-Boolean) | see [Analog](#CIM17v40-Analog) | |
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OilAnalysisPCBAnalog}
### OilAnalysisPCBAnalog

Inheritance path = [AssetAnalog](#CIM17v40-AssetAnalog) => [Analog](#CIM17v40-Analog) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OilAnalysisPCBAnalog {

+ kind : enum:OilAnalysisPCBAnalogKind [0..1]
}

class AssetAnalog {

}

AssetAnalog <|-- OilAnalysisPCBAnalog : inherits from
```

Asset oil analysis PCB type of analog.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [OilAnalysisPCBAnalogKind](#CIM17v40-OilAnalysisPCBAnalogKind) | Kind of analog representing oil PCB analysis result. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| detectionLimit [0..1] | [Float](#CIM17v40-Float) | see [AssetAnalog](#CIM17v40-AssetAnalog) | |
| precision [0..1] | [Float](#CIM17v40-Float) | see [AssetAnalog](#CIM17v40-AssetAnalog) | |
| reportingTemperature [0..1] | [Temperature](#CIM17v40-Temperature) | see [AssetAnalog](CIM17v40-AssetAnalog) | |
| TestStandard [0..1] | [TestStandard](#CIM17v40-TestStandard) | see [AssetAnalog](CIM17v40-AssetAnalog) | |
| maxValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| minValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| normalValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| positiveFlowIn [0..1] | [Boolean](#CIM17v40-Boolean) | see [Analog](#CIM17v40-Analog) | |
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OilAnalysisPCBDiscrete}
### OilAnalysisPCBDiscrete

Inheritance path = [AssetDiscrete](#CIM17v40-AssetDiscrete) => [Discrete](#CIM17v40-Discrete) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OilAnalysisPCBDiscrete {

+ kind : enum:OilAnalysisPCBDiscreteKind [0..1]
}

class AssetDiscrete {

}

AssetDiscrete <|-- OilAnalysisPCBDiscrete : inherits from
```

Asset oil analysis PCB type of discrete.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [OilAnalysisPCBDiscreteKind](#CIM17v40-OilAnalysisPCBDiscreteKind) | Kind of discrete representing oil PCB test analysis result. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| TestStandard [0..1] | [TestStandard](#CIM17v40-TestStandard) | see [AssetDiscrete](CIM17v40-AssetDiscrete) | |
| maxValue [0..1] | [Integer](#CIM17v40-Integer) | see [Discrete](#CIM17v40-Discrete) | |
| minValue [0..1] | [Integer](#CIM17v40-Integer) | see [Discrete](#CIM17v40-Discrete) | |
| normalValue [0..1] | [Integer](#CIM17v40-Integer) | see [Discrete](#CIM17v40-Discrete) | |
| ValueAliasSet [0..1] | [ValueAliasSet](#CIM17v40-ValueAliasSet) | see [Discrete](CIM17v40-Discrete) | |
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OilAnalysisPaperAnalog}
### OilAnalysisPaperAnalog

Inheritance path = [AssetAnalog](#CIM17v40-AssetAnalog) => [Analog](#CIM17v40-Analog) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OilAnalysisPaperAnalog {

+ kind : enum:OilAnalysisPaperAnalogKind [0..1]
}

class AssetAnalog {

}

AssetAnalog <|-- OilAnalysisPaperAnalog : inherits from
```

Asset oil inspection paper type of analog.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [OilAnalysisPaperAnalogKind](#CIM17v40-OilAnalysisPaperAnalogKind) | Kind of analog representing oil paper degradation analysis result. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| detectionLimit [0..1] | [Float](#CIM17v40-Float) | see [AssetAnalog](#CIM17v40-AssetAnalog) | |
| precision [0..1] | [Float](#CIM17v40-Float) | see [AssetAnalog](#CIM17v40-AssetAnalog) | |
| reportingTemperature [0..1] | [Temperature](#CIM17v40-Temperature) | see [AssetAnalog](CIM17v40-AssetAnalog) | |
| TestStandard [0..1] | [TestStandard](#CIM17v40-TestStandard) | see [AssetAnalog](CIM17v40-AssetAnalog) | |
| maxValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| minValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| normalValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| positiveFlowIn [0..1] | [Boolean](#CIM17v40-Boolean) | see [Analog](#CIM17v40-Analog) | |
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OilAnalysisParticleAnalog}
### OilAnalysisParticleAnalog

Inheritance path = [AssetAnalog](#CIM17v40-AssetAnalog) => [Analog](#CIM17v40-Analog) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OilAnalysisParticleAnalog {

+ kind : enum:OilAnalysisParticleAnalogKind [0..1]
}

class AssetAnalog {

}

AssetAnalog <|-- OilAnalysisParticleAnalog : inherits from
```

Asset oil analysis particle type of analog.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [OilAnalysisParticleAnalogKind](#CIM17v40-OilAnalysisParticleAnalogKind) | Kind of analog representing oil particulate analysis result. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| detectionLimit [0..1] | [Float](#CIM17v40-Float) | see [AssetAnalog](#CIM17v40-AssetAnalog) | |
| precision [0..1] | [Float](#CIM17v40-Float) | see [AssetAnalog](#CIM17v40-AssetAnalog) | |
| reportingTemperature [0..1] | [Temperature](#CIM17v40-Temperature) | see [AssetAnalog](CIM17v40-AssetAnalog) | |
| TestStandard [0..1] | [TestStandard](#CIM17v40-TestStandard) | see [AssetAnalog](CIM17v40-AssetAnalog) | |
| maxValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| minValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| normalValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| positiveFlowIn [0..1] | [Boolean](#CIM17v40-Boolean) | see [Analog](#CIM17v40-Analog) | |
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OilAnalysisParticleDiscrete}
### OilAnalysisParticleDiscrete

Inheritance path = [AssetDiscrete](#CIM17v40-AssetDiscrete) => [Discrete](#CIM17v40-Discrete) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OilAnalysisParticleDiscrete {

+ kind : enum:OilAnalysisParticleDiscreteKind [0..1]
}

class AssetDiscrete {

}

AssetDiscrete <|-- OilAnalysisParticleDiscrete : inherits from
```

Asset oil analysis particle type of discrete.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [OilAnalysisParticleDiscreteKind](#CIM17v40-OilAnalysisParticleDiscreteKind) | Kind of discrete representing oil particulate analysis result. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| TestStandard [0..1] | [TestStandard](#CIM17v40-TestStandard) | see [AssetDiscrete](CIM17v40-AssetDiscrete) | |
| maxValue [0..1] | [Integer](#CIM17v40-Integer) | see [Discrete](#CIM17v40-Discrete) | |
| minValue [0..1] | [Integer](#CIM17v40-Integer) | see [Discrete](#CIM17v40-Discrete) | |
| normalValue [0..1] | [Integer](#CIM17v40-Integer) | see [Discrete](#CIM17v40-Discrete) | |
| ValueAliasSet [0..1] | [ValueAliasSet](#CIM17v40-ValueAliasSet) | see [Discrete](CIM17v40-Discrete) | |
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OilPrice}
### OilPrice


```mermaid
classDiagram
direction TB

class OilPrice {

+ oilPriceIndex : Float [0..1]
}

class FuelRegion {

}

OilPrice --> "1" FuelRegion : FuelRegion
```

Price of oil in monetary units.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| oilPriceIndex [0..1] | [Float](#CIM17v40-Float) | The average oil price at a defined fuel region. | |
| FuelRegion [1] | [FuelRegion](#CIM17v40-FuelRegion) | | |

{#CIM17v40-OilSpecimen}
### OilSpecimen

Inheritance path = [Specimen](#CIM17v40-Specimen) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OilSpecimen {

+ oilSampleTakenFrom : enum:OilSampleLocation [0..1]
+ oilSampleTemperature : Temperature [0..1]
+ oilTemperatureSource : enum:OilTemperatureSource [0..1]
+ sampleContainer : enum:SampleContainerType [0..1]
}

class Specimen {

}

Specimen <|-- OilSpecimen : inherits from
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| oilSampleTakenFrom [0..1] | [OilSampleLocation](#CIM17v40-OilSampleLocation) | Location from which oil sample taken. | |
| oilSampleTemperature [0..1] | [Temperature](#CIM17v40-Temperature) | Oil sample temperature. | |
| oilTemperatureSource [0..1] | [OilTemperatureSource](#CIM17v40-OilTemperatureSource) | Source of oil temperature. | |
| sampleContainer [0..1] | [SampleContainerType](#CIM17v40-SampleContainerType) | Type of sample container. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ambientTemperatureAtSampling [0..1] | [Temperature](#CIM17v40-Temperature) | see [Specimen](CIM17v40-Specimen) | |
| humidityAtSampling [0..1] | [PerCent](#CIM17v40-PerCent) | see [Specimen](CIM17v40-Specimen) | |
| specimenID [0..1] | [String](#CIM17v40-String) | see [Specimen](#CIM17v40-Specimen) | |
| specimenSampleDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Specimen](#CIM17v40-Specimen) | |
| specimenToLabDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Specimen](#CIM17v40-Specimen) | |
| AssetTestSampleTaker [0..1] | [AssetTestSampleTaker](#CIM17v40-AssetTestSampleTaker) | see [Specimen](CIM17v40-Specimen) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OldCrew}
### (informative) OldCrew

Inheritance path = [Crew](#CIM17v40-Crew) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OldCrew {

+ type : String [0..1]
}

class Crew {

}

Crew <|-- OldCrew : inherits from
class Route {

}

OldCrew --> "0..1" Route : Route
```

A crew is a group of people with specific skills, tools, and vehicles.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| type [0..1] | [String](#CIM17v40-String) | Classification by utility's work management standards and practices. | |
| `Route [0..1]` (informative) | [Route](#CIM17v40-Route) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CrewType [0..1] | [CrewType](#CIM17v40-CrewType) | see [Crew](CIM17v40-Crew) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Crew](CIM17v40-Crew) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Crew](CIM17v40-Crew) | |
| SwitchingAction [1] | [SwitchingAction](#CIM17v40-SwitchingAction) | see [Crew](CIM17v40-Crew) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OldPerson}
### (informative) OldPerson

Inheritance path = [Person](#CIM17v40-Person) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OldPerson {

+ type : String [0..1]
+ status : Status [0..1]
}

class Person {

}

Person <|-- OldPerson : inherits from
class Customer {

}

OldPerson --> "0..1" Customer : CustomerData
class ErpCompetency {

}

OldPerson --> "0..1" ErpCompetency : ErpCompetency
class ErpPersonnel {

}

OldPerson --> "0..1" ErpPersonnel : ErpPersonnel
```

General purpose information for name and other information to contact people.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| type [0..1] | [String](#CIM17v40-String) | Utility-specific classification for this person, according to the utility's corporate standards and practices. Examples include employee, contractor, agent, not affiliated, etc.Note that this field is not used to indicate whether this person is a customer of the utility. Often an employee or contractor is also a customer. Customer information is gained with relationship to Organisation and CustomerData. In similar fashion, this field does not indicate the various roles this person may fill as part of utility operations. | |
| `CustomerData [0..1]` (informative) | [Customer](#CIM17v40-Customer) | | |
| `ErpCompetency [0..1]` (informative) | [ErpCompetency](#CIM17v40-ErpCompetency) | | |
| `ErpPersonnel [0..1]` (informative) | [ErpPersonnel](#CIM17v40-ErpPersonnel) | | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| firstName [0..1] | [String](#CIM17v40-String) | see [Person](#CIM17v40-Person) | |
| lastName [0..1] | [String](#CIM17v40-String) | see [Person](#CIM17v40-Person) | |
| mName [0..1] | [String](#CIM17v40-String) | see [Person](#CIM17v40-Person) | |
| prefix [0..1] | [String](#CIM17v40-String) | see [Person](#CIM17v40-Person) | |
| specialNeed [0..1] | [String](#CIM17v40-String) | see [Person](#CIM17v40-Person) | |
| suffix [0..1] | [String](#CIM17v40-String) | see [Person](#CIM17v40-Person) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Person](CIM17v40-Person) | |
| landlinePhone [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Person](CIM17v40-Person) | |
| mobilePhone [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Person](CIM17v40-Person) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OldSwitchInfo}
### OldSwitchInfo

Inheritance path = [SwitchInfo](#CIM17v40-SwitchInfo) => [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OldSwitchInfo {

+ dielectricStrength : Voltage [0..1]
+ loadBreak : Boolean [0..1]
+ makingCapacity : CurrentFlow [0..1]
+ minimumCurrent : CurrentFlow [0..1]
+ poleCount : Integer [0..1]
+ remote : Boolean [0..1]
+ withstandCurrent : CurrentFlow [0..1]
}

class SwitchInfo {

}

SwitchInfo <|-- OldSwitchInfo : inherits from
```

Properties of switch assets.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dielectricStrength [0..1] | [Voltage](#CIM17v40-Voltage) | The maximum rms voltage that may be applied across an open contact without breaking down the dielectric properties of the switch in the open position. | |
| loadBreak [0..1] | [Boolean](#CIM17v40-Boolean) | True if switch has load breaking capabiity. Unless specified false, this is always assumed to be true for breakers and reclosers. | |
| makingCapacity [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | The highest value of current the switch can make at the rated voltage under specified operating conditions without suffering significant deterioration of its performance. | |
| minimumCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | The lowest value of current that the switch can make, carry and break in uninterrupted duty at the rated voltage under specified operating conditions without suffering significant deterioration of its performance. | |
| poleCount [0..1] | [Integer](#CIM17v40-Integer) | Number of poles (i.e. of current carrying conductors that are switched). | |
| remote [0..1] | [Boolean](#CIM17v40-Boolean) | True if device is capable of being operated by remote control. | |
| withstandCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | The highest value of current the switch can carry in the closed position at the rated voltage under specified operating conditions without suffering significant deterioration of its performance. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| breakingCapacity [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| gasWeightPerTank [0..1] | [Mass](#CIM17v40-Mass) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| isSinglePhase [0..1] | [Boolean](#CIM17v40-Boolean) | see [SwitchInfo](#CIM17v40-SwitchInfo) | |
| isUnganged [0..1] | [Boolean](#CIM17v40-Boolean) | see [SwitchInfo](#CIM17v40-SwitchInfo) | |
| lowPressureAlarm [0..1] | [Pressure](#CIM17v40-Pressure) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| lowPressureLockOut [0..1] | [Pressure](#CIM17v40-Pressure) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| oilVolumePerTank [0..1] | [Volume](#CIM17v40-Volume) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| ratedFrequency [0..1] | [Frequency](#CIM17v40-Frequency) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| ratedImpulseWithstandVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| ratedInterruptingTime [0..1] | [Seconds](#CIM17v40-Seconds) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| ratedVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OldTransformerEndInfo}
### OldTransformerEndInfo

Inheritance path = [TransformerEndInfo](#CIM17v40-TransformerEndInfo) => [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OldTransformerEndInfo {

+ dayOverLoadRating : ApparentPower [0..1]
+ hourOverLoadRating : ApparentPower [0..1]
+ solidInsulationWeight : Mass [0..1]
+ windingInsulationKind : enum:WindingInsulationKind [0..1]
}

class TransformerEndInfo {

}

TransformerEndInfo <|-- OldTransformerEndInfo : inherits from
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dayOverLoadRating [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | Overload rating for 24 hours. | |
| hourOverLoadRating [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | Overload rating for 1 hour. | |
| solidInsulationWeight [0..1] | [Mass](#CIM17v40-Mass) | Weight of solid insultation in transformer. | |
| windingInsulationKind [0..1] | [WindingInsulationKind](#CIM17v40-WindingInsulationKind) | Type of insultation used for transformer windings. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| connectionKind [0..1] | [WindingConnection](#CIM17v40-WindingConnection) | see [TransformerEndInfo](CIM17v40-TransformerEndInfo) | |
| emergencyS [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | see [TransformerEndInfo](CIM17v40-TransformerEndInfo) | |
| endNumber [0..1] | [Integer](#CIM17v40-Integer) | see [TransformerEndInfo](#CIM17v40-TransformerEndInfo) | |
| insulationU [0..1] | [Voltage](#CIM17v40-Voltage) | see [TransformerEndInfo](CIM17v40-TransformerEndInfo) | |
| phaseAngleClock [0..1] | [Integer](#CIM17v40-Integer) | see [TransformerEndInfo](#CIM17v40-TransformerEndInfo) | |
| r [0..1] | [Resistance](#CIM17v40-Resistance) | see [TransformerEndInfo](CIM17v40-TransformerEndInfo) | |
| ratedS [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | see [TransformerEndInfo](CIM17v40-TransformerEndInfo) | |
| ratedU [0..1] | [Voltage](#CIM17v40-Voltage) | see [TransformerEndInfo](CIM17v40-TransformerEndInfo) | |
| shortTermS [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | see [TransformerEndInfo](CIM17v40-TransformerEndInfo) | |
| CoreAdmittance [0..1] | [TransformerCoreAdmittance](#CIM17v40-TransformerCoreAdmittance) | see [TransformerEndInfo](CIM17v40-TransformerEndInfo) | |
| TransformerStarImpedance [0..1] | [TransformerStarImpedance](#CIM17v40-TransformerStarImpedance) | see [TransformerEndInfo](CIM17v40-TransformerEndInfo) | |
| TransformerTankInfo [1] | [TransformerTankInfo](#CIM17v40-TransformerTankInfo) | see [TransformerEndInfo](CIM17v40-TransformerEndInfo) | |
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OldTransformerTankInfo}
### OldTransformerTankInfo

Inheritance path = [TransformerTankInfo](#CIM17v40-TransformerTankInfo) => [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OldTransformerTankInfo {

+ constructionKind : enum:TransformerConstructionKind [0..1]
+ coreCoilsWeight : Mass [0..1]
+ coreKind : enum:TransformerCoreKind [0..1]
+ function : enum:TransformerFunctionKind [0..1]
+ neutralBIL : Voltage [0..1]
+ oilPreservationKind : enum:OilPreservationKind [0..1]
}

class TransformerTankInfo {

}

TransformerTankInfo <|-- OldTransformerTankInfo : inherits from
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| constructionKind [0..1] | [TransformerConstructionKind](#CIM17v40-TransformerConstructionKind) | Kind of construction for this transformer. | |
| coreCoilsWeight [0..1] | [Mass](#CIM17v40-Mass) | Weight of core and coils in transformer. | |
| coreKind [0..1] | [TransformerCoreKind](#CIM17v40-TransformerCoreKind) | Core kind of this transformer product. | |
| function [0..1] | [TransformerFunctionKind](#CIM17v40-TransformerFunctionKind) | Function of this transformer. | |
| neutralBIL [0..1] | [Voltage](#CIM17v40-Voltage) | Basic insulation level of neutral. | |
| oilPreservationKind [0..1] | [OilPreservationKind](#CIM17v40-OilPreservationKind) | Kind of oil preservation system. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| PowerTransformerInfo [1] | [PowerTransformerInfo](#CIM17v40-PowerTransformerInfo) | see [TransformerTankInfo](CIM17v40-TransformerTankInfo) | |
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OldWorkTask}
### (informative) OldWorkTask

Inheritance path = [WorkTask](#CIM17v40-WorkTask) => [BaseWork](#CIM17v40-BaseWork) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OldWorkTask {

}

class WorkTask {

}

WorkTask <|-- OldWorkTask : inherits from
class Design {

}

OldWorkTask --> "0..1" Design : Design
class OverheadCost {

}

OldWorkTask --> "0..1" OverheadCost : OverheadCost
class WorkFlowStep {

}

OldWorkTask --> "0..1" WorkFlowStep : WorkFlowStep
```

A set of tasks is required to implement a design.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Design [0..1]` (informative) | [Design](#CIM17v40-Design) | | |
| `OverheadCost [0..1]` (informative) | [OverheadCost](#CIM17v40-OverheadCost) | | |
| `WorkFlowStep [0..1]` (informative) | [WorkFlowStep](#CIM17v40-WorkFlowStep) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| completedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [WorkTask](#CIM17v40-WorkTask) | |
| contractorCost [0..1] | [Money](#CIM17v40-Money) | see [WorkTask](CIM17v40-WorkTask) | |
| crewETA [0..1] | [DateTime](#CIM17v40-DateTime) | see [WorkTask](#CIM17v40-WorkTask) | |
| estimatedCompletionTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [WorkTask](#CIM17v40-WorkTask) | |
| instruction [0..1] | [String](#CIM17v40-String) | see [WorkTask](#CIM17v40-WorkTask) | |
| laborCost [0..1] | [Money](#CIM17v40-Money) | see [WorkTask](CIM17v40-WorkTask) | |
| laborHours [0..1] | [Hours](#CIM17v40-Hours) | see [WorkTask](CIM17v40-WorkTask) | |
| materiallCost [0..1] | [Money](#CIM17v40-Money) | see [WorkTask](CIM17v40-WorkTask) | |
| schedOverride [0..1] | [String](#CIM17v40-String) | see [WorkTask](#CIM17v40-WorkTask) | |
| startedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [WorkTask](#CIM17v40-WorkTask) | |
| taskKind [0..1] | [WorkTaskKind](#CIM17v40-WorkTaskKind) | see [WorkTask](CIM17v40-WorkTask) | |
| toolCost [0..1] | [Money](#CIM17v40-Money) | see [WorkTask](CIM17v40-WorkTask) | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | see [WorkTask](CIM17v40-WorkTask) | |
| TroubleOrder [0..1] | [TroubleOrder](#CIM17v40-TroubleOrder) | see [WorkTask](CIM17v40-WorkTask) | |
| Work [1] | [Work](#CIM17v40-Work) | see [WorkTask](CIM17v40-WorkTask) | |
| kind [0..1] | [ServiceRequestKind](#CIM17v40-ServiceRequestKind) | see [BaseWork](CIM17v40-BaseWork) | |
| statusKind [0..1] | [WorkStatusKind](#CIM17v40-WorkStatusKind) | see [BaseWork](CIM17v40-BaseWork) | |
| priority [0..1] | [Priority](#CIM17v40-Priority) | see [BaseWork](CIM17v40-BaseWork) | |
| WorkLocation [0..1] | [WorkLocation](#CIM17v40-WorkLocation) | see [BaseWork](CIM17v40-BaseWork) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OneCallRequest}
### (informative) OneCallRequest

Inheritance path = [WorkDocument](#CIM17v40-WorkDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OneCallRequest {

+ explosivesUsed : Boolean [0..1]
+ markedIndicator : Boolean [0..1]
+ markingInstruction : String [0..1]
}

class WorkDocument {

}

WorkDocument <|-- OneCallRequest : inherits from
```

A request for other utilities to mark their underground facilities prior to commencement of construction and/or maintenance.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| explosivesUsed [0..1] | [Boolean](#CIM17v40-Boolean) | True if explosives have been or are planned to be used. | |
| markedIndicator [0..1] | [Boolean](#CIM17v40-Boolean) | True if work location has been marked, for example for a dig area. | |
| markingInstruction [0..1] | [String](#CIM17v40-String) | Instructions for marking a dig area, if applicable. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OpenAccessProduct}
### OpenAccessProduct

Inheritance path = [Agreement](#CIM17v40-Agreement) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OpenAccessProduct {

}

class Agreement {

}

Agreement <|-- OpenAccessProduct : inherits from
```

Contracts for services offered commercially.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| signDate [0..1] | [Date](#CIM17v40-Date) | see [Agreement](#CIM17v40-Agreement) | |
| validityInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [Agreement](CIM17v40-Agreement) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OpenCircuitTest}
### OpenCircuitTest

Inheritance path = [TransformerTest](#CIM17v40-TransformerTest) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OpenCircuitTest {

+ energisedEndStep : Integer [0..1]
+ energisedEndVoltage : Voltage [0..1]
+ openEndStep : Integer [0..1]
+ openEndVoltage : Voltage [0..1]
+ phaseShift : AngleDegrees [0..1]
}

class TransformerTest {

}

TransformerTest <|-- OpenCircuitTest : inherits from
class TransformerEndInfo {

}

OpenCircuitTest --> "1" TransformerEndInfo : EnergisedEnd
class TransformerEndInfo {

}

OpenCircuitTest --> "1" TransformerEndInfo : OpenEnd
```

Open-circuit test results verify winding turn ratios and phase shifts. They include induced voltage and phase shift measurements on open-circuit windings, with voltage applied to the energised end. For three-phase windings, the excitation can be a positive sequence (the default) or a zero sequence.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| energisedEndStep [0..1] | [Integer](#CIM17v40-Integer) | Tap step number for the energised end of the test pair. | |
| energisedEndVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Voltage applied to the winding (end) during test. | |
| openEndStep [0..1] | [Integer](#CIM17v40-Integer) | Tap step number for the open end of the test pair. | |
| openEndVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Voltage measured at the open-circuited end, with the energised end set to rated voltage and all other ends open. | |
| phaseShift [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Phase shift measured at the open end with the energised end set to rated voltage and all other ends open. | |
| EnergisedEnd [1] | [TransformerEndInfo](#CIM17v40-TransformerEndInfo) | Transformer end that current is applied to in this open-circuit test. | |
| OpenEnd [1] | [TransformerEndInfo](#CIM17v40-TransformerEndInfo) | Transformer end measured for induced voltage and angle in this open-circuit test. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| basePower [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | see [TransformerTest](CIM17v40-TransformerTest) | |
| temperature [0..1] | [Temperature](#CIM17v40-Temperature) | see [TransformerTest](CIM17v40-TransformerTest) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OpenTieSchedule}
### OpenTieSchedule

Inheritance path = [BidHourlySchedule](#CIM17v40-BidHourlySchedule) => [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) => [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OpenTieSchedule {

+ value : Boolean [0..1]
}

class BidHourlySchedule {

}

BidHourlySchedule <|-- OpenTieSchedule : inherits from
```

Result of bid validation against conditions that may exist on an interchange that becomes disconnected or is heavily discounted with respect the MW flow.

This schedule is assocated with the hourly parameters in a resource bid.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| value [0..1] | [Boolean](#CIM17v40-Boolean) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Bid [1] | [Bid](#CIM17v40-Bid) | see [BidHourlySchedule](CIM17v40-BidHourlySchedule) | |
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | see [RegularIntervalSchedule](CIM17v40-RegularIntervalSchedule) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OperatingMechanism}
### OperatingMechanism

Inheritance path = [Asset](#CIM17v40-Asset) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OperatingMechanism {

}

class Asset {

}

Asset <|-- OperatingMechanism : inherits from
```

Breaker mechanism.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | see [Asset](#CIM17v40-Asset) | |
| initialCondition [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | see [Asset](CIM17v40-Asset) | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | see [Asset](CIM17v40-Asset) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [Asset](CIM17v40-Asset) | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | see [Asset](CIM17v40-Asset) | |
| lotNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| position [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | see [Asset](CIM17v40-Asset) | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | see [Asset](CIM17v40-Asset) | |
| serialNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| type [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| utcNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | see [Asset](CIM17v40-Asset) | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | see [Asset](CIM17v40-Asset) | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | see [Asset](CIM17v40-Asset) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [Asset](CIM17v40-Asset) | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | see [Asset](CIM17v40-Asset) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Asset](CIM17v40-Asset) | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | see [Asset](CIM17v40-Asset) | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | see [Asset](CIM17v40-Asset) | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | see [Asset](CIM17v40-Asset) | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | see [Asset](CIM17v40-Asset) | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | see [Asset](CIM17v40-Asset) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Asset](CIM17v40-Asset) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [Asset](CIM17v40-Asset) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [Asset](CIM17v40-Asset) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Asset](CIM17v40-Asset) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OperatingMechanismInfo}
### OperatingMechanismInfo

Inheritance path = [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OperatingMechanismInfo {

+ closeAmps : CurrentFlow [0..1]
+ closeVoltage : Voltage [0..1]
+ mechanismKind : enum:OperatingMechanismKind [0..1]
+ motorRunCurrent : CurrentFlow [0..1]
+ motorStartCurrent : CurrentFlow [0..1]
+ motorVoltage : Voltage [0..1]
+ tripAmps : CurrentFlow [0..1]
+ tripVoltage : Voltage [0..1]
}

class AssetInfo {

}

AssetInfo <|-- OperatingMechanismInfo : inherits from
```

Breaker operating mechanism datasheet information.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| closeAmps [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Close current (nominal). | |
| closeVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Close voltage in volts DC. | |
| mechanismKind [0..1] | [OperatingMechanismKind](#CIM17v40-OperatingMechanismKind) | Kind of breaker operating mechanism. | |
| motorRunCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Rated motor run current in amps. | |
| motorStartCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Rated motor start current in amps. | |
| motorVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Nominal motor voltage in volts DC. | |
| tripAmps [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Trip current (nominal). | |
| tripVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Trip voltage in volts DC. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OperatingParticipant}
### OperatingParticipant

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OperatingParticipant {

}

class IdentifiedObject {

}

IdentifiedObject <|-- OperatingParticipant : inherits from
```

An operator of multiple power system resource objects. Note multple operating participants may operate the same power system resource object. This can be used for modeling jointly owned units where each owner operates as a contractual share.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OperatingShare}
### OperatingShare


```mermaid
classDiagram
direction TB

class OperatingShare {

+ percentage : PerCent [0..1]
}

class OperatingParticipant {

}

OperatingShare --> "1" OperatingParticipant : OperatingParticipant
class PowerSystemResource {

}

OperatingShare --> "1" PowerSystemResource : PowerSystemResource
```

Specifies the operations contract relationship between a power system resource and a contract participant.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| percentage [0..1] | [PerCent](#CIM17v40-PerCent) | Percentage operational ownership between the pair (power system resource and operating participant) associated with this share. The total percentage ownership for a power system resource should add to 100%. | |
| OperatingParticipant [1] | [OperatingParticipant](#CIM17v40-OperatingParticipant) | The operating participant having this share with the associated power system resource. | |
| PowerSystemResource [1] | [PowerSystemResource](#CIM17v40-PowerSystemResource) | The power system resource to which the share applies. | |

{#CIM17v40-Operation}
### Operation


```mermaid
classDiagram
direction TB

class Operation {

}

```


{#CIM17v40-OperationPersonRole}
### OperationPersonRole

Inheritance path = [PersonRole](#CIM17v40-PersonRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OperationPersonRole {

}

class PersonRole {

}

PersonRole <|-- OperationPersonRole : inherits from
```

Person role in the context of utility operations.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Person [0..1] | [Person](#CIM17v40-Person) | see [PersonRole](CIM17v40-PersonRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OperationalLimit}
### (informative) OperationalLimit

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OperationalLimit {

}

class IdentifiedObject {

}

IdentifiedObject <|-- OperationalLimit : inherits from
class OperationalLimitSet {

}

OperationalLimit --> "1" OperationalLimitSet : OperationalLimitSet
class OperationalLimitType {

}

OperationalLimit --> "0..1" OperationalLimitType : OperationalLimitType
```

A value and normal value associated with a specific kind of limit.

The sub class value and normalValue attributes vary inversely to the associated OperationalLimitType.acceptableDuration (acceptableDuration for short).

If a particular piece of equipment has multiple operational limits of the same kind (apparent power, current, etc.), the limit with the greatest acceptableDuration shall have the smallest limit value and the limit with the smallest acceptableDuration shall have the largest limit value. Note: A large current can only be allowed to flow through a piece of equipment for a short duration without causing damage, but a lesser current can be allowed to flow for a longer duration.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `OperationalLimitSet [1]` (OfAggregate) | [OperationalLimitSet](#CIM17v40-OperationalLimitSet) | The limit set to which the limit values belong. | |
| OperationalLimitType [0..1] | [OperationalLimitType](#CIM17v40-OperationalLimitType) | The limit type associated with this limit. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OperationalLimitSet}
### OperationalLimitSet

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OperationalLimitSet {

}

class IdentifiedObject {

}

IdentifiedObject <|-- OperationalLimitSet : inherits from
class Equipment {

}

OperationalLimitSet --> "0..1" Equipment : Equipment
class ACDCTerminal {

}

OperationalLimitSet --> "0..1" ACDCTerminal : Terminal
```

A set of limits associated with equipment. Sets of limits might apply to a specific temperature, or season for example. A set of limits may contain different severities of limit levels that would apply to the same equipment. The set may contain limits of different types such as apparent power and current limits or high and low voltage limits that are logically applied together as a set.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Equipment [0..1] | [Equipment](#CIM17v40-Equipment) | The equipment to which the limit set applies. | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | The terminal where the operational limit set apply. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OperationalLimitType}
### (informative) OperationalLimitType

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OperationalLimitType {

+ acceptableDuration : Seconds [0..1]
+ direction : enum:OperationalLimitDirectionKind [0..1]
+ isInfiniteDuration : Boolean [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- OperationalLimitType : inherits from
class OperatonalLimitTypeScaling {

}

OperationalLimitType --> "0..1" OperatonalLimitTypeScaling : TargetOperationalLimitmTypeScaling
```

The operational meaning of a category of limits.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| acceptableDuration [0..1] | [Seconds](#CIM17v40-Seconds) | The nominal acceptable duration of the limit. Limits are commonly expressed in terms of the time limit for which the limit is normally acceptable. The actual acceptable duration of a specific limit may depend on other local factors such as temperature or wind speed. The attribute has meaning only if the flag isInfiniteDuration is set to false, hence it shall not be exchanged when isInfiniteDuration is set to true. | |
| direction [0..1] | [OperationalLimitDirectionKind](#CIM17v40-OperationalLimitDirectionKind) | The direction of the limit. | |
| isInfiniteDuration [0..1] | [Boolean](#CIM17v40-Boolean) | Defines if the operational limit type has infinite duration. If true, the limit has infinite duration. If false, the limit has definite duration which is defined by the attribute acceptableDuration. | |
| `TargetOperationalLimitmTypeScaling [0..1]` (informative) | [OperatonalLimitTypeScaling](#CIM17v40-OperatonalLimitTypeScaling) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OperationalRestriction}
### OperationalRestriction

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OperationalRestriction {

+ activePeriod : DateTimeInterval [0..1]
+ restrictedValue : FloatQuantity [0..1]
}

class Document {

}

Document <|-- OperationalRestriction : inherits from
class ProductAssetModel {

}

OperationalRestriction --> "0..1" ProductAssetModel : ProductAssetModel
```

A document that can be associated with equipment to describe any sort of restrictions compared with the original manufacturer's specification or with the usual operational practice e.g. temporary maximum loadings, maximum switching current, do not operate if bus couplers are open, etc.

In the UK, for example, if a breaker or switch ever mal-operates, this is reported centrally and utilities use their asset systems to identify all the installed devices of the same manufacturer's type. They then apply operational restrictions in the operational systems to warn operators of potential problems. After appropriate inspection and maintenance, the operational restrictions may be removed.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| activePeriod [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Interval during which this restriction is applied. | |
| `ProductAssetModel [0..1]` (informative) | [ProductAssetModel](#CIM17v40-ProductAssetModel) | Asset model to which this restriction applies. | |
| restrictedValue [0..1] | [FloatQuantity](#CIM17v40-FloatQuantity) | Restricted (new) value; includes unit of measure and potentially multiplier. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OperationalTag}
### OperationalTag

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OperationalTag {

}

class Document {

}

Document <|-- OperationalTag : inherits from
class Asset {

}

OperationalTag --> "0..1" Asset : Asset
class PowerSystemResource {

}

OperationalTag --> "0..1" PowerSystemResource : PowerSystemResource
class TagAction {

}

OperationalTag --> "0..1" TagAction : TagAction
```

Operational tag placed on a power system resource or asset in the context of switching plan execution or other work in the field.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Asset [0..1] | [Asset](#CIM17v40-Asset) | Asset on which this tag has been placed. | |
| PowerSystemResource [0..1] | [PowerSystemResource](#CIM17v40-PowerSystemResource) | Power system resource on which this tag has been placed. | |
| TagAction [0..1] | [TagAction](#CIM17v40-TagAction) | Tag action associated with this tag. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OperationalUpdatedRating}
### OperationalUpdatedRating

Inheritance path = [OperationalRestriction](#CIM17v40-OperationalRestriction) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OperationalUpdatedRating {

+ changeType : String [0..1]
}

class OperationalRestriction {

}

OperationalRestriction <|-- OperationalUpdatedRating : inherits from
class PlannedOutage {

}

OperationalUpdatedRating --> "1" PlannedOutage : PlannedOutage
```

Lowered capability because of deterioration or inadequacy (sometimes referred to as derating or partial outage) or other kind of operational rating change.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| changeType [0..1] | [String](#CIM17v40-String) | Type of operational updated rating, e.g. a derate, a rerate or a return to normal. | |
| PlannedOutage [1] | [PlannedOutage](#CIM17v40-PlannedOutage) | Planned equipment outage with this updated rating. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| activePeriod [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [OperationalRestriction](CIM17v40-OperationalRestriction) | |
| `ProductAssetModel [0..1]` (informative) | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [OperationalRestriction](CIM17v40-OperationalRestriction) | |
| restrictedValue [0..1] | [FloatQuantity](#CIM17v40-FloatQuantity) | see [OperationalRestriction](CIM17v40-OperationalRestriction) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OperationsSafetySupervisor}
### OperationsSafetySupervisor

Inheritance path = [Operator](#CIM17v40-Operator) => [OperationPersonRole](#CIM17v40-OperationPersonRole) => [PersonRole](#CIM17v40-PersonRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OperationsSafetySupervisor {

}

class Operator {

}

Operator <|-- OperationsSafetySupervisor : inherits from
```

Operator with responsibility that the work in high voltage installation is executed in a safe manner and according to safety regulation.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Person [0..1] | [Person](#CIM17v40-Person) | see [PersonRole](CIM17v40-PersonRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OperatonalLimitTypeScaling}
### (informative) OperatonalLimitTypeScaling


```mermaid
classDiagram
direction TB

class OperatonalLimitTypeScaling {

+ scalingPercent : PerCent [0..1]
}

class OperationalLimitType {

}

OperatonalLimitTypeScaling --> "0..1" OperationalLimitType : SourceOperationalLimitType
class OperationalLimitType {

}

OperatonalLimitTypeScaling --> "1" OperationalLimitType : TargetOperationalLimit
```

One operational limit type scales values of another operational limit type when under the same operational limit set. This applies to any operational limit assigned to the target operational limit type and without other limit dependency models.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| scalingPercent [0..1] | [PerCent](#CIM17v40-PerCent) | The percentage scaling of the source limit to compute the target limit. Applys to operational limits within an operaitonal limit set when both source and target operational limit types exist. | |
| `SourceOperationalLimitType [0..1]` (informative) | [OperationalLimitType](#CIM17v40-OperationalLimitType) | | |
| `TargetOperationalLimit [1]` (informative) | [OperationalLimitType](#CIM17v40-OperationalLimitType) | | |

{#CIM17v40-Operator}
### Operator

Inheritance path = [OperationPersonRole](#CIM17v40-OperationPersonRole) => [PersonRole](#CIM17v40-PersonRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Operator {

}

class OperationPersonRole {

}

OperationPersonRole <|-- Operator : inherits from
```

Control room operator.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Person [0..1] | [Person](#CIM17v40-Person) | see [PersonRole](CIM17v40-PersonRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OrgOrgRole}
### OrgOrgRole

Inheritance path = [OrganisationRole](#CIM17v40-OrganisationRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OrgOrgRole {

+ clientID : String [0..1]
}

class OrganisationRole {

}

OrganisationRole <|-- OrgOrgRole : inherits from
```

Roles played between Organisations and other Organisations. This includes role ups for ogranisations, cost centers, profit centers, regulatory reporting, etc.

Note that the parent and child relationship is indicated by the name on each end of the association.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| clientID [0..1] | [String](#CIM17v40-String) | Identifiers of the organisation held by another organisation, such as a government agency (federal, state, province, city, county), financial institution (Dun and Bradstreet), etc. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Organisation [0..1] | [Organisation](#CIM17v40-Organisation) | see [OrganisationRole](CIM17v40-OrganisationRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OrgPnodeAllocation}
### OrgPnodeAllocation

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OrgPnodeAllocation {

+ maxMWAllocation : ActivePower [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- OrgPnodeAllocation : inherits from
class Pnode {

}

OrgPnodeAllocation --> "1" Pnode : Pnode
```

This class models the allocation between asset owners and pricing nodes.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maxMWAllocation [0..1] | [ActivePower](#CIM17v40-ActivePower) | Maximum MW for the Source/Sink for the Allocation | |
| Pnode [1] | [Pnode](#CIM17v40-Pnode) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OrgResOwnership}
### OrgResOwnership

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OrgResOwnership {

+ asscType : enum:ResourceAssnType [0..1]
+ masterSchedulingCoordinatorFlag : enum:YesNo [0..1]
+ ownershipPercent : PerCent [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- OrgResOwnership : inherits from
class RegisteredResource {

}

OrgResOwnership --> "1" RegisteredResource : RegisteredResource
```

This class model the ownership percent and type of ownership between resource and organisation.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| asscType [0..1] | [ResourceAssnType](#CIM17v40-ResourceAssnType) | association type for the association between Organisation and Resource: | |
| masterSchedulingCoordinatorFlag [0..1] | [YesNo](#CIM17v40-YesNo) | Flag to indicate that the SC representing the Resource is the Master SC. | |
| ownershipPercent [0..1] | [PerCent](#CIM17v40-PerCent) | ownership percentage for each resource | |
| RegisteredResource [1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Organisation}
### Organisation

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Organisation {

+ electronicAddress : ElectronicAddress [0..1]
+ phone1 : TelephoneNumber [0..1]
+ phone2 : TelephoneNumber [0..1]
+ postalAddress : StreetAddress [0..1]
+ streetAddress : StreetAddress [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Organisation : inherits from
class ParentOrganization {

}

Organisation --> "0..1" ParentOrganization : ParentOrganisation
```

Organisation that might have roles as utility, contractor, supplier, manufacturer, customer, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | Electronic address. | |
| ParentOrganisation [0..1] | [ParentOrganization](#CIM17v40-ParentOrganization) | Parent organisation of this organisation. | |
| phone1 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | Phone number. | |
| phone2 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | Additional phone number. | |
| postalAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | Postal address, potentially different than 'streetAddress' (e.g., another city). | |
| streetAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | Street address. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OrganisationRole}
### OrganisationRole

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OrganisationRole {

}

class IdentifiedObject {

}

IdentifiedObject <|-- OrganisationRole : inherits from
class Organisation {

}

OrganisationRole --> "0..1" Organisation : Organisation
```

Identifies a way in which an organisation may participate in the utility enterprise (e.g., customer, manufacturer, etc).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Organisation [0..1] | [Organisation](#CIM17v40-Organisation) | Organisation having this role. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Outage}
### Outage

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Outage {

+ communityDescriptor : String [0..1]
+ customersRestored : Integer [0..1]
+ metersAffected : Integer [0..1]
+ originalCustomersServed : Integer [0..1]
+ originalMetersAffected : Integer [0..1]
+ outageKind : enum:OutageStatusKind [0..1]
+ statusKind : enum:CrewStatusKind [0..1]
+ utilityDisclaimer : String [0..1]
+ actualPeriod : DateTimeInterval [0..1]
+ estimatedPeriod : DateTimeInterval [0..1]
+ summary : ServicePointOutageSummary [0..1]
}

class Document {

}

Document <|-- Outage : inherits from
class EstimatedRestorationTime {

}

Outage --> "0..1" EstimatedRestorationTime : EstimatedRestorationTime
```

Document describing details of an active or planned outage in a part of the electrical network.

A non-planned outage may be created upon:

- a breaker trip,

- a fault indicator status change,

- a meter event indicating customer outage,

- a reception of one or more customer trouble calls, or

- an operator command, reflecting information obtained from the field crew.

Outage restoration may be performed using a switching plan which complements the outage information with detailed switching activities, including the relationship to the crew and work.

A planned outage may be created upon:

- a request for service, maintenance or construction work in the field, or

- an operator-defined outage for what-if/contingency network analysis.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| communityDescriptor [0..1] | [String](#CIM17v40-String) | a name to denote the community - this could be a name or a code of some kind. | |
| customersRestored [0..1] | [Integer](#CIM17v40-Integer) | number of customers that have been restored in the area. | |
| metersAffected [0..1] | [Integer](#CIM17v40-Integer) | The updated number of meters affected by the outage as reported by the OMS within the utility. It is assumed this number will be updated repeatedly until the full outage is resolved. | |
| originalCustomersServed [0..1] | [Integer](#CIM17v40-Integer) | the total number of customers that are served in the area (both outaged and not outaged). | |
| originalMetersAffected [0..1] | [Integer](#CIM17v40-Integer) | The original number of meters that were affected as reported by the OMS within the utility. That is, this is the total number of meters that were out at the beginning of the outage. | |
| outageKind [0..1] | [OutageStatusKind](#CIM17v40-OutageStatusKind) | Defines if the outage has been verified or is only estimated | |
| statusKind [0..1] | [CrewStatusKind](#CIM17v40-CrewStatusKind) | defines the status of the crew as in dispatched or arrived, etc. | |
| utilityDisclaimer [0..1] | [String](#CIM17v40-String) | This contains an disclaimers the utility would like to place on the data provided to any stakeholder. This may be different for different stakeholders. This should possibly be an attribute under the Organization class but it is placed here for now. | |
| actualPeriod [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Actual outage period; end of the period corresponds to the actual restoration time. | |
| estimatedPeriod [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Estimated outage period for a planned outage. The start of the period is the start of the planned outage and the end of the period corresponds to the end of the planned outage. | |
| EstimatedRestorationTime [0..1] | [EstimatedRestorationTime](#CIM17v40-EstimatedRestorationTime) | The estimated time that the power will be restored after an outage | |
| summary [0..1] | [ServicePointOutageSummary](#CIM17v40-ServicePointOutageSummary) | Summary counts of service points (customers) affected by this outage. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OutageArea}
### OutageArea


```mermaid
classDiagram
direction TB

class OutageArea {

+ earliestReportedTime : DateTime [0..1]
+ metersServed : Integer [0..1]
+ outageAreaKind : enum:AreaKind [0..1]
}

```

This defines the area covered by the Outage.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| earliestReportedTime [0..1] | [DateTime](#CIM17v40-DateTime) | This is the reported time of the first outage report | |
| metersServed [0..1] | [Integer](#CIM17v40-Integer) | defines the number of meters served in the defined area. | |
| outageAreaKind [0..1] | [AreaKind](#CIM17v40-AreaKind) | defines the type of area that has the outage - county, state, zipcode, etc. | |

{#CIM17v40-OutageOrder}
### OutageOrder

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OutageOrder {

+ comment : String [0..1]
}

class Document {

}

Document <|-- OutageOrder : inherits from
class OutagePlan {

}

OutageOrder --> "0..1" OutagePlan : OutagePlan
```

Transmits an outage plan to a crew in order for the planned outage to be executed.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| comment [0..1] | [String](#CIM17v40-String) | Free-form comment associated with the outage order | |
| OutagePlan [0..1] | [OutagePlan](#CIM17v40-OutagePlan) | The outage plan that is defined to address the outage order. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OutagePlan}
### OutagePlan

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OutagePlan {

+ approvedDateTime : DateTime [0..1]
+ cancelledDateTime : DateTime [0..1]
+ purpose : String [0..1]
+ plannedPeriod : DateTimeInterval [0..1]
}

class Document {

}

Document <|-- OutagePlan : inherits from
class OutageOrder {

}

OutagePlan --> "0..1" OutageOrder : OutageOrder
class PlannedOutage {

}

OutagePlan --> "0..1" PlannedOutage : PlannedOutage
class SwitchingPlan {

}

OutagePlan --> "0..1" SwitchingPlan : SwitchingPlan
```

Document containing the definition of planned outages of equipment and/or usage points. It will reference switching plans that are used to execute the planned outage.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| approvedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | The date and time the outage plan was approved | |
| cancelledDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and Time the planned outage was canceled. | |
| purpose [0..1] | [String](#CIM17v40-String) | Purpose of this outage plan, such as whether it is to replace equipment or perform maintenance or repairs or to reconfigure network topology. | |
| OutageOrder [0..1] | [OutageOrder](#CIM17v40-OutageOrder) | The outage order that will address the outage plan. | |
| PlannedOutage [0..1] | [PlannedOutage](#CIM17v40-PlannedOutage) | The outage resulting from the execution of the outage plan. | |
| plannedPeriod [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | planned start and end time of the planned outage. | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | The swiching plan that is associated with the outage plan. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OverexcLim2}
### OverexcLim2

Inheritance path = [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OverexcLim2 {

+ ifdlim : PU [0..1]
+ koi : PU [0..1]
+ voimax : PU [0..1]
+ voimin : PU [0..1]
}

class OverexcitationLimiterDynamics {

}

OverexcitationLimiterDynamics <|-- OverexcLim2 : inherits from
```

Different from LimIEEEOEL, LimOEL2 has a fixed pickup threshold and reduces the excitation set-point by means of a non-windup integral regulator.

<i>Irated</i> is the rated machine excitation current (calculated from nameplate conditions: <i>V</i><i><sub>nom</sub></i>, <i>P</i><i><sub>nom</sub></i>, <i>CosPhi</i><i><sub>nom</sub></i>).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ifdlim [0..1] | [PU](#CIM17v40-PU) | Limit value of rated field current (<i>I</i><i><sub>FDLIM</sub></i>). Typical value = 1,05. | |
| koi [0..1] | [PU](#CIM17v40-PU) | Gain Over excitation limiter (<i>K</i><i><sub>OI</sub></i>). Typical value = 0,1. | |
| voimax [0..1] | [PU](#CIM17v40-PU) | Maximum error signal (<i>V</i><i><sub>OIMAX</sub></i>) (&gt; OverexcLim2.voimin). Typical value = 0. | |
| voimin [0..1] | [PU](#CIM17v40-PU) | Minimum error signal (<i>V</i><i><sub>OIMIN</sub></i>) (&lt; OverexcLim2.voimax). Typical value = -9999. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [OverexcitationLimiterDynamics](CIM17v40-OverexcitationLimiterDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OverexcLimIEEE}
### OverexcLimIEEE

Inheritance path = [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OverexcLimIEEE {

+ hyst : PU [0..1]
+ ifdlim : PU [0..1]
+ ifdmax : PU [0..1]
+ itfpu : PU [0..1]
+ kcd : PU [0..1]
+ kramp : Float [0..1]
}

class OverexcitationLimiterDynamics {

}

OverexcitationLimiterDynamics <|-- OverexcLimIEEE : inherits from
```

The over excitation limiter model is intended to represent the significant features of OELs necessary for some large-scale system studies. It is the result of a pragmatic approach to obtain a model that can be widely applied with attainable data from generator owners. An attempt to include all variations in the functionality of OELs and duplicate how they interact with the rest of the excitation systems would likely result in a level of application insufficient for the studies for which they are intended.

Reference: IEEE OEL 421.5-2005, 9.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| hyst [0..1] | [PU](#CIM17v40-PU) | OEL pickup/drop-out hysteresis (<i>HYST</i>). Typical value = 0,03. | |
| ifdlim [0..1] | [PU](#CIM17v40-PU) | OEL timed field current limit (<i>I</i><i><sub>FDLIM</sub></i>). Typical value = 1,05. | |
| ifdmax [0..1] | [PU](#CIM17v40-PU) | OEL instantaneous field current limit (<i>I</i><i><sub>FDMAX</sub></i>). Typical value = 1,5. | |
| itfpu [0..1] | [PU](#CIM17v40-PU) | OEL timed field current limiter pickup level (<i>I</i><i><sub>TFPU</sub></i>). Typical value = 1,05. | |
| kcd [0..1] | [PU](#CIM17v40-PU) | OEL cooldown gain (<i>K</i><i><sub>CD</sub></i>). Typical value = 1. | |
| kramp [0..1] | [Float](#CIM17v40-Float) | OEL ramped limit rate (<i>K</i><i><sub>RAMP</sub></i>). Unit = PU / s. Typical value = 10. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [OverexcitationLimiterDynamics](CIM17v40-OverexcitationLimiterDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OverexcLimX1}
### OverexcLimX1

Inheritance path = [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OverexcLimX1 {

+ efd1 : PU [0..1]
+ efd2 : PU [0..1]
+ efd3 : PU [0..1]
+ efddes : PU [0..1]
+ efdrated : PU [0..1]
+ kmx : PU [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ vlow : PU [0..1]
}

class OverexcitationLimiterDynamics {

}

OverexcitationLimiterDynamics <|-- OverexcLimX1 : inherits from
```

Field voltage over excitation limiter.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efd1 [0..1] | [PU](#CIM17v40-PU) | Low voltage point on the inverse time characteristic (<i>EFD</i><i><sub>1</sub></i>). Typical value = 1,1. | |
| efd2 [0..1] | [PU](#CIM17v40-PU) | Mid voltage point on the inverse time characteristic (<i>EFD</i><i><sub>2</sub></i>). Typical value = 1,2. | |
| efd3 [0..1] | [PU](#CIM17v40-PU) | High voltage point on the inverse time characteristic (<i>EFD</i><i><sub>3</sub></i>). Typical value = 1,5. | |
| efddes [0..1] | [PU](#CIM17v40-PU) | Desired field voltage (<i>EFD</i><i><sub>DES</sub></i>). Typical value = 0,9. | |
| efdrated [0..1] | [PU](#CIM17v40-PU) | Rated field voltage (<i>EFD</i><i><sub>RATED</sub></i>). Typical value = 1,05. | |
| kmx [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K</i><i><sub>MX</sub></i>). Typical value = 0,01. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Time to trip the exciter at the low voltage point on the inverse time characteristic (<i>TIME</i><i><sub>1</sub></i>) (&gt;= 0). Typical value = 120. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Time to trip the exciter at the mid voltage point on the inverse time characteristic (<i>TIME</i><i><sub>2</sub></i>) (&gt;= 0). Typical value = 40. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Time to trip the exciter at the high voltage point on the inverse time characteristic (<i>TIME</i><i><sub>3</sub></i>) (&gt;= 0). Typical value = 15. | |
| vlow [0..1] | [PU](#CIM17v40-PU) | Low voltage limit (<i>V</i><i><sub>LOW</sub></i>) (&gt; 0). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [OverexcitationLimiterDynamics](CIM17v40-OverexcitationLimiterDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OverexcLimX2}
### OverexcLimX2

Inheritance path = [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OverexcLimX2 {

+ efd1 : PU [0..1]
+ efd2 : PU [0..1]
+ efd3 : PU [0..1]
+ efddes : PU [0..1]
+ efdrated : PU [0..1]
+ kmx : PU [0..1]
+ m : Boolean [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ vlow : PU [0..1]
}

class OverexcitationLimiterDynamics {

}

OverexcitationLimiterDynamics <|-- OverexcLimX2 : inherits from
```

Field voltage or current overexcitation limiter designed to protect the generator field of an AC machine with automatic excitation control from overheating due to prolonged overexcitation.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efd1 [0..1] | [PU](#CIM17v40-PU) | Low voltage or current point on the inverse time characteristic (<i>EFD</i><i><sub>1</sub></i>). Typical value = 1,1. | |
| efd2 [0..1] | [PU](#CIM17v40-PU) | Mid voltage or current point on the inverse time characteristic (<i>EFD</i><i><sub>2</sub></i>). Typical value = 1,2. | |
| efd3 [0..1] | [PU](#CIM17v40-PU) | High voltage or current point on the inverse time characteristic (<i>EFD</i><i><sub>3</sub></i>). Typical value = 1,5. | |
| efddes [0..1] | [PU](#CIM17v40-PU) | Desired field voltage if <i>m</i> = false or desired field current if <i>m </i>= true (<i>EFD</i><i><sub>DES</sub></i>). Typical value = 1. | |
| efdrated [0..1] | [PU](#CIM17v40-PU) | Rated field voltage if m = false or rated field current if m = true (<i>EFD</i><i><sub>RATED</sub></i>). Typical value = 1,05. | |
| kmx [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K</i><i><sub>MX</sub></i>). Typical value = 0,002. | |
| m [0..1] | [Boolean](#CIM17v40-Boolean) | (<i>m</i>).true = IFD limitingfalse = EFD limiting. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Time to trip the exciter at the low voltage or current point on the inverse time characteristic (<i>TIME</i><i><sub>1</sub></i>) (&gt;= 0). Typical value = 120. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Time to trip the exciter at the mid voltage or current point on the inverse time characteristic (<i>TIME</i><i><sub>2</sub></i>) (&gt;= 0). Typical value = 40. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Time to trip the exciter at the high voltage or current point on the inverse time characteristic (<i>TIME</i><i><sub>3</sub></i>) (&gt;= 0). Typical value = 15. | |
| vlow [0..1] | [PU](#CIM17v40-PU) | Low voltage limit (<i>V</i><i><sub>LOW</sub></i>) (&gt; 0). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [OverexcitationLimiterDynamics](CIM17v40-OverexcitationLimiterDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OverexcitationLimiterDynamics}
### OverexcitationLimiterDynamics

Inheritance path = [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OverexcitationLimiterDynamics {

}

class DynamicsFunctionBlock {

}

DynamicsFunctionBlock <|-- OverexcitationLimiterDynamics : inherits from
class ExcitationSystemDynamics {

}

OverexcitationLimiterDynamics --> "1" ExcitationSystemDynamics : ExcitationSystemDynamics
```

Overexcitation limiter function block whose behaviour is described by reference to a standard model <font color="#0f0f0f">or by definition of a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | Excitation system model with which this overexcitation limiter model is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OverexcitationLimiterUserDefined}
### OverexcitationLimiterUserDefined

Inheritance path = [OverexcitationLimiterDynamics](#CIM17v40-OverexcitationLimiterDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OverexcitationLimiterUserDefined {

+ proprietary : Boolean [0..1]
}

class OverexcitationLimiterDynamics {

}

OverexcitationLimiterDynamics <|-- OverexcitationLimiterUserDefined : inherits from
```

Overexcitation limiter system function block whose dynamic behaviour is described by <font color="#0f0f0f">a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| proprietary [0..1] | [Boolean](#CIM17v40-Boolean) | Behaviour is based on a proprietary model as opposed to a detailed model.true = user-defined model is proprietary with behaviour mutually understood by sending and receiving applications and parameters passed as general attributesfalse = user-defined model is explicitly defined in terms of control blocks and their input and output signals. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [OverexcitationLimiterDynamics](CIM17v40-OverexcitationLimiterDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OverheadCost}
### (informative) OverheadCost

Inheritance path = [WorkIdentifiedObject](#CIM17v40-WorkIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OverheadCost {

+ code : String [0..1]
+ cost : Money [0..1]
+ status : Status [0..1]
}

class WorkIdentifiedObject {

}

WorkIdentifiedObject <|-- OverheadCost : inherits from
```

Overhead cost applied to work order.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| code [0..1] | [String](#CIM17v40-String) | Overhead code. | |
| cost [0..1] | [Money](#CIM17v40-Money) | The overhead cost to be applied. | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-OverheadWireInfo}
### OverheadWireInfo

Inheritance path = [WireInfo](#CIM17v40-WireInfo) => [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class OverheadWireInfo {

}

class WireInfo {

}

WireInfo <|-- OverheadWireInfo : inherits from
```

Overhead wire data.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| coreRadius [0..1] | [Length](#CIM17v40-Length) | see [WireInfo](CIM17v40-WireInfo) | |
| coreStrandCount [0..1] | [Integer](#CIM17v40-Integer) | see [WireInfo](#CIM17v40-WireInfo) | |
| gmr [0..1] | [Length](#CIM17v40-Length) | see [WireInfo](CIM17v40-WireInfo) | |
| insulated [0..1] | [Boolean](#CIM17v40-Boolean) | see [WireInfo](#CIM17v40-WireInfo) | |
| insulationMaterial [0..1] | [WireInsulationKind](#CIM17v40-WireInsulationKind) | see [WireInfo](CIM17v40-WireInfo) | |
| insulationThickness [0..1] | [Length](#CIM17v40-Length) | see [WireInfo](CIM17v40-WireInfo) | |
| material [0..1] | [WireMaterialKind](#CIM17v40-WireMaterialKind) | see [WireInfo](CIM17v40-WireInfo) | |
| rAC25 [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | see [WireInfo](CIM17v40-WireInfo) | |
| rAC50 [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | see [WireInfo](CIM17v40-WireInfo) | |
| rAC75 [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | see [WireInfo](CIM17v40-WireInfo) | |
| radius [0..1] | [Length](#CIM17v40-Length) | see [WireInfo](CIM17v40-WireInfo) | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [WireInfo](CIM17v40-WireInfo) | |
| rDC20 [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | see [WireInfo](CIM17v40-WireInfo) | |
| sizeDescription [0..1] | [String](#CIM17v40-String) | see [WireInfo](#CIM17v40-WireInfo) | |
| strandCount [0..1] | [Integer](#CIM17v40-Integer) | see [WireInfo](#CIM17v40-WireInfo) | |
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Ownership}
### Ownership

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Ownership {

+ share : PerCent [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Ownership : inherits from
class Asset {

}

Ownership --> "0..1" Asset : Asset
class AssetOwner {

}

Ownership --> "0..1" AssetOwner : AssetOwner
```

Ownership of e.g. asset.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| share [0..1] | [PerCent](#CIM17v40-PerCent) | Share of this ownership. | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | Asset that is object of this ownership. | |
| AssetOwner [0..1] | [AssetOwner](#CIM17v40-AssetOwner) | Asset owner that is subject in this ownership. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PFVArControllerType1Dynamics}
### PFVArControllerType1Dynamics

Inheritance path = [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PFVArControllerType1Dynamics {

}

class DynamicsFunctionBlock {

}

DynamicsFunctionBlock <|-- PFVArControllerType1Dynamics : inherits from
class ExcitationSystemDynamics {

}

PFVArControllerType1Dynamics --> "1" ExcitationSystemDynamics : ExcitationSystemDynamics
class RemoteInputSignal {

}

PFVArControllerType1Dynamics --> "0..1" RemoteInputSignal : RemoteInputSignal
class VoltageAdjusterDynamics {

}

PFVArControllerType1Dynamics --> "0..1" VoltageAdjusterDynamics : VoltageAdjusterDynamics
```

Power factor or VAr controller type 1 function block whose behaviour is described by reference to a standard model <font color="#0f0f0f">or by definition of a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | Excitation system model with which this power actor or VAr controller type 1 model is associated. | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | Remote input signal used by this power factor or VAr controller type 1 model. | |
| VoltageAdjusterDynamics [0..1] | [VoltageAdjusterDynamics](#CIM17v40-VoltageAdjusterDynamics) | Voltage adjuster model associated with this power factor or VAr controller type 1 model. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PFVArControllerType1UserDefined}
### PFVArControllerType1UserDefined

Inheritance path = [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PFVArControllerType1UserDefined {

+ proprietary : Boolean [0..1]
}

class PFVArControllerType1Dynamics {

}

PFVArControllerType1Dynamics <|-- PFVArControllerType1UserDefined : inherits from
```

Power factor or VAr controller type 1 function block whose dynamic behaviour is described by <font color="#0f0f0f">a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| proprietary [0..1] | [Boolean](#CIM17v40-Boolean) | Behaviour is based on a proprietary model as opposed to a detailed model.true = user-defined model is proprietary with behaviour mutually understood by sending and receiving applications and parameters passed as general attributesfalse = user-defined model is explicitly defined in terms of control blocks and their input and output signals. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PFVArControllerType1Dynamics](CIM17v40-PFVArControllerType1Dynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [PFVArControllerType1Dynamics](CIM17v40-PFVArControllerType1Dynamics) | |
| VoltageAdjusterDynamics [0..1] | [VoltageAdjusterDynamics](#CIM17v40-VoltageAdjusterDynamics) | see [PFVArControllerType1Dynamics](CIM17v40-PFVArControllerType1Dynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PFVArControllerType2Dynamics}
### PFVArControllerType2Dynamics

Inheritance path = [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PFVArControllerType2Dynamics {

}

class DynamicsFunctionBlock {

}

DynamicsFunctionBlock <|-- PFVArControllerType2Dynamics : inherits from
class ExcitationSystemDynamics {

}

PFVArControllerType2Dynamics --> "1" ExcitationSystemDynamics : ExcitationSystemDynamics
```

Power factor or VAr controller type 2 function block whose behaviour is described by reference to a standard model <font color="#0f0f0f">or by definition of a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | Excitation system model with which this power factor or VAr controller type 2 is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PFVArControllerType2UserDefined}
### PFVArControllerType2UserDefined

Inheritance path = [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PFVArControllerType2UserDefined {

+ proprietary : Boolean [0..1]
}

class PFVArControllerType2Dynamics {

}

PFVArControllerType2Dynamics <|-- PFVArControllerType2UserDefined : inherits from
```

Power factor or VAr controller type 2 function block whose dynamic behaviour is described by <font color="#0f0f0f">a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| proprietary [0..1] | [Boolean](#CIM17v40-Boolean) | Behaviour is based on a proprietary model as opposed to a detailed model.true = user-defined model is proprietary with behaviour mutually understood by sending and receiving applications and parameters passed as general attributesfalse = user-defined model is explicitly defined in terms of control blocks and their input and output signals. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PFVArControllerType2Dynamics](CIM17v40-PFVArControllerType2Dynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PFVArType1IEEEPFController}
### PFVArType1IEEEPFController

Inheritance path = [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PFVArType1IEEEPFController {

+ ovex : Boolean [0..1]
+ tpfc : Seconds [0..1]
+ vitmin : PU [0..1]
+ vpf : PU [0..1]
+ vpfcbw : Float [0..1]
+ vpfref : PU [0..1]
+ vvtmax : PU [0..1]
+ vvtmin : PU [0..1]
}

class PFVArControllerType1Dynamics {

}

PFVArControllerType1Dynamics <|-- PFVArType1IEEEPFController : inherits from
```

IEEE PF controller type 1 which operates by moving the voltage reference directly.

Reference: IEEE 421.5-2005, 11.2.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ovex [0..1] | [Boolean](#CIM17v40-Boolean) | Overexcitation Flag (<i>OVEX</i>)true = overexcitedfalse = underexcited. | |
| tpfc [0..1] | [Seconds](#CIM17v40-Seconds) | PF controller time delay (<i>T</i><i><sub>PFC</sub></i>) (&gt;= 0). Typical value = 5. | |
| vitmin [0..1] | [PU](#CIM17v40-PU) | Minimum machine terminal current needed to enable pf/var controller (<i>V</i><i><sub>ITMIN</sub></i>). | |
| vpf [0..1] | [PU](#CIM17v40-PU) | Synchronous machine power factor (<i>V</i><i><sub>PF</sub></i>). | |
| vpfcbw [0..1] | [Float](#CIM17v40-Float) | PF controller deadband (<i>V</i><i><sub>PFC_BW</sub></i>). Typical value = 0,05. | |
| vpfref [0..1] | [PU](#CIM17v40-PU) | PF controller reference (<i>V</i><i><sub>PFREF</sub></i>). | |
| vvtmax [0..1] | [PU](#CIM17v40-PU) | Maximum machine terminal voltage needed for pf/var controller to be enabled (<i>V</i><i><sub>VTMAX</sub></i>) (&gt; PFVArType1IEEEPFController.vvtmin). | |
| vvtmin [0..1] | [PU](#CIM17v40-PU) | Minimum machine terminal voltage needed to enable pf/var controller (<i>V</i><i><sub>VTMIN</sub></i>) (&lt; PFVArType1IEEEPFController.vvtmax). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PFVArControllerType1Dynamics](CIM17v40-PFVArControllerType1Dynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [PFVArControllerType1Dynamics](CIM17v40-PFVArControllerType1Dynamics) | |
| VoltageAdjusterDynamics [0..1] | [VoltageAdjusterDynamics](#CIM17v40-VoltageAdjusterDynamics) | see [PFVArControllerType1Dynamics](CIM17v40-PFVArControllerType1Dynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PFVArType1IEEEVArController}
### PFVArType1IEEEVArController

Inheritance path = [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PFVArType1IEEEVArController {

+ tvarc : Seconds [0..1]
+ vvar : PU [0..1]
+ vvarcbw : Float [0..1]
+ vvarref : PU [0..1]
+ vvtmax : PU [0..1]
+ vvtmin : PU [0..1]
}

class PFVArControllerType1Dynamics {

}

PFVArControllerType1Dynamics <|-- PFVArType1IEEEVArController : inherits from
```

IEEE VAR controller type 1 which operates by moving the voltage reference directly.

Reference: IEEE 421.5-2005, 11.3.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| tvarc [0..1] | [Seconds](#CIM17v40-Seconds) | Var controller time delay (<i>T</i><i><sub>VARC</sub></i>) (&gt;= 0). Typical value = 5. | |
| vvar [0..1] | [PU](#CIM17v40-PU) | Synchronous machine power factor (<i>V</i><i><sub>VAR</sub></i>). | |
| vvarcbw [0..1] | [Float](#CIM17v40-Float) | Var controller deadband (<i>V</i><i><sub>VARC_BW</sub></i>). Typical value = 0,02. | |
| vvarref [0..1] | [PU](#CIM17v40-PU) | Var controller reference (<i>V</i><i><sub>VARREF</sub></i>). | |
| vvtmax [0..1] | [PU](#CIM17v40-PU) | Maximum machine terminal voltage needed for pf/VAr controller to be enabled (<i>V</i><i><sub>VTMAX</sub></i>) (&gt; PVFArType1IEEEVArController.vvtmin). | |
| vvtmin [0..1] | [PU](#CIM17v40-PU) | Minimum machine terminal voltage needed to enable pf/var controller (<i>V</i><i><sub>VTMIN</sub></i>) (&lt; PVFArType1IEEEVArController.vvtmax). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PFVArControllerType1Dynamics](CIM17v40-PFVArControllerType1Dynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [PFVArControllerType1Dynamics](CIM17v40-PFVArControllerType1Dynamics) | |
| VoltageAdjusterDynamics [0..1] | [VoltageAdjusterDynamics](#CIM17v40-VoltageAdjusterDynamics) | see [PFVArControllerType1Dynamics](CIM17v40-PFVArControllerType1Dynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PFVArType2Common1}
### PFVArType2Common1

Inheritance path = [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PFVArType2Common1 {

+ j : Boolean [0..1]
+ ki : PU [0..1]
+ kp : PU [0..1]
+ max : PU [0..1]
+ ref : PU [0..1]
}

class PFVArControllerType2Dynamics {

}

PFVArControllerType2Dynamics <|-- PFVArType2Common1 : inherits from
```

Power factor / reactive power regulator. This model represents the power factor or reactive power controller such as the Basler SCP-250. The controller measures power factor or reactive power (PU on generator rated power) and compares it with the operator's set point.

[Footnote: Basler SCP-250 is an example of a suitable product available commercially. This information is given for the convenience of users of this document and does not constitute an endorsement by IEC of this product.]


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| j [0..1] | [Boolean](#CIM17v40-Boolean) | Selector (<i>J</i>).true = control mode for reactive powerfalse = control mode for power factor. | |
| ki [0..1] | [PU](#CIM17v40-PU) | Reset gain (<i>Ki</i>). | |
| kp [0..1] | [PU](#CIM17v40-PU) | Proportional gain (<i>Kp</i>). | |
| max [0..1] | [PU](#CIM17v40-PU) | Output limit (<i>max</i>). | |
| ref [0..1] | [PU](#CIM17v40-PU) | Reference value of reactive power or power factor (<i>Ref</i>).The reference value is initialised by this model. This initialisation can override the value exchanged by this attribute to represent a plant operator's change of the reference setting. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PFVArControllerType2Dynamics](CIM17v40-PFVArControllerType2Dynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PFVArType2IEEEPFController}
### PFVArType2IEEEPFController

Inheritance path = [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PFVArType2IEEEPFController {

+ exlon : Boolean [0..1]
+ ki : PU [0..1]
+ kp : PU [0..1]
+ pfref : PU [0..1]
+ vclmt : PU [0..1]
+ vref : PU [0..1]
+ vs : Float [0..1]
}

class PFVArControllerType2Dynamics {

}

PFVArControllerType2Dynamics <|-- PFVArType2IEEEPFController : inherits from
```

IEEE PF controller type 2 which is a summing point type controller making up the outside loop of a two-loop system. This controller is implemented as a slow PI type controller. The voltage regulator forms the inner loop and is implemented as a fast controller.

Reference: IEEE 421.5-2005, 11.4.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| exlon [0..1] | [Boolean](#CIM17v40-Boolean) | Overexcitation or under excitation flag (<i>EXLON</i>)true = 1 (not in the overexcitation or underexcitation state, integral action is active)false = 0 (in the overexcitation or underexcitation state, so integral action is disabled to allow the limiter to play its role). | |
| ki [0..1] | [PU](#CIM17v40-PU) | Integral gain of the pf controller (<i>K</i><i><sub>I</sub></i>). Typical value = 1. | |
| kp [0..1] | [PU](#CIM17v40-PU) | Proportional gain of the pf controller (<i>K</i><i><sub>P</sub></i>). Typical value = 1. | |
| pfref [0..1] | [PU](#CIM17v40-PU) | Power factor reference (<i>P</i><i><sub>FREF</sub></i>). | |
| vclmt [0..1] | [PU](#CIM17v40-PU) | Maximum output of the pf controller (<i>V</i><i><sub>CLMT</sub></i>). Typical value = 0,1. | |
| vref [0..1] | [PU](#CIM17v40-PU) | Voltage regulator reference (<i>V</i><i><sub>REF</sub></i>). | |
| vs [0..1] | [Float](#CIM17v40-Float) | Generator sensing voltage (<i>V</i><i><sub>S</sub></i>). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PFVArControllerType2Dynamics](CIM17v40-PFVArControllerType2Dynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PFVArType2IEEEVArController}
### PFVArType2IEEEVArController

Inheritance path = [PFVArControllerType2Dynamics](#CIM17v40-PFVArControllerType2Dynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PFVArType2IEEEVArController {

+ exlon : Boolean [0..1]
+ ki : PU [0..1]
+ kp : PU [0..1]
+ qref : PU [0..1]
+ vclmt : PU [0..1]
+ vref : PU [0..1]
+ vs : Float [0..1]
}

class PFVArControllerType2Dynamics {

}

PFVArControllerType2Dynamics <|-- PFVArType2IEEEVArController : inherits from
```

IEEE VAR controller type 2 which is a summing point type controller. It makes up the outside loop of a two-loop system. This controller is implemented as a slow PI type controller, and the voltage regulator forms the inner loop and is implemented as a fast controller.

Reference: IEEE 421.5-2005, 11.5.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| exlon [0..1] | [Boolean](#CIM17v40-Boolean) | Overexcitation or under excitation flag (<i>EXLON</i>)true = 1 (not in the overexcitation or underexcitation state, integral action is active)false = 0 (in the overexcitation or underexcitation state, so integral action is disabled to allow the limiter to play its role). | |
| ki [0..1] | [PU](#CIM17v40-PU) | Integral gain of the pf controller (<i>K</i><i><sub>I</sub></i>). | |
| kp [0..1] | [PU](#CIM17v40-PU) | Proportional gain of the pf controller (<i>K</i><i><sub>P</sub></i>). | |
| qref [0..1] | [PU](#CIM17v40-PU) | Reactive power reference (<i>Q</i><i><sub>REF</sub></i>). | |
| vclmt [0..1] | [PU](#CIM17v40-PU) | Maximum output of the pf controller (<i>V</i><i><sub>CLMT</sub></i>). | |
| vref [0..1] | [PU](#CIM17v40-PU) | Voltage regulator reference (<i>V</i><i><sub>REF</sub></i>). | |
| vs [0..1] | [Float](#CIM17v40-Float) | Generator sensing voltage (<i>V</i><i><sub>S</sub></i>). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PFVArControllerType2Dynamics](CIM17v40-PFVArControllerType2Dynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PFmode}
### (informative) PFmode


```mermaid
classDiagram
direction TB

class PFmode {

}

class Delay {

}

PFmode --> "1" Delay : Delay
class VSCtype1 {

}

PFmode --> "0..1" VSCtype1 : VSCtype1
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Delay [1]` (informative) | [Delay](#CIM17v40-Delay) | | |
| `VSCtype1 [0..1]` (informative) | [VSCtype1](#CIM17v40-VSCtype1) | | |

{#CIM17v40-PSREvent}
### PSREvent

Inheritance path = [ActivityRecord](#CIM17v40-ActivityRecord) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PSREvent {

+ kind : enum:PSREventKind [0..1]
}

class ActivityRecord {

}

ActivityRecord <|-- PSREvent : inherits from
class PowerSystemResource {

}

PSREvent --> "0..1" PowerSystemResource : PowerSystemResource
```

Event recording the change in operational status of a power system resource (PSR); may be for an event that has already occurred or for a planned activity.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [PSREventKind](#CIM17v40-PSREventKind) | Kind of event. | |
| PowerSystemResource [0..1] | [PowerSystemResource](#CIM17v40-PowerSystemResource) | Power system resource that generated this event. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| reason [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| severity [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| type [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| Document [0..1] | [Document](#CIM17v40-Document) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PSRType}
### PSRType

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PSRType {

}

class IdentifiedObject {

}

IdentifiedObject <|-- PSRType : inherits from
```

Classifying instances of the same class, e.g. overhead and underground ACLineSegments. This classification mechanism is intended to provide flexibility outside the scope of this document, i.e. provide customisation that is non standard.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PWRSteamSupply}
### PWRSteamSupply

Inheritance path = [SteamSupply](#CIM17v40-SteamSupply) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PWRSteamSupply {

+ coldLegFBLagTC : PU [0..1]
+ coldLegFBLeadTC1 : PU [0..1]
+ coldLegFBLeadTC2 : PU [0..1]
+ coldLegFG1 : PU [0..1]
+ coldLegFG2 : PU [0..1]
+ coldLegLagTC : PU [0..1]
+ coreHTLagTC1 : PU [0..1]
+ coreHTLagTC2 : PU [0..1]
+ coreNeutronicsEffTC : PU [0..1]
+ coreNeutronicsHT : PU [0..1]
+ feedbackFactor : PU [0..1]
+ hotLegLagTC : PU [0..1]
+ hotLegSteamGain : PU [0..1]
+ hotLegToColdLegGain : PU [0..1]
+ pressureCG : PU [0..1]
+ steamFlowFG : PU [0..1]
+ steamPressureDropLagTC : PU [0..1]
+ steamPressureFG : PU [0..1]
+ throttlePressureFactor : PU [0..1]
+ throttlePressureSP : PU [0..1]
}

class SteamSupply {

}

SteamSupply <|-- PWRSteamSupply : inherits from
```

Pressurized water reactor used as a steam supply to a steam turbine.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| coldLegFBLagTC [0..1] | [PU](#CIM17v40-PU) | Cold leg feedback lag time constant. | |
| coldLegFBLeadTC1 [0..1] | [PU](#CIM17v40-PU) | Cold leg feedback lead time constant. | |
| coldLegFBLeadTC2 [0..1] | [PU](#CIM17v40-PU) | Cold leg feedback lead time constant. | |
| coldLegFG1 [0..1] | [PU](#CIM17v40-PU) | Cold leg feedback gain 1. | |
| coldLegFG2 [0..1] | [PU](#CIM17v40-PU) | Cold leg feedback gain 2. | |
| coldLegLagTC [0..1] | [PU](#CIM17v40-PU) | Cold leg lag time constant. | |
| coreHTLagTC1 [0..1] | [PU](#CIM17v40-PU) | Core heat transfer lag time constant. | |
| coreHTLagTC2 [0..1] | [PU](#CIM17v40-PU) | Core heat transfer lag time constant. | |
| coreNeutronicsEffTC [0..1] | [PU](#CIM17v40-PU) | Core neutronics effective time constant. | |
| coreNeutronicsHT [0..1] | [PU](#CIM17v40-PU) | Core neutronics and heat transfer. | |
| feedbackFactor [0..1] | [PU](#CIM17v40-PU) | Feedback factor. | |
| hotLegLagTC [0..1] | [PU](#CIM17v40-PU) | Hot leg lag time constant. | |
| hotLegSteamGain [0..1] | [PU](#CIM17v40-PU) | Hot leg steam gain. | |
| hotLegToColdLegGain [0..1] | [PU](#CIM17v40-PU) | Hot leg to cold leg gain. | |
| pressureCG [0..1] | [PU](#CIM17v40-PU) | Pressure control gain. | |
| steamFlowFG [0..1] | [PU](#CIM17v40-PU) | Steam flow feedback gain. | |
| steamPressureDropLagTC [0..1] | [PU](#CIM17v40-PU) | Steam pressure drop lag time constant. | |
| steamPressureFG [0..1] | [PU](#CIM17v40-PU) | Steam pressure feedback gain. | |
| throttlePressureFactor [0..1] | [PU](#CIM17v40-PU) | Throttle pressure factor. | |
| throttlePressureSP [0..1] | [PU](#CIM17v40-PU) | Throttle pressure setpoint. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| steamSupplyRating [0..1] | [Float](#CIM17v40-Float) | see [SteamSupply](#CIM17v40-SteamSupply) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PanDemandResponse}
### PanDemandResponse

Inheritance path = [EndDeviceAction](#CIM17v40-EndDeviceAction)

```mermaid
classDiagram
direction TB

class PanDemandResponse {

+ avgLoadAdjustment : PerCent [0..1]
+ cancelControlMode : String [0..1]
+ cancelDateTime : DateTime [0..1]
+ cancelNow : Boolean [0..1]
+ coolingOffset : Temperature [0..1]
+ coolingSetpoint : Temperature [0..1]
+ criticalityLevel : String [0..1]
+ dutyCycle : PerCent [0..1]
+ enrollmentGroup : String [0..1]
+ heatingOffset : Temperature [0..1]
+ heatingSetpoint : Temperature [0..1]
+ appliance : ControlledAppliance [0..1]
}

class EndDeviceAction {

}

EndDeviceAction <|-- PanDemandResponse : inherits from
```

PAN control used to issue action/command to PAN devices during a demand response/load control event.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| avgLoadAdjustment [0..1] | [PerCent](#CIM17v40-PerCent) | Used to define a maximum energy usage limit as a percentage of the client implementations specific average energy usage. The load adjustment percentage is added to 100% creating a percentage limit applied to the client implementations specific average energy usage. A -10% load adjustment percentage will establish an energy usage limit equal to 90% of the client implementations specific average energy usage. Each load adjustment percentage is referenced to the client implementations specific average energy usage. There are no cumulative effects.The range of this field is -100% to +100% with a resolution of 1. A -100% value equals a total load shed. A +100% value will limit the energy usage to the client implementations specific average energy usage. | |
| cancelControlMode [0..1] | [String](#CIM17v40-String) | Encoding of cancel control. | |
| cancelDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Timestamp when a canceling of the event is scheduled to start. | |
| cancelNow [0..1] | [Boolean](#CIM17v40-Boolean) | If true, a canceling of the event should start immediately. | |
| coolingOffset [0..1] | [Temperature](#CIM17v40-Temperature) | Requested offset to apply to the normal cooling setpoint at the time of the start of the event. It represents a temperature change that will be applied to the associated cooling set point. The temperature offsets will be calculated per the local temperature in the thermostat. The calculated temperature will be interpreted as the number of degrees to be added to the cooling set point. Sequential demand response events are not cumulative. The offset shall be applied to the normal setpoint. | |
| coolingSetpoint [0..1] | [Temperature](#CIM17v40-Temperature) | Requested cooling set point. Temperature set point is typically defined and calculated based on local temperature. | |
| criticalityLevel [0..1] | [String](#CIM17v40-String) | Level of criticality for the action of this control. The action taken by load control devices for an event can be solely based on this value, or in combination with other load control event fields supported by the device. | |
| dutyCycle [0..1] | [PerCent](#CIM17v40-PerCent) | Maximum "on" state duty cycle as a percentage of time. For example, if the value is 80, the device would be in an "on" state for 80% of the time for the duration of the action. | |
| enrollmentGroup [0..1] | [String](#CIM17v40-String) | Provides a mechanism to direct load control actions to groups of PAN devices. It can be used in conjunction with the PAN device types. | |
| heatingOffset [0..1] | [Temperature](#CIM17v40-Temperature) | Requested offset to apply to the normal heating setpoint at the time of the start of the event. It represents a temperature change that will be applied to the associated heating set point. The temperature offsets will be calculated per the local temperature in the thermostat. The calculated temperature will be interpreted as the number of degrees to be subtracted from the heating set point. Sequential demand response events are not cumulative. The offset shall be applied to the normal setpoint. | |
| heatingSetpoint [0..1] | [Temperature](#CIM17v40-Temperature) | Requested heating set point. Temperature set point is typically defined and calculated based on local temperature. | |
| appliance [0..1] | [ControlledAppliance](#CIM17v40-ControlledAppliance) | Appliance being controlled. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| command [0..1] | [String](#CIM17v40-String) | see [EndDeviceAction](#CIM17v40-EndDeviceAction) | |
| duration [0..1] | [Minutes](#CIM17v40-Minutes) | see [EndDeviceAction](CIM17v40-EndDeviceAction) | |
| durationIndefinite [0..1] | [Boolean](#CIM17v40-Boolean) | see [EndDeviceAction](#CIM17v40-EndDeviceAction) | |
| startDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [EndDeviceAction](#CIM17v40-EndDeviceAction) | |
| EndDeviceControl [0..1] | [EndDeviceControl](#CIM17v40-EndDeviceControl) | see [EndDeviceAction](CIM17v40-EndDeviceAction) | |

{#CIM17v40-PanDisplay}
### PanDisplay

Inheritance path = [EndDeviceAction](#CIM17v40-EndDeviceAction)

```mermaid
classDiagram
direction TB

class PanDisplay {

+ confirmationRequired : Boolean [0..1]
+ priority : String [0..1]
+ textMessage : String [0..1]
+ transmissionMode : enum:TransmissionModeKind [0..1]
}

class EndDeviceAction {

}

EndDeviceAction <|-- PanDisplay : inherits from
```

PAN action/command used to issue the displaying of text messages on PAN devices.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| confirmationRequired [0..1] | [Boolean](#CIM17v40-Boolean) | If true, the requesting entity (e.g. retail electric provider) requires confirmation of the successful display of the text message. | |
| priority [0..1] | [String](#CIM17v40-String) | Priority associated with the text message to be displayed. | |
| textMessage [0..1] | [String](#CIM17v40-String) | Text to be displayed by a PAN device. | |
| transmissionMode [0..1] | [TransmissionModeKind](#CIM17v40-TransmissionModeKind) | Transmission mode to be used for this PAN display control. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| command [0..1] | [String](#CIM17v40-String) | see [EndDeviceAction](#CIM17v40-EndDeviceAction) | |
| duration [0..1] | [Minutes](#CIM17v40-Minutes) | see [EndDeviceAction](CIM17v40-EndDeviceAction) | |
| durationIndefinite [0..1] | [Boolean](#CIM17v40-Boolean) | see [EndDeviceAction](#CIM17v40-EndDeviceAction) | |
| startDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [EndDeviceAction](#CIM17v40-EndDeviceAction) | |
| EndDeviceControl [0..1] | [EndDeviceControl](#CIM17v40-EndDeviceControl) | see [EndDeviceAction](CIM17v40-EndDeviceAction) | |

{#CIM17v40-PanPricing}
### PanPricing

Inheritance path = [EndDeviceAction](#CIM17v40-EndDeviceAction)

```mermaid
classDiagram
direction TB

class PanPricing {

+ providerID : Integer [0..1]
}

class EndDeviceAction {

}

EndDeviceAction <|-- PanPricing : inherits from
```

PAN action/command used to issue pricing information to a PAN device.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| providerID [0..1] | [Integer](#CIM17v40-Integer) | Unique identifier for the commodity provider. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| command [0..1] | [String](#CIM17v40-String) | see [EndDeviceAction](#CIM17v40-EndDeviceAction) | |
| duration [0..1] | [Minutes](#CIM17v40-Minutes) | see [EndDeviceAction](CIM17v40-EndDeviceAction) | |
| durationIndefinite [0..1] | [Boolean](#CIM17v40-Boolean) | see [EndDeviceAction](#CIM17v40-EndDeviceAction) | |
| startDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [EndDeviceAction](#CIM17v40-EndDeviceAction) | |
| EndDeviceControl [0..1] | [EndDeviceControl](#CIM17v40-EndDeviceControl) | see [EndDeviceAction](CIM17v40-EndDeviceAction) | |

{#CIM17v40-PanPricingDetail}
### PanPricingDetail


```mermaid
classDiagram
direction TB

class PanPricingDetail {

+ alternateCostDelivered : Float [0..1]
+ alternateCostUnit : String [0..1]
+ currentTimeDate : DateTime [0..1]
+ generationPrice : Money [0..1]
+ generationPriceRatio : Float [0..1]
+ price : Money [0..1]
+ priceRatio : Float [0..1]
+ priceTier : Integer [0..1]
+ priceTierCount : Integer [0..1]
+ priceTierLabel : String [0..1]
+ rateLabel : String [0..1]
+ registerTier : String [0..1]
+ unitOfMeasure : String [0..1]
}

class PanPricing {

}

PanPricingDetail --> "0..1" PanPricing : PanPricing
```

Detail for a single price command/action.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| alternateCostDelivered [0..1] | [Float](#CIM17v40-Float) | Alternative measure of the cost of the energy consumed. An example might be the emissions of CO2 for each kWh of electricity consumed providing a measure of the environmental cost. | |
| alternateCostUnit [0..1] | [String](#CIM17v40-String) | Cost unit for the alternate cost delivered field. One example is kg of CO2 per unit of measure. | |
| currentTimeDate [0..1] | [DateTime](#CIM17v40-DateTime) | Current time as determined by a PAN device. | |
| generationPrice [0..1] | [Money](#CIM17v40-Money) | Price of the commodity measured in base unit of currency per 'unitOfMeasure'. | |
| generationPriceRatio [0..1] | [Float](#CIM17v40-Float) | Ratio of 'generationPrice' to the "normal" price chosen by the commodity provider. | |
| price [0..1] | [Money](#CIM17v40-Money) | Price of the commodity measured in base unit of currency per 'unitOfMeasure'. | |
| priceRatio [0..1] | [Float](#CIM17v40-Float) | Ratio of 'price' to the "normal" price chosen by the commodity provider. | |
| priceTier [0..1] | [Integer](#CIM17v40-Integer) | Pricing tier as chosen by the commodity provider. | |
| priceTierCount [0..1] | [Integer](#CIM17v40-Integer) | Maximum number of price tiers available. | |
| priceTierLabel [0..1] | [String](#CIM17v40-String) | Label for price tier. | |
| rateLabel [0..1] | [String](#CIM17v40-String) | Label of the current billing rate specified by commodity provider. | |
| registerTier [0..1] | [String](#CIM17v40-String) | Register tier accumulating usage information. | |
| unitOfMeasure [0..1] | [String](#CIM17v40-String) | Defines commodity as well as its base unit of measure. | |
| PanPricing [0..1] | [PanPricing](#CIM17v40-PanPricing) | PAN pricing command/action issuing this price detail. | |

{#CIM17v40-ParentOrganization}
### ParentOrganization

Inheritance path = [Organisation](#CIM17v40-Organisation) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ParentOrganization {

}

class Organisation {

}

Organisation <|-- ParentOrganization : inherits from
```


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Organisation](CIM17v40-Organisation) | |
| ParentOrganisation [0..1] | [ParentOrganization](#CIM17v40-ParentOrganization) | see [Organisation](CIM17v40-Organisation) | |
| phone1 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Organisation](CIM17v40-Organisation) | |
| phone2 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Organisation](CIM17v40-Organisation) | |
| postalAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Organisation](CIM17v40-Organisation) | |
| streetAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Organisation](CIM17v40-Organisation) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Participation}
### Participation

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Participation {

+ factor : Float [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Participation : inherits from
```

Participation level of a given Pnode in a given AggregatePnode.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| factor [0..1] | [Float](#CIM17v40-Float) | Used to calculate "participation" of Pnode in an AggregatePnode. For example, for regulation region this factor is 1 and total sum of all factors for a specific regulation region does not have to be 1. For pricing zone the total sum of all factors has to be 1. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PassThroughBill}
### PassThroughBill

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PassThroughBill {

+ adjustedAmount : Money [0..1]
+ amount : Money [0..1]
+ billedTo : String [0..1]
+ billEnd : DateTime [0..1]
+ billRunType : String [0..1]
+ billStart : DateTime [0..1]
+ effectiveDate : DateTime [0..1]
+ isDisputed : Boolean [0..1]
+ isProfiled : Boolean [0..1]
+ paidTo : String [0..1]
+ previousEnd : DateTime [0..1]
+ previousStart : DateTime [0..1]
+ price : Money [0..1]
+ productCode : String [0..1]
+ providedBy : String [0..1]
+ serviceEnd : DateTime [0..1]
+ serviceStart : DateTime [0..1]
+ soldTo : String [0..1]
+ taxAmount : Money [0..1]
+ timeZone : String [0..1]
+ tradeDate : DateTime [0..1]
+ transactionDate : DateTime [0..1]
+ transactionType : String [0..1]
+ quantity : FloatQuantity [0..1]
}

class Document {

}

Document <|-- PassThroughBill : inherits from
class MarketStatementLineItem {

}

PassThroughBill --> "0..1" MarketStatementLineItem : MarketStatementLineItem
```

Pass Through Bill is used for:

1)Two sided charge transactions with or without ISO involvement

2) Specific direct charges or payments that are calculated outside or provided directly to settlements

3) Specific charge bill determinants that are externally supplied and used in charge calculations


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| adjustedAmount [0..1] | [Money](#CIM17v40-Money) | | |
| amount [0..1] | [Money](#CIM17v40-Money) | The charge amount of the product/service. | |
| billedTo [0..1] | [String](#CIM17v40-String) | The company to which the PTB transaction is billed. | |
| billEnd [0..1] | [DateTime](#CIM17v40-DateTime) | Bill period end date | |
| billRunType [0..1] | [String](#CIM17v40-String) | The settlement run type, for example: prelim, final, and rerun. | |
| billStart [0..1] | [DateTime](#CIM17v40-DateTime) | Bill period start date | |
| effectiveDate [0..1] | [DateTime](#CIM17v40-DateTime) | The effective date of the transaction | |
| isDisputed [0..1] | [Boolean](#CIM17v40-Boolean) | Disputed transaction indicator | |
| isProfiled [0..1] | [Boolean](#CIM17v40-Boolean) | A flag indicating whether there is a profile data associated with the PTB. | |
| paidTo [0..1] | [String](#CIM17v40-String) | The company to which the PTB transaction is paid. | |
| previousEnd [0..1] | [DateTime](#CIM17v40-DateTime) | The previous bill period end date | |
| previousStart [0..1] | [DateTime](#CIM17v40-DateTime) | The previous bill period start date | |
| price [0..1] | [Money](#CIM17v40-Money) | The price of product/service. | |
| productCode [0..1] | [String](#CIM17v40-String) | The product identifier for determining the charge type of the transaction. | |
| providedBy [0..1] | [String](#CIM17v40-String) | The company by which the PTB transaction service is provided. | |
| serviceEnd [0..1] | [DateTime](#CIM17v40-DateTime) | The end date of service provided, if periodic. | |
| serviceStart [0..1] | [DateTime](#CIM17v40-DateTime) | The start date of service provided, if periodic. | |
| soldTo [0..1] | [String](#CIM17v40-String) | The company to which the PTB transaction is sold. | |
| taxAmount [0..1] | [Money](#CIM17v40-Money) | The tax on services taken. | |
| timeZone [0..1] | [String](#CIM17v40-String) | The time zone code | |
| tradeDate [0..1] | [DateTime](#CIM17v40-DateTime) | The trade date | |
| transactionDate [0..1] | [DateTime](#CIM17v40-DateTime) | The date the transaction occurs. | |
| transactionType [0..1] | [String](#CIM17v40-String) | The type of transaction. For example, charge customer, bill customer, matching AR/AP, or bill determinant | |
| MarketStatementLineItem [0..1] | [MarketStatementLineItem](#CIM17v40-MarketStatementLineItem) | | |
| quantity [0..1] | [FloatQuantity](#CIM17v40-FloatQuantity) | The product quantity. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Pcontrol}
### (informative) Pcontrol


```mermaid
classDiagram
direction TB

class Pcontrol {

}

class Delay {

}

Pcontrol --> "1" Delay : Delay
class VSCtype1 {

}

Pcontrol --> "0..1" VSCtype1 : VSCtype1
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Delay [1]` (informative) | [Delay](#CIM17v40-Delay) | | |
| `VSCtype1 [0..1]` (informative) | [VSCtype1](#CIM17v40-VSCtype1) | | |

{#CIM17v40-PendingCalculation}
### PendingCalculation


```mermaid
classDiagram
direction TB

class PendingCalculation {

+ multiplyBeforeAdd : Boolean [0..1]
+ offset : Integer [0..1]
+ scalarDenominator : Integer [0..1]
+ scalarFloat : Float [0..1]
+ scalarNumerator : Integer [0..1]
}

class ReadingType {

}

PendingCalculation --> "1" ReadingType : ReadingType
```

When present, a scalar conversion that needs to be applied to every IntervalReading.value contained in IntervalBlock. This conversion results in a new associated ReadingType, reflecting the true dimensions of IntervalReading values after the conversion.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| multiplyBeforeAdd [0..1] | [Boolean](#CIM17v40-Boolean) | Whether scalars should be applied before adding the 'offset'. | |
| offset [0..1] | [Integer](#CIM17v40-Integer) | (if applicable) Offset to be added as well as multiplication using scalars. | |
| scalarDenominator [0..1] | [Integer](#CIM17v40-Integer) | (if scalar is rational number) When 'IntervalReading.value' is multiplied by 'scalarNumerator' and divided by this value, it causes a unit of measure conversion to occur, resulting in the 'ReadingType.unit'. | |
| scalarFloat [0..1] | [Float](#CIM17v40-Float) | (if scalar is floating number) When multiplied with 'IntervalReading.value', it causes a unit of measure conversion to occur, according to the 'ReadingType.unit'. | |
| scalarNumerator [0..1] | [Integer](#CIM17v40-Integer) | (if scalar is integer or rational number) When the scalar is a simple integer, and this attribute is presented alone and multiplied with 'IntervalReading.value', it causes a unit of measure conversion to occur, resulting in the 'ReadingType.unit'. It is never used in conjunction with 'scalarFloat', only with 'scalarDenominator'. | |
| ReadingType [1] | [ReadingType](#CIM17v40-ReadingType) | Reading type resulting from this pending conversion. | |

{#CIM17v40-PenstockLossCurve}
### PenstockLossCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PenstockLossCurve {

}

class Curve {

}

Curve <|-- PenstockLossCurve : inherits from
class HydroGeneratingUnit {

}

PenstockLossCurve --> "1" HydroGeneratingUnit : HydroGeneratingUnit
```

Relationship between penstock head loss (in meters) and total discharge through the penstock (in cubic meters per second). One or more turbines may be connected to the same penstock.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `HydroGeneratingUnit [1]` (OfAggregate) | [HydroGeneratingUnit](#CIM17v40-HydroGeneratingUnit) | A hydro generating unit has a penstock loss curve. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PerLengthDCLineParameter}
### PerLengthDCLineParameter

Inheritance path = [PerLengthLineParameter](#CIM17v40-PerLengthLineParameter) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PerLengthDCLineParameter {

+ capacitance : CapacitancePerLength [0..1]
+ inductance : InductancePerLength [0..1]
+ resistance : ResistancePerLength [0..1]
}

class PerLengthLineParameter {

}

PerLengthLineParameter <|-- PerLengthDCLineParameter : inherits from
```

Common type for per-length electrical catalogues describing DC line parameters.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| capacitance [0..1] | [CapacitancePerLength](#CIM17v40-CapacitancePerLength) | Capacitance per unit of length of the DC line segment; significant for cables only. | |
| inductance [0..1] | [InductancePerLength](#CIM17v40-InductancePerLength) | Inductance per unit of length of the DC line segment. | |
| resistance [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | Resistance per length of the DC line segment. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WireAssemblyInfo [0..1] | [WireAssemblyInfo](#CIM17v40-WireAssemblyInfo) | see [PerLengthLineParameter](CIM17v40-PerLengthLineParameter) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PerLengthImpedance}
### PerLengthImpedance

Inheritance path = [PerLengthLineParameter](#CIM17v40-PerLengthLineParameter) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PerLengthImpedance {

}

class PerLengthLineParameter {

}

PerLengthLineParameter <|-- PerLengthImpedance : inherits from
```

Common type for per-length impedance electrical catalogues.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WireAssemblyInfo [0..1] | [WireAssemblyInfo](#CIM17v40-WireAssemblyInfo) | see [PerLengthLineParameter](CIM17v40-PerLengthLineParameter) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PerLengthLineParameter}
### PerLengthLineParameter

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PerLengthLineParameter {

}

class IdentifiedObject {

}

IdentifiedObject <|-- PerLengthLineParameter : inherits from
class WireAssemblyInfo {

}

PerLengthLineParameter --> "0..1" WireAssemblyInfo : WireAssemblyInfo
```

Common type for per-length electrical catalogues describing line parameters.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WireAssemblyInfo [0..1] | [WireAssemblyInfo](#CIM17v40-WireAssemblyInfo) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PerLengthPhaseImpedance}
### PerLengthPhaseImpedance

Inheritance path = [PerLengthImpedance](#CIM17v40-PerLengthImpedance) => [PerLengthLineParameter](#CIM17v40-PerLengthLineParameter) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PerLengthPhaseImpedance {

+ conductorCount : Integer [0..1]
}

class PerLengthImpedance {

}

PerLengthImpedance <|-- PerLengthPhaseImpedance : inherits from
```

Impedance and admittance parameters per unit length for n-wire unbalanced lines, in matrix form.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| conductorCount [0..1] | [Integer](#CIM17v40-Integer) | Number of phase, neutral, and other wires retained. Constrains the number of matrix elements and the phase codes that can be used with this matrix. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WireAssemblyInfo [0..1] | [WireAssemblyInfo](#CIM17v40-WireAssemblyInfo) | see [PerLengthLineParameter](CIM17v40-PerLengthLineParameter) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PerLengthSequenceImpedance}
### PerLengthSequenceImpedance

Inheritance path = [PerLengthImpedance](#CIM17v40-PerLengthImpedance) => [PerLengthLineParameter](#CIM17v40-PerLengthLineParameter) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PerLengthSequenceImpedance {

+ b0ch : SusceptancePerLength [0..1]
+ bch : SusceptancePerLength [0..1]
+ g0ch : ConductancePerLength [0..1]
+ gch : ConductancePerLength [0..1]
+ r : ResistancePerLength [0..1]
+ r0 : ResistancePerLength [0..1]
+ x : ReactancePerLength [0..1]
+ x0 : ReactancePerLength [0..1]
}

class PerLengthImpedance {

}

PerLengthImpedance <|-- PerLengthSequenceImpedance : inherits from
```

Sequence impedance and admittance parameters per unit length, for transposed lines of 1, 2, or 3 phases. For 1-phase lines, define x=x0=xself. For 2-phase lines, define x=xs-xm and x0=xs+xm.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| b0ch [0..1] | [SusceptancePerLength](#CIM17v40-SusceptancePerLength) | Zero sequence shunt (charging) susceptance, per unit of length. | |
| bch [0..1] | [SusceptancePerLength](#CIM17v40-SusceptancePerLength) | Positive sequence shunt (charging) susceptance, per unit of length. | |
| g0ch [0..1] | [ConductancePerLength](#CIM17v40-ConductancePerLength) | Zero sequence shunt (charging) conductance, per unit of length. | |
| gch [0..1] | [ConductancePerLength](#CIM17v40-ConductancePerLength) | Positive sequence shunt (charging) conductance, per unit of length. | |
| r [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | Positive sequence series resistance, per unit of length. | |
| r0 [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | Zero sequence series resistance, per unit of length. | |
| x [0..1] | [ReactancePerLength](#CIM17v40-ReactancePerLength) | Positive sequence series reactance, per unit of length. | |
| x0 [0..1] | [ReactancePerLength](#CIM17v40-ReactancePerLength) | Zero sequence series reactance, per unit of length. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WireAssemblyInfo [0..1] | [WireAssemblyInfo](#CIM17v40-WireAssemblyInfo) | see [PerLengthLineParameter](CIM17v40-PerLengthLineParameter) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Period}
### Period


```mermaid
classDiagram
direction TB

class Period {

+ resolution : Duration [0..1]
+ timeInterval : DateTimeInterval [0..1]
}

```

An identification of a time interval that may have a given resolution.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| resolution [0..1] | [Duration](#CIM17v40-Duration) | The number of units of time that compose an individual step within a period. | |
| timeInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | The start and end date and time for a given interval. | |

{#CIM17v40-PeriodicStatisticalCalculation}
### PeriodicStatisticalCalculation

Inheritance path = [StatisticalCalculation](#CIM17v40-StatisticalCalculation) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PeriodicStatisticalCalculation {

+ calculationIntervalMagnitude : Integer [0..1]
+ calculationIntervalUnit : enum:CalculationIntervalUnitKind [0..1]
}

class StatisticalCalculation {

}

StatisticalCalculation <|-- PeriodicStatisticalCalculation : inherits from
```

Description of period for which calculation is performed.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| calculationIntervalMagnitude [0..1] | [Integer](#CIM17v40-Integer) | Number of units (of calculationIntervalUnit) in the calculation interval. | |
| calculationIntervalUnit [0..1] | [CalculationIntervalUnitKind](#CIM17v40-CalculationIntervalUnitKind) | Unit in which calculation interval is defined. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| calculationMode [0..1] | [CalculationModeKind](#CIM17v40-CalculationModeKind) | see [StatisticalCalculation](CIM17v40-StatisticalCalculation) | |
| calculationTechnique [0..1] | [CalculationTechniqueKind](#CIM17v40-CalculationTechniqueKind) | see [StatisticalCalculation](CIM17v40-StatisticalCalculation) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Person}
### Person

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Person {

+ firstName : String [0..1]
+ lastName : String [0..1]
+ mName : String [0..1]
+ prefix : String [0..1]
+ specialNeed : String [0..1]
+ suffix : String [0..1]
+ electronicAddress : ElectronicAddress [0..1]
+ landlinePhone : TelephoneNumber [0..1]
+ mobilePhone : TelephoneNumber [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Person : inherits from
```

General purpose information for name and other information to contact people.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| firstName [0..1] | [String](#CIM17v40-String) | Person's first name. | |
| lastName [0..1] | [String](#CIM17v40-String) | Person's last (family, sir) name. | |
| mName [0..1] | [String](#CIM17v40-String) | Middle name(s) or initial(s). | |
| prefix [0..1] | [String](#CIM17v40-String) | A prefix or title for the person's name, such as Miss, Mister, Doctor, etc. | |
| specialNeed [0..1] | [String](#CIM17v40-String) | Special service needs for the person (contact) are described; examples include life support, etc. | |
| suffix [0..1] | [String](#CIM17v40-String) | A suffix for the person's name, such as II, III, etc. | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | Electronic address. | |
| landlinePhone [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | Landline phone number. | |
| mobilePhone [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | Mobile phone number. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PersonOrganisationRole}
### PersonOrganisationRole

Inheritance path = [OrganisationRole](#CIM17v40-OrganisationRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PersonOrganisationRole {

+ clientID : String [0..1]
}

class OrganisationRole {

}

OrganisationRole <|-- PersonOrganisationRole : inherits from
class OldPerson {

}

PersonOrganisationRole --> "1" OldPerson : ErpPerson
```

Role an organisation plays with respect to persons.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| clientID [0..1] | [String](#CIM17v40-String) | Identifiers of the person held by an organisation, such as a government agency (federal, state, province, city, county), financial institutions, etc. | |
| `ErpPerson [1]` (informative) | [OldPerson](#CIM17v40-OldPerson) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Organisation [0..1] | [Organisation](#CIM17v40-Organisation) | see [OrganisationRole](CIM17v40-OrganisationRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PersonPropertyRole}
### PersonPropertyRole

Inheritance path = [Role](#CIM17v40-Role) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PersonPropertyRole {

}

class Role {

}

Role <|-- PersonPropertyRole : inherits from
class LandProperty {

}

PersonPropertyRole --> "1" LandProperty : LandProperty
class OldPerson {

}

PersonPropertyRole --> "1" OldPerson : Person
```

The role of a person relative to a given piece of property. Examples of roles include: owner, renter, contractor, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `LandProperty [1]` (informative) | [LandProperty](#CIM17v40-LandProperty) | | |
| `Person [1]` (informative) | [OldPerson](#CIM17v40-OldPerson) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| type [0..1] | [String](#CIM17v40-String) | see [Role](#CIM17v40-Role) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Role](CIM17v40-Role) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PersonRole}
### PersonRole

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PersonRole {

}

class IdentifiedObject {

}

IdentifiedObject <|-- PersonRole : inherits from
class Person {

}

PersonRole --> "0..1" Person : Person
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Person [0..1] | [Person](#CIM17v40-Person) | Person having this role. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PetersenCoil}
### PetersenCoil

Inheritance path = [EarthFaultCompensator](#CIM17v40-EarthFaultCompensator) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PetersenCoil {

+ mode : enum:PetersenCoilModeKind [0..1]
+ nominalU : Voltage [0..1]
+ offsetCurrent : CurrentFlow [0..1]
+ positionCurrent : CurrentFlow [0..1]
+ xGroundMax : Reactance [0..1]
+ xGroundMin : Reactance [0..1]
+ xGroundNominal : Reactance [0..1]
}

class EarthFaultCompensator {

}

EarthFaultCompensator <|-- PetersenCoil : inherits from
```

A variable impedance device normally used to offset line charging during single line faults in an ungrounded section of network.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mode [0..1] | [PetersenCoilModeKind](#CIM17v40-PetersenCoilModeKind) | The mode of operation of the Petersen coil. | |
| nominalU [0..1] | [Voltage](#CIM17v40-Voltage) | The nominal voltage for which the coil is designed. | |
| offsetCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | The offset current that the Petersen coil controller is operating from the resonant point. This is normally a fixed amount for which the controller is configured and could be positive or negative. Typically 0 to 60 A depending on voltage and resonance conditions. | |
| positionCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | The control current used to control the Petersen coil also known as the position current. Typically in the range of 20 mA to 200 mA. | |
| xGroundMax [0..1] | [Reactance](#CIM17v40-Reactance) | The maximum reactance. | |
| xGroundMin [0..1] | [Reactance](#CIM17v40-Reactance) | The minimum reactance. | |
| xGroundNominal [0..1] | [Reactance](#CIM17v40-Reactance) | The nominal reactance. This is the operating point (normally over compensation) that is defined based on the resonance point in the healthy network condition. The impedance is calculated based on nominal voltage divided by position current. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| r [0..1] | [Resistance](#CIM17v40-Resistance) | see [EarthFaultCompensator](CIM17v40-EarthFaultCompensator) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PhaseImpedanceData}
### PhaseImpedanceData


```mermaid
classDiagram
direction TB

class PhaseImpedanceData {

+ b : SusceptancePerLength [0..1]
+ column : Integer [0..1]
+ fromPhase : enum:SinglePhaseKind [0..1]
+ g : ConductancePerLength [0..1]
+ r : ResistancePerLength [0..1]
+ row : Integer [0..1]
+ toPhase : enum:SinglePhaseKind [0..1]
+ x : ReactancePerLength [0..1]
}

class PerLengthPhaseImpedance {

}

PhaseImpedanceData --> "1" PerLengthPhaseImpedance : PhaseImpedance
```

Impedance and conductance matrix element values.

The diagonal elements are described by the elements having the same toPhase and fromPhase value and the off diagonal elements have different toPhase and fromPhase values. The matrix can also be stored in symmetric lower triangular format using the row and column attributes, which map to ACLineSegmentPhase.sequenceNumber.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| b [0..1] | [SusceptancePerLength](#CIM17v40-SusceptancePerLength) | Susceptance matrix element value, per length of unit. | |
| column [0..1] | [Integer](#CIM17v40-Integer) | The matrix element's column number, in the range 1 to row. Only the lower triangle needs to be stored. This column number matches ACLineSegmentPhase.sequenceNumber. | |
| fromPhase [0..1] | [SinglePhaseKind](#CIM17v40-SinglePhaseKind) | Refer to the class description. | |
| g [0..1] | [ConductancePerLength](#CIM17v40-ConductancePerLength) | Conductance matrix element value, per length of unit. | |
| r [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | Resistance matrix element value, per length of unit. | |
| row [0..1] | [Integer](#CIM17v40-Integer) | The matrix element�s row number, in the range 1 to PerLengthPhaseImpedance.conductorCount. Only the lower triangle needs to be stored. This row number matches ACLineSegmentPhase.sequenceNumber. | |
| toPhase [0..1] | [SinglePhaseKind](#CIM17v40-SinglePhaseKind) | Refer to the class description. | |
| x [0..1] | [ReactancePerLength](#CIM17v40-ReactancePerLength) | Reactance matrix element value, per length of unit. | |
| PhaseImpedance [1] | [PerLengthPhaseImpedance](#CIM17v40-PerLengthPhaseImpedance) | Conductor phase impedance to which this data belongs. | |

{#CIM17v40-PhaseTapChanger}
### PhaseTapChanger

Inheritance path = [TapChanger](#CIM17v40-TapChanger) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PhaseTapChanger {

}

class TapChanger {

}

TapChanger <|-- PhaseTapChanger : inherits from
class TransformerEnd {

}

PhaseTapChanger --> "1" TransformerEnd : TransformerEnd
```

A transformer phase shifting tap model that controls the phase angle difference across the power transformer and potentially the active power flow through the power transformer. This phase tap model may also impact the voltage magnitude.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| TransformerEnd [1] | [TransformerEnd](#CIM17v40-TransformerEnd) | Transformer end to which this phase tap changer belongs. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| controlEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [TapChanger](#CIM17v40-TapChanger) | |
| highStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| initialDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [TapChanger](CIM17v40-TapChanger) | |
| lowStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| ltcFlag [0..1] | [Boolean](#CIM17v40-Boolean) | see [TapChanger](#CIM17v40-TapChanger) | |
| neutralStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| neutralU [0..1] | [Voltage](#CIM17v40-Voltage) | see [TapChanger](CIM17v40-TapChanger) | |
| normalStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| step [0..1] | [Float](#CIM17v40-Float) | see [TapChanger](#CIM17v40-TapChanger) | |
| subsequentDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [TapChanger](CIM17v40-TapChanger) | |
| SvTapStep [0..1] | [SvTapStep](#CIM17v40-SvTapStep) | see [TapChanger](CIM17v40-TapChanger) | |
| TapChangerControl [0..1] | [TapChangerControl](#CIM17v40-TapChangerControl) | see [TapChanger](CIM17v40-TapChanger) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PhaseTapChangerAsymmetrical}
### PhaseTapChangerAsymmetrical

Inheritance path = [PhaseTapChangerNonLinear](#CIM17v40-PhaseTapChangerNonLinear) => [PhaseTapChanger](#CIM17v40-PhaseTapChanger) => [TapChanger](#CIM17v40-TapChanger) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PhaseTapChangerAsymmetrical {

+ windingConnectionAngle : AngleDegrees [0..1]
}

class PhaseTapChangerNonLinear {

}

PhaseTapChangerNonLinear <|-- PhaseTapChangerAsymmetrical : inherits from
```

Describes the tap model for an asymmetrical phase shifting transformer in which the difference voltage vector adds to the in-phase winding. The out-of-phase winding is the transformer end where the tap changer is located. The angle between the in-phase and out-of-phase windings is named the winding connection angle. The phase shift depends on both the difference voltage magnitude and the winding connection angle.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| windingConnectionAngle [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | The phase angle between the in-phase winding and the out-of -phase winding used for creating phase shift. The out-of-phase winding produces what is known as the difference voltage. Setting this angle to 90 degrees is not the same as a symmetrical transformer. The attribute can only be multiples of 30 degrees. The allowed range is -150 degrees to 150 degrees excluding 0. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| voltageStepIncrement [0..1] | [PerCent](#CIM17v40-PerCent) | see [PhaseTapChangerNonLinear](CIM17v40-PhaseTapChangerNonLinear) | |
| xMax [0..1] | [Reactance](#CIM17v40-Reactance) | see [PhaseTapChangerNonLinear](CIM17v40-PhaseTapChangerNonLinear) | |
| `xMin [0..1]` (deprecated) | [Reactance](#CIM17v40-Reactance) | see [PhaseTapChangerNonLinear](CIM17v40-PhaseTapChangerNonLinear) | |
| TransformerEnd [1] | [TransformerEnd](#CIM17v40-TransformerEnd) | see [PhaseTapChanger](CIM17v40-PhaseTapChanger) | |
| controlEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [TapChanger](#CIM17v40-TapChanger) | |
| highStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| initialDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [TapChanger](CIM17v40-TapChanger) | |
| lowStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| ltcFlag [0..1] | [Boolean](#CIM17v40-Boolean) | see [TapChanger](#CIM17v40-TapChanger) | |
| neutralStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| neutralU [0..1] | [Voltage](#CIM17v40-Voltage) | see [TapChanger](CIM17v40-TapChanger) | |
| normalStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| step [0..1] | [Float](#CIM17v40-Float) | see [TapChanger](#CIM17v40-TapChanger) | |
| subsequentDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [TapChanger](CIM17v40-TapChanger) | |
| SvTapStep [0..1] | [SvTapStep](#CIM17v40-SvTapStep) | see [TapChanger](CIM17v40-TapChanger) | |
| TapChangerControl [0..1] | [TapChangerControl](#CIM17v40-TapChangerControl) | see [TapChanger](CIM17v40-TapChanger) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PhaseTapChangerLinear}
### PhaseTapChangerLinear

Inheritance path = [PhaseTapChanger](#CIM17v40-PhaseTapChanger) => [TapChanger](#CIM17v40-TapChanger) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PhaseTapChangerLinear {

+ stepPhaseShiftIncrement : AngleDegrees [0..1]
+ xMax : Reactance [0..1]
+ xMin : Reactance [0..1]
}

class PhaseTapChanger {

}

PhaseTapChanger <|-- PhaseTapChangerLinear : inherits from
```

Describes a tap changer with a linear relation between the tap step and the phase angle difference across the transformer. This is a mathematical model that is an approximation of a real phase tap changer.

The phase angle is computed as stepPhaseShiftIncrement times the tap position.

The voltage magnitude of both sides is the same.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| stepPhaseShiftIncrement [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Phase shift per step position. A positive value indicates a positive angle variation from the Terminal at the PowerTransformerEnd, where the TapChanger is located, into the transformer.The actual phase shift increment might be more accurately computed from the symmetrical or asymmetrical models or a tap step table lookup if those are available. | |
| xMax [0..1] | [Reactance](#CIM17v40-Reactance) | The reactance depends on the tap position according to a "u" shaped curve. The maximum reactance (xMax) appears at the low and high tap positions. Depending on the �u� curve the attribute can be either higher or lower than PowerTransformerEnd.x. | |
| `xMin [0..1]` (deprecated) | [Reactance](#CIM17v40-Reactance) | The reactance depends on the tap position according to a "u" shaped curve. The minimum reactance (xMin) appears at the mid tap position. PowerTransformerEnd.x shall be consistent with PhaseTapChangerLinear.xMin and PhaseTapChangerNonLinear.xMin. In case of inconsistency, PowerTransformerEnd.x shall be used. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| TransformerEnd [1] | [TransformerEnd](#CIM17v40-TransformerEnd) | see [PhaseTapChanger](CIM17v40-PhaseTapChanger) | |
| controlEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [TapChanger](#CIM17v40-TapChanger) | |
| highStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| initialDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [TapChanger](CIM17v40-TapChanger) | |
| lowStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| ltcFlag [0..1] | [Boolean](#CIM17v40-Boolean) | see [TapChanger](#CIM17v40-TapChanger) | |
| neutralStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| neutralU [0..1] | [Voltage](#CIM17v40-Voltage) | see [TapChanger](CIM17v40-TapChanger) | |
| normalStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| step [0..1] | [Float](#CIM17v40-Float) | see [TapChanger](#CIM17v40-TapChanger) | |
| subsequentDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [TapChanger](CIM17v40-TapChanger) | |
| SvTapStep [0..1] | [SvTapStep](#CIM17v40-SvTapStep) | see [TapChanger](CIM17v40-TapChanger) | |
| TapChangerControl [0..1] | [TapChangerControl](#CIM17v40-TapChangerControl) | see [TapChanger](CIM17v40-TapChanger) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PhaseTapChangerNonLinear}
### PhaseTapChangerNonLinear

Inheritance path = [PhaseTapChanger](#CIM17v40-PhaseTapChanger) => [TapChanger](#CIM17v40-TapChanger) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PhaseTapChangerNonLinear {

+ voltageStepIncrement : PerCent [0..1]
+ xMax : Reactance [0..1]
+ xMin : Reactance [0..1]
}

class PhaseTapChanger {

}

PhaseTapChanger <|-- PhaseTapChangerNonLinear : inherits from
```

The non-linear phase tap changer describes the non-linear behaviour of a phase tap changer. This is a base class for the symmetrical and asymmetrical phase tap changer models. The details of these models can be found in IEC 61970-301.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| voltageStepIncrement [0..1] | [PerCent](#CIM17v40-PerCent) | The voltage step increment on the out of phase winding (the PowerTransformerEnd where the TapChanger is located) specified in percent of rated voltage of the PowerTransformerEnd. A positive value means a positive voltage variation from the Terminal at the PowerTransformerEnd, where the TapChanger is located, into the transformer.When the increment is negative, the voltage decreases when the tap step increases. | |
| xMax [0..1] | [Reactance](#CIM17v40-Reactance) | The reactance depends on the tap position according to a "u" shaped curve. The maximum reactance (xMax) appears at the low and high tap positions. Depending on the �u� curve the attribute can be either higher or lower than PowerTransformerEnd.x. | |
| `xMin [0..1]` (deprecated) | [Reactance](#CIM17v40-Reactance) | The reactance depend on the tap position according to a "u" shaped curve. The minimum reactance (xMin) appear at the mid tap position. PowerTransformerEnd.x shall be consistent with PhaseTapChangerLinear.xMin and PhaseTapChangerNonLinear.xMin. In case of inconsistency, PowerTransformerEnd.x shall be used. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| TransformerEnd [1] | [TransformerEnd](#CIM17v40-TransformerEnd) | see [PhaseTapChanger](CIM17v40-PhaseTapChanger) | |
| controlEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [TapChanger](#CIM17v40-TapChanger) | |
| highStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| initialDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [TapChanger](CIM17v40-TapChanger) | |
| lowStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| ltcFlag [0..1] | [Boolean](#CIM17v40-Boolean) | see [TapChanger](#CIM17v40-TapChanger) | |
| neutralStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| neutralU [0..1] | [Voltage](#CIM17v40-Voltage) | see [TapChanger](CIM17v40-TapChanger) | |
| normalStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| step [0..1] | [Float](#CIM17v40-Float) | see [TapChanger](#CIM17v40-TapChanger) | |
| subsequentDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [TapChanger](CIM17v40-TapChanger) | |
| SvTapStep [0..1] | [SvTapStep](#CIM17v40-SvTapStep) | see [TapChanger](CIM17v40-TapChanger) | |
| TapChangerControl [0..1] | [TapChangerControl](#CIM17v40-TapChangerControl) | see [TapChanger](CIM17v40-TapChanger) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PhaseTapChangerSymmetrical}
### PhaseTapChangerSymmetrical

Inheritance path = [PhaseTapChangerNonLinear](#CIM17v40-PhaseTapChangerNonLinear) => [PhaseTapChanger](#CIM17v40-PhaseTapChanger) => [TapChanger](#CIM17v40-TapChanger) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PhaseTapChangerSymmetrical {

}

class PhaseTapChangerNonLinear {

}

PhaseTapChangerNonLinear <|-- PhaseTapChangerSymmetrical : inherits from
```

Describes a symmetrical phase shifting transformer tap model in which the voltage magnitude of both sides is the same. The difference voltage magnitude is the base in an equal-sided triangle where the sides corresponds to the primary and secondary voltages. The phase angle difference corresponds to the top angle and can be expressed as twice the arctangent of half the total difference voltage.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| voltageStepIncrement [0..1] | [PerCent](#CIM17v40-PerCent) | see [PhaseTapChangerNonLinear](CIM17v40-PhaseTapChangerNonLinear) | |
| xMax [0..1] | [Reactance](#CIM17v40-Reactance) | see [PhaseTapChangerNonLinear](CIM17v40-PhaseTapChangerNonLinear) | |
| `xMin [0..1]` (deprecated) | [Reactance](#CIM17v40-Reactance) | see [PhaseTapChangerNonLinear](CIM17v40-PhaseTapChangerNonLinear) | |
| TransformerEnd [1] | [TransformerEnd](#CIM17v40-TransformerEnd) | see [PhaseTapChanger](CIM17v40-PhaseTapChanger) | |
| controlEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [TapChanger](#CIM17v40-TapChanger) | |
| highStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| initialDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [TapChanger](CIM17v40-TapChanger) | |
| lowStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| ltcFlag [0..1] | [Boolean](#CIM17v40-Boolean) | see [TapChanger](#CIM17v40-TapChanger) | |
| neutralStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| neutralU [0..1] | [Voltage](#CIM17v40-Voltage) | see [TapChanger](CIM17v40-TapChanger) | |
| normalStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| step [0..1] | [Float](#CIM17v40-Float) | see [TapChanger](#CIM17v40-TapChanger) | |
| subsequentDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [TapChanger](CIM17v40-TapChanger) | |
| SvTapStep [0..1] | [SvTapStep](#CIM17v40-SvTapStep) | see [TapChanger](CIM17v40-TapChanger) | |
| TapChangerControl [0..1] | [TapChangerControl](#CIM17v40-TapChangerControl) | see [TapChanger](CIM17v40-TapChanger) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PhaseTapChangerTable}
### PhaseTapChangerTable

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PhaseTapChangerTable {

}

class IdentifiedObject {

}

IdentifiedObject <|-- PhaseTapChangerTable : inherits from
```

Describes a tabular curve for how the phase angle difference and impedance varies with the tap step.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PhaseTapChangerTablePoint}
### PhaseTapChangerTablePoint

Inheritance path = [TapChangerTablePoint](#CIM17v40-TapChangerTablePoint)

```mermaid
classDiagram
direction TB

class PhaseTapChangerTablePoint {

+ angle : AngleDegrees [0..1]
}

class TapChangerTablePoint {

}

TapChangerTablePoint <|-- PhaseTapChangerTablePoint : inherits from
class PhaseTapChangerTable {

}

PhaseTapChangerTablePoint --> "1" PhaseTapChangerTable : PhaseTapChangerTable
```

Describes each tap step in the phase tap changer tabular curve.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| angle [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | The angle difference in degrees. A positive value indicates a positive angle variation from the Terminal at the PowerTransformerEnd, where the TapChanger is located, into the transformer. | |
| PhaseTapChangerTable [1] | [PhaseTapChangerTable](#CIM17v40-PhaseTapChangerTable) | The table of this point. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| b [0..1] | [PerCent](#CIM17v40-PerCent) | see [TapChangerTablePoint](CIM17v40-TapChangerTablePoint) | |
| g [0..1] | [PerCent](#CIM17v40-PerCent) | see [TapChangerTablePoint](CIM17v40-TapChangerTablePoint) | |
| r [0..1] | [PerCent](#CIM17v40-PerCent) | see [TapChangerTablePoint](CIM17v40-TapChangerTablePoint) | |
| ratio [0..1] | [Float](#CIM17v40-Float) | see [TapChangerTablePoint](#CIM17v40-TapChangerTablePoint) | |
| step [0..1] | [Integer](#CIM17v40-Integer) | see [TapChangerTablePoint](#CIM17v40-TapChangerTablePoint) | |
| x [0..1] | [PerCent](#CIM17v40-PerCent) | see [TapChangerTablePoint](CIM17v40-TapChangerTablePoint) | |

{#CIM17v40-PhaseTapChangerTabular}
### PhaseTapChangerTabular

Inheritance path = [PhaseTapChanger](#CIM17v40-PhaseTapChanger) => [TapChanger](#CIM17v40-TapChanger) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PhaseTapChangerTabular {

}

class PhaseTapChanger {

}

PhaseTapChanger <|-- PhaseTapChangerTabular : inherits from
class PhaseTapChangerTable {

}

PhaseTapChangerTabular --> "0..1" PhaseTapChangerTable : PhaseTapChangerTable
```

Describes a tap changer with a table defining the relation between the tap step and the phase angle difference across the transformer.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| PhaseTapChangerTable [0..1] | [PhaseTapChangerTable](#CIM17v40-PhaseTapChangerTable) | The phase tap changer table for this phase tap changer. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| TransformerEnd [1] | [TransformerEnd](#CIM17v40-TransformerEnd) | see [PhaseTapChanger](CIM17v40-PhaseTapChanger) | |
| controlEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [TapChanger](#CIM17v40-TapChanger) | |
| highStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| initialDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [TapChanger](CIM17v40-TapChanger) | |
| lowStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| ltcFlag [0..1] | [Boolean](#CIM17v40-Boolean) | see [TapChanger](#CIM17v40-TapChanger) | |
| neutralStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| neutralU [0..1] | [Voltage](#CIM17v40-Voltage) | see [TapChanger](CIM17v40-TapChanger) | |
| normalStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| step [0..1] | [Float](#CIM17v40-Float) | see [TapChanger](#CIM17v40-TapChanger) | |
| subsequentDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [TapChanger](CIM17v40-TapChanger) | |
| SvTapStep [0..1] | [SvTapStep](#CIM17v40-SvTapStep) | see [TapChanger](CIM17v40-TapChanger) | |
| TapChangerControl [0..1] | [TapChangerControl](#CIM17v40-TapChangerControl) | see [TapChanger](CIM17v40-TapChanger) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PhenomenonClassification}
### PhenomenonClassification

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PhenomenonClassification {

}

class IdentifiedObject {

}

IdentifiedObject <|-- PhenomenonClassification : inherits from
class EnvironmentalDataAuthority {

}

PhenomenonClassification --> "0..1" EnvironmentalDataAuthority : EnvironmentalDataAuthority
```

A pre-defined phenomenon classification as defined by a particular authority.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| EnvironmentalDataAuthority [0..1] | [EnvironmentalDataAuthority](#CIM17v40-EnvironmentalDataAuthority) | Authority defining this environmental phenomenon. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PhotoVoltaicUnit}
### PhotoVoltaicUnit

Inheritance path = [PowerElectronicsUnit](#CIM17v40-PowerElectronicsUnit) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PhotoVoltaicUnit {

}

class PowerElectronicsUnit {

}

PowerElectronicsUnit <|-- PhotoVoltaicUnit : inherits from
```

A photovoltaic device or an aggregation of such devices.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [PowerElectronicsUnit](CIM17v40-PowerElectronicsUnit) | |
| minP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [PowerElectronicsUnit](CIM17v40-PowerElectronicsUnit) | |
| PowerElectronicsConnection [1] | [PowerElectronicsConnection](#CIM17v40-PowerElectronicsConnection) | see [PowerElectronicsUnit](CIM17v40-PowerElectronicsUnit) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PinBranchGroup}
### PinBranchGroup

Inheritance path = [GateInputPin](#CIM17v40-GateInputPin) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PinBranchGroup {

+ kind : enum:PinBranchGroupKind [0..1]
}

class GateInputPin {

}

GateInputPin <|-- PinBranchGroup : inherits from
class BranchGroup {

}

PinBranchGroup --> "1" BranchGroup : BranchGroup
```

Value associated with branch group is used as compare.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [PinBranchGroupKind](#CIM17v40-PinBranchGroupKind) | The compare operation done on the branch group. | |
| `BranchGroup [1]` (informative) | [BranchGroup](#CIM17v40-BranchGroup) | The branch group that should be used in compare. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| absoluteValue [0..1] | [Boolean](#CIM17v40-Boolean) | see [GateInputPin](#CIM17v40-GateInputPin) | |
| aDLogicKind [0..1] | [AnalogToDigitalLogicKind](#CIM17v40-AnalogToDigitalLogicKind) | see [GateInputPin](CIM17v40-GateInputPin) | |
| duration [0..1] | [Seconds](#CIM17v40-Seconds) | see [GateInputPin](CIM17v40-GateInputPin) | |
| negate [0..1] | [Boolean](#CIM17v40-Boolean) | see [GateInputPin](#CIM17v40-GateInputPin) | |
| thresholdPercentage [0..1] | [PerCent](#CIM17v40-PerCent) | see [GateInputPin](CIM17v40-GateInputPin) | |
| thresholdValue [0..1] | [Float](#CIM17v40-Float) | see [GateInputPin](#CIM17v40-GateInputPin) | |
| `Gate [1]` (OfAggregate, informative) | [Gate](#CIM17v40-Gate) | see [GateInputPin](CIM17v40-GateInputPin) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PinEquipment}
### PinEquipment

Inheritance path = [GateInputPin](#CIM17v40-GateInputPin) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PinEquipment {

+ kind : enum:PinEquipmentKind [0..1]
}

class GateInputPin {

}

GateInputPin <|-- PinEquipment : inherits from
class Equipment {

}

PinEquipment --> "1" Equipment : Equipment
```

Value associated with Equipment is used as compare.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [PinEquipmentKind](#CIM17v40-PinEquipmentKind) | The compare operation done on the equipment. | |
| `Equipment [1]` (informative) | [Equipment](#CIM17v40-Equipment) | The Equipment that should be used in compare. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| absoluteValue [0..1] | [Boolean](#CIM17v40-Boolean) | see [GateInputPin](#CIM17v40-GateInputPin) | |
| aDLogicKind [0..1] | [AnalogToDigitalLogicKind](#CIM17v40-AnalogToDigitalLogicKind) | see [GateInputPin](CIM17v40-GateInputPin) | |
| duration [0..1] | [Seconds](#CIM17v40-Seconds) | see [GateInputPin](CIM17v40-GateInputPin) | |
| negate [0..1] | [Boolean](#CIM17v40-Boolean) | see [GateInputPin](#CIM17v40-GateInputPin) | |
| thresholdPercentage [0..1] | [PerCent](#CIM17v40-PerCent) | see [GateInputPin](CIM17v40-GateInputPin) | |
| thresholdValue [0..1] | [Float](#CIM17v40-Float) | see [GateInputPin](#CIM17v40-GateInputPin) | |
| `Gate [1]` (OfAggregate, informative) | [Gate](#CIM17v40-Gate) | see [GateInputPin](CIM17v40-GateInputPin) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PinGate}
### PinGate

Inheritance path = [GateInputPin](#CIM17v40-GateInputPin) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PinGate {

}

class GateInputPin {

}

GateInputPin <|-- PinGate : inherits from
class Gate {

}

PinGate --> "1" Gate : GateOutput
```

An output from one gate represent an input to another gate.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `GateOutput [1]` (OfAggregate, informative) | [Gate](#CIM17v40-Gate) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| absoluteValue [0..1] | [Boolean](#CIM17v40-Boolean) | see [GateInputPin](#CIM17v40-GateInputPin) | |
| aDLogicKind [0..1] | [AnalogToDigitalLogicKind](#CIM17v40-AnalogToDigitalLogicKind) | see [GateInputPin](CIM17v40-GateInputPin) | |
| duration [0..1] | [Seconds](#CIM17v40-Seconds) | see [GateInputPin](CIM17v40-GateInputPin) | |
| negate [0..1] | [Boolean](#CIM17v40-Boolean) | see [GateInputPin](#CIM17v40-GateInputPin) | |
| thresholdPercentage [0..1] | [PerCent](#CIM17v40-PerCent) | see [GateInputPin](CIM17v40-GateInputPin) | |
| thresholdValue [0..1] | [Float](#CIM17v40-Float) | see [GateInputPin](#CIM17v40-GateInputPin) | |
| `Gate [1]` (OfAggregate, informative) | [Gate](#CIM17v40-Gate) | see [GateInputPin](CIM17v40-GateInputPin) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PinMeasurement}
### PinMeasurement

Inheritance path = [GateInputPin](#CIM17v40-GateInputPin) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PinMeasurement {

}

class GateInputPin {

}

GateInputPin <|-- PinMeasurement : inherits from
class Measurement {

}

PinMeasurement --> "0..1" Measurement : Measurement
class MeasurementCalculator {

}

PinMeasurement --> "0..1" MeasurementCalculator : MeasurementCalculator
```

Gate input pin that is associated with a Measurement or a calculation of Measurement.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Measurement [0..1]` (informative) | [Measurement](#CIM17v40-Measurement) | The Measurement that should be used in compare. | |
| `MeasurementCalculator [0..1]` (informative) | [MeasurementCalculator](#CIM17v40-MeasurementCalculator) | Result of the calculation used as input to a gate. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| absoluteValue [0..1] | [Boolean](#CIM17v40-Boolean) | see [GateInputPin](#CIM17v40-GateInputPin) | |
| aDLogicKind [0..1] | [AnalogToDigitalLogicKind](#CIM17v40-AnalogToDigitalLogicKind) | see [GateInputPin](CIM17v40-GateInputPin) | |
| duration [0..1] | [Seconds](#CIM17v40-Seconds) | see [GateInputPin](CIM17v40-GateInputPin) | |
| negate [0..1] | [Boolean](#CIM17v40-Boolean) | see [GateInputPin](#CIM17v40-GateInputPin) | |
| thresholdPercentage [0..1] | [PerCent](#CIM17v40-PerCent) | see [GateInputPin](CIM17v40-GateInputPin) | |
| thresholdValue [0..1] | [Float](#CIM17v40-Float) | see [GateInputPin](#CIM17v40-GateInputPin) | |
| `Gate [1]` (OfAggregate, informative) | [Gate](#CIM17v40-Gate) | see [GateInputPin](CIM17v40-GateInputPin) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PinTerminal}
### PinTerminal

Inheritance path = [GateInputPin](#CIM17v40-GateInputPin) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PinTerminal {

+ kind : enum:PinTerminalKind [0..1]
}

class GateInputPin {

}

GateInputPin <|-- PinTerminal : inherits from
class Terminal {

}

PinTerminal --> "1" Terminal : Terminal
```

Value associated with Terminal is used as compare.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [PinTerminalKind](#CIM17v40-PinTerminalKind) | The compare operation done on the terminal. | |
| `Terminal [1]` (informative) | [Terminal](#CIM17v40-Terminal) | The Terminal that should be used in compare. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| absoluteValue [0..1] | [Boolean](#CIM17v40-Boolean) | see [GateInputPin](#CIM17v40-GateInputPin) | |
| aDLogicKind [0..1] | [AnalogToDigitalLogicKind](#CIM17v40-AnalogToDigitalLogicKind) | see [GateInputPin](CIM17v40-GateInputPin) | |
| duration [0..1] | [Seconds](#CIM17v40-Seconds) | see [GateInputPin](CIM17v40-GateInputPin) | |
| negate [0..1] | [Boolean](#CIM17v40-Boolean) | see [GateInputPin](#CIM17v40-GateInputPin) | |
| thresholdPercentage [0..1] | [PerCent](#CIM17v40-PerCent) | see [GateInputPin](CIM17v40-GateInputPin) | |
| thresholdValue [0..1] | [Float](#CIM17v40-Float) | see [GateInputPin](#CIM17v40-GateInputPin) | |
| `Gate [1]` (OfAggregate, informative) | [Gate](#CIM17v40-Gate) | see [GateInputPin](CIM17v40-GateInputPin) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PlannedMarket}
### PlannedMarket


```mermaid
classDiagram
direction TB

class PlannedMarket {

+ marketEndTime : DateTime [0..1]
+ marketStartTime : DateTime [0..1]
+ marketType : enum:MarketType [0..1]
}

class MarketPlan {

}

PlannedMarket --> "1" MarketPlan : MarketPlan
```

Represent a planned market. For example a planned DA/HA/RT market.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| marketEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | Market end time. | |
| marketStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | Market start time. | |
| marketType [0..1] | [MarketType](#CIM17v40-MarketType) | Market type. | |
| MarketPlan [1] | [MarketPlan](#CIM17v40-MarketPlan) | A market plan has a number of markets (DA, HA, RT). | |

{#CIM17v40-PlannedMarketEvent}
### PlannedMarketEvent

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PlannedMarketEvent {

+ eventType : String [0..1]
+ plannedTime : Integer [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- PlannedMarketEvent : inherits from
```

This class represents planned events. Used to model the various planned events in a market (closing time, clearing time, etc.)


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| eventType [0..1] | [String](#CIM17v40-String) | Planned event type. | |
| plannedTime [0..1] | [Integer](#CIM17v40-Integer) | This is relative time so that this attribute can be used by more than one planned market. For example the bid submission is 10am everyday. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PlannedOutage}
### PlannedOutage

Inheritance path = [Outage](#CIM17v40-Outage) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PlannedOutage {

+ reason : String [0..1]
}

class Outage {

}

Outage <|-- PlannedOutage : inherits from
class FieldDispatchHistory {

}

PlannedOutage --> "0..1" FieldDispatchHistory : FieldDispatchHistory
class OutagePlan {

}

PlannedOutage --> "0..1" OutagePlan : OutagePlan
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| reason [0..1] | [String](#CIM17v40-String) | The reason for the planned outage. | |
| FieldDispatchHistory [0..1] | [FieldDispatchHistory](#CIM17v40-FieldDispatchHistory) | The dispatch history associated with the planned outage | |
| OutagePlan [0..1] | [OutagePlan](#CIM17v40-OutagePlan) | Outage plan for executing a planned outage. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| communityDescriptor [0..1] | [String](#CIM17v40-String) | see [Outage](#CIM17v40-Outage) | |
| customersRestored [0..1] | [Integer](#CIM17v40-Integer) | see [Outage](#CIM17v40-Outage) | |
| metersAffected [0..1] | [Integer](#CIM17v40-Integer) | see [Outage](#CIM17v40-Outage) | |
| originalCustomersServed [0..1] | [Integer](#CIM17v40-Integer) | see [Outage](#CIM17v40-Outage) | |
| originalMetersAffected [0..1] | [Integer](#CIM17v40-Integer) | see [Outage](#CIM17v40-Outage) | |
| outageKind [0..1] | [OutageStatusKind](#CIM17v40-OutageStatusKind) | see [Outage](CIM17v40-Outage) | |
| statusKind [0..1] | [CrewStatusKind](#CIM17v40-CrewStatusKind) | see [Outage](CIM17v40-Outage) | |
| utilityDisclaimer [0..1] | [String](#CIM17v40-String) | see [Outage](#CIM17v40-Outage) | |
| actualPeriod [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [Outage](CIM17v40-Outage) | |
| estimatedPeriod [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [Outage](CIM17v40-Outage) | |
| EstimatedRestorationTime [0..1] | [EstimatedRestorationTime](#CIM17v40-EstimatedRestorationTime) | see [Outage](CIM17v40-Outage) | |
| summary [0..1] | [ServicePointOutageSummary](#CIM17v40-ServicePointOutageSummary) | see [Outage](CIM17v40-Outage) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PlannedOutageNotification}
### PlannedOutageNotification

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PlannedOutageNotification {

}

class Document {

}

Document <|-- PlannedOutageNotification : inherits from
class SwitchingPlan {

}

PlannedOutageNotification --> "0..1" SwitchingPlan : SwitchingPlan
```

This class will be used to generate call ahead lists for customers who will be affected by a planned outage.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | The switching plan that contains the planned outage notification. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Plant}
### Plant

Inheritance path = [EquipmentContainer](#CIM17v40-EquipmentContainer) => [ConnectivityNodeContainer](#CIM17v40-ConnectivityNodeContainer) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Plant {

}

class EquipmentContainer {

}

EquipmentContainer <|-- Plant : inherits from
```

A Plant is a collection of equipment for purposes of generation.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Pnode}
### Pnode

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Pnode {

+ isPublic : Boolean [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Pnode : inherits from
class RTO {

}

Pnode --> "0..1" RTO : RTO
class SubControlArea {

}

Pnode --> "0..1" SubControlArea : SubControlArea
```

A pricing node is directly associated with a connectivity node. It is a pricing location for which market participants submit their bids, offers, buy/sell CRRs, and settle.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| isPublic [0..1] | [Boolean](#CIM17v40-Boolean) | If true, this Pnode is public (prices are published for DA/RT and FTR markets), otherwise it is private (location is not usable by market for bidding/FTRs/transactions). | |
| RTO [0..1] | [RTO](#CIM17v40-RTO) | | |
| SubControlArea [0..1] | [SubControlArea](#CIM17v40-SubControlArea) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PnodeClearing}
### PnodeClearing

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PnodeClearing {

}

class MarketFactors {

}

MarketFactors <|-- PnodeClearing : inherits from
```

Pricing node clearing results posted for a given settlement period.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PnodeDistributionFactor}
### PnodeDistributionFactor


```mermaid
classDiagram
direction TB

class PnodeDistributionFactor {

+ factor : Float [0..1]
+ offPeak : enum:YesNo [0..1]
+ onPeak : enum:YesNo [0..1]
+ podLossFactor : Float [0..1]
}

class AggregatedPnode {

}

PnodeDistributionFactor --> "1" AggregatedPnode : AggregatedPnode
class BidDistributionFactor {

}

PnodeDistributionFactor --> "0..1" BidDistributionFactor : BidDistributionFactor
class IndividualPnode {

}

PnodeDistributionFactor --> "1" IndividualPnode : IndividualPnode
```

This class allows SC to input different distribution factors for pricing node.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| factor [0..1] | [Float](#CIM17v40-Float) | Used to calculate "participation" of Pnode in an AggregatePnode. For example, for regulation region this factor is 1 and total sum of all factors for a specific regulation region does not have to be 1. For pricing zone the total sum of all factors has to be 1. | |
| offPeak [0..1] | [YesNo](#CIM17v40-YesNo) | Indication that this distribution factor is to apply during off peak. | |
| onPeak [0..1] | [YesNo](#CIM17v40-YesNo) | Indication that this factor is to apply during Peak periods. | |
| podLossFactor [0..1] | [Float](#CIM17v40-Float) | Point of delivery loss factor | |
| AggregatedPnode [1] | [AggregatedPnode](#CIM17v40-AggregatedPnode) | | |
| BidDistributionFactor [0..1] | [BidDistributionFactor](#CIM17v40-BidDistributionFactor) | | |
| IndividualPnode [1] | [IndividualPnode](#CIM17v40-IndividualPnode) | | |

{#CIM17v40-PnodeResults}
### PnodeResults


```mermaid
classDiagram
direction TB

class PnodeResults {

+ congestLMP : Float [0..1]
+ costLMP : Float [0..1]
+ lossLMP : Float [0..1]
+ marginalClearingPrice : Float [0..1]
+ scheduledMW : Float [0..1]
+ updateTimeStamp : DateTime [0..1]
+ updateType : enum:MQSCHGType [0..1]
+ updateUser : String [0..1]
}

class Pnode {

}

PnodeResults --> "0..1" Pnode : Pnode
class PnodeClearing {

}

PnodeResults --> "0..1" PnodeClearing : PnodeClearing
```

Provides the total price, the cost component, the loss component, and the congestion component for Pnodes for the forward and real time markets. There are several prices produced based on the run type (MPM, RUC, Pricing, or Scheduling/Dispatch).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| congestLMP [0..1] | [Float](#CIM17v40-Float) | Congestion component of Location Marginal Price (LMP) in monetary units per MW. | |
| costLMP [0..1] | [Float](#CIM17v40-Float) | Cost component of Locational Marginal Pricing (LMP) in monetary units per MW. | |
| lossLMP [0..1] | [Float](#CIM17v40-Float) | Loss component of Location Marginal Price (LMP) in monetary units per MW. | |
| marginalClearingPrice [0..1] | [Float](#CIM17v40-Float) | Locational Marginal Price (LMP) ($/MWh) | |
| scheduledMW [0..1] | [Float](#CIM17v40-Float) | total MW schedule at the pnode | |
| updateTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| updateType [0..1] | [MQSCHGType](#CIM17v40-MQSCHGType) | | |
| updateUser [0..1] | [String](#CIM17v40-String) | | |
| Pnode [0..1] | [Pnode](#CIM17v40-Pnode) | | |
| PnodeClearing [0..1] | [PnodeClearing](#CIM17v40-PnodeClearing) | | |

{#CIM17v40-Point}
### Point


```mermaid
classDiagram
direction TB

class Point {

+ position : Integer [0..1]
+ quality : String [0..1]
+ secondaryQuantity : Decimal [0..1]
}

class Period {

}

Point --> "1" Period : Period
class Quantity {

}

Point --> "0..*" Quantity : quantity
```

An identification of a set of values beeing adressed within a specific interval of time.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| position [0..1] | [Integer](#CIM17v40-Integer) | A sequential value representing the relative position within a given time interval. | |
| quality [0..1] | [String](#CIM17v40-String) | The quality of the information being provided. This quality may be estimated, not available, as provided, etc. | |
| secondaryQuantity [0..1] | [Decimal](#CIM17v40-Decimal) | Secondary quantity identified for a point. | |
| Period [1] | [Period](#CIM17v40-Period) | | |
| quantity [0..*] | [Quantity](#CIM17v40-Quantity) | | |

{#CIM17v40-PointOfSale}
### PointOfSale

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PointOfSale {

+ location : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- PointOfSale : inherits from
```

Logical point where transactions take place with operational interaction between cashier and the payment system; in certain cases the point of sale interacts directly with the end customer, in which case the cashier might not be a real person: for example a self-service kiosk or over the internet.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| location [0..1] | [String](#CIM17v40-String) | Local description for where this point of sale is physically located. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Pole}
### (informative) Pole

Inheritance path = [Structure](#CIM17v40-Structure) => [AssetContainer](#CIM17v40-AssetContainer) => [Asset](#CIM17v40-Asset) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Pole {

+ baseKind : enum:PoleBaseKind [0..1]
+ breastBlock : Boolean [0..1]
+ classification : String [0..1]
+ construction : String [0..1]
+ diameter : Length [0..1]
+ jpaReference : String [0..1]
+ length : Length [0..1]
+ preservativeKind : enum:PolePreservativeKind [0..1]
+ speciesType : String [0..1]
+ treatedDateTime : DateTime [0..1]
+ treatmentKind : enum:PoleTreatmentKind [0..1]
}

class Structure {

}

Structure <|-- Pole : inherits from
```

Pole asset.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| baseKind [0..1] | [PoleBaseKind](#CIM17v40-PoleBaseKind) | Kind of base for this pole. | |
| breastBlock [0..1] | [Boolean](#CIM17v40-Boolean) | True if a block of material has been attached to base of pole in ground for stability. This technique is used primarily when anchors can not be used. | |
| classification [0..1] | [String](#CIM17v40-String) | Pole class: 1, 2, 3, 4, 5, 6, 7, H1, H2, Other, Unknown. | |
| construction [0..1] | [String](#CIM17v40-String) | The framing structure mounted on the pole. | |
| diameter [0..1] | [Length](#CIM17v40-Length) | Diameter of the pole. | |
| jpaReference [0..1] | [String](#CIM17v40-String) | Joint pole agreement reference number. | |
| length [0..1] | [Length](#CIM17v40-Length) | Length of the pole (inclusive of any section of the pole that may be underground post-installation). | |
| preservativeKind [0..1] | [PolePreservativeKind](#CIM17v40-PolePreservativeKind) | Kind of preservative for this pole. | |
| speciesType [0..1] | [String](#CIM17v40-String) | Pole species. Aluminum, Aluminum Davit, Concrete, Fiberglass, Galvanized Davit, Galvanized, Steel Davit Primed, Steel Davit, Steel Standard Primed, Steel, Truncated, Wood-Treated, Wood-Hard, Wood-Salt Treated, Wood-Soft, Wood, Other, Unknown. | |
| treatedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time pole was last treated with preservative. | |
| treatmentKind [0..1] | [PoleTreatmentKind](#CIM17v40-PoleTreatmentKind) | Kind of treatment for this pole. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| fumigantAppliedDate [0..1] | [Date](#CIM17v40-Date) | see [Structure](#CIM17v40-Structure) | |
| fumigantName [0..1] | [String](#CIM17v40-String) | see [Structure](#CIM17v40-Structure) | |
| height [0..1] | [Length](#CIM17v40-Length) | see [Structure](CIM17v40-Structure) | |
| materialKind [0..1] | [StructureMaterialKind](#CIM17v40-StructureMaterialKind) | see [Structure](CIM17v40-Structure) | |
| ratedVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | see [Structure](CIM17v40-Structure) | |
| removeWeed [0..1] | [Boolean](#CIM17v40-Boolean) | see [Structure](#CIM17v40-Structure) | |
| weedRemovedDate [0..1] | [Date](#CIM17v40-Date) | see [Structure](#CIM17v40-Structure) | |
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | see [Asset](#CIM17v40-Asset) | |
| initialCondition [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | see [Asset](CIM17v40-Asset) | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | see [Asset](CIM17v40-Asset) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [Asset](CIM17v40-Asset) | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | see [Asset](CIM17v40-Asset) | |
| lotNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| position [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | see [Asset](CIM17v40-Asset) | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | see [Asset](CIM17v40-Asset) | |
| serialNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| type [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| utcNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | see [Asset](CIM17v40-Asset) | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | see [Asset](CIM17v40-Asset) | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | see [Asset](CIM17v40-Asset) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [Asset](CIM17v40-Asset) | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | see [Asset](CIM17v40-Asset) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Asset](CIM17v40-Asset) | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | see [Asset](CIM17v40-Asset) | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | see [Asset](CIM17v40-Asset) | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | see [Asset](CIM17v40-Asset) | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | see [Asset](CIM17v40-Asset) | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | see [Asset](CIM17v40-Asset) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Asset](CIM17v40-Asset) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [Asset](CIM17v40-Asset) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [Asset](CIM17v40-Asset) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Asset](CIM17v40-Asset) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PositionPoint}
### PositionPoint


```mermaid
classDiagram
direction TB

class PositionPoint {

+ groupNumber : Integer [0..1]
+ sequenceNumber : Integer [0..1]
+ xPosition : String [0..1]
+ yPosition : String [0..1]
+ zPosition : String [0..1]
}

class Location {

}

PositionPoint --> "1" Location : Location
```

Set of spatial coordinates that determine a point, defined in the coordinate system specified in 'Location.CoordinateSystem'. Use a single position point instance to describe a point-oriented location. Use a sequence of position points to describe a line-oriented object (physical location of non-point oriented objects like cables or lines), or area of an object (like a substation or a geographical zone - in this case, have first and last position point with the same values).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| groupNumber [0..1] | [Integer](#CIM17v40-Integer) | Zero-relative sequence number of this group within a series of points; used when there is a need to express disjoint groups of points that are considered to be part of a single location. | |
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | Zero-relative sequence number of this point within a series of points. | |
| xPosition [0..1] | [String](#CIM17v40-String) | X axis position. | |
| yPosition [0..1] | [String](#CIM17v40-String) | Y axis position. | |
| zPosition [0..1] | [String](#CIM17v40-String) | (if applicable) Z axis position. | |
| Location [1] | [Location](#CIM17v40-Location) | Location described by this position point. | |

{#CIM17v40-PostLineSensor}
### PostLineSensor

Inheritance path = [Sensor](#CIM17v40-Sensor) => [AuxiliaryEquipment](#CIM17v40-AuxiliaryEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PostLineSensor {

}

class Sensor {

}

Sensor <|-- PostLineSensor : inherits from
```

A sensor used mainly in overhead distribution networks as the source of both current and voltage measurements.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Terminal [1] | [Terminal](#CIM17v40-Terminal) | see [AuxiliaryEquipment](CIM17v40-AuxiliaryEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PotentialTransformer}
### PotentialTransformer

Inheritance path = [Sensor](#CIM17v40-Sensor) => [AuxiliaryEquipment](#CIM17v40-AuxiliaryEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PotentialTransformer {

+ accuracyClass : String [0..1]
+ nominalRatio : Float [0..1]
+ ptClass : String [0..1]
+ type : enum:PotentialTransformerKind [0..1]
}

class Sensor {

}

Sensor <|-- PotentialTransformer : inherits from
```

Instrument transformer (also known as Voltage Transformer) used to measure electrical qualities of the circuit that is being protected and/or monitored. Typically used as voltage transducer for the purpose of metering, protection, or sometimes auxiliary substation supply. A typical secondary voltage rating would be 120V.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| accuracyClass [0..1] | [String](#CIM17v40-String) | PT accuracy classification. | |
| nominalRatio [0..1] | [Float](#CIM17v40-Float) | Nominal ratio between the primary and secondary voltage. | |
| ptClass [0..1] | [String](#CIM17v40-String) | Potential transformer (PT) classification covering burden. | |
| type [0..1] | [PotentialTransformerKind](#CIM17v40-PotentialTransformerKind) | Potential transformer construction type. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Terminal [1] | [Terminal](#CIM17v40-Terminal) | see [AuxiliaryEquipment](CIM17v40-AuxiliaryEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PotentialTransformerInfo}
### PotentialTransformerInfo

Inheritance path = [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PotentialTransformerInfo {

+ accuracyClass : String [0..1]
+ ptClass : String [0..1]
+ ratedVoltage : Voltage [0..1]
+ nominalRatio : Ratio [0..1]
+ primaryRatio : Ratio [0..1]
+ secondaryRatio : Ratio [0..1]
+ tertiaryRatio : Ratio [0..1]
}

class AssetInfo {

}

AssetInfo <|-- PotentialTransformerInfo : inherits from
```

Properties of potential transformer asset.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| accuracyClass [0..1] | [String](#CIM17v40-String) | | |
| ptClass [0..1] | [String](#CIM17v40-String) | | |
| ratedVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Rated voltage on the primary side. | |
| nominalRatio [0..1] | [Ratio](#CIM17v40-Ratio) | | |
| primaryRatio [0..1] | [Ratio](#CIM17v40-Ratio) | Ratio for the primary winding tap changer. | |
| secondaryRatio [0..1] | [Ratio](#CIM17v40-Ratio) | Ratio for the secondary winding tap changer. | |
| tertiaryRatio [0..1] | [Ratio](#CIM17v40-Ratio) | Ratio for the tertiary winding tap changer. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PowerCutZone}
### PowerCutZone

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PowerCutZone {

+ cutLevel1 : PerCent [0..1]
+ cutLevel2 : PerCent [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- PowerCutZone : inherits from
```

An area or zone of the power system which is used for load shedding purposes.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| cutLevel1 [0..1] | [PerCent](#CIM17v40-PerCent) | First level (amount) of load to cut as a percentage of total zone load. | |
| cutLevel2 [0..1] | [PerCent](#CIM17v40-PerCent) | Second level (amount) of load to cut as a percentage of total zone load. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PowerElectronicsConnection}
### PowerElectronicsConnection

Inheritance path = [RegulatingCondEq](#CIM17v40-RegulatingCondEq) => [EnergyConnection](#CIM17v40-EnergyConnection) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PowerElectronicsConnection {

+ maxIFault : PU [0..1]
+ maxQ : ReactivePower [0..1]
+ minQ : ReactivePower [0..1]
+ p : ActivePower [0..1]
+ q : ReactivePower [0..1]
+ r : Resistance [0..1]
+ r0 : Resistance [0..1]
+ ratedS : ApparentPower [0..1]
+ ratedU : Voltage [0..1]
+ rn : Resistance [0..1]
+ x : Reactance [0..1]
+ x0 : Reactance [0..1]
+ xn : Reactance [0..1]
}

class RegulatingCondEq {

}

RegulatingCondEq <|-- PowerElectronicsConnection : inherits from
class WindTurbineType3or4Dynamics {

}

PowerElectronicsConnection --> "0..1" WindTurbineType3or4Dynamics : WindTurbineType3or4Dynamics
```

A connection to the AC network for energy production or consumption that uses power electronics rather than rotating machines.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maxIFault [0..1] | [PU](#CIM17v40-PU) | Maximum fault current this device will contribute, in per-unit of rated current, before the converter protection will trip or bypass. | |
| maxQ [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Maximum reactive power limit. This is the maximum (nameplate) limit for the unit. | |
| minQ [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Minimum reactive power limit for the unit. This is the minimum (nameplate) limit for the unit. | |
| p [0..1] | [ActivePower](#CIM17v40-ActivePower) | Active power injection. Load sign convention is used, i.e. positive sign means flow out from a node.Starting value for a steady state solution. | |
| q [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Reactive power injection. Load sign convention is used, i.e. positive sign means flow out from a node.Starting value for a steady state solution. | |
| `r [0..1]` (deprecated) | [Resistance](#CIM17v40-Resistance) | Equivalent resistance (RG) of generator. RG is considered for the calculation of all currents, except for the calculation of the peak current ip. Used for short circuit data exchange according to IEC 60909. | |
| `r0 [0..1]` (deprecated) | [Resistance](#CIM17v40-Resistance) | Zero sequence resistance of the synchronous machine. | |
| ratedS [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | Nameplate apparent power rating for the unit.The attribute shall have a positive value. | |
| ratedU [0..1] | [Voltage](#CIM17v40-Voltage) | Rated voltage (nameplate data, Ur in IEC 60909-0). It is primarily used for short circuit data exchange according to IEC 60909.The attribute shall be a positive value. | |
| `rn [0..1]` (deprecated) | [Resistance](#CIM17v40-Resistance) | Negative sequence Thevenin resistance. | |
| `x [0..1]` (deprecated) | [Reactance](#CIM17v40-Reactance) | Positive sequence Thevenin reactance. | |
| `x0 [0..1]` (deprecated) | [Reactance](#CIM17v40-Reactance) | Zero sequence Thevenin reactance. | |
| `xn [0..1]` (deprecated) | [Reactance](#CIM17v40-Reactance) | Negative sequence Thevenin reactance. | |
| WindTurbineType3or4Dynamics [0..1] | [WindTurbineType3or4Dynamics](#CIM17v40-WindTurbineType3or4Dynamics) | The wind turbine type 3 or type 4 dynamics model associated with this power electronics connection. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| controlEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [RegulatingCondEq](#CIM17v40-RegulatingCondEq) | |
| RegulatingControl [0..1] | [RegulatingControl](#CIM17v40-RegulatingControl) | see [RegulatingCondEq](CIM17v40-RegulatingCondEq) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PowerElectronicsConnectionPhase}
### PowerElectronicsConnectionPhase

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PowerElectronicsConnectionPhase {

+ p : ActivePower [0..1]
+ phase : enum:SinglePhaseKind [0..1]
+ q : ReactivePower [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- PowerElectronicsConnectionPhase : inherits from
class PowerElectronicsConnection {

}

PowerElectronicsConnectionPhase --> "1" PowerElectronicsConnection : PowerElectronicsConnection
```

A single phase of a power electronics connection.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| p [0..1] | [ActivePower](#CIM17v40-ActivePower) | Active power injection. Load sign convention is used, i.e. positive sign means flow into the equipment from the network. | |
| phase [0..1] | [SinglePhaseKind](#CIM17v40-SinglePhaseKind) | Phase of this energy producer component. If the energy producer is wye connected, the connection is from the indicated phase to the central ground or neutral point. If the energy producer is delta connected, the phase indicates an energy producer connected from the indicated phase to the next logical non-neutral phase. | |
| q [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Reactive power injection. Load sign convention is used, i.e. positive sign means flow into the equipment from the network. | |
| PowerElectronicsConnection [1] | [PowerElectronicsConnection](#CIM17v40-PowerElectronicsConnection) | Power electronics connection of this power electronics connection phase. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PowerElectronicsUnit}
### PowerElectronicsUnit

Inheritance path = [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PowerElectronicsUnit {

+ maxP : ActivePower [0..1]
+ minP : ActivePower [0..1]
}

class Equipment {

}

Equipment <|-- PowerElectronicsUnit : inherits from
class PowerElectronicsConnection {

}

PowerElectronicsUnit --> "1" PowerElectronicsConnection : PowerElectronicsConnection
```

A generating unit or battery or aggregation that connects to the AC network using power electronics rather than rotating machines.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | Maximum active power limit. This is the maximum (nameplate) limit for the unit. | |
| minP [0..1] | [ActivePower](#CIM17v40-ActivePower) | Minimum active power limit. This is the minimum (nameplate) limit for the unit. | |
| PowerElectronicsConnection [1] | [PowerElectronicsConnection](#CIM17v40-PowerElectronicsConnection) | A power electronics unit has a connection to the AC network. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PowerElectronicsWindUnit}
### PowerElectronicsWindUnit

Inheritance path = [PowerElectronicsUnit](#CIM17v40-PowerElectronicsUnit) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PowerElectronicsWindUnit {

}

class PowerElectronicsUnit {

}

PowerElectronicsUnit <|-- PowerElectronicsWindUnit : inherits from
```

A wind generating unit that connects to the AC network with power electronics rather than rotating machines or an aggregation of such units.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [PowerElectronicsUnit](CIM17v40-PowerElectronicsUnit) | |
| minP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [PowerElectronicsUnit](CIM17v40-PowerElectronicsUnit) | |
| PowerElectronicsConnection [1] | [PowerElectronicsConnection](#CIM17v40-PowerElectronicsConnection) | see [PowerElectronicsUnit](CIM17v40-PowerElectronicsUnit) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PowerQualityPricing}
### PowerQualityPricing

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PowerQualityPricing {

+ emergencyHighVoltLimit : Voltage [0..1]
+ emergencyLowVoltLimit : Voltage [0..1]
+ normalHighVoltLimit : Voltage [0..1]
+ normalLowVoltLimit : Voltage [0..1]
+ powerFactorMin : Float [0..1]
+ valueUninterruptedServiceEnergy : CostPerEnergyUnit [0..1]
+ valueUninterruptedServiceP : Float [0..1]
+ voltImbalanceViolCost : Float [0..1]
+ voltLimitViolCost : Float [0..1]
}

class Document {

}

Document <|-- PowerQualityPricing : inherits from
```

Pricing can be based on power quality.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| emergencyHighVoltLimit [0..1] | [Voltage](#CIM17v40-Voltage) | Emergency high voltage limit. | |
| emergencyLowVoltLimit [0..1] | [Voltage](#CIM17v40-Voltage) | Emergency low voltage limit. | |
| normalHighVoltLimit [0..1] | [Voltage](#CIM17v40-Voltage) | Normal high voltage limit. | |
| normalLowVoltLimit [0..1] | [Voltage](#CIM17v40-Voltage) | Normal low voltage limit. | |
| powerFactorMin [0..1] | [Float](#CIM17v40-Float) | Threshold minimum power factor for this PricingStructure, specified in instances where a special charge is levied if the actual power factor for a Service falls below the value specified here. | |
| valueUninterruptedServiceEnergy [0..1] | [CostPerEnergyUnit](#CIM17v40-CostPerEnergyUnit) | Value of uninterrupted service (Cost per energy). | |
| valueUninterruptedServiceP [0..1] | [Float](#CIM17v40-Float) | Value of uninterrupted service (Cost per active power). | |
| voltImbalanceViolCost [0..1] | [Float](#CIM17v40-Float) | Voltage imbalance violation cost (Cost per unit Voltage). | |
| voltLimitViolCost [0..1] | [Float](#CIM17v40-Float) | Voltage limit violation cost (Cost per unit Voltage). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PowerSystemResource}
### PowerSystemResource

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PowerSystemResource {

}

class IdentifiedObject {

}

IdentifiedObject <|-- PowerSystemResource : inherits from
class AssetInfo {

}

PowerSystemResource --> "0..1" AssetInfo : AssetDatasheet
class Location {

}

PowerSystemResource --> "0..1" Location : Location
class PSRType {

}

PowerSystemResource --> "0..1" PSRType : PSRType
```

A power system resource (PSR) can be an item of equipment such as a switch, an equipment container containing many individual items of equipment such as a substation, or an organisational entity such as sub-control area. Power system resources can have measurements associated.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | Datasheet information for this power system resource. | |
| Location [0..1] | [Location](#CIM17v40-Location) | Location of this power system resource. | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | Custom classification for this power system resource. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PowerSystemStabilizerDynamics}
### PowerSystemStabilizerDynamics

Inheritance path = [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PowerSystemStabilizerDynamics {

}

class DynamicsFunctionBlock {

}

DynamicsFunctionBlock <|-- PowerSystemStabilizerDynamics : inherits from
class ExcitationSystemDynamics {

}

PowerSystemStabilizerDynamics --> "1" ExcitationSystemDynamics : ExcitationSystemDynamics
```

Power system stabilizer function block whose behaviour is described by reference to a standard model <font color="#0f0f0f">or by definition of a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | Excitation system model with which this power system stabilizer model is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PowerSystemStabilizerUserDefined}
### PowerSystemStabilizerUserDefined

Inheritance path = [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PowerSystemStabilizerUserDefined {

+ proprietary : Boolean [0..1]
}

class PowerSystemStabilizerDynamics {

}

PowerSystemStabilizerDynamics <|-- PowerSystemStabilizerUserDefined : inherits from
```

<font color="#0f0f0f">Power system stabilizer</font> function block whose dynamic behaviour is described by <font color="#0f0f0f">a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| proprietary [0..1] | [Boolean](#CIM17v40-Boolean) | Behaviour is based on a proprietary model as opposed to a detailed model.true = user-defined model is proprietary with behaviour mutually understood by sending and receiving applications and parameters passed as general attributesfalse = user-defined model is explicitly defined in terms of control blocks and their input and output signals. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PowerSystemStabilizerDynamics](CIM17v40-PowerSystemStabilizerDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PowerTransformer}
### PowerTransformer

Inheritance path = [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PowerTransformer {

+ beforeShCircuitHighestOperatingCurrent : CurrentFlow [0..1]
+ beforeShCircuitHighestOperatingVoltage : Voltage [0..1]
+ beforeShortCircuitAnglePf : AngleDegrees [0..1]
+ highSideMinOperatingU : Voltage [0..1]
+ isPartOfGeneratorUnit : Boolean [0..1]
+ operationalValuesConsidered : Boolean [0..1]
+ vectorGroup : String [0..1]
}

class ConductingEquipment {

}

ConductingEquipment <|-- PowerTransformer : inherits from
```

An electrical device consisting of two or more coupled windings, with or without a magnetic core, for introducing mutual coupling between electric circuits. Transformers can be used to control voltage and phase shift (active power flow).

A power transformer may be composed of separate transformer tanks that need not be identical.

A power transformer can be modelled with or without tanks and is intended for use in both balanced and unbalanced representations. A power transformer typically has two terminals, but may have one (grounding), three or more terminals.

The inherited association ConductingEquipment.BaseVoltage should not be used. The association from TransformerEnd to BaseVoltage should be used instead.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| beforeShCircuitHighestOperatingCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | The highest operating current (Ib in IEC 60909-0) before short circuit (depends on network configuration and relevant reliability philosophy). It is used for calculation of the impedance correction factor KT defined in IEC 60909-0. | |
| beforeShCircuitHighestOperatingVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | The highest operating voltage (Ub in IEC 60909-0) before short circuit. It is used for calculation of the impedance correction factor KT defined in IEC 60909-0. This is worst case voltage on the low side winding (3.7.1 of IEC 60909:2001). Used to define operating conditions. | |
| beforeShortCircuitAnglePf [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | The angle of power factor before short circuit (phib in IEC 60909-0). It is used for calculation of the impedance correction factor KT defined in IEC 60909-0. This is the worst case power factor. Used to define operating conditions. | |
| highSideMinOperatingU [0..1] | [Voltage](#CIM17v40-Voltage) | The minimum operating voltage (uQmin in IEC 60909-0) at the high voltage side (Q side) of the unit transformer of the power station unit. A value well established from long-term operating experience of the system. It is used for calculation of the impedance correction factor KG defined in IEC 60909-0. | |
| isPartOfGeneratorUnit [0..1] | [Boolean](#CIM17v40-Boolean) | Indicates whether the machine is part of a power station unit. Used for short circuit data exchange according to IEC 60909. It has an impact on how the correction factors are calculated for transformers, since the transformer is not necessarily part of a synchronous machine and generating unit. It is not always possible to derive this information from the model. This is why the attribute is necessary. | |
| operationalValuesConsidered [0..1] | [Boolean](#CIM17v40-Boolean) | It is used to define if the data (other attributes related to short circuit data exchange) defines long term operational conditions or not. Used for short circuit data exchange according to IEC 60909. | |
| vectorGroup [0..1] | [String](#CIM17v40-String) | Vector group of the transformer for protective relaying, e.g., Dyn1. For unbalanced transformers, this may not be simply determined from the constituent winding connections and phase angle displacements.The vectorGroup string consists of the following components in the order listed: high voltage winding connection, mid voltage winding connection (for three winding transformers), phase displacement clock number from 0 to 11, low voltage winding connectionphase displacement clock number from 0 to 11. The winding connections are D (delta), Y (wye), YN (wye with neutral), Z (zigzag), ZN (zigzag with neutral), A (auto transformer). Upper case means the high voltage, lower case mid or low. The high voltage winding always has clock position 0 and is not included in the vector group string. Some examples: YNy0 (two winding wye to wye with no phase displacement), YNd11 (two winding wye to delta with 330 degrees phase displacement), YNyn0d5 (three winding transformer wye with neutral high voltage, wye with neutral mid voltage and no phase displacement, delta low voltage with 150 degrees displacement).Phase displacement is defined as the angular difference between the phasors representing the voltages between the neutral point (real or imaginary) and the corresponding terminals of two windings, a positive sequence voltage system being applied to the high-voltage terminals, following each other in alphabetical sequence if they are lettered, or in numerical sequence if they are numbered: the phasors are assumed to rotate in a counter-clockwise sense. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PowerTransformerEnd}
### PowerTransformerEnd

Inheritance path = [TransformerEnd](#CIM17v40-TransformerEnd) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PowerTransformerEnd {

+ b : Susceptance [0..1]
+ b0 : Susceptance [0..1]
+ connectionKind : enum:WindingConnection [0..1]
+ g : Conductance [0..1]
+ g0 : Conductance [0..1]
+ phaseAngleClock : Integer [0..1]
+ r : Resistance [0..1]
+ r0 : Resistance [0..1]
+ ratedS : ApparentPower [0..1]
+ ratedU : Voltage [0..1]
+ x : Reactance [0..1]
+ x0 : Reactance [0..1]
}

class TransformerEnd {

}

TransformerEnd <|-- PowerTransformerEnd : inherits from
class PowerTransformer {

}

PowerTransformerEnd --> "0..1" PowerTransformer : PowerTransformer
```

A PowerTransformerEnd is associated with each Terminal of a PowerTransformer.

The impedance values r, r0, x, and x0 of a PowerTransformerEnd represents a star equivalent as follows.

1) for a two Terminal PowerTransformer the high voltage (TransformerEnd.endNumber=1) PowerTransformerEnd has non zero values on r, r0, x, and x0 while the low voltage (TransformerEnd.endNumber=2) PowerTransformerEnd has zero values for r, r0, x, and x0. Parameters are always provided, even if the PowerTransformerEnds have the same rated voltage. In this case, the parameters are provided at the PowerTransformerEnd which has TransformerEnd.endNumber equal to 1.

2) for a three Terminal PowerTransformer the three PowerTransformerEnds represent a star equivalent with each leg in the star represented by r, r0, x, and x0 values.

3) For a three Terminal transformer each PowerTransformerEnd shall have g, g0, b and b0 values corresponding to the no load losses distributed on the three PowerTransformerEnds. The total no load loss shunt impedances may also be placed at one of the PowerTransformerEnds, preferably the end numbered 1, having the shunt values on end 1. This is the preferred way.

4) for a PowerTransformer with more than three Terminals the PowerTransformerEnd impedance values cannot be used. Instead use the TransformerMeshImpedance or split the transformer into multiple PowerTransformers.

Each PowerTransformerEnd must be contained by a PowerTransformer. Because a PowerTransformerEnd (or any other object) can not be contained by more than one parent, a PowerTransformerEnd can not have an association to an EquipmentContainer (Substation, VoltageLevel, etc).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| b [0..1] | [Susceptance](#CIM17v40-Susceptance) | Magnetizing branch susceptance (B mag). The value can be positive or negative. | |
| b0 [0..1] | [Susceptance](#CIM17v40-Susceptance) | Zero sequence magnetizing branch susceptance. | |
| connectionKind [0..1] | [WindingConnection](#CIM17v40-WindingConnection) | Kind of connection. | |
| g [0..1] | [Conductance](#CIM17v40-Conductance) | Magnetizing branch conductance. | |
| g0 [0..1] | [Conductance](#CIM17v40-Conductance) | Zero sequence magnetizing branch conductance (star-model). | |
| phaseAngleClock [0..1] | [Integer](#CIM17v40-Integer) | Terminal voltage phase angle displacement where 360 degrees are represented with clock hours. The valid values are 0 to 11. For example, for the secondary side end of a transformer with vector group code of 'Dyn11', specify the connection kind as wye with neutral and specify the phase angle of the clock as 11. The clock value of the transformer end number specified as 1, is assumed to be zero. Note the transformer end number is not assumed to be the same as the terminal sequence number. | |
| r [0..1] | [Resistance](#CIM17v40-Resistance) | Resistance (star-model) of the transformer end.The attribute shall be equal to or greater than zero for non-equivalent transformers. | |
| r0 [0..1] | [Resistance](#CIM17v40-Resistance) | Zero sequence series resistance (star-model) of the transformer end. | |
| ratedS [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | Normal apparent power rating.The attribute shall be a positive value. For a two-winding transformer the values for the high and low voltage sides shall be identical. | |
| ratedU [0..1] | [Voltage](#CIM17v40-Voltage) | Rated voltage: phase-phase for three-phase windings, and either phase-phase or phase-neutral for single-phase windings.A high voltage side, as given by TransformerEnd.endNumber, shall have a ratedU that is greater than or equal to ratedU for the lower voltage sides.The attribute shall be a positive value. | |
| x [0..1] | [Reactance](#CIM17v40-Reactance) | Positive sequence series reactance (star-model) of the transformer end. | |
| x0 [0..1] | [Reactance](#CIM17v40-Reactance) | Zero sequence series reactance of the transformer end. | |
| PowerTransformer [0..1] | [PowerTransformer](#CIM17v40-PowerTransformer) | The power transformer of this power transformer end. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| bmagSat [0..1] | [PerCent](#CIM17v40-PerCent) | see [TransformerEnd](CIM17v40-TransformerEnd) | |
| endNumber [0..1] | [Integer](#CIM17v40-Integer) | see [TransformerEnd](#CIM17v40-TransformerEnd) | |
| grounded [0..1] | [Boolean](#CIM17v40-Boolean) | see [TransformerEnd](#CIM17v40-TransformerEnd) | |
| magBaseU [0..1] | [Voltage](#CIM17v40-Voltage) | see [TransformerEnd](CIM17v40-TransformerEnd) | |
| magSatFlux [0..1] | [PerCent](#CIM17v40-PerCent) | see [TransformerEnd](CIM17v40-TransformerEnd) | |
| rground [0..1] | [Resistance](#CIM17v40-Resistance) | see [TransformerEnd](CIM17v40-TransformerEnd) | |
| xground [0..1] | [Reactance](#CIM17v40-Reactance) | see [TransformerEnd](CIM17v40-TransformerEnd) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [TransformerEnd](CIM17v40-TransformerEnd) | |
| CoreAdmittance [0..1] | [TransformerCoreAdmittance](#CIM17v40-TransformerCoreAdmittance) | see [TransformerEnd](CIM17v40-TransformerEnd) | |
| PhaseTapChanger [0..1] | [PhaseTapChanger](#CIM17v40-PhaseTapChanger) | see [TransformerEnd](CIM17v40-TransformerEnd) | |
| RatioTapChanger [0..1] | [RatioTapChanger](#CIM17v40-RatioTapChanger) | see [TransformerEnd](CIM17v40-TransformerEnd) | |
| StarImpedance [0..1] | [TransformerStarImpedance](#CIM17v40-TransformerStarImpedance) | see [TransformerEnd](CIM17v40-TransformerEnd) | |
| Terminal [0..1] | [Terminal](#CIM17v40-Terminal) | see [TransformerEnd](CIM17v40-TransformerEnd) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PowerTransformerInfo}
### PowerTransformerInfo

Inheritance path = [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PowerTransformerInfo {

}

class AssetInfo {

}

AssetInfo <|-- PowerTransformerInfo : inherits from
```

Set of power transformer data, from an equipment library.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Price}
### Price


```mermaid
classDiagram
direction TB

class Price {

+ amount : Decimal [0..1]
+ category : String [0..1]
+ direction : String [0..1]
}

class Point {

}

Price --> "0..1" Point : Point
```

The cost corresponding to a specific measure and expressed in a currency.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| amount [0..1] | [Decimal](#CIM17v40-Decimal) | A number of monetary units specified in a unit of currency. | |
| category [0..1] | [String](#CIM17v40-String) | The category of a price to be used in a price calculation. The price category is mutually agreed between System Operators. | |
| direction [0..1] | [String](#CIM17v40-String) | The direction indicates whether a System Operator pays the Market Parties or inverse. | |
| Point [0..1] | [Point](#CIM17v40-Point) | | |

{#CIM17v40-PriceDescriptor}
### PriceDescriptor


```mermaid
classDiagram
direction TB

class PriceDescriptor {

+ marketType : enum:MarketType [0..1]
+ priceType : enum:PriceTypeKind [0..1]
}

```

The price of a Commodity during a given time interval may change over time. For example, a price may be forecasted a year ahead, a month ahead, a day ahead, an hour ahead, and in real time; this is defined using the MarketType. Additionally a price may have one or more components. For example, a locational marginal energy price may be the arithmetic sum of the system price, the congestion price, and the loss price. The priceType enumeration is used determine if the price is the complete price (priceType="total") or one of potentially many constituent components.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| marketType [0..1] | [MarketType](#CIM17v40-MarketType) | The time frame for the price, using the standard conventions associated with the MarketType enumeration. | |
| priceType [0..1] | [PriceTypeKind](#CIM17v40-PriceTypeKind) | The "kind" of price being described. In general, the priceType will either be "total" to signify that the price is the price paid to buy or sell the commodity, sometimes referred to as an "all-in" price, or one of potentially many components. | |

{#CIM17v40-PricingStructure}
### PricingStructure

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PricingStructure {

+ code : String [0..1]
+ dailyCeilingUsage : Integer [0..1]
+ dailyEstimatedUsage : Integer [0..1]
+ dailyFloorUsage : Integer [0..1]
+ revenueKind : enum:RevenueKind [0..1]
+ taxExemption : Boolean [0..1]
}

class Document {

}

Document <|-- PricingStructure : inherits from
class ServiceCategory {

}

PricingStructure --> "1" ServiceCategory : ServiceCategory
```

Grouping of pricing components and prices used in the creation of customer charges and the eligibility criteria under which these terms may be offered to a customer. The reasons for grouping include state, customer classification, site characteristics, classification (i.e. fee price structure, deposit price structure, electric service price structure, etc.) and accounting requirements.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| code [0..1] | [String](#CIM17v40-String) | Unique user-allocated key for this pricing structure, used by company representatives to identify the correct price structure for allocating to a customer. For rate schedules it is often prefixed by a state code. | |
| dailyCeilingUsage [0..1] | [Integer](#CIM17v40-Integer) | Absolute maximum valid non-demand usage quantity used in validating a customer's billed non-demand usage. | |
| dailyEstimatedUsage [0..1] | [Integer](#CIM17v40-Integer) | Used in place of actual computed estimated average when history of usage is not available, and typically manually entered by customer accounting. | |
| dailyFloorUsage [0..1] | [Integer](#CIM17v40-Integer) | Absolute minimum valid non-demand usage quantity used in validating a customer's billed non-demand usage. | |
| revenueKind [0..1] | [RevenueKind](#CIM17v40-RevenueKind) | (accounting) Kind of revenue, often used to determine the grace period allowed, before collection actions are taken on a customer (grace periods vary between revenue classes). | |
| taxExemption [0..1] | [Boolean](#CIM17v40-Boolean) | True if this pricing structure is not taxable. | |
| ServiceCategory [1] | [ServiceCategory](#CIM17v40-ServiceCategory) | Service category to which this pricing structure applies. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PrimeMover}
### PrimeMover

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PrimeMover {

+ primeMoverRating : Float [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- PrimeMover : inherits from
```

The machine used to develop mechanical energy used to drive a generator.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| primeMoverRating [0..1] | [Float](#CIM17v40-Float) | Rating of prime mover. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Procedure}
### Procedure

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Procedure {

+ instruction : String [0..1]
+ kind : enum:ProcedureKind [0..1]
+ sequenceNumber : String [0..1]
}

class Document {

}

Document <|-- Procedure : inherits from
```

Documented procedure for various types of work or work tasks on assets.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| instruction [0..1] | [String](#CIM17v40-String) | Textual description of this procedure. | |
| kind [0..1] | [ProcedureKind](#CIM17v40-ProcedureKind) | Kind of procedure. | |
| sequenceNumber [0..1] | [String](#CIM17v40-String) | Sequence number in a sequence of procedures being performed. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ProcedureDataSet}
### ProcedureDataSet

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ProcedureDataSet {

+ completedDateTime : DateTime [0..1]
}

class Document {

}

Document <|-- ProcedureDataSet : inherits from
class Asset {

}

ProcedureDataSet --> "0..1" Asset : Asset
class Procedure {

}

ProcedureDataSet --> "0..1" Procedure : Procedure
class WorkTask {

}

ProcedureDataSet --> "0..1" WorkTask : WorkTask
```

A data set recorded each time a procedure is executed. Observed results are captured in associated measurement values and/or values for properties relevant to the type of procedure performed.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| completedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time procedure was completed. | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | Asset to which this procedure data set applies. | |
| Procedure [0..1] | [Procedure](#CIM17v40-Procedure) | Procedure capturing this data set. | |
| WorkTask [0..1] | [WorkTask](#CIM17v40-WorkTask) | Work task that created this procedure data set. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Process}
### Process

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Process {

+ classificationType : String [0..1]
+ processType : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Process : inherits from
```

The formal specification of a set of business transactions having the same business goal.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| classificationType [0..1] | [String](#CIM17v40-String) | The classification mechanism used to group a set of objects together within a business process. The grouping may be of a detailed or a summary nature. | |
| processType [0..1] | [String](#CIM17v40-String) | The kind of business process. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ProductAssetModel}
### (informative) ProductAssetModel

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ProductAssetModel {

+ catalogueNumber : String [0..1]
+ corporateStandardKind : enum:CorporateStandardKind [0..1]
+ drawingNumber : String [0..1]
+ instructionManual : String [0..1]
+ modelNumber : String [0..1]
+ modelVersion : String [0..1]
+ overallLength : Length [0..1]
+ styleNumber : String [0..1]
+ usageKind : enum:AssetModelUsageKind [0..1]
+ weightTotal : Mass [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ProductAssetModel : inherits from
class AssetInfo {

}

ProductAssetModel --> "0..1" AssetInfo : AssetInfo
class CatalogAssetType {

}

ProductAssetModel --> "0..1" CatalogAssetType : CatalogAssetType
class Manufacturer {

}

ProductAssetModel --> "0..1" Manufacturer : Manufacturer
```

Asset model by a specific manufacturer.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| catalogueNumber [0..1] | [String](#CIM17v40-String) | Catalogue number for asset model. | |
| corporateStandardKind [0..1] | [CorporateStandardKind](#CIM17v40-CorporateStandardKind) | Kind of corporate standard for this asset model. | |
| drawingNumber [0..1] | [String](#CIM17v40-String) | Drawing number for asset model. | |
| instructionManual [0..1] | [String](#CIM17v40-String) | Reference manual or instruction book for this asset model. | |
| modelNumber [0..1] | [String](#CIM17v40-String) | Manufacturer's model number. | |
| modelVersion [0..1] | [String](#CIM17v40-String) | Version number for product model, which indicates vintage of the product. | |
| overallLength [0..1] | [Length](#CIM17v40-Length) | Overall length of this asset model. | |
| styleNumber [0..1] | [String](#CIM17v40-String) | Style number of asset model. | |
| usageKind [0..1] | [AssetModelUsageKind](#CIM17v40-AssetModelUsageKind) | Intended usage for this asset model. | |
| weightTotal [0..1] | [Mass](#CIM17v40-Mass) | Total manufactured weight of asset. | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | Asset information (nameplate) for this product asset model. | |
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | Catalog asset type to which this product asset model conforms. | |
| Manufacturer [0..1] | [Manufacturer](#CIM17v40-Manufacturer) | Manufacturer of this asset model. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ProductBid}
### ProductBid

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ProductBid {

}

class IdentifiedObject {

}

IdentifiedObject <|-- ProductBid : inherits from
class Bid {

}

ProductBid --> "1" Bid : Bid
class MarketProduct {

}

ProductBid --> "1" MarketProduct : MarketProduct
```

Component of a bid that pertains to one market product.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Bid [1] | [Bid](#CIM17v40-Bid) | A bid comprises one or more product bids of market products | |
| MarketProduct [1] | [MarketProduct](#CIM17v40-MarketProduct) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Profile}
### Profile

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Profile {

}

class IdentifiedObject {

}

IdentifiedObject <|-- Profile : inherits from
```

A profile is a simpler curve type.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ProfileData}
### ProfileData


```mermaid
classDiagram
direction TB

class ProfileData {

+ bidPrice : Float [0..1]
+ capacityLevel : ActivePower [0..1]
+ energyLevel : RealEnergy [0..1]
+ minimumLevel : Float [0..1]
+ sequenceNumber : Integer [0..1]
+ startDateTime : DateTime [0..1]
+ stopDateTime : DateTime [0..1]
}

```

Data for profile.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| bidPrice [0..1] | [Float](#CIM17v40-Float) | Bid price associated with contract | |
| capacityLevel [0..1] | [ActivePower](#CIM17v40-ActivePower) | Capacity level for the profile, in MW. | |
| energyLevel [0..1] | [RealEnergy](#CIM17v40-RealEnergy) | Energy level for the profile, in MWH. | |
| minimumLevel [0..1] | [Float](#CIM17v40-Float) | Minimum MW value of contract | |
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | Sequence to provide item numbering for the profile. { greater than or equal to 1 } | |
| startDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Start date/time for this profile. | |
| stopDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Stop date/time for this profile. | |

{#CIM17v40-Project}
### (informative) Project

Inheritance path = [WorkDocument](#CIM17v40-WorkDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Project {

+ budget : Money [0..1]
}

class WorkDocument {

}

WorkDocument <|-- Project : inherits from
class BusinessCase {

}

Project --> "0..1" BusinessCase : BusinessCase
class ErpProjectAccounting {

}

Project --> "1" ErpProjectAccounting : ErpProjectAccounting
class Project {

}

Project --> "0..1" Project : ParentProject
```

A collection of related work. For construction projects and maintenance projects, multiple phases may be performed.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| budget [0..1] | [Money](#CIM17v40-Money) | Overall project budget. | |
| `BusinessCase [0..1]` (informative) | [BusinessCase](#CIM17v40-BusinessCase) | | |
| `ErpProjectAccounting [1]` (informative) | [ErpProjectAccounting](#CIM17v40-ErpProjectAccounting) | | |
| `ParentProject [0..1]` (informative) | [Project](#CIM17v40-Project) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ProjectAlternative}
### ProjectAlternative

Inheritance path = [NetworkModelProjectRelationship](#CIM17v40-NetworkModelProjectRelationship) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ProjectAlternative {

}

class NetworkModelProjectRelationship {

}

NetworkModelProjectRelationship <|-- ProjectAlternative : inherits from
```

Project B is an alternative to project A. Project A is the primary alternative.

Multiple project alternatives should not be selected into a single network study case.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ProjectA [1]` (informative) | [NetworkModelProjectComponent](#CIM17v40-NetworkModelProjectComponent) | see [NetworkModelProjectRelationship](CIM17v40-NetworkModelProjectRelationship) | |
| `ProjectB [1]` (informative) | [NetworkModelProjectComponent](#CIM17v40-NetworkModelProjectComponent) | see [NetworkModelProjectRelationship](CIM17v40-NetworkModelProjectRelationship) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ProjectDependency}
### ProjectDependency

Inheritance path = [NetworkModelProjectRelationship](#CIM17v40-NetworkModelProjectRelationship) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ProjectDependency {

}

class NetworkModelProjectRelationship {

}

NetworkModelProjectRelationship <|-- ProjectDependency : inherits from
```

Project A change sets should be applied before Project B during case creation.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ProjectA [1]` (informative) | [NetworkModelProjectComponent](#CIM17v40-NetworkModelProjectComponent) | see [NetworkModelProjectRelationship](CIM17v40-NetworkModelProjectRelationship) | |
| `ProjectB [1]` (informative) | [NetworkModelProjectComponent](#CIM17v40-NetworkModelProjectComponent) | see [NetworkModelProjectRelationship](CIM17v40-NetworkModelProjectRelationship) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PropertyOrganisationRole}
### PropertyOrganisationRole

Inheritance path = [OrganisationRole](#CIM17v40-OrganisationRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PropertyOrganisationRole {

}

class OrganisationRole {

}

OrganisationRole <|-- PropertyOrganisationRole : inherits from
class LandProperty {

}

PropertyOrganisationRole --> "0..1" LandProperty : LandProperty
```

Role an organisation plays with respect to property (for example, the organisation may be the owner, renter, occupier, taxiing authority, etc.).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `LandProperty [0..1]` (informative) | [LandProperty](#CIM17v40-LandProperty) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Organisation [0..1] | [Organisation](#CIM17v40-Organisation) | see [OrganisationRole](CIM17v40-OrganisationRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PropertyUnit}
### (informative) PropertyUnit

Inheritance path = [WorkIdentifiedObject](#CIM17v40-WorkIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PropertyUnit {

+ accountingUsage : String [0..1]
+ activityCode : enum:WorkActionKind [0..1]
+ propertyAccount : String [0..1]
+ status : Status [0..1]
}

class WorkIdentifiedObject {

}

WorkIdentifiedObject <|-- PropertyUnit : inherits from
```

Unit of property for reporting purposes.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| accountingUsage [0..1] | [String](#CIM17v40-String) | A code that identifies appropriate type of property accounts such as distribution, streetlgihts, communications. | |
| activityCode [0..1] | [WorkActionKind](#CIM17v40-WorkActionKind) | Activity code identifies a specific and distinguishable work action. | |
| propertyAccount [0..1] | [String](#CIM17v40-String) | Used for property record accounting. For example, in the USA, this would be a FERC account. | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ProportionalDistributionComponent}
### ProportionalDistributionComponent

Inheritance path = [EnergyComponent](#CIM17v40-EnergyComponent) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ProportionalDistributionComponent {

+ distributionFactor : ActivePower [0..1]
}

class EnergyComponent {

}

EnergyComponent <|-- ProportionalDistributionComponent : inherits from
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| distributionFactor [0..1] | [ActivePower](#CIM17v40-ActivePower) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ProprietaryParameterDynamics}
### ProprietaryParameterDynamics


```mermaid
classDiagram
direction TB

class ProprietaryParameterDynamics {

+ booleanParameterValue : Boolean [0..1]
+ floatParameterValue : Float [0..1]
+ integerParameterValue : Integer [0..1]
+ parameterNumber : Integer [0..1]
}

class AsynchronousMachineUserDefined {

}

ProprietaryParameterDynamics --> "0..1" AsynchronousMachineUserDefined : AsynchronousMachineUserDefined
class CSCUserDefined {

}

ProprietaryParameterDynamics --> "0..1" CSCUserDefined : CSCUserDefined
class DiscontinuousExcitationControlUserDefined {

}

ProprietaryParameterDynamics --> "0..1" DiscontinuousExcitationControlUserDefined : DiscontinuousExcitationControlUserDefined
class ExcitationSystemUserDefined {

}

ProprietaryParameterDynamics --> "0..1" ExcitationSystemUserDefined : ExcitationSystemUserDefined
class LoadUserDefined {

}

ProprietaryParameterDynamics --> "0..1" LoadUserDefined : LoadUserDefined
class MechanicalLoadUserDefined {

}

ProprietaryParameterDynamics --> "0..1" MechanicalLoadUserDefined : MechanicalLoadUserDefined
class OverexcitationLimiterUserDefined {

}

ProprietaryParameterDynamics --> "0..1" OverexcitationLimiterUserDefined : OverexcitationLimiterUserDefined
class PFVArControllerType1UserDefined {

}

ProprietaryParameterDynamics --> "0..1" PFVArControllerType1UserDefined : PFVArControllerType1UserDefined
class PFVArControllerType2UserDefined {

}

ProprietaryParameterDynamics --> "0..1" PFVArControllerType2UserDefined : PFVArControllerType2UserDefined
class PowerSystemStabilizerUserDefined {

}

ProprietaryParameterDynamics --> "0..1" PowerSystemStabilizerUserDefined : PowerSystemStabilizerUserDefined
class SVCUserDefined {

}

ProprietaryParameterDynamics --> "0..1" SVCUserDefined : SVCUserDefined
class SynchronousMachineUserDefined {

}

ProprietaryParameterDynamics --> "0..1" SynchronousMachineUserDefined : SynchronousMachineUserDefined
class TurbineGovernorUserDefined {

}

ProprietaryParameterDynamics --> "0..1" TurbineGovernorUserDefined : TurbineGovernorUserDefined
class TurbineLoadControllerUserDefined {

}

ProprietaryParameterDynamics --> "0..1" TurbineLoadControllerUserDefined : TurbineLoadControllerUserDefined
class UnderexcitationLimiterUserDefined {

}

ProprietaryParameterDynamics --> "0..1" UnderexcitationLimiterUserDefined : UnderexcitationLimiterUserDefined
class VoltageAdjusterUserDefined {

}

ProprietaryParameterDynamics --> "0..1" VoltageAdjusterUserDefined : VoltageAdjusterUserDefined
class VoltageCompensatorUserDefined {

}

ProprietaryParameterDynamics --> "0..1" VoltageCompensatorUserDefined : VoltageCompensatorUserDefined
class VSCUserDefined {

}

ProprietaryParameterDynamics --> "0..1" VSCUserDefined : VSCUserDefined
class WindPlantUserDefined {

}

ProprietaryParameterDynamics --> "0..1" WindPlantUserDefined : WindPlantUserDefined
class WindType1or2UserDefined {

}

ProprietaryParameterDynamics --> "0..1" WindType1or2UserDefined : WindType1or2UserDefined
class WindType3or4UserDefined {

}

ProprietaryParameterDynamics --> "0..1" WindType3or4UserDefined : WindType3or4UserDefined
```

Supports definition of one or more parameters of several different datatypes for use by proprietary user-defined models.

This class does not inherit from IdentifiedObject since it is not intended that a single instance of it be referenced by more than one proprietary user-defined model instance.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| booleanParameterValue [0..1] | [Boolean](#CIM17v40-Boolean) | Boolean parameter value. If this attribute is populated, integerParameterValue and floatParameterValue will not be. | |
| floatParameterValue [0..1] | [Float](#CIM17v40-Float) | Floating point parameter value. If this attribute is populated, booleanParameterValue and integerParameterValue will not be. | |
| integerParameterValue [0..1] | [Integer](#CIM17v40-Integer) | Integer parameter value. If this attribute is populated, booleanParameterValue and floatParameterValue will not be. | |
| parameterNumber [0..1] | [Integer](#CIM17v40-Integer) | Sequence number of the parameter among the set of parameters associated with the related proprietary user-defined model. | |
| AsynchronousMachineUserDefined [0..1] | [AsynchronousMachineUserDefined](#CIM17v40-AsynchronousMachineUserDefined) | Proprietary user-defined model with which this parameter is associated. | |
| CSCUserDefined [0..1] | [CSCUserDefined](#CIM17v40-CSCUserDefined) | Proprietary user-defined model with which this parameter is associated. | |
| DiscontinuousExcitationControlUserDefined [0..1] | [DiscontinuousExcitationControlUserDefined](#CIM17v40-DiscontinuousExcitationControlUserDefined) | Proprietary user-defined model with which this parameter is associated. | |
| ExcitationSystemUserDefined [0..1] | [ExcitationSystemUserDefined](#CIM17v40-ExcitationSystemUserDefined) | Proprietary user-defined model with which this parameter is associated. | |
| LoadUserDefined [0..1] | [LoadUserDefined](#CIM17v40-LoadUserDefined) | Proprietary user-defined model with which this parameter is associated. | |
| MechanicalLoadUserDefined [0..1] | [MechanicalLoadUserDefined](#CIM17v40-MechanicalLoadUserDefined) | Proprietary user-defined model with which this parameter is associated. | |
| OverexcitationLimiterUserDefined [0..1] | [OverexcitationLimiterUserDefined](#CIM17v40-OverexcitationLimiterUserDefined) | Proprietary user-defined model with which this parameter is associated. | |
| PFVArControllerType1UserDefined [0..1] | [PFVArControllerType1UserDefined](#CIM17v40-PFVArControllerType1UserDefined) | Proprietary user-defined model with which this parameter is associated. | |
| PFVArControllerType2UserDefined [0..1] | [PFVArControllerType2UserDefined](#CIM17v40-PFVArControllerType2UserDefined) | Proprietary user-defined model with which this parameter is associated. | |
| PowerSystemStabilizerUserDefined [0..1] | [PowerSystemStabilizerUserDefined](#CIM17v40-PowerSystemStabilizerUserDefined) | Proprietary user-defined model with which this parameter is associated. | |
| SVCUserDefined [0..1] | [SVCUserDefined](#CIM17v40-SVCUserDefined) | Proprietary user-defined model with which this parameter is associated. | |
| SynchronousMachineUserDefined [0..1] | [SynchronousMachineUserDefined](#CIM17v40-SynchronousMachineUserDefined) | Proprietary user-defined model with which this parameter is associated. | |
| TurbineGovernorUserDefined [0..1] | [TurbineGovernorUserDefined](#CIM17v40-TurbineGovernorUserDefined) | Proprietary user-defined model with which this parameter is associated. | |
| TurbineLoadControllerUserDefined [0..1] | [TurbineLoadControllerUserDefined](#CIM17v40-TurbineLoadControllerUserDefined) | Proprietary user-defined model with which this parameter is associated. | |
| UnderexcitationLimiterUserDefined [0..1] | [UnderexcitationLimiterUserDefined](#CIM17v40-UnderexcitationLimiterUserDefined) | Proprietary user-defined model with which this parameter is associated. | |
| VoltageAdjusterUserDefined [0..1] | [VoltageAdjusterUserDefined](#CIM17v40-VoltageAdjusterUserDefined) | Proprietary user-defined model with which this parameter is associated. | |
| VoltageCompensatorUserDefined [0..1] | [VoltageCompensatorUserDefined](#CIM17v40-VoltageCompensatorUserDefined) | Proprietary user-defined model with which this parameter is associated. | |
| VSCUserDefined [0..1] | [VSCUserDefined](#CIM17v40-VSCUserDefined) | Proprietary user-defined model with which this parameter is associated. | |
| WindPlantUserDefined [0..1] | [WindPlantUserDefined](#CIM17v40-WindPlantUserDefined) | Proprietary user-defined model with which this parameter is associated. | |
| WindType1or2UserDefined [0..1] | [WindType1or2UserDefined](#CIM17v40-WindType1or2UserDefined) | Proprietary user-defined model with which this parameter is associated. | |
| WindType3or4UserDefined [0..1] | [WindType3or4UserDefined](#CIM17v40-WindType3or4UserDefined) | Proprietary user-defined model with which this parameter is associated. | |

{#CIM17v40-ProtectedSwitch}
### ProtectedSwitch

Inheritance path = [Switch](#CIM17v40-Switch) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ProtectedSwitch {

+ breakingCapacity : CurrentFlow [0..1]
}

class Switch {

}

Switch <|-- ProtectedSwitch : inherits from
```

A ProtectedSwitch is a switching device that can be operated by ProtectionEquipment.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| breakingCapacity [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | The maximum fault current a breaking device can break safely under prescribed conditions of use. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| locked [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| normalOpen [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| open [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [Switch](CIM17v40-Switch) | |
| retained [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| `switchOnCount [0..1]` (deprecated) | [Integer](#CIM17v40-Integer) | see [Switch](#CIM17v40-Switch) | |
| `switchOnDate [0..1]` (deprecated) | [DateTime](#CIM17v40-DateTime) | see [Switch](#CIM17v40-Switch) | |
| `CompositeSwitch [0..1]` (OfAggregate) | [CompositeSwitch](#CIM17v40-CompositeSwitch) | see [Switch](CIM17v40-Switch) | |
| SwitchAction [0..1] | [SwitchAction](#CIM17v40-SwitchAction) | see [Switch](CIM17v40-Switch) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ProtectionEquipment}
### (informative) ProtectionEquipment

Inheritance path = [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ProtectionEquipment {

+ highLimit : Float [0..1]
+ lowLimit : Float [0..1]
+ powerDirectionFlag : Boolean [0..1]
+ relayDelayTime : Seconds [0..1]
+ unitMultiplier : enum:UnitMultiplier [0..1]
+ unitSymbol : enum:UnitSymbol [0..1]
}

class Equipment {

}

Equipment <|-- ProtectionEquipment : inherits from
```

An electrical device designed to respond to input conditions in a prescribed manner and after specified conditions are met to cause contact operation or similar abrupt change in associated electric control circuits, or simply to display the detected condition. Protection equipment is associated with conducting equipment and usually operate circuit breakers.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| highLimit [0..1] | [Float](#CIM17v40-Float) | The maximum allowable value. | |
| lowLimit [0..1] | [Float](#CIM17v40-Float) | The minimum allowable value. | |
| powerDirectionFlag [0..1] | [Boolean](#CIM17v40-Boolean) | Direction same as positive active power flow value. | |
| relayDelayTime [0..1] | [Seconds](#CIM17v40-Seconds) | The time delay from detection of abnormal conditions to relay operation. | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | The unit multiplier of the value. | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | The unit of measure of the value. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ProtectionEquipmentInfo}
### ProtectionEquipmentInfo

Inheritance path = [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ProtectionEquipmentInfo {

+ groundTrip : CurrentFlow [0..1]
+ phaseTrip : CurrentFlow [0..1]
}

class AssetInfo {

}

AssetInfo <|-- ProtectionEquipmentInfo : inherits from
```

Properties of protection equipment asset.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| groundTrip [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Actual ground trip for this type of relay, if applicable. | |
| phaseTrip [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Actual phase trip for this type of relay, if applicable. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ProtectiveAction}
### ProtectiveAction

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ProtectiveAction {

+ enabled : Boolean [0..1]
+ normalEnabled : Boolean [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ProtectiveAction : inherits from
class Gate {

}

ProtectiveAction --> "0..1" Gate : GateComCondition
class Gate {

}

ProtectiveAction --> "0..1" Gate : GateEnabledCondition
class ProtectionEquipment {

}

ProtectiveAction --> "0..1" ProtectionEquipment : ProtectionEquipment
class ProtectiveActionCollection {

}

ProtectiveAction --> "1" ProtectiveActionCollection : ProtectiveActionCollection
```

A protective action for supporting the integrity of the power system.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | The status of the class set by operation or by signal. Optional field that will override other status fields. | |
| normalEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | The default/normal value used when other active signal/values are missing. | |
| `GateComCondition [0..1]` (informative) | [Gate](#CIM17v40-Gate) | | |
| `GateEnabledCondition [0..1]` (informative) | [Gate](#CIM17v40-Gate) | Association to a Gate that through a gate logic and input pin defines enabling of the ProtectiveAction. | |
| `ProtectionEquipment [0..1]` (informative) | [ProtectionEquipment](#CIM17v40-ProtectionEquipment) | | |
| `ProtectiveActionCollection [1]` (informative) | [ProtectiveActionCollection](#CIM17v40-ProtectiveActionCollection) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ProtectiveActionAdjustment}
### ProtectiveActionAdjustment

Inheritance path = [ProtectiveAction](#CIM17v40-ProtectiveAction) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ProtectiveActionAdjustment {

+ byPercentage : PerCent [0..1]
+ byValue : Float [0..1]
+ kind : enum:ProtectiveActionAdjustmentKind [0..1]
+ reduce : Boolean [0..1]
+ setValue : Float [0..1]
}

class ProtectiveAction {

}

ProtectiveAction <|-- ProtectiveActionAdjustment : inherits from
class ConductingEquipment {

}

ProtectiveActionAdjustment --> "1" ConductingEquipment : ConductingEquipment
class DCConductingEquipment {

}

ProtectiveActionAdjustment --> "1" DCConductingEquipment : DCConductingEquipment
class Measurement {

}

ProtectiveActionAdjustment --> "0..1" Measurement : Measurement
```

Protective actions on non-switching equipment. The operating condition is adjusted.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| byPercentage [0..1] | [PerCent](#CIM17v40-PerCent) | The adjustment is given in percent of the active value. | |
| byValue [0..1] | [Float](#CIM17v40-Float) | The adjustment is given in value of the active value. | |
| kind [0..1] | [ProtectiveActionAdjustmentKind](#CIM17v40-ProtectiveActionAdjustmentKind) | Defines the kind of adjustment that should be done. With this value the correct attribute containing the value needs to be used. | |
| reduce [0..1] | [Boolean](#CIM17v40-Boolean) | If true, the adjusted value is an reduction. Other wise it is an increase in the value. | |
| setValue [0..1] | [Float](#CIM17v40-Float) | The adjustment is given by a new active value. | |
| `ConductingEquipment [1]` (informative) | [ConductingEquipment](#CIM17v40-ConductingEquipment) | ConductingEquipment whose operating condition is changed when this protective action adjustment gets activated. | |
| `DCConductingEquipment [1]` (informative) | [DCConductingEquipment](#CIM17v40-DCConductingEquipment) | The operating condition to the Conducting Equipment is changed when protective action adjustment is activated. | |
| `Measurement [0..1]` (informative) | [Measurement](#CIM17v40-Measurement) | The measurement is used to control the operation of an equipment. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [ProtectiveAction](#CIM17v40-ProtectiveAction) | |
| normalEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [ProtectiveAction](#CIM17v40-ProtectiveAction) | |
| `GateComCondition [0..1]` (informative) | [Gate](#CIM17v40-Gate) | see [ProtectiveAction](CIM17v40-ProtectiveAction) | |
| `GateEnabledCondition [0..1]` (informative) | [Gate](#CIM17v40-Gate) | see [ProtectiveAction](CIM17v40-ProtectiveAction) | |
| `ProtectionEquipment [0..1]` (informative) | [ProtectionEquipment](#CIM17v40-ProtectionEquipment) | see [ProtectiveAction](CIM17v40-ProtectiveAction) | |
| `ProtectiveActionCollection [1]` (informative) | [ProtectiveActionCollection](#CIM17v40-ProtectiveActionCollection) | see [ProtectiveAction](CIM17v40-ProtectiveAction) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ProtectiveActionCollection}
### (informative) ProtectiveActionCollection

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ProtectiveActionCollection {

}

class IdentifiedObject {

}

IdentifiedObject <|-- ProtectiveActionCollection : inherits from
```

A collection of protective actions to protect the integrity of the power system.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ProtectiveActionEquipment}
### ProtectiveActionEquipment

Inheritance path = [ProtectiveAction](#CIM17v40-ProtectiveAction) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ProtectiveActionEquipment {

+ inService : Boolean [0..1]
}

class ProtectiveAction {

}

ProtectiveAction <|-- ProtectiveActionEquipment : inherits from
class Equipment {

}

ProtectiveActionEquipment --> "1" Equipment : Equipment
```

Protective action to put an Equipment in-service/out-of-service.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | If true the equipment is put in-service, otherwise out-of-service. | |
| `Equipment [1]` (informative) | [Equipment](#CIM17v40-Equipment) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [ProtectiveAction](#CIM17v40-ProtectiveAction) | |
| normalEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [ProtectiveAction](#CIM17v40-ProtectiveAction) | |
| `GateComCondition [0..1]` (informative) | [Gate](#CIM17v40-Gate) | see [ProtectiveAction](CIM17v40-ProtectiveAction) | |
| `GateEnabledCondition [0..1]` (informative) | [Gate](#CIM17v40-Gate) | see [ProtectiveAction](CIM17v40-ProtectiveAction) | |
| `ProtectionEquipment [0..1]` (informative) | [ProtectionEquipment](#CIM17v40-ProtectionEquipment) | see [ProtectiveAction](CIM17v40-ProtectiveAction) | |
| `ProtectiveActionCollection [1]` (informative) | [ProtectiveActionCollection](#CIM17v40-ProtectiveActionCollection) | see [ProtectiveAction](CIM17v40-ProtectiveAction) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ProtectiveActionRegulation}
### ProtectiveActionRegulation

Inheritance path = [ProtectiveAction](#CIM17v40-ProtectiveAction) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ProtectiveActionRegulation {

+ isRegulating : Boolean [0..1]
+ targetValue : Float [0..1]
}

class ProtectiveAction {

}

ProtectiveAction <|-- ProtectiveActionRegulation : inherits from
class RegulatingControl {

}

ProtectiveActionRegulation --> "1" RegulatingControl : RegulatingControl
```

Protective action to change regulation to Equipment.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| isRegulating [0..1] | [Boolean](#CIM17v40-Boolean) | If true the regulator is put in-service, otherwise out-of-service (no regulation). | |
| targetValue [0..1] | [Float](#CIM17v40-Float) | The target value specified the new case input for the regulator. The value has the units appropriate to the mode attribute. The protective action does not change the mode attribute. | |
| `RegulatingControl [1]` (informative) | [RegulatingControl](#CIM17v40-RegulatingControl) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [ProtectiveAction](#CIM17v40-ProtectiveAction) | |
| normalEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [ProtectiveAction](#CIM17v40-ProtectiveAction) | |
| `GateComCondition [0..1]` (informative) | [Gate](#CIM17v40-Gate) | see [ProtectiveAction](CIM17v40-ProtectiveAction) | |
| `GateEnabledCondition [0..1]` (informative) | [Gate](#CIM17v40-Gate) | see [ProtectiveAction](CIM17v40-ProtectiveAction) | |
| `ProtectionEquipment [0..1]` (informative) | [ProtectionEquipment](#CIM17v40-ProtectionEquipment) | see [ProtectiveAction](CIM17v40-ProtectiveAction) | |
| `ProtectiveActionCollection [1]` (informative) | [ProtectiveActionCollection](#CIM17v40-ProtectiveActionCollection) | see [ProtectiveAction](CIM17v40-ProtectiveAction) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ProvidedBilateralPoint}
### ProvidedBilateralPoint

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ProvidedBilateralPoint {

}

class IdentifiedObject {

}

IdentifiedObject <|-- ProvidedBilateralPoint : inherits from
class BilateralExchangeActor {

}

ProvidedBilateralPoint --> "1" BilateralExchangeActor : BilateralExchangeActor
class IOPoint {

}

ProvidedBilateralPoint --> "0..1" IOPoint : IOPoint
```

Allows declaration of ICCP points to be provided through a Bilateral Table agreement.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BilateralExchangeActor [1] | [BilateralExchangeActor](#CIM17v40-BilateralExchangeActor) | Remote peer that will receive ICCP information in a Bilateral table. | |
| IOPoint [0..1] | [IOPoint](#CIM17v40-IOPoint) | Measurement or control for the bilateral ICCP point. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Pss1}
### Pss1

Inheritance path = [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Pss1 {

+ kf : Float [0..1]
+ komega : Float [0..1]
+ kpe : Float [0..1]
+ ks : Float [0..1]
+ pmin : PU [0..1]
+ t10 : Seconds [0..1]
+ t5 : Seconds [0..1]
+ t6 : Seconds [0..1]
+ t7 : Seconds [0..1]
+ t8 : Seconds [0..1]
+ t9 : Seconds [0..1]
+ tpe : Seconds [0..1]
+ vadat : Boolean [0..1]
+ vsmn : PU [0..1]
+ vsmx : PU [0..1]
}

class PowerSystemStabilizerDynamics {

}

PowerSystemStabilizerDynamics <|-- Pss1 : inherits from
```

Italian PSS with three inputs (speed, frequency, power).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kf [0..1] | [Float](#CIM17v40-Float) | Frequency power input gain (<i>K</i><i><sub>F</sub></i>). Typical value = 5. | |
| komega [0..1] | [Float](#CIM17v40-Float) | Shaft speed power input gain (<i>K</i><i><sub>omega</sub></i>). Typical value = 0. | |
| kpe [0..1] | [Float](#CIM17v40-Float) | Electric power input gain (<i>K</i><i><sub>PE</sub></i>). Typical value = 0,3. | |
| ks [0..1] | [Float](#CIM17v40-Float) | PSS gain (<i>Ks</i>). Typical value = 1. | |
| pmin [0..1] | [PU](#CIM17v40-PU) | Minimum power PSS enabling (<i>Pmin</i>). Typical value = 0,25. | |
| t10 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T</i><i><sub>10</sub></i>) (&gt;= 0). Typical value = 0. | |
| t5 [0..1] | [Seconds](#CIM17v40-Seconds) | Washout (<i>T</i><i><sub>5</sub></i>) (&gt;= 0). Typical value = 3,5. | |
| t6 [0..1] | [Seconds](#CIM17v40-Seconds) | Filter time constant (<i>T</i><i><sub>6</sub></i>) (&gt;= 0). Typical value = 0. | |
| t7 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T</i><i><sub>7</sub></i>) (&gt;= 0). If = 0, both blocks are bypassed. Typical value = 0. | |
| t8 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T</i><i><sub>8</sub></i>) (&gt;= 0). Typical value = 0. | |
| t9 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T</i><i><sub>9</sub></i>) (&gt;= 0). If = 0, both blocks are bypassed. Typical value = 0. | |
| tpe [0..1] | [Seconds](#CIM17v40-Seconds) | Electric power filter time constant (<i>T</i><i><sub>PE</sub></i>) (&gt;= 0). Typical value = 0,05. | |
| vadat [0..1] | [Boolean](#CIM17v40-Boolean) | <font color="#0f0f0f">Signal selector (<i>V</i><i><sub>ADAT</sub></i>).</font><font color="#0f0f0f">true = closed (generator power is greater than <i>Pmin</i>)</font><font color="#0f0f0f">false = open (<i>Pe</i> is smaller than <i>Pmin</i>).</font><font color="#0f0f0f">Typical value = true.</font> | |
| vsmn [0..1] | [PU](#CIM17v40-PU) | Stabilizer output maximum limit (<i>V</i><i><sub>SMN</sub></i>). Typical value = -0,06. | |
| vsmx [0..1] | [PU](#CIM17v40-PU) | Stabilizer output minimum limit (<i>V</i><i><sub>SMX</sub></i>). Typical value = 0,06. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PowerSystemStabilizerDynamics](CIM17v40-PowerSystemStabilizerDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Pss1A}
### Pss1A

Inheritance path = [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Pss1A {

+ a1 : PU [0..1]
+ a2 : PU [0..1]
+ a3 : PU [0..1]
+ a4 : PU [0..1]
+ a5 : PU [0..1]
+ a6 : PU [0..1]
+ a7 : PU [0..1]
+ a8 : PU [0..1]
+ inputSignalType : enum:InputSignalKind [0..1]
+ kd : Boolean [0..1]
+ ks : PU [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ t5 : Seconds [0..1]
+ t6 : Seconds [0..1]
+ tdelay : Seconds [0..1]
+ vcl : PU [0..1]
+ vcu : PU [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class PowerSystemStabilizerDynamics {

}

PowerSystemStabilizerDynamics <|-- Pss1A : inherits from
```

Single input power system stabilizer. It is a modified version in order to allow representation of various vendors' implementations on PSS type 1A.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| a1 [0..1] | [PU](#CIM17v40-PU) | Notch filter parameter (<i>A</i><i><sub>1</sub></i>). | |
| a2 [0..1] | [PU](#CIM17v40-PU) | Notch filter parameter (<i>A</i><i><sub>2</sub></i>). | |
| a3 [0..1] | [PU](#CIM17v40-PU) | Notch filter parameter (<i>A</i><i><sub>3</sub></i>). | |
| a4 [0..1] | [PU](#CIM17v40-PU) | Notch filter parameter (<i>A</i><i><sub>4</sub></i>). | |
| a5 [0..1] | [PU](#CIM17v40-PU) | Notch filter parameter (<i>A</i><i><sub>5</sub></i>). | |
| a6 [0..1] | [PU](#CIM17v40-PU) | Notch filter parameter (<i>A</i><i><sub>6</sub></i>). | |
| a7 [0..1] | [PU](#CIM17v40-PU) | Notch filter parameter (<i>A</i><i><sub>7</sub></i>). | |
| a8 [0..1] | [PU](#CIM17v40-PU) | Notch filter parameter (<i>A</i><i><sub>8</sub></i>). | |
| inputSignalType [0..1] | [InputSignalKind](#CIM17v40-InputSignalKind) | Type of input signal (rotorAngularFrequencyDeviation, busFrequencyDeviation, generatorElectricalPower, generatorAcceleratingPower, busVoltage, or busVoltageDerivative). | |
| kd [0..1] | [Boolean](#CIM17v40-Boolean) | Selector (<i>Kd</i>).true = e<sup>-sTdelay</sup> usedfalse = e<sup>-sTdelay</sup> not used. | |
| ks [0..1] | [PU](#CIM17v40-PU) | Stabilizer gain (<i>K</i><i><sub>s</sub></i>). | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T</i><i><sub>1</sub></i>) (&gt;= 0). | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T</i><i><sub>2</sub></i>) (&gt;= 0). | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T</i><i><sub>3</sub></i>) (&gt;= 0). | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T</i><i><sub>4</sub></i>) (&gt;= 0). | |
| t5 [0..1] | [Seconds](#CIM17v40-Seconds) | Washout time constant (<i>T</i><i><sub>5</sub></i>) (&gt;= 0). | |
| t6 [0..1] | [Seconds](#CIM17v40-Seconds) | Transducer time constant (<i>T</i><i><sub>6</sub></i>) (&gt;= 0). | |
| tdelay [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Tdelay</i>) (&gt;= 0). | |
| vcl [0..1] | [PU](#CIM17v40-PU) | Stabilizer input cutoff threshold (<i>Vcl</i>). | |
| vcu [0..1] | [PU](#CIM17v40-PU) | Stabilizer input cutoff threshold (<i>Vcu</i>). | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum stabilizer output (<i>Vrmax</i>) (&gt; Pss1A.vrmin). | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum stabilizer output (<i>Vrmin</i>) (&lt; Pss1A.vrmax). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PowerSystemStabilizerDynamics](CIM17v40-PowerSystemStabilizerDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Pss2B}
### Pss2B

Inheritance path = [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Pss2B {

+ a : Float [0..1]
+ ks1 : PU [0..1]
+ ks2 : PU [0..1]
+ ks3 : PU [0..1]
+ ks4 : PU [0..1]
+ m : Integer [0..1]
+ n : Integer [0..1]
+ t1 : Seconds [0..1]
+ t10 : Seconds [0..1]
+ t11 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ t6 : Seconds [0..1]
+ t7 : Seconds [0..1]
+ t8 : Seconds [0..1]
+ t9 : Seconds [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ tw1 : Seconds [0..1]
+ tw2 : Seconds [0..1]
+ tw3 : Seconds [0..1]
+ tw4 : Seconds [0..1]
+ vsi1max : PU [0..1]
+ vsi1min : PU [0..1]
+ vsi2max : PU [0..1]
+ vsi2min : PU [0..1]
+ vstmax : PU [0..1]
+ vstmin : PU [0..1]
}

class PowerSystemStabilizerDynamics {

}

PowerSystemStabilizerDynamics <|-- Pss2B : inherits from
```

Modified IEEE PSS2B. Extra lead/lag (or rate) block added at end (up to 4 lead/lags total).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| a [0..1] | [Float](#CIM17v40-Float) | Numerator constant (<i>a</i>). Typical value = 1. | |
| ks1 [0..1] | [PU](#CIM17v40-PU) | Stabilizer gain (<i>Ks1</i>). Typical value = 12. | |
| ks2 [0..1] | [PU](#CIM17v40-PU) | Gain on signal #2 (<i>Ks2</i>). Typical value = 0,2. | |
| ks3 [0..1] | [PU](#CIM17v40-PU) | Gain on signal #2 input before ramp-tracking filter (<i>Ks3</i>). Typical value = 1. | |
| ks4 [0..1] | [PU](#CIM17v40-PU) | Gain on signal #2 input after ramp-tracking filter (<i>Ks4</i>). Typical value = 1. | |
| m [0..1] | [Integer](#CIM17v40-Integer) | Denominator order of ramp tracking filter (<i>m</i>). Typical value = 5. | |
| n [0..1] | [Integer](#CIM17v40-Integer) | Order of ramp tracking filter (<i>n</i>). Typical value = 1. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T</i><i><sub>1</sub></i>) (&gt;= 0). Typical value = 0,12. | |
| t10 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T</i><i><sub>10</sub></i>) (&gt;= 0). Typical value = 0. | |
| t11 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T</i><i><sub>11</sub></i>) (&gt;= 0). Typical value = 0. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T</i><i><sub>2</sub></i>) (&gt;= 0). Typical value = 0,02. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T</i><i><sub>3</sub></i>) (&gt;= 0). Typical value = 0,3. | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T</i><i><sub>4</sub></i>) (&gt;= 0). Typical value = 0,02. | |
| t6 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant on signal #1 (<i>T</i><i><sub>6</sub></i>) (&gt;= 0). Typical value = 0. | |
| t7 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant on signal #2 (<i>T</i><i><sub>7</sub></i>) (&gt;= 0). Typical value = 2. | |
| t8 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead of ramp tracking filter (<i>T</i><i><sub>8</sub></i>) (&gt;= 0). Typical value = 0,2. | |
| t9 [0..1] | [Seconds](#CIM17v40-Seconds) | Lag of ramp tracking filter (<i>T</i><i><sub>9</sub></i>) (&gt;= 0). Typical value = 0,1. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Lead constant (<i>T</i><i><sub>a</sub></i>) (&gt;= 0). Typical value = 0. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Lag time constant (<i>T</i><i><sub>b</sub></i>) (&gt;= 0). Typical value = 0. | |
| tw1 [0..1] | [Seconds](#CIM17v40-Seconds) | First washout on signal #1 (<i>T</i><i><sub>w1</sub></i>) (&gt;= 0). Typical value = 2. | |
| tw2 [0..1] | [Seconds](#CIM17v40-Seconds) | Second washout on signal #1 (<i>T</i><i><sub>w2</sub></i>) (&gt;= 0). Typical value = 2. | |
| tw3 [0..1] | [Seconds](#CIM17v40-Seconds) | First washout on signal #2 (<i>T</i><i><sub>w3</sub></i>) (&gt;= 0). Typical value = 2. | |
| tw4 [0..1] | [Seconds](#CIM17v40-Seconds) | Second washout on signal #2 (<i>T</i><i><sub>w4</sub></i>) (&gt;= 0). Typical value = 0. | |
| vsi1max [0..1] | [PU](#CIM17v40-PU) | Input signal #1 maximum limit (<i>Vsi1max</i>) (&gt; Pss2B.vsi1min). Typical value = 2. | |
| vsi1min [0..1] | [PU](#CIM17v40-PU) | Input signal #1 minimum limit (<i>Vsi1min</i>) (&lt; Pss2B.vsi1max). Typical value = -2. | |
| vsi2max [0..1] | [PU](#CIM17v40-PU) | Input signal #2 maximum limit (<i>Vsi2max</i>) (&gt; Pss2B.vsi2min). Typical value = 2. | |
| vsi2min [0..1] | [PU](#CIM17v40-PU) | Input signal #2 minimum limit (<i>Vsi2min</i>) (&lt; Pss2B.vsi2max). Typical value = -2. | |
| vstmax [0..1] | [PU](#CIM17v40-PU) | Stabilizer output maximum limit (<i>Vstmax</i>) (&gt; Pss2B.vstmin). Typical value = 0,1. | |
| vstmin [0..1] | [PU](#CIM17v40-PU) | Stabilizer output minimum limit (<i>Vstmin</i>) (&lt; Pss2B.vstmax). Typical value = -0,1. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PowerSystemStabilizerDynamics](CIM17v40-PowerSystemStabilizerDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Pss2ST}
### Pss2ST

Inheritance path = [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Pss2ST {

+ inputSignal1Type : enum:InputSignalKind [0..1]
+ inputSignal2Type : enum:InputSignalKind [0..1]
+ k1 : PU [0..1]
+ k2 : PU [0..1]
+ lsmax : PU [0..1]
+ lsmin : PU [0..1]
+ t1 : Seconds [0..1]
+ t10 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ t5 : Seconds [0..1]
+ t6 : Seconds [0..1]
+ t7 : Seconds [0..1]
+ t8 : Seconds [0..1]
+ t9 : Seconds [0..1]
+ vcl : PU [0..1]
+ vcu : PU [0..1]
}

class PowerSystemStabilizerDynamics {

}

PowerSystemStabilizerDynamics <|-- Pss2ST : inherits from
```

PTI microprocessor-based stabilizer type 1.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| inputSignal1Type [0..1] | [InputSignalKind](#CIM17v40-InputSignalKind) | Type of input signal #1 (rotorAngularFrequencyDeviation, busFrequencyDeviation, generatorElectricalPower, generatorAcceleratingPower, busVoltage, or busVoltageDerivative - shall be different than Pss2ST.inputSignal2Type). Typical value = rotorAngularFrequencyDeviation. | |
| inputSignal2Type [0..1] | [InputSignalKind](#CIM17v40-InputSignalKind) | Type of input signal #2 (rotorAngularFrequencyDeviation, busFrequencyDeviation, generatorElectricalPower, generatorAcceleratingPower, busVoltage, or busVoltageDerivative - shall be different than Pss2ST.inputSignal1Type). Typical value = busVoltageDerivative. | |
| k1 [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K</i><i><sub>1</sub></i>). | |
| k2 [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K</i><i><sub>2</sub></i>). | |
| lsmax [0..1] | [PU](#CIM17v40-PU) | Limiter (<i>L</i><i><sub>SMAX</sub></i>) (&gt; Pss2ST.lsmin). | |
| lsmin [0..1] | [PU](#CIM17v40-PU) | Limiter (<i>L</i><i><sub>SMIN</sub></i>) (&lt; Pss2ST.lsmax). | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>1</sub></i>) (&gt;= 0). | |
| t10 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>10</sub></i>) (&gt;= 0). | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>2</sub></i>) (&gt;= 0). | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>3</sub></i>) (&gt;= 0). | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>4</sub></i>) (&gt;= 0). | |
| t5 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>5</sub></i>) (&gt;= 0). | |
| t6 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>6</sub></i>) (&gt;= 0). | |
| t7 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>7</sub></i>) (&gt;= 0). | |
| t8 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>8</sub></i>) (&gt;= 0). | |
| t9 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>9</sub></i>) (&gt;= 0). | |
| vcl [0..1] | [PU](#CIM17v40-PU) | Cutoff limiter (<i>V</i><i><sub>CL</sub></i>). | |
| vcu [0..1] | [PU](#CIM17v40-PU) | Cutoff limiter (<i>V</i><i><sub>CU</sub></i>). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PowerSystemStabilizerDynamics](CIM17v40-PowerSystemStabilizerDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Pss5}
### Pss5

Inheritance path = [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Pss5 {

+ ctw2 : Boolean [0..1]
+ deadband : PU [0..1]
+ isfreq : Boolean [0..1]
+ kf : Float [0..1]
+ kpe : Float [0..1]
+ kpss : Float [0..1]
+ pmin : PU [0..1]
+ tl1 : Seconds [0..1]
+ tl2 : Seconds [0..1]
+ tl3 : Seconds [0..1]
+ tl4 : Seconds [0..1]
+ tpe : Seconds [0..1]
+ tw1 : Seconds [0..1]
+ tw2 : Seconds [0..1]
+ vadat : Boolean [0..1]
+ vsmn : PU [0..1]
+ vsmx : PU [0..1]
}

class PowerSystemStabilizerDynamics {

}

PowerSystemStabilizerDynamics <|-- Pss5 : inherits from
```

Detailed Italian PSS.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ctw2 [0..1] | [Boolean](#CIM17v40-Boolean) | Selector for second washout enabling (<i>C</i><i><sub>TW2</sub></i>).true = second washout filter is bypassedfalse = second washout filter in use.Typical value = true. | |
| deadband [0..1] | [PU](#CIM17v40-PU) | Stabilizer output deadband (<i>DEADBAND</i>). Typical value = 0. | |
| isfreq [0..1] | [Boolean](#CIM17v40-Boolean) | Selector for frequency/shaft speed input (<i>isFreq</i>).true = speed (same meaning as InputSignaKind.rotorSpeed)false = frequency (same meaning as InputSignalKind.busFrequency).Typical value = true (same meaning as InputSignalKind.rotorSpeed). | |
| kf [0..1] | [Float](#CIM17v40-Float) | Frequency/shaft speed input gain (<i>K</i><i><sub>F</sub></i>). Typical value = 5. | |
| kpe [0..1] | [Float](#CIM17v40-Float) | Electric power input gain (<i>K</i><i><sub>PE</sub></i>). Typical value = 0,3. | |
| kpss [0..1] | [Float](#CIM17v40-Float) | PSS gain (<i>K</i><i><sub>PSS</sub></i>). Typical value = 1. | |
| pmin [0..1] | [PU](#CIM17v40-PU) | Minimum power PSS enabling (<i>Pmin</i>). Typical value = 0,25. | |
| tl1 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T</i><i><sub>L1</sub></i>) (&gt;= 0). Typical value = 0. | |
| tl2 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T</i><i><sub>L2</sub></i>) (&gt;= 0). If = 0, both blocks are bypassed. Typical value = 0. | |
| tl3 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T</i><i><sub>L3</sub></i>) (&gt;= 0). Typical value = 0. | |
| tl4 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (T<sub>L4</sub>) (&gt;= 0). If = 0, both blocks are bypassed. Typical value = 0. | |
| tpe [0..1] | [Seconds](#CIM17v40-Seconds) | Electric power filter time constant (<i>T</i><i><sub>PE</sub></i>) (&gt;= 0). Typical value = 0,05. | |
| tw1 [0..1] | [Seconds](#CIM17v40-Seconds) | First washout (<i>T</i><i><sub>W1</sub></i>) (&gt;= 0). Typical value = 3,5. | |
| tw2 [0..1] | [Seconds](#CIM17v40-Seconds) | Second washout (<i>T</i><i><sub>W2</sub></i>) (&gt;= 0). Typical value = 0. | |
| vadat [0..1] | [Boolean](#CIM17v40-Boolean) | <font color="#0f0f0f">Signal selector (<i>V</i><i><sub>adAtt</sub></i>).</font><font color="#0f0f0f">true = closed (generator power is greater than <i>Pmin</i>)</font><font color="#0f0f0f">false = open (<i>Pe</i> is smaller than <i>Pmin</i>).</font><font color="#0f0f0f">Typical value = true.</font> | |
| vsmn [0..1] | [PU](#CIM17v40-PU) | Stabilizer output maximum limit (<i>V</i><i><sub>SMN</sub></i>). Typical value = -0,1. | |
| vsmx [0..1] | [PU](#CIM17v40-PU) | Stabilizer output minimum limit (<i>V</i><i><sub>SMX</sub></i>). Typical value = 0,1. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PowerSystemStabilizerDynamics](CIM17v40-PowerSystemStabilizerDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PssELIN2}
### PssELIN2

Inheritance path = [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PssELIN2 {

+ apss : PU [0..1]
+ ks1 : PU [0..1]
+ ks2 : PU [0..1]
+ ppss : PU [0..1]
+ psslim : PU [0..1]
+ ts1 : Seconds [0..1]
+ ts2 : Seconds [0..1]
+ ts3 : Seconds [0..1]
+ ts4 : Seconds [0..1]
+ ts5 : Seconds [0..1]
+ ts6 : Seconds [0..1]
}

class PowerSystemStabilizerDynamics {

}

PowerSystemStabilizerDynamics <|-- PssELIN2 : inherits from
```

Power system stabilizer typically associated with ExcELIN2 (though PssIEEE2B or Pss2B can also be used).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| apss [0..1] | [PU](#CIM17v40-PU) | Coefficient (<i>a_PSS</i>). Typical value = 0,1. | |
| ks1 [0..1] | [PU](#CIM17v40-PU) | Gain (<i>Ks1</i>). Typical value = 1. | |
| ks2 [0..1] | [PU](#CIM17v40-PU) | Gain (<i>Ks2</i>). Typical value = 0,1. | |
| ppss [0..1] | [PU](#CIM17v40-PU) | Coefficient (<i>p_PSS</i>) (&gt;= 0 and &lt;= 4). Typical value = 0,1. | |
| psslim [0..1] | [PU](#CIM17v40-PU) | PSS limiter (<i>psslim</i>). Typical value = 0,1. | |
| ts1 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Ts1</i>) (&gt;= 0). Typical value = 0. | |
| ts2 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Ts2</i>) (&gt;= 0). Typical value = 1. | |
| ts3 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Ts3</i>) (&gt;= 0). Typical value = 1. | |
| ts4 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Ts4</i>) (&gt;= 0). Typical value = 0,1. | |
| ts5 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Ts5</i>) (&gt;= 0). Typical value = 0. | |
| ts6 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Ts6</i>) (&gt;= 0). Typical value = 1. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PowerSystemStabilizerDynamics](CIM17v40-PowerSystemStabilizerDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PssIEEE1A}
### PssIEEE1A

Inheritance path = [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PssIEEE1A {

+ a1 : PU [0..1]
+ a2 : PU [0..1]
+ inputSignalType : enum:InputSignalKind [0..1]
+ ks : PU [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ t5 : Seconds [0..1]
+ t6 : Seconds [0..1]
+ vrmax : PU [0..1]
+ vrmin : PU [0..1]
}

class PowerSystemStabilizerDynamics {

}

PowerSystemStabilizerDynamics <|-- PssIEEE1A : inherits from
```

IEEE 421.5-2005 type PSS1A power system stabilizer model. PSS1A is the generalized form of a PSS with a single input signal.

Reference: IEEE 1A 421.5-2005, 8.1.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| a1 [0..1] | [PU](#CIM17v40-PU) | PSS signal conditioning frequency filter constant (<i>A1</i>). Typical value = 0,061. | |
| a2 [0..1] | [PU](#CIM17v40-PU) | PSS signal conditioning frequency filter constant (<i>A2</i>). Typical value = 0,0017. | |
| inputSignalType [0..1] | [InputSignalKind](#CIM17v40-InputSignalKind) | Type of input signal (rotorAngularFrequencyDeviation, generatorElectricalPower, or busFrequencyDeviation). Typical value = rotorAngularFrequencyDeviation. | |
| ks [0..1] | [PU](#CIM17v40-PU) | Stabilizer gain (<i>Ks</i>). Typical value = 5. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T1</i>) (&gt;= 0). Typical value = 0,3. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T2</i>) (&gt;= 0). Typical value = 0,03. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T3</i>) (&gt;= 0). Typical value = 0,3. | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T4</i>) (&gt;= 0). Typical value = 0,03. | |
| t5 [0..1] | [Seconds](#CIM17v40-Seconds) | Washout time constant (<i>T5</i>) (&gt;= 0). Typical value = 10. | |
| t6 [0..1] | [Seconds](#CIM17v40-Seconds) | Transducer time constant (<i>T6</i>) (&gt;= 0). Typical value = 0,01. | |
| vrmax [0..1] | [PU](#CIM17v40-PU) | Maximum stabilizer output (<i>Vrmax</i>) (&gt; PssIEEE1A.vrmin). Typical value = 0,05. | |
| vrmin [0..1] | [PU](#CIM17v40-PU) | Minimum stabilizer output (<i>Vrmin</i>) (&lt; PssIEEE1A.vrmax). Typical value = -0,05. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PowerSystemStabilizerDynamics](CIM17v40-PowerSystemStabilizerDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PssIEEE2B}
### PssIEEE2B

Inheritance path = [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PssIEEE2B {

+ inputSignal1Type : enum:InputSignalKind [0..1]
+ inputSignal2Type : enum:InputSignalKind [0..1]
+ ks1 : PU [0..1]
+ ks2 : PU [0..1]
+ ks3 : PU [0..1]
+ m : Integer [0..1]
+ n : Integer [0..1]
+ t1 : Seconds [0..1]
+ t10 : Seconds [0..1]
+ t11 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ t6 : Seconds [0..1]
+ t7 : Seconds [0..1]
+ t8 : Seconds [0..1]
+ t9 : Seconds [0..1]
+ tw1 : Seconds [0..1]
+ tw2 : Seconds [0..1]
+ tw3 : Seconds [0..1]
+ tw4 : Seconds [0..1]
+ vsi1max : PU [0..1]
+ vsi1min : PU [0..1]
+ vsi2max : PU [0..1]
+ vsi2min : PU [0..1]
+ vstmax : PU [0..1]
+ vstmin : PU [0..1]
}

class PowerSystemStabilizerDynamics {

}

PowerSystemStabilizerDynamics <|-- PssIEEE2B : inherits from
```

IEEE 421.5-2005 type PSS2B power system stabilizer model. This stabilizer model is designed to represent a variety of dual-input stabilizers, which normally use combinations of power and speed or frequency to derive the stabilizing signal.

Reference: IEEE 2B 421.5-2005, 8.2.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| inputSignal1Type [0..1] | [InputSignalKind](#CIM17v40-InputSignalKind) | Type of input signal #1 (rotorAngularFrequencyDeviation, busFrequencyDeviation). Typical value = rotorAngularFrequencyDeviation. | |
| inputSignal2Type [0..1] | [InputSignalKind](#CIM17v40-InputSignalKind) | Type of input signal #2 (generatorElectricalPower). Typical value = generatorElectricalPower. | |
| ks1 [0..1] | [PU](#CIM17v40-PU) | Stabilizer gain (<i>Ks1</i>). Typical value = 12. | |
| ks2 [0..1] | [PU](#CIM17v40-PU) | Gain on signal #2 (<i>Ks2</i>). Typical value = 0,2. | |
| ks3 [0..1] | [PU](#CIM17v40-PU) | Gain on signal #2 input before ramp-tracking filter (<i>Ks3</i>). Typical value = 1. | |
| m [0..1] | [Integer](#CIM17v40-Integer) | Denominator order of ramp tracking filter (<i>M</i>). Typical value = 5. | |
| n [0..1] | [Integer](#CIM17v40-Integer) | Order of ramp tracking filter (<i>N</i>). Typical value = 1. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T1</i>) (&gt;= 0). Typical value = 0,12. | |
| t10 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T10</i>) (&gt;= 0). Typical value = 0. | |
| t11 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T11</i>) (&gt;= 0). Typical value = 0. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T2</i>) (&gt;= 0). Typical value = 0,02. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T3</i>) (&gt;= 0). Typical value = 0,3. | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead/lag time constant (<i>T4</i>) (&gt;= 0). Typical value = 0,02. | |
| t6 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant on signal #1 (<i>T6</i>) (&gt;= 0). Typical value = 0. | |
| t7 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant on signal #2 (<i>T7</i>) (&gt;= 0). Typical value = 2. | |
| t8 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead of ramp tracking filter (<i>T8</i>) (&gt;= 0). Typical value = 0,2. | |
| t9 [0..1] | [Seconds](#CIM17v40-Seconds) | Lag of ramp tracking filter (<i>T9</i>) (&gt;= 0). Typical value = 0,1. | |
| tw1 [0..1] | [Seconds](#CIM17v40-Seconds) | First washout on signal #1 (<i>Tw1</i>) (&gt;= 0). Typical value = 2. | |
| tw2 [0..1] | [Seconds](#CIM17v40-Seconds) | Second washout on signal #1 (<i>Tw2</i>) (&gt;= 0). Typical value = 2. | |
| tw3 [0..1] | [Seconds](#CIM17v40-Seconds) | First washout on signal #2 (<i>Tw3</i>) (&gt;= 0). Typical value = 2. | |
| tw4 [0..1] | [Seconds](#CIM17v40-Seconds) | Second washout on signal #2 (<i>Tw4</i>) (&gt;= 0). Typical value = 0. | |
| vsi1max [0..1] | [PU](#CIM17v40-PU) | Input signal #1 maximum limit (<i>Vsi1max</i>) (&gt; PssIEEE2B.vsi1min). Typical value = 2. | |
| vsi1min [0..1] | [PU](#CIM17v40-PU) | Input signal #1 minimum limit (<i>Vsi1min</i>) (&lt; PssIEEE2B.vsi1max). Typical value = -2. | |
| vsi2max [0..1] | [PU](#CIM17v40-PU) | Input signal #2 maximum limit (<i>Vsi2max</i>) (&gt; PssIEEE2B.vsi2min). Typical value = 2. | |
| vsi2min [0..1] | [PU](#CIM17v40-PU) | Input signal #2 minimum limit (<i>Vsi2min</i>) (&lt; PssIEEE2B.vsi2max). Typical value = -2. | |
| vstmax [0..1] | [PU](#CIM17v40-PU) | Stabilizer output maximum limit (<i>Vstmax</i>) (&gt; PssIEEE2B.vstmin). Typical value = 0,1. | |
| vstmin [0..1] | [PU](#CIM17v40-PU) | Stabilizer output minimum limit (<i>Vstmin</i>) (&lt; PssIEEE2B.vstmax). Typical value = -0,1. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PowerSystemStabilizerDynamics](CIM17v40-PowerSystemStabilizerDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PssIEEE3B}
### PssIEEE3B

Inheritance path = [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PssIEEE3B {

+ a1 : PU [0..1]
+ a2 : PU [0..1]
+ a3 : PU [0..1]
+ a4 : PU [0..1]
+ a5 : PU [0..1]
+ a6 : PU [0..1]
+ a7 : PU [0..1]
+ a8 : PU [0..1]
+ ks1 : PU [0..1]
+ ks2 : PU [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ tw1 : Seconds [0..1]
+ tw2 : Seconds [0..1]
+ tw3 : Seconds [0..1]
+ vstmax : PU [0..1]
+ vstmin : PU [0..1]
}

class PowerSystemStabilizerDynamics {

}

PowerSystemStabilizerDynamics <|-- PssIEEE3B : inherits from
```

IEEE 421.5-2005 type PSS3B power system stabilizer model. The PSS model PSS3B has dual inputs of electrical power and rotor angular frequency deviation. The signals are used to derive an equivalent mechanical power signal.

This model has 2 input signals. They have the following fixed types (expressed in terms of InputSignalKind values): the first one is of rotorAngleFrequencyDeviation type and the second one is of generatorElectricalPower type.

Reference: IEEE 3B 421.5-2005, 8.3.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| a1 [0..1] | [PU](#CIM17v40-PU) | Notch filter parameter (<i>A1</i>). Typical value = 0,359. | |
| a2 [0..1] | [PU](#CIM17v40-PU) | Notch filter parameter (<i>A2</i>). Typical value = 0,586. | |
| a3 [0..1] | [PU](#CIM17v40-PU) | Notch filter parameter (<i>A3</i>). Typical value = 0,429. | |
| a4 [0..1] | [PU](#CIM17v40-PU) | Notch filter parameter (<i>A4</i>). Typical value = 0,564. | |
| a5 [0..1] | [PU](#CIM17v40-PU) | Notch filter parameter (<i>A5</i>). Typical value = 0,001. | |
| a6 [0..1] | [PU](#CIM17v40-PU) | Notch filter parameter (<i>A6</i>). Typical value = 0. | |
| a7 [0..1] | [PU](#CIM17v40-PU) | Notch filter parameter (<i>A7</i>). Typical value = 0,031. | |
| a8 [0..1] | [PU](#CIM17v40-PU) | Notch filter parameter (<i>A8</i>). Typical value = 0. | |
| ks1 [0..1] | [PU](#CIM17v40-PU) | Gain on signal # 1 (<i>Ks1</i>). Typical value = -0,602. | |
| ks2 [0..1] | [PU](#CIM17v40-PU) | Gain on signal # 2 (<i>Ks2</i>). Typical value = 30,12. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Transducer time constant (<i>T1</i>) (&gt;= 0). Typical value = 0,012. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Transducer time constant (<i>T2</i>) (&gt;= 0). Typical value = 0,012. | |
| tw1 [0..1] | [Seconds](#CIM17v40-Seconds) | Washout time constant (<i>Tw1</i>) (&gt;= 0). Typical value = 0,3. | |
| tw2 [0..1] | [Seconds](#CIM17v40-Seconds) | Washout time constant (<i>Tw2</i>) (&gt;= 0). Typical value = 0,3. | |
| tw3 [0..1] | [Seconds](#CIM17v40-Seconds) | Washout time constant (<i>Tw3</i>) (&gt;= 0). Typical value = 0,6. | |
| vstmax [0..1] | [PU](#CIM17v40-PU) | Stabilizer output maximum limit (<i>Vstmax</i>) (&gt; PssIEEE3B.vstmin). Typical value = 0,1. | |
| vstmin [0..1] | [PU](#CIM17v40-PU) | Stabilizer output minimum limit (<i>Vstmin</i>) (&lt; PssIEEE3B.vstmax). Typical value = -0,1. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PowerSystemStabilizerDynamics](CIM17v40-PowerSystemStabilizerDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PssIEEE4B}
### PssIEEE4B

Inheritance path = [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PssIEEE4B {

+ bwh1 : Float [0..1]
+ bwh2 : Float [0..1]
+ bwl1 : Float [0..1]
+ bwl2 : Float [0..1]
+ kh : PU [0..1]
+ kh1 : PU [0..1]
+ kh11 : PU [0..1]
+ kh17 : PU [0..1]
+ kh2 : PU [0..1]
+ ki : PU [0..1]
+ ki1 : PU [0..1]
+ ki11 : PU [0..1]
+ ki17 : PU [0..1]
+ ki2 : PU [0..1]
+ kl : PU [0..1]
+ kl1 : PU [0..1]
+ kl11 : PU [0..1]
+ kl17 : PU [0..1]
+ kl2 : PU [0..1]
+ omeganh1 : Float [0..1]
+ omeganh2 : Float [0..1]
+ omeganl1 : Float [0..1]
+ omeganl2 : Float [0..1]
+ th1 : Seconds [0..1]
+ th10 : Seconds [0..1]
+ th11 : Seconds [0..1]
+ th12 : Seconds [0..1]
+ th2 : Seconds [0..1]
+ th3 : Seconds [0..1]
+ th4 : Seconds [0..1]
+ th5 : Seconds [0..1]
+ th6 : Seconds [0..1]
+ th7 : Seconds [0..1]
+ th8 : Seconds [0..1]
+ th9 : Seconds [0..1]
+ ti1 : Seconds [0..1]
+ ti10 : Seconds [0..1]
+ ti11 : Seconds [0..1]
+ ti12 : Seconds [0..1]
+ ti2 : Seconds [0..1]
+ ti3 : Seconds [0..1]
+ ti4 : Seconds [0..1]
+ ti5 : Seconds [0..1]
+ ti6 : Seconds [0..1]
+ ti7 : Seconds [0..1]
+ ti8 : Seconds [0..1]
+ ti9 : Seconds [0..1]
+ tl1 : Seconds [0..1]
+ tl10 : Seconds [0..1]
+ tl11 : Seconds [0..1]
+ tl12 : Seconds [0..1]
+ tl2 : Seconds [0..1]
+ tl3 : Seconds [0..1]
+ tl4 : Seconds [0..1]
+ tl5 : Seconds [0..1]
+ tl6 : Seconds [0..1]
+ tl7 : Seconds [0..1]
+ tl8 : Seconds [0..1]
+ tl9 : Seconds [0..1]
+ vhmax : PU [0..1]
+ vhmin : PU [0..1]
+ vimax : PU [0..1]
+ vimin : PU [0..1]
+ vlmax : PU [0..1]
+ vlmin : PU [0..1]
+ vstmax : PU [0..1]
+ vstmin : PU [0..1]
}

class PowerSystemStabilizerDynamics {

}

PowerSystemStabilizerDynamics <|-- PssIEEE4B : inherits from
```

IEEE 421.5-2005 type PSS4B power system stabilizer. The PSS4B model represents a structure based on multiple working frequency bands. Three separate bands, respectively dedicated to the low-, intermediate- and high-frequency modes of oscillations, are used in this delta omega (speed input) PSS.

There is an error in the in IEEE 421.5-2005 PSS4B model: the <i>Pe</i> input should read �<i>Pe</i>. This implies that the input <i>Pe</i> needs to be multiplied by -1.

Reference: IEEE 4B 421.5-2005, 8.4.

Parameter details:

This model has 2 input signals. They have the following fixed types (expressed in terms of InputSignalKind values): the first one is of rotorAngleFrequencyDeviation type and the second one is of generatorElectricalPower type.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| bwh1 [0..1] | [Float](#CIM17v40-Float) | Notch filter 1 (high-frequency band): three dB bandwidth (<i>B</i><i><sub>wi</sub></i>). | |
| bwh2 [0..1] | [Float](#CIM17v40-Float) | Notch filter 2 (high-frequency band): three dB bandwidth (<i>B</i><i><sub>wi</sub></i>). | |
| bwl1 [0..1] | [Float](#CIM17v40-Float) | Notch filter 1 (low-frequency band): three dB bandwidth (<i>B</i><i><sub>wi</sub></i>). | |
| bwl2 [0..1] | [Float](#CIM17v40-Float) | Notch filter 2 (low-frequency band): three dB bandwidth (<i>B</i><i><sub>wi</sub></i>). | |
| kh [0..1] | [PU](#CIM17v40-PU) | High band gain (<i>K</i><i><sub>H</sub></i>). Typical value = 120. | |
| kh1 [0..1] | [PU](#CIM17v40-PU) | High band differential filter gain (<i>K</i><i><sub>H1</sub></i>). Typical value = 66. | |
| kh11 [0..1] | [PU](#CIM17v40-PU) | High band first lead-lag blocks coefficient (<i>K</i><i><sub>H11</sub></i>). Typical value = 1. | |
| kh17 [0..1] | [PU](#CIM17v40-PU) | High band first lead-lag blocks coefficient (<i>K</i><i><sub>H17</sub></i>). Typical value = 1. | |
| kh2 [0..1] | [PU](#CIM17v40-PU) | High band differential filter gain (<i>K</i><i><sub>H2</sub></i>). Typical value = 66. | |
| ki [0..1] | [PU](#CIM17v40-PU) | Intermediate band gain (<i>K</i><i><sub>I</sub></i>). Typical value = 30. | |
| ki1 [0..1] | [PU](#CIM17v40-PU) | Intermediate band differential filter gain (<i>K</i><i><sub>I1</sub></i>). Typical value = 66. | |
| ki11 [0..1] | [PU](#CIM17v40-PU) | Intermediate band first lead-lag blocks coefficient (<i>K</i><i><sub>I11</sub></i>). Typical value = 1. | |
| ki17 [0..1] | [PU](#CIM17v40-PU) | Intermediate band first lead-lag blocks coefficient (<i>K</i><i><sub>I17</sub></i>). Typical value = 1. | |
| ki2 [0..1] | [PU](#CIM17v40-PU) | Intermediate band differential filter gain (<i>K</i><i><sub>I2</sub></i>). Typical value = 66. | |
| kl [0..1] | [PU](#CIM17v40-PU) | Low band gain (<i>K</i><i><sub>L</sub></i>). Typical value = 7.5. | |
| kl1 [0..1] | [PU](#CIM17v40-PU) | Low band differential filter gain (<i>K</i><i><sub>L1</sub></i>). Typical value = 66. | |
| kl11 [0..1] | [PU](#CIM17v40-PU) | Low band first lead-lag blocks coefficient (<i>K</i><i><sub>L11</sub></i>). Typical value = 1. | |
| kl17 [0..1] | [PU](#CIM17v40-PU) | Low band first lead-lag blocks coefficient (<i>K</i><i><sub>L17</sub></i>). Typical value = 1. | |
| kl2 [0..1] | [PU](#CIM17v40-PU) | Low band differential filter gain (<i>K</i><i><sub>L2</sub></i>). Typical value = 66. | |
| omeganh1 [0..1] | [Float](#CIM17v40-Float) | Notch filter 1 (high-frequency band): filter frequency (<i>omega</i><i><sub>ni</sub></i>). | |
| omeganh2 [0..1] | [Float](#CIM17v40-Float) | Notch filter 2 (high-frequency band): filter frequency (<i>omega</i><i><sub>ni</sub></i>). | |
| omeganl1 [0..1] | [Float](#CIM17v40-Float) | Notch filter 1 (low-frequency band): filter frequency (<i>omega</i><i><sub>ni</sub></i>). | |
| omeganl2 [0..1] | [Float](#CIM17v40-Float) | Notch filter 2 (low-frequency band): filter frequency (<i>omega</i><i><sub>ni</sub></i>). | |
| th1 [0..1] | [Seconds](#CIM17v40-Seconds) | High band time constant (<i>T</i><i><sub>H1</sub></i>) (&gt;= 0). Typical value = 0,01513. | |
| th10 [0..1] | [Seconds](#CIM17v40-Seconds) | High band time constant (<i>T</i><i><sub>H10</sub></i>) (&gt;= 0). Typical value = 0. | |
| th11 [0..1] | [Seconds](#CIM17v40-Seconds) | High band time constant (<i>T</i><i><sub>H11</sub></i>) (&gt;= 0). Typical value = 0. | |
| th12 [0..1] | [Seconds](#CIM17v40-Seconds) | High band time constant (<i>T</i><i><sub>H12</sub></i>) (&gt;= 0). Typical value = 0. | |
| th2 [0..1] | [Seconds](#CIM17v40-Seconds) | High band time constant (<i>T</i><i><sub>H2</sub></i>) (&gt;= 0). Typical value = 0,01816. | |
| th3 [0..1] | [Seconds](#CIM17v40-Seconds) | High band time constant (<i>T</i><i><sub>H3</sub></i>) (&gt;= 0). Typical value = 0. | |
| th4 [0..1] | [Seconds](#CIM17v40-Seconds) | High band time constant (<i>T</i><i><sub>H4</sub></i>) (&gt;= 0). Typical value = 0. | |
| th5 [0..1] | [Seconds](#CIM17v40-Seconds) | High band time constant (<i>T</i><i><sub>H5</sub></i>) (&gt;= 0). Typical value = 0. | |
| th6 [0..1] | [Seconds](#CIM17v40-Seconds) | High band time constant (<i>T</i><i><sub>H6</sub></i>) (&gt;= 0). Typical value = 0. | |
| th7 [0..1] | [Seconds](#CIM17v40-Seconds) | High band time constant (<i>T</i><i><sub>H7</sub></i>) (&gt;= 0). Typical value = 0,01816. | |
| th8 [0..1] | [Seconds](#CIM17v40-Seconds) | High band time constant (<i>T</i><i><sub>H8</sub></i>) (&gt;= 0). Typical value = 0,02179. | |
| th9 [0..1] | [Seconds](#CIM17v40-Seconds) | High band time constant (<i>T</i><i><sub>H9</sub></i>) (&gt;= 0). Typical value = 0. | |
| ti1 [0..1] | [Seconds](#CIM17v40-Seconds) | Intermediate band time constant (<i>T</i><i><sub>I1</sub></i>) (&gt;= 0). Typical value = 0,173. | |
| ti10 [0..1] | [Seconds](#CIM17v40-Seconds) | Intermediate band time constant (<i>T</i><i><sub>I10</sub></i>) (&gt;= 0). Typical value = 0. | |
| ti11 [0..1] | [Seconds](#CIM17v40-Seconds) | Intermediate band time constant (<i>T</i><i><sub>I11</sub></i>) (&gt;= 0). Typical value = 0. | |
| ti12 [0..1] | [Seconds](#CIM17v40-Seconds) | Intermediate band time constant (<i>T</i><i><sub>I12</sub></i>) (&gt;= 0). Typical value = 0. | |
| ti2 [0..1] | [Seconds](#CIM17v40-Seconds) | Intermediate band time constant (<i>T</i><i><sub>I2</sub></i>) (&gt;= 0). Typical value = 0,2075. | |
| ti3 [0..1] | [Seconds](#CIM17v40-Seconds) | Intermediate band time constant (<i>T</i><i><sub>I3</sub></i>) (&gt;= 0). Typical value = 0. | |
| ti4 [0..1] | [Seconds](#CIM17v40-Seconds) | Intermediate band time constant (<i>T</i><i><sub>I4</sub></i>) (&gt;= 0). Typical value = 0. | |
| ti5 [0..1] | [Seconds](#CIM17v40-Seconds) | Intermediate band time constant (<i>T</i><i><sub>I5</sub></i>) (&gt;= 0). Typical value = 0. | |
| ti6 [0..1] | [Seconds](#CIM17v40-Seconds) | Intermediate band time constant (<i>T</i><i><sub>I6</sub></i>) (&gt;= 0). Typical value = 0. | |
| ti7 [0..1] | [Seconds](#CIM17v40-Seconds) | Intermediate band time constant (<i>T</i><i><sub>I7</sub></i>) (&gt;= 0). Typical value = 0,2075. | |
| ti8 [0..1] | [Seconds](#CIM17v40-Seconds) | Intermediate band time constant (<i>T</i><i><sub>I8</sub></i>) (&gt;= 0). Typical value = 0,2491. | |
| ti9 [0..1] | [Seconds](#CIM17v40-Seconds) | Intermediate band time constant (<i>T</i><i><sub>I9</sub></i>) (&gt;= 0). Typical value = 0. | |
| tl1 [0..1] | [Seconds](#CIM17v40-Seconds) | Low band time constant (<i>T</i><i><sub>L1</sub></i>) (&gt;= 0). Typical value = 1,73. | |
| tl10 [0..1] | [Seconds](#CIM17v40-Seconds) | Low band time constant (<i>T</i><i><sub>L10</sub></i>) (&gt;= 0). Typical value = 0. | |
| tl11 [0..1] | [Seconds](#CIM17v40-Seconds) | Low band time constant (<i>T</i><i><sub>L11</sub></i>) (&gt;= 0). Typical value = 0. | |
| tl12 [0..1] | [Seconds](#CIM17v40-Seconds) | Low band time constant (<i>T</i><i><sub>L12</sub></i>) (&gt;= 0). Typical value = 0. | |
| tl2 [0..1] | [Seconds](#CIM17v40-Seconds) | Low band time constant (<i>T</i><i><sub>L2</sub></i>) (&gt;= 0). Typical value = 2,075. | |
| tl3 [0..1] | [Seconds](#CIM17v40-Seconds) | Low band time constant (<i>T</i><i><sub>L3</sub></i>) (&gt;= 0). Typical value = 0. | |
| tl4 [0..1] | [Seconds](#CIM17v40-Seconds) | Low band time constant (<i>T</i><i><sub>L4</sub></i>) (&gt;= 0). Typical value = 0. | |
| tl5 [0..1] | [Seconds](#CIM17v40-Seconds) | Low band time constant (<i>T</i><i><sub>L5</sub></i>) (&gt;= 0). Typical value = 0. | |
| tl6 [0..1] | [Seconds](#CIM17v40-Seconds) | Low band time constant (<i>T</i><i><sub>L6</sub></i>) (&gt;= 0). Typical value = 0. | |
| tl7 [0..1] | [Seconds](#CIM17v40-Seconds) | Low band time constant (<i>T</i><i><sub>L7</sub></i>) (&gt;= 0). Typical value = 2,075. | |
| tl8 [0..1] | [Seconds](#CIM17v40-Seconds) | Low band time constant (<i>T</i><i><sub>L8</sub></i>) (&gt;= 0). Typical value = 2,491. | |
| tl9 [0..1] | [Seconds](#CIM17v40-Seconds) | Low band time constant (<i>T</i><i><sub>L9</sub></i>) (&gt;= 0). Typical value = 0. | |
| vhmax [0..1] | [PU](#CIM17v40-PU) | High band output maximum limit (<i>V</i><i><sub>Hmax</sub></i>) (&gt; PssIEEE4B.vhmin). Typical value = 0,6. | |
| vhmin [0..1] | [PU](#CIM17v40-PU) | High band output minimum limit (<i>V</i><i><sub>Hmin</sub></i>) (&lt; PssIEEE4V.vhmax). Typical value = -0,6. | |
| vimax [0..1] | [PU](#CIM17v40-PU) | Intermediate band output maximum limit (<i>V</i><i><sub>Imax</sub></i>) (&gt; PssIEEE4B.vimin). Typical value = 0,6. | |
| vimin [0..1] | [PU](#CIM17v40-PU) | Intermediate band output minimum limit (<i>V</i><i><sub>Imin</sub></i>) (&lt; PssIEEE4B.vimax). Typical value = -0,6. | |
| vlmax [0..1] | [PU](#CIM17v40-PU) | Low band output maximum limit (<i>V</i><i><sub>Lmax</sub></i>) (&gt; PssIEEE4B.vlmin). Typical value = 0,075. | |
| vlmin [0..1] | [PU](#CIM17v40-PU) | Low band output minimum limit (<i>V</i><i><sub>Lmin</sub></i>) (&lt; PssIEEE4B.vlmax). Typical value = -0,075. | |
| vstmax [0..1] | [PU](#CIM17v40-PU) | PSS output maximum limit (<i>V</i><i><sub>STmax</sub></i>) (&gt; PssIEEE4B.vstmin). Typical value = 0,15. | |
| vstmin [0..1] | [PU](#CIM17v40-PU) | PSS output minimum limit (<i>V</i><i><sub>STmin</sub></i>) (&lt; PssIEEE4B.vstmax). Typical value = -0,15. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PowerSystemStabilizerDynamics](CIM17v40-PowerSystemStabilizerDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PssPTIST1}
### PssPTIST1

Inheritance path = [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PssPTIST1 {

+ dtc : Seconds [0..1]
+ dtf : Seconds [0..1]
+ dtp : Seconds [0..1]
+ k : PU [0..1]
+ m : PU [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ tf : Seconds [0..1]
+ tp : Seconds [0..1]
}

class PowerSystemStabilizerDynamics {

}

PowerSystemStabilizerDynamics <|-- PssPTIST1 : inherits from
```

PTI microprocessor-based stabilizer type 1.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dtc [0..1] | [Seconds](#CIM17v40-Seconds) | Time step related to activation of controls (<i>deltatc</i>) (&gt;= 0). Typical value = 0,025. | |
| dtf [0..1] | [Seconds](#CIM17v40-Seconds) | Time step frequency calculation (<i>deltatf</i>) (&gt;= 0). Typical value = 0,025. | |
| dtp [0..1] | [Seconds](#CIM17v40-Seconds) | Time step active power calculation (<i>deltatp</i>) (&gt;= 0). Typical value = 0,0125. | |
| k [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K</i>). Typical value = 9. | |
| m [0..1] | [PU](#CIM17v40-PU) | (<i>M</i>). <i>M </i>= 2 x <i>H</i>. Typical value = 5. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T1</i>) (&gt;= 0). Typical value = 0,3. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T2</i>) (&gt;= 0). Typical value = 1. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T3</i>) (&gt;= 0). Typical value = 0,2. | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T4</i>) (&gt;= 0). Typical value = 0,05. | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Tf</i>) (&gt;= 0). Typical value = 0,2. | |
| tp [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Tp</i>) (&gt;= 0). Typical value = 0,2. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PowerSystemStabilizerDynamics](CIM17v40-PowerSystemStabilizerDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PssPTIST3}
### PssPTIST3

Inheritance path = [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PssPTIST3 {

+ a0 : PU [0..1]
+ a1 : PU [0..1]
+ a2 : PU [0..1]
+ a3 : PU [0..1]
+ a4 : PU [0..1]
+ a5 : PU [0..1]
+ al : PU [0..1]
+ athres : PU [0..1]
+ b0 : PU [0..1]
+ b1 : PU [0..1]
+ b2 : PU [0..1]
+ b3 : PU [0..1]
+ b4 : PU [0..1]
+ b5 : PU [0..1]
+ dl : PU [0..1]
+ dtc : Seconds [0..1]
+ dtf : Seconds [0..1]
+ dtp : Seconds [0..1]
+ isw : Boolean [0..1]
+ k : PU [0..1]
+ lthres : PU [0..1]
+ m : PU [0..1]
+ nav : Float [0..1]
+ ncl : Float [0..1]
+ ncr : Float [0..1]
+ pmin : PU [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ t5 : Seconds [0..1]
+ t6 : Seconds [0..1]
+ tf : Seconds [0..1]
+ tp : Seconds [0..1]
}

class PowerSystemStabilizerDynamics {

}

PowerSystemStabilizerDynamics <|-- PssPTIST3 : inherits from
```

PTI microprocessor-based stabilizer type 3.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| a0 [0..1] | [PU](#CIM17v40-PU) | Filter coefficient (<i>A0</i>). | |
| a1 [0..1] | [PU](#CIM17v40-PU) | Limiter (<i>Al</i>). | |
| a2 [0..1] | [PU](#CIM17v40-PU) | Filter coefficient (<i>A2</i>). | |
| a3 [0..1] | [PU](#CIM17v40-PU) | Filter coefficient (<i>A3</i>). | |
| a4 [0..1] | [PU](#CIM17v40-PU) | Filter coefficient (<i>A4</i>). | |
| a5 [0..1] | [PU](#CIM17v40-PU) | Filter coefficient (<i>A5</i>). | |
| al [0..1] | [PU](#CIM17v40-PU) | Limiter (<i>Al</i>). | |
| athres [0..1] | [PU](#CIM17v40-PU) | Threshold value above which output averaging will be bypassed (<i>Athres</i>). Typical value = 0,005. | |
| b0 [0..1] | [PU](#CIM17v40-PU) | Filter coefficient (<i>B0</i>). | |
| b1 [0..1] | [PU](#CIM17v40-PU) | Filter coefficient (<i>B1</i>). | |
| b2 [0..1] | [PU](#CIM17v40-PU) | Filter coefficient (<i>B2</i>). | |
| b3 [0..1] | [PU](#CIM17v40-PU) | Filter coefficient (<i>B3</i>). | |
| b4 [0..1] | [PU](#CIM17v40-PU) | Filter coefficient (<i>B4</i>). | |
| b5 [0..1] | [PU](#CIM17v40-PU) | Filter coefficient (<i>B5</i>). | |
| dl [0..1] | [PU](#CIM17v40-PU) | Limiter (<i>Dl</i>). | |
| dtc [0..1] | [Seconds](#CIM17v40-Seconds) | Time step related to activation of controls (<i>deltatc</i>) (&gt;= 0). Typical value = 0,025 (0,03 for 50 Hz). | |
| dtf [0..1] | [Seconds](#CIM17v40-Seconds) | Time step frequency calculation (<i>deltatf</i>) (&gt;= 0). Typical value = 0,025 (0,03 for 50 Hz). | |
| dtp [0..1] | [Seconds](#CIM17v40-Seconds) | Time step active power calculation (<i>deltatp</i>) (&gt;= 0). Typical value = 0,0125 (0,015 for 50 Hz). | |
| isw [0..1] | [Boolean](#CIM17v40-Boolean) | Digital/analogue output switch (<i>Isw</i>).true = produce analogue outputfalse = convert to digital output, using tap selection table. | |
| k [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K</i>). Typical value = 9. | |
| lthres [0..1] | [PU](#CIM17v40-PU) | Threshold value (<i>Lthres</i>). | |
| m [0..1] | [PU](#CIM17v40-PU) | (<i>M</i>). <i>M</i> = 2 x <i>H</i>. Typical value = 5. | |
| nav [0..1] | [Float](#CIM17v40-Float) | Number of control outputs to average (<i>NAV</i>) (1 &lt;= <i>NAV</i> &lt;= 16). Typical value = 4. | |
| ncl [0..1] | [Float](#CIM17v40-Float) | Number of counts at limit to active limit function (<i>NCL</i>) (&gt; 0). | |
| ncr [0..1] | [Float](#CIM17v40-Float) | Number of counts until reset after limit function is triggered (<i>NCR</i>). | |
| pmin [0..1] | [PU](#CIM17v40-PU) | (<i>Pmin</i>). | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T1</i>) (&gt;= 0). Typical value = 0,3. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T2</i>) (&gt;= 0). Typical value = 1. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T3</i>) (&gt;= 0). Typical value = 0,2. | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T4</i>) (&gt;= 0). Typical value = 0,05. | |
| t5 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T5</i>) (&gt;= 0). | |
| t6 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T6</i>) (&gt;= 0). | |
| tf [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Tf</i>) (&gt;= 0). Typical value = 0,2. | |
| tp [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Tp</i>) (&gt;= 0). Typical value = 0,2. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PowerSystemStabilizerDynamics](CIM17v40-PowerSystemStabilizerDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PssRQB}
### PssRQB

Inheritance path = [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PssRQB {

+ kdpm : Float [0..1]
+ ki2 : Float [0..1]
+ ki3 : Float [0..1]
+ ki4 : Float [0..1]
+ sibv : PU [0..1]
+ t4f : Seconds [0..1]
+ t4m : Seconds [0..1]
+ t4mom : Seconds [0..1]
+ tomd : Seconds [0..1]
+ tomsl : Seconds [0..1]
}

class PowerSystemStabilizerDynamics {

}

PowerSystemStabilizerDynamics <|-- PssRQB : inherits from
```

Power system stabilizer type RQB. This power system stabilizer is intended to be used together with excitation system type ExcRQB, which is primarily used in nuclear or thermal generating units.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kdpm [0..1] | [Float](#CIM17v40-Float) | Lead lag gain (<i>KDPM</i>). Typical value = 0,185. | |
| ki2 [0..1] | [Float](#CIM17v40-Float) | Speed input gain (<i>Ki2</i>). Typical value = 3,43. | |
| ki3 [0..1] | [Float](#CIM17v40-Float) | Electrical power input gain (<i>Ki3</i>). Typical value = -11,45. | |
| ki4 [0..1] | [Float](#CIM17v40-Float) | Mechanical power input gain (<i>Ki4</i>). Typical value = 11,86. | |
| sibv [0..1] | [PU](#CIM17v40-PU) | Speed deadband (<i>SIBV</i>). Typical value = 0,006. | |
| t4f [0..1] | [Seconds](#CIM17v40-Seconds) | Lead lag time constant (<i>T4F</i>) (&gt;= 0). Typical value = 0,045. | |
| t4m [0..1] | [Seconds](#CIM17v40-Seconds) | Input time constant (<i>T4M</i>) (&gt;= 0). Typical value = 5. | |
| t4mom [0..1] | [Seconds](#CIM17v40-Seconds) | Speed time constant (<i>T4MOM</i>) (&gt;= 0). Typical value = 1,27. | |
| tomd [0..1] | [Seconds](#CIM17v40-Seconds) | Speed delay (<i>TOMD</i>) (&gt;= 0). Typical value = 0,02. | |
| tomsl [0..1] | [Seconds](#CIM17v40-Seconds) | Speed time constant (<i>TOMSL</i>) (&gt;= 0). Typical value = 0,04. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PowerSystemStabilizerDynamics](CIM17v40-PowerSystemStabilizerDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PssSB4}
### PssSB4

Inheritance path = [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PssSB4 {

+ kx : PU [0..1]
+ ta : Seconds [0..1]
+ tb : Seconds [0..1]
+ tc : Seconds [0..1]
+ td : Seconds [0..1]
+ te : Seconds [0..1]
+ tt : Seconds [0..1]
+ tx1 : Seconds [0..1]
+ tx2 : Seconds [0..1]
+ vsmax : PU [0..1]
+ vsmin : PU [0..1]
}

class PowerSystemStabilizerDynamics {

}

PowerSystemStabilizerDynamics <|-- PssSB4 : inherits from
```

Power sensitive stabilizer model.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kx [0..1] | [PU](#CIM17v40-PU) | Gain (<i>Kx</i>). Typical value = 2,7. | |
| ta [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Ta</i>) (&gt;= 0). Typical value = 0,37. | |
| tb [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Tb</i>) (&gt;= 0). Typical value = 0,37. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Tc</i>) (&gt;= 0). Typical value = 0,035. | |
| td [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Td</i>) (&gt;= 0). Typical value = 0,0. | |
| te [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Te</i>) (&gt;= 0). Typical value = 0,0169. | |
| tt [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Tt</i>) (&gt;= 0). Typical value = 0,18. | |
| tx1 [0..1] | [Seconds](#CIM17v40-Seconds) | Reset time constant (<i>Tx1</i>) (&gt;= 0). Typical value = 0,035. | |
| tx2 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>Tx2</i>) (&gt;= 0). Typical value = 5,0. | |
| vsmax [0..1] | [PU](#CIM17v40-PU) | Limiter (<i>Vsmax</i>) (&gt; PssSB4.vsmin). Typical value = 0,062. | |
| vsmin [0..1] | [PU](#CIM17v40-PU) | Limiter (<i>Vsmin</i>) (&lt; PssSB4.vsmax). Typical value = -0,062. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PowerSystemStabilizerDynamics](CIM17v40-PowerSystemStabilizerDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PssSH}
### PssSH

Inheritance path = [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PssSH {

+ k : PU [0..1]
+ k0 : PU [0..1]
+ k1 : PU [0..1]
+ k2 : PU [0..1]
+ k3 : PU [0..1]
+ k4 : PU [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ td : Seconds [0..1]
+ vsmax : PU [0..1]
+ vsmin : PU [0..1]
}

class PowerSystemStabilizerDynamics {

}

PowerSystemStabilizerDynamics <|-- PssSH : inherits from
```

Siemens<sup>TM</sup> �H infinity� power system stabilizer with generator electrical power input.

[Footnote: Siemens "H infinity" power system stabilizers are an example of suitable products available commercially. This information is given for the convenience of users of this document and does not constitute an endorsement by IEC of these products.]


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| k [0..1] | [PU](#CIM17v40-PU) | Main gain (<i>K</i>). Typical value = 1. | |
| k0 [0..1] | [PU](#CIM17v40-PU) | Gain 0 (<i>K0</i>). Typical value = 0,012. | |
| k1 [0..1] | [PU](#CIM17v40-PU) | Gain 1 (<i>K1</i>). Typical value = 0,488. | |
| k2 [0..1] | [PU](#CIM17v40-PU) | Gain 2 (<i>K2</i>). Typical value = 0,064. | |
| k3 [0..1] | [PU](#CIM17v40-PU) | Gain 3 (<i>K3</i>). Typical value = 0,224. | |
| k4 [0..1] | [PU](#CIM17v40-PU) | Gain 4 (<i>K4</i>). Typical value = 0,1. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant 1 (<i>T1</i>) (&gt; 0). Typical value = 0,076. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant 2 (<i>T2</i>) (&gt; 0). Typical value = 0,086. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant 3 (<i>T3</i>) (&gt; 0). Typical value = 1,068. | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant 4 (<i>T4</i>) (&gt; 0). Typical value = 1,913. | |
| td [0..1] | [Seconds](#CIM17v40-Seconds) | Input time constant (<i>T</i><i><sub>d</sub></i>) (&gt;= 0). Typical value = 10. | |
| vsmax [0..1] | [PU](#CIM17v40-PU) | Output maximum limit (<i>Vsmax</i>) (&gt; PssSH.vsmin). Typical value = 0,1. | |
| vsmin [0..1] | [PU](#CIM17v40-PU) | Output minimum limit (<i>Vsmin</i>) (&lt; PssSH.vsmax). Typical value = -0,1. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PowerSystemStabilizerDynamics](CIM17v40-PowerSystemStabilizerDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PssSK}
### PssSK

Inheritance path = [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PssSK {

+ k1 : PU [0..1]
+ k2 : PU [0..1]
+ k3 : PU [0..1]
+ t1 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ t5 : Seconds [0..1]
+ t6 : Seconds [0..1]
+ vsmax : PU [0..1]
+ vsmin : PU [0..1]
}

class PowerSystemStabilizerDynamics {

}

PowerSystemStabilizerDynamics <|-- PssSK : inherits from
```

Slovakian PSS with three inputs.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| k1 [0..1] | [PU](#CIM17v40-PU) | Gain <i>P</i> (<i>K</i><i><sub>1</sub></i>). Typical value = -0,3. | |
| k2 [0..1] | [PU](#CIM17v40-PU) | Gain <i>f</i><i><sub>E</sub></i><i> </i>(<i>K</i><i><sub>2</sub></i>). Typical value = -0,15. | |
| k3 [0..1] | [PU](#CIM17v40-PU) | Gain <i>I</i><i><sub>f</sub></i><i> </i>(<i>K</i><i><sub>3</sub></i>). Typical value = 10. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Denominator time constant (<i>T</i><i><sub>1</sub></i>) (&gt; 0,005). Typical value = 0,3. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Filter time constant (<i>T</i><i><sub>2</sub></i>) (&gt; 0,005). Typical value = 0,35. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Denominator time constant (<i>T</i><i><sub>3</sub></i>) (&gt; 0,005). Typical value = 0,22. | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Filter time constant (<i>T</i><i><sub>4</sub></i>) (&gt; 0,005). Typical value = 0,02. | |
| t5 [0..1] | [Seconds](#CIM17v40-Seconds) | Denominator time constant (<i>T</i><i><sub>5</sub></i>) (&gt; 0,005). Typical value = 0,02. | |
| t6 [0..1] | [Seconds](#CIM17v40-Seconds) | Filter time constant (<i>T</i><i><sub>6</sub></i>) (&gt; 0,005). Typical value = 0,02. | |
| vsmax [0..1] | [PU](#CIM17v40-PU) | Stabilizer output maximum limit (<i>V</i><i><sub>SMAX</sub></i>) (&gt; PssSK.vsmin). Typical value = 0,4. | |
| vsmin [0..1] | [PU](#CIM17v40-PU) | Stabilizer output minimum limit (<i>V</i><i><sub>SMIN</sub></i>) (&lt; PssSK.vsmax). Typical value = -0.4. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PowerSystemStabilizerDynamics](CIM17v40-PowerSystemStabilizerDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PssSTAB2A}
### PssSTAB2A

Inheritance path = [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PssSTAB2A {

+ hlim : PU [0..1]
+ k2 : PU [0..1]
+ k3 : PU [0..1]
+ k4 : PU [0..1]
+ k5 : PU [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t5 : Seconds [0..1]
}

class PowerSystemStabilizerDynamics {

}

PowerSystemStabilizerDynamics <|-- PssSTAB2A : inherits from
```

Power system stabilizer part of an ABB excitation system.

[Footnote: ABB excitation systems are an example of suitable products available commercially. This information is given for the convenience of users of this document and does not constitute an endorsement by IEC of these products.]


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| hlim [0..1] | [PU](#CIM17v40-PU) | Stabilizer output limiter (<i>H</i><i><sub>LIM</sub></i>). Typical value = 0,5. | |
| k2 [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K2</i>). Typical value = 1,0. | |
| k3 [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K3</i>). Typical value = 0,25. | |
| k4 [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K4</i>). Typical value = 0,075. | |
| k5 [0..1] | [PU](#CIM17v40-PU) | Gain (<i>K5</i>). Typical value = 2,5. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T2</i>). Typical value = 4,0. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T3</i>). Typical value = 2,0. | |
| t5 [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T5</i>). Typical value = 4,5. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PowerSystemStabilizerDynamics](CIM17v40-PowerSystemStabilizerDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PssWECC}
### PssWECC

Inheritance path = [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PssWECC {

+ inputSignal1Type : enum:InputSignalKind [0..1]
+ inputSignal2Type : enum:InputSignalKind [0..1]
+ k1 : PU [0..1]
+ k2 : PU [0..1]
+ t1 : Seconds [0..1]
+ t10 : Seconds [0..1]
+ t2 : Seconds [0..1]
+ t3 : Seconds [0..1]
+ t4 : Seconds [0..1]
+ t5 : Seconds [0..1]
+ t6 : Seconds [0..1]
+ t7 : Seconds [0..1]
+ t8 : Seconds [0..1]
+ t9 : Seconds [0..1]
+ vcl : PU [0..1]
+ vcu : PU [0..1]
+ vsmax : PU [0..1]
+ vsmin : PU [0..1]
}

class PowerSystemStabilizerDynamics {

}

PowerSystemStabilizerDynamics <|-- PssWECC : inherits from
```

Dual input power system stabilizer, based on IEEE type 2, with modified output limiter defined by WECC (Western Electricity Coordinating Council, USA).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| inputSignal1Type [0..1] | [InputSignalKind](#CIM17v40-InputSignalKind) | Type of input signal #1 (rotorAngularFrequencyDeviation, busFrequencyDeviation, generatorElectricalPower, generatorAcceleratingPower, busVoltage, or busVoltageDerivative - shall be different than PssWECC.inputSignal2Type). Typical value = rotorAngularFrequencyDeviation. | |
| inputSignal2Type [0..1] | [InputSignalKind](#CIM17v40-InputSignalKind) | Type of input signal #2 (rotorAngularFrequencyDeviation, busFrequencyDeviation, generatorElectricalPower, generatorAcceleratingPower, busVoltage, busVoltageDerivative - shall be different than PssWECC.inputSignal1Type). Typical value = busVoltageDerivative. | |
| k1 [0..1] | [PU](#CIM17v40-PU) | Input signal 1 gain (<i>K</i><i><sub>1</sub></i>). Typical value = 1,13. | |
| k2 [0..1] | [PU](#CIM17v40-PU) | Input signal 2 gain (<i>K</i><i><sub>2</sub></i>). Typical value = 0,0. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Input signal 1 transducer time constant (<i>T</i><i><sub>1</sub></i>) (&gt;= 0). Typical value = 0,037. | |
| t10 [0..1] | [Seconds](#CIM17v40-Seconds) | Lag time constant (<i>T</i><i><sub>10</sub></i>) (&gt;= 0). Typical value = 0. | |
| t2 [0..1] | [Seconds](#CIM17v40-Seconds) | Input signal 2 transducer time constant (<i>T</i><i><sub>2</sub></i>) (&gt;= 0). Typical value = 0,0. | |
| t3 [0..1] | [Seconds](#CIM17v40-Seconds) | Stabilizer washout time constant (<i>T</i><i><sub>3</sub></i>) (&gt;= 0). Typical value = 9,5. | |
| t4 [0..1] | [Seconds](#CIM17v40-Seconds) | Stabilizer washout time lag constant (<i>T</i><i><sub>4</sub></i>) (&gt;= 0). Typical value = 9,5. | |
| t5 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead time constant (<i>T</i><i><sub>5</sub></i>) (&gt;= 0). Typical value = 1,7. | |
| t6 [0..1] | [Seconds](#CIM17v40-Seconds) | Lag time constant (<i>T</i><i><sub>6</sub></i>) (&gt;= 0). Typical value = 1,5. | |
| t7 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead time constant (<i>T</i><i><sub>7</sub></i>) (&gt;= 0). Typical value = 1,7. | |
| t8 [0..1] | [Seconds](#CIM17v40-Seconds) | Lag time constant (<i>T</i><i><sub>8</sub></i>) (&gt;= 0). Typical value = 1,5. | |
| t9 [0..1] | [Seconds](#CIM17v40-Seconds) | Lead time constant (<i>T</i><i><sub>9</sub></i>) (&gt;= 0). Typical value = 0. | |
| vcl [0..1] | [PU](#CIM17v40-PU) | Minimum value for voltage compensator output (<i>V</i><i><sub>CL</sub></i>). Typical value = 0. | |
| vcu [0..1] | [PU](#CIM17v40-PU) | Maximum value for voltage compensator output (<i>V</i><i><sub>CU</sub></i>). Typical value = 0. | |
| vsmax [0..1] | [PU](#CIM17v40-PU) | Maximum output signal (<i>Vsmax</i>) (&gt; PssWECC.vsmin). Typical value = 0,05. | |
| vsmin [0..1] | [PU](#CIM17v40-PU) | Minimum output signal (<i>Vsmin</i>) (&lt; PssWECC.vsmax). Typical value = -0,05. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [PowerSystemStabilizerDynamics](CIM17v40-PowerSystemStabilizerDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PublicX509Certificate}
### PublicX509Certificate


```mermaid
classDiagram
direction TB

class PublicX509Certificate {

+ issuerName : String [0..1]
+ serialNumber : String [0..1]
}

class ISOUpperLayer {

}

PublicX509Certificate --> "0..1" ISOUpperLayer : ISOUpperLayer
class TCPAccessPoint {

}

PublicX509Certificate --> "0..1" TCPAccessPoint : TCPAccessPoint
```

Used to convey information that will allow matching in order to determine which certificate to use. Actual certificates are exchanged externally to the CIM exchange.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| issuerName [0..1] | [String](#CIM17v40-String) | Represents the CA that issued the certificate. Defined to be per X.509. | |
| serialNumber [0..1] | [String](#CIM17v40-String) | Is the serial number of the certificate per X.509 definition. | |
| ISOUpperLayer [0..1] | [ISOUpperLayer](#CIM17v40-ISOUpperLayer) | Application layer used with the certificate for mutual authentication. | |
| TCPAccessPoint [0..1] | [TCPAccessPoint](#CIM17v40-TCPAccessPoint) | The association allows a certificate to be bound for use by TLS. | |

{#CIM17v40-PumpingCostSchedule}
### PumpingCostSchedule

Inheritance path = [BidHourlyProductSchedule](#CIM17v40-BidHourlyProductSchedule) => [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) => [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PumpingCostSchedule {

+ value : Float [0..1]
}

class BidHourlyProductSchedule {

}

BidHourlyProductSchedule <|-- PumpingCostSchedule : inherits from
```

The operating cost of a Pump Storage Hydro Unit operating as a hydro pump.

This schedule is assocated with the hourly parameters in a resource bid associated with a specific product within the bid.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| value [0..1] | [Float](#CIM17v40-Float) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ProductBid [1] | [ProductBid](#CIM17v40-ProductBid) | see [BidHourlyProductSchedule](CIM17v40-BidHourlyProductSchedule) | |
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | see [RegularIntervalSchedule](CIM17v40-RegularIntervalSchedule) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PumpingLevelSchedule}
### PumpingLevelSchedule

Inheritance path = [BidHourlyProductSchedule](#CIM17v40-BidHourlyProductSchedule) => [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) => [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PumpingLevelSchedule {

+ value : Float [0..1]
}

class BidHourlyProductSchedule {

}

BidHourlyProductSchedule <|-- PumpingLevelSchedule : inherits from
```

The fixed operating level of a Pump Storage Hydro Unit operating as a hydro pump. Associated with the energy market product type.

This schedule is assocated with the hourly parameters in a resource bid associated with a specific product within the bid.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| value [0..1] | [Float](#CIM17v40-Float) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ProductBid [1] | [ProductBid](#CIM17v40-ProductBid) | see [BidHourlyProductSchedule](CIM17v40-BidHourlyProductSchedule) | |
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | see [RegularIntervalSchedule](CIM17v40-RegularIntervalSchedule) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-PumpingShutDownCostSchedule}
### PumpingShutDownCostSchedule

Inheritance path = [BidHourlyProductSchedule](#CIM17v40-BidHourlyProductSchedule) => [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) => [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class PumpingShutDownCostSchedule {

+ value : Float [0..1]
}

class BidHourlyProductSchedule {

}

BidHourlyProductSchedule <|-- PumpingShutDownCostSchedule : inherits from
```

The cost to shutdown a Pump Storage Hydro Unit (in pump mode) or a pump.

This schedule is assocated with the hourly parameters in a resource bid associated with a specific product within the bid.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| value [0..1] | [Float](#CIM17v40-Float) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ProductBid [1] | [ProductBid](#CIM17v40-ProductBid) | see [BidHourlyProductSchedule](CIM17v40-BidHourlyProductSchedule) | |
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | see [RegularIntervalSchedule](CIM17v40-RegularIntervalSchedule) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Qlimiter}
### (informative) Qlimiter


```mermaid
classDiagram
direction TB

class Qlimiter {

}

class Delay {

}

Qlimiter --> "1" Delay : Delay
class VSCtype1 {

}

Qlimiter --> "0..1" VSCtype1 : VSCtype1
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Delay [1]` (informative) | [Delay](#CIM17v40-Delay) | | |
| `VSCtype1 [0..1]` (informative) | [VSCtype1](#CIM17v40-VSCtype1) | | |

{#CIM17v40-Qmode}
### (informative) Qmode


```mermaid
classDiagram
direction TB

class Qmode {

}

class Delay {

}

Qmode --> "1" Delay : Delay
class VSCtype1 {

}

Qmode --> "0..1" VSCtype1 : VSCtype1
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Delay [1]` (informative) | [Delay](#CIM17v40-Delay) | | |
| `VSCtype1 [0..1]` (informative) | [VSCtype1](#CIM17v40-VSCtype1) | | |

{#CIM17v40-Qregulator}
### (informative) Qregulator


```mermaid
classDiagram
direction TB

class Qregulator {

}

class Delay {

}

Qregulator --> "1" Delay : Delay
class VSCtype1 {

}

Qregulator --> "0..1" VSCtype1 : VSCtype1
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Delay [1]` (informative) | [Delay](#CIM17v40-Delay) | | |
| `VSCtype1 [0..1]` (informative) | [VSCtype1](#CIM17v40-VSCtype1) | | |

{#CIM17v40-QualificationRequirement}
### QualificationRequirement

Inheritance path = [WorkIdentifiedObject](#CIM17v40-WorkIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class QualificationRequirement {

+ qualificationID : String [0..1]
}

class WorkIdentifiedObject {

}

WorkIdentifiedObject <|-- QualificationRequirement : inherits from
```

Certain skills are required and must be certified in order for a person (typically a member of a crew) to be qualified to work on types of equipment.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| qualificationID [0..1] | [String](#CIM17v40-String) | Qualification identifier. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Quality61850}
### Quality61850


```mermaid
classDiagram
direction TB

class Quality61850 {

+ badReference : Boolean [0..1]
+ estimatorReplaced : Boolean [0..1]
+ failure : Boolean [0..1]
+ oldData : Boolean [0..1]
+ operatorBlocked : Boolean [0..1]
+ oscillatory : Boolean [0..1]
+ outOfRange : Boolean [0..1]
+ overFlow : Boolean [0..1]
+ source : enum:Source [0..1]
+ suspect : Boolean [0..1]
+ test : Boolean [0..1]
+ validity : enum:Validity [0..1]
}

```

Quality flags in this class are as defined in IEC 61850, except for estimatorReplaced, which has been included in this class for convenience.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| badReference [0..1] | [Boolean](#CIM17v40-Boolean) | Measurement value may be incorrect due to a reference being out of calibration. | |
| estimatorReplaced [0..1] | [Boolean](#CIM17v40-Boolean) | Value has been replaced by State Estimator. estimatorReplaced is not an IEC61850 quality bit but has been put in this class for convenience. | |
| failure [0..1] | [Boolean](#CIM17v40-Boolean) | This identifier indicates that a supervision function has detected an internal or external failure, e.g. communication failure. | |
| oldData [0..1] | [Boolean](#CIM17v40-Boolean) | Measurement value is old and possibly invalid, as it has not been successfully updated during a specified time interval. | |
| operatorBlocked [0..1] | [Boolean](#CIM17v40-Boolean) | Measurement value is blocked and hence unavailable for transmission. | |
| oscillatory [0..1] | [Boolean](#CIM17v40-Boolean) | To prevent some overload of the communication it is sensible to detect and suppress oscillating (fast changing) binary inputs. If a signal changes in a defined time twice in the same direction (from 0 to 1 or from 1 to 0) then oscillation is detected and the detail quality identifier "oscillatory" is set. If it is detected a configured numbers of transient changes could be passed by. In this time the validity status "questionable" is set. If after this defined numbers of changes the signal is still in the oscillating state the value shall be set either to the opposite state of the previous stable value or to a defined default value. In this case the validity status "questionable" is reset and "invalid" is set as long as the signal is oscillating. If it is configured such that no transient changes should be passed by then the validity status "invalid" is set immediately in addition to the detail quality identifier "oscillatory" (used for status information only). | |
| outOfRange [0..1] | [Boolean](#CIM17v40-Boolean) | Measurement value is beyond a predefined range of value. | |
| overFlow [0..1] | [Boolean](#CIM17v40-Boolean) | Measurement value is beyond the capability of being represented properly. For example, a counter value overflows from maximum count back to a value of zero. | |
| source [0..1] | [Source](#CIM17v40-Source) | Source gives information related to the origin of a value. The value may be acquired from the process, defaulted or substituted. | |
| suspect [0..1] | [Boolean](#CIM17v40-Boolean) | A correlation function has detected that the value is not consistent with other values. Typically set by a network State Estimator. | |
| test [0..1] | [Boolean](#CIM17v40-Boolean) | Measurement value is transmitted for test purposes. | |
| validity [0..1] | [Validity](#CIM17v40-Validity) | Validity of the measurement value. | |

{#CIM17v40-Quantity}
### (Attribute) Quantity


```mermaid
classDiagram
direction TB

class Quantity {

+ quality : String [0..1]
+ type : String [0..1]
}

```

Description of quantities needed in the data exchange.

The type of the quantity is described either by the role of the association or the type attribute.

The quality attribute provides the information about the quality of the quantity (measured, estimated, etc.).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| quality [0..1] | [String](#CIM17v40-String) | The quality of the information being provided. This quality may be estimated, not available, as provided, etc. | |
| type [0..1] | [String](#CIM17v40-String) | The description of the type of the quantity. | |

{#CIM17v40-RMRDetermination}
### RMRDetermination


```mermaid
classDiagram
direction TB

class RMRDetermination {

}

class Bid {

}

RMRDetermination --> "0..1" Bid : Bid
```

Indicates whether unit is a reliablity must run unit: required to be on to satisfy Grid Code Reliablitiy criteria, load demand, or voltage support.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Bid [0..1] | [Bid](#CIM17v40-Bid) | | |

{#CIM17v40-RMRHeatRateCurve}
### RMRHeatRateCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RMRHeatRateCurve {

}

class Curve {

}

Curve <|-- RMRHeatRateCurve : inherits from
class RegisteredGenerator {

}

RMRHeatRateCurve --> "0..1" RegisteredGenerator : RegisteredGenerator
```

Model to support processing of reliability must run units.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| RegisteredGenerator [0..1] | [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RMROperatorInput}
### RMROperatorInput

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RMROperatorInput {

+ manuallySchedRMRMw : Float [0..1]
+ updateTimeStamp : DateTime [0..1]
+ updateType : enum:MQSCHGType [0..1]
+ updateUser : String [0..1]
}

class MarketFactors {

}

MarketFactors <|-- RMROperatorInput : inherits from
class RegisteredResource {

}

RMROperatorInput --> "0..1" RegisteredResource : RegisteredResource
```

RMR Operator's entry of the RMR requirement per market interval.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| manuallySchedRMRMw [0..1] | [Float](#CIM17v40-Float) | The lower of the original pre-dispatch or the AC run schedule (Also known as the RMR Reguirement) becomes the pre-dispatch value. | |
| updateTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| updateType [0..1] | [MQSCHGType](#CIM17v40-MQSCHGType) | | |
| updateUser [0..1] | [String](#CIM17v40-String) | | |
| RegisteredResource [0..1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RMRStartUpCostCurve}
### RMRStartUpCostCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RMRStartUpCostCurve {

}

class Curve {

}

Curve <|-- RMRStartUpCostCurve : inherits from
class RegisteredGenerator {

}

RMRStartUpCostCurve --> "0..1" RegisteredGenerator : RegisteredGenerator
```

Model to support processing of reliability must run units.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| RegisteredGenerator [0..1] | [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RMRStartUpEnergyCurve}
### RMRStartUpEnergyCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RMRStartUpEnergyCurve {

}

class Curve {

}

Curve <|-- RMRStartUpEnergyCurve : inherits from
class RegisteredGenerator {

}

RMRStartUpEnergyCurve --> "0..1" RegisteredGenerator : RegisteredGenerator
```

Model to support processing of reliability must run units.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| RegisteredGenerator [0..1] | [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RMRStartUpFuelCurve}
### RMRStartUpFuelCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RMRStartUpFuelCurve {

}

class Curve {

}

Curve <|-- RMRStartUpFuelCurve : inherits from
class RegisteredGenerator {

}

RMRStartUpFuelCurve --> "0..1" RegisteredGenerator : RegisteredGenerator
```

Model to support processing of reliability must run units.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| RegisteredGenerator [0..1] | [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RMRStartUpTimeCurve}
### RMRStartUpTimeCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RMRStartUpTimeCurve {

}

class Curve {

}

Curve <|-- RMRStartUpTimeCurve : inherits from
class RegisteredGenerator {

}

RMRStartUpTimeCurve --> "0..1" RegisteredGenerator : RegisteredGenerator
```

Model to support processing of reliability must run units.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| RegisteredGenerator [0..1] | [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RTO}
### RTO

Inheritance path = [MarketParticipant](#CIM17v40-MarketParticipant) => [Organisation](#CIM17v40-Organisation) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RTO {

}

class MarketParticipant {

}

MarketParticipant <|-- RTO : inherits from
```

Regional transmission operator.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Organisation](CIM17v40-Organisation) | |
| ParentOrganisation [0..1] | [ParentOrganization](#CIM17v40-ParentOrganization) | see [Organisation](CIM17v40-Organisation) | |
| phone1 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Organisation](CIM17v40-Organisation) | |
| phone2 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Organisation](CIM17v40-Organisation) | |
| postalAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Organisation](CIM17v40-Organisation) | |
| streetAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Organisation](CIM17v40-Organisation) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RUCAwardInstruction}
### RUCAwardInstruction


```mermaid
classDiagram
direction TB

class RUCAwardInstruction {

+ clearedPrice : Float [0..1]
+ marketProductType : enum:MarketProductType [0..1]
+ RUCAward : Float [0..1]
+ RUCCapacity : Float [0..1]
+ RUCSchedule : Float [0..1]
+ updateTimeStamp : DateTime [0..1]
+ updateType : enum:MQSCHGType [0..1]
+ updateUser : String [0..1]
}

class RegisteredResource {

}

RUCAwardInstruction --> "0..1" RegisteredResource : RegisteredResource
```

This class models the information about the RUC awards.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| clearedPrice [0..1] | [Float](#CIM17v40-Float) | Marginal Price ($/MW) for the commodity (Regulation Up, Regulation Down, Spinning Reserve, or Non-spinning reserve) for pricing run. | |
| marketProductType [0..1] | [MarketProductType](#CIM17v40-MarketProductType) | major product type may include the following but not limited to:EnergyRegulation UpRegulation DnSpinning ReserveNon-Spinning ReserveOperating Reserve | |
| RUCAward [0..1] | [Float](#CIM17v40-Float) | The RUC Award of a resource is the portion of the RUC Capacity that is not under RA or RMR contracts. The RUC Award of a resource is the portion of the RUC Capacity that is eligible for RUC Availability payment. | |
| RUCCapacity [0..1] | [Float](#CIM17v40-Float) | The RUC Capacity of a resource is the difference between (i) the RUC Schedule and (ii) the higher of the DA Schedule and the Minimum Load. | |
| RUCSchedule [0..1] | [Float](#CIM17v40-Float) | The RUC Schedule of a resource is its output level that balances the load forecast used in RUC. The RUC Schedule in RUC is similar to the DA Schedule in DAM. | |
| updateTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| updateType [0..1] | [MQSCHGType](#CIM17v40-MQSCHGType) | | |
| updateUser [0..1] | [String](#CIM17v40-String) | | |
| RegisteredResource [0..1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |

{#CIM17v40-RUCZone}
### RUCZone

Inheritance path = [AggregateNode](#CIM17v40-AggregateNode) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RUCZone {

}

class AggregateNode {

}

AggregateNode <|-- RUCZone : inherits from
```

A specialized class of type AggregatedNode type. Defines RUC Zones. A forecast region represents a collection of Nodes for which the Market operator has developed sufficient historical demand and relevant weather data to perform a demand forecast for such area. The Market Operator may further adjust this forecast to ensure that the Reliability Unit Commitment produces adequate local capacity procurement.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| anodeType [0..1] | [AnodeType](#CIM17v40-AnodeType) | see [AggregateNode](CIM17v40-AggregateNode) | |
| qualifASOrder [0..1] | [Integer](#CIM17v40-Integer) | see [AggregateNode](#CIM17v40-AggregateNode) | |
| RTO [1] | [RTO](#CIM17v40-RTO) | see [AggregateNode](CIM17v40-AggregateNode) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RaiseLowerCommand}
### RaiseLowerCommand

Inheritance path = [AnalogControl](#CIM17v40-AnalogControl) => [Control](#CIM17v40-Control) => [IOPoint](#CIM17v40-IOPoint) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RaiseLowerCommand {

}

class AnalogControl {

}

AnalogControl <|-- RaiseLowerCommand : inherits from
class ValueAliasSet {

}

RaiseLowerCommand --> "0..1" ValueAliasSet : ValueAliasSet
```

An analog control that increases or decreases a set point value with pulses. Unless otherwise specified, one pulse moves the set point by one.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ValueAliasSet [0..1] | [ValueAliasSet](#CIM17v40-ValueAliasSet) | The ValueAliasSet used for translation of a Control value to a name. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maxValue [0..1] | [Float](#CIM17v40-Float) | see [AnalogControl](#CIM17v40-AnalogControl) | |
| minValue [0..1] | [Float](#CIM17v40-Float) | see [AnalogControl](#CIM17v40-AnalogControl) | |
| AnalogValue [1] | [AnalogValue](#CIM17v40-AnalogValue) | see [AnalogControl](CIM17v40-AnalogControl) | |
| controlType [0..1] | [String](#CIM17v40-String) | see [Control](#CIM17v40-Control) | |
| operationInProgress [0..1] | [Boolean](#CIM17v40-Boolean) | see [Control](#CIM17v40-Control) | |
| timeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | see [Control](#CIM17v40-Control) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Control](CIM17v40-Control) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Control](CIM17v40-Control) | |
| ControlAction [0..1] | [ControlAction](#CIM17v40-ControlAction) | see [Control](CIM17v40-Control) | |
| PowerSystemResource [0..1] | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Control](CIM17v40-Control) | |
| RemoteControl [0..1] | [RemoteControl](#CIM17v40-RemoteControl) | see [Control](CIM17v40-Control) | |
| IOPointSource [0..1] | [IOPointSource](#CIM17v40-IOPointSource) | see [IOPoint](CIM17v40-IOPoint) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RampRateCurve}
### RampRateCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RampRateCurve {

+ condition : enum:RampRateCondition [0..1]
+ constraintRampType : enum:ConstraintRampType [0..1]
+ rampRateType : enum:RampRateType [0..1]
}

class Curve {

}

Curve <|-- RampRateCurve : inherits from
class GeneratingBid {

}

RampRateCurve --> "0..1" GeneratingBid : GeneratingBid
class InterTieBid {

}

RampRateCurve --> "0..1" InterTieBid : InterTieBid
class LoadBid {

}

RampRateCurve --> "0..1" LoadBid : LoadBid
```

Ramp rate as a function of resource MW output.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| condition [0..1] | [RampRateCondition](#CIM17v40-RampRateCondition) | condition for the ramp rate | |
| constraintRampType [0..1] | [ConstraintRampType](#CIM17v40-ConstraintRampType) | The condition that identifies whether a Generating Resource should be constrained from Ancillary Service provision if its Schedule or Dispatch change across Trading Hours or Trading Intervals requires more than a specified fraction of the duration of the Trading Hour or Trading Interval.Valid values are Fast/Slow | |
| rampRateType [0..1] | [RampRateType](#CIM17v40-RampRateType) | How ramp rate is applied (e.g. raise or lower, as when applied to a generation resource) | |
| GeneratingBid [0..1] | [GeneratingBid](#CIM17v40-GeneratingBid) | | |
| InterTieBid [0..1] | [InterTieBid](#CIM17v40-InterTieBid) | | |
| LoadBid [0..1] | [LoadBid](#CIM17v40-LoadBid) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RatioTapChanger}
### RatioTapChanger

Inheritance path = [TapChanger](#CIM17v40-TapChanger) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RatioTapChanger {

+ stepVoltageIncrement : PerCent [0..1]
+ tculControlMode : enum:TransformerControlMode [0..1]
}

class TapChanger {

}

TapChanger <|-- RatioTapChanger : inherits from
class RatioTapChangerTable {

}

RatioTapChanger --> "0..1" RatioTapChangerTable : RatioTapChangerTable
class TransformerEnd {

}

RatioTapChanger --> "1" TransformerEnd : TransformerEnd
```

A tap changer that changes the voltage ratio impacting the voltage magnitude but not the phase angle across the transformer.

Angle sign convention (general): Positive value indicates a positive phase shift from the winding where the tap is located to the other winding (for a two-winding transformer).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| stepVoltageIncrement [0..1] | [PerCent](#CIM17v40-PerCent) | Tap step increment, in per cent of rated voltage of the power transformer end, per step position.When the increment is negative, the voltage decreases when the tap step increases. | |
| `tculControlMode [0..1]` (deprecated) | [TransformerControlMode](#CIM17v40-TransformerControlMode) | Specifies the regulation control mode (voltage or reactive) of the RatioTapChanger. | |
| RatioTapChangerTable [0..1] | [RatioTapChangerTable](#CIM17v40-RatioTapChangerTable) | The tap ratio table for this ratio tap changer. | |
| TransformerEnd [1] | [TransformerEnd](#CIM17v40-TransformerEnd) | Transformer end to which this ratio tap changer belongs. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| controlEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [TapChanger](#CIM17v40-TapChanger) | |
| highStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| initialDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [TapChanger](CIM17v40-TapChanger) | |
| lowStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| ltcFlag [0..1] | [Boolean](#CIM17v40-Boolean) | see [TapChanger](#CIM17v40-TapChanger) | |
| neutralStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| neutralU [0..1] | [Voltage](#CIM17v40-Voltage) | see [TapChanger](CIM17v40-TapChanger) | |
| normalStep [0..1] | [Integer](#CIM17v40-Integer) | see [TapChanger](#CIM17v40-TapChanger) | |
| step [0..1] | [Float](#CIM17v40-Float) | see [TapChanger](#CIM17v40-TapChanger) | |
| subsequentDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [TapChanger](CIM17v40-TapChanger) | |
| SvTapStep [0..1] | [SvTapStep](#CIM17v40-SvTapStep) | see [TapChanger](CIM17v40-TapChanger) | |
| TapChangerControl [0..1] | [TapChangerControl](#CIM17v40-TapChangerControl) | see [TapChanger](CIM17v40-TapChanger) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RatioTapChangerTable}
### RatioTapChangerTable

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RatioTapChangerTable {

}

class IdentifiedObject {

}

IdentifiedObject <|-- RatioTapChangerTable : inherits from
```

Describes a curve for how the voltage magnitude and impedance varies with the tap step.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RatioTapChangerTablePoint}
### RatioTapChangerTablePoint

Inheritance path = [TapChangerTablePoint](#CIM17v40-TapChangerTablePoint)

```mermaid
classDiagram
direction TB

class RatioTapChangerTablePoint {

}

class TapChangerTablePoint {

}

TapChangerTablePoint <|-- RatioTapChangerTablePoint : inherits from
class RatioTapChangerTable {

}

RatioTapChangerTablePoint --> "1" RatioTapChangerTable : RatioTapChangerTable
```

Describes each tap step in the ratio tap changer tabular curve.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| RatioTapChangerTable [1] | [RatioTapChangerTable](#CIM17v40-RatioTapChangerTable) | Table of this point. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| b [0..1] | [PerCent](#CIM17v40-PerCent) | see [TapChangerTablePoint](CIM17v40-TapChangerTablePoint) | |
| g [0..1] | [PerCent](#CIM17v40-PerCent) | see [TapChangerTablePoint](CIM17v40-TapChangerTablePoint) | |
| r [0..1] | [PerCent](#CIM17v40-PerCent) | see [TapChangerTablePoint](CIM17v40-TapChangerTablePoint) | |
| ratio [0..1] | [Float](#CIM17v40-Float) | see [TapChangerTablePoint](#CIM17v40-TapChangerTablePoint) | |
| step [0..1] | [Integer](#CIM17v40-Integer) | see [TapChangerTablePoint](#CIM17v40-TapChangerTablePoint) | |
| x [0..1] | [PerCent](#CIM17v40-PerCent) | see [TapChangerTablePoint](CIM17v40-TapChangerTablePoint) | |

{#CIM17v40-ReactiveCapabilityCurve}
### ReactiveCapabilityCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ReactiveCapabilityCurve {

+ coolantTemperature : Temperature [0..1]
+ hydrogenPressure : Pressure [0..1]
}

class Curve {

}

Curve <|-- ReactiveCapabilityCurve : inherits from
```

Reactive power rating envelope versus the synchronous machine's active power, in both the generating and motoring modes. For each active power value there is a corresponding high and low reactive power limit value. Typically there will be a separate curve for each coolant condition, such as hydrogen pressure. The Y1 axis values represent reactive minimum and the Y2 axis values represent reactive maximum.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| coolantTemperature [0..1] | [Temperature](#CIM17v40-Temperature) | The machine's coolant temperature (e.g., ambient air or stator circulating water). | |
| hydrogenPressure [0..1] | [Pressure](#CIM17v40-Pressure) | The hydrogen coolant pressure. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Reading}
### Reading

Inheritance path = [BaseReading](#CIM17v40-BaseReading) => [MeasurementValue](#CIM17v40-MeasurementValue) => [IOPoint](#CIM17v40-IOPoint) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Reading {

+ position : Integer [0..1]
+ reason : enum:ReadingReasonKind [0..1]
+ valueMissing : Boolean [0..1]
}

class BaseReading {

}

BaseReading <|-- Reading : inherits from
class ReadingType {

}

Reading --> "1" ReadingType : ReadingType
```

Specific value measured by a meter or other asset, or calculated by a system. Each Reading is associated with a specific ReadingType.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| position [0..1] | [Integer](#CIM17v40-Integer) | A sequential value representing the relative position within a given time interval. | |
| reason [0..1] | [ReadingReasonKind](#CIM17v40-ReadingReasonKind) | Reason for this reading being taken. | |
| valueMissing [0..1] | [Boolean](#CIM17v40-Boolean) | The indication of whether or not the quantity of this reading is missing. | |
| ReadingType [1] | [ReadingType](#CIM17v40-ReadingType) | Type information for this reading value. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| reportedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BaseReading](#CIM17v40-BaseReading) | |
| source [0..1] | [String](#CIM17v40-String) | see [BaseReading](#CIM17v40-BaseReading) | |
| value [0..1] | [String](#CIM17v40-String) | see [BaseReading](#CIM17v40-BaseReading) | |
| timePeriod [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [BaseReading](CIM17v40-BaseReading) | |
| sensorAccuracy [0..1] | [PerCent](#CIM17v40-PerCent) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| timeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | see [MeasurementValue](#CIM17v40-MeasurementValue) | |
| `CalculationMethodHierarchy [0..1]` (harmonization) | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| `ErpPerson [0..1]` (informative) | [OldPerson](#CIM17v40-OldPerson) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| `MeasurementValueQuality [0..1]` (AggregateOf) | [MeasurementValueQuality](#CIM17v40-MeasurementValueQuality) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| MeasurementValueSource [1] | [MeasurementValueSource](#CIM17v40-MeasurementValueSource) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| RemoteSource [0..1] | [RemoteSource](#CIM17v40-RemoteSource) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| IOPointSource [0..1] | [IOPointSource](#CIM17v40-IOPointSource) | see [IOPoint](CIM17v40-IOPoint) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ReadingQuality}
### ReadingQuality


```mermaid
classDiagram
direction TB

class ReadingQuality {

+ comment : String [0..1]
+ source : String [0..1]
+ timeStamp : DateTime [0..1]
}

class BaseReading {

}

ReadingQuality --> "0..1" BaseReading : Reading
class ReadingQualityType {

}

ReadingQuality --> "1" ReadingQualityType : ReadingQualityType
```

Quality of a specific reading value or interval reading value. Note that more than one quality may be applicable to a given reading. Typically not used unless problems or unusual conditions occur (i.e., quality for each reading is assumed to be good unless stated otherwise in associated reading quality type). It can also be used with the corresponding reading quality type to indicate that the validation has been performed and succeeded.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| comment [0..1] | [String](#CIM17v40-String) | Elaboration on the quality code. | |
| source [0..1] | [String](#CIM17v40-String) | System acting as the source of the quality code. | |
| timeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time at which the quality code was assigned or ascertained. | |
| Reading [0..1] | [BaseReading](#CIM17v40-BaseReading) | Reading value to which this quality applies. | |
| ReadingQualityType [1] | [ReadingQualityType](#CIM17v40-ReadingQualityType) | Type of this reading quality. | |

{#CIM17v40-ReadingQualityType}
### ReadingQualityType

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ReadingQualityType {

+ category : String [0..1]
+ subCategory : String [0..1]
+ systemId : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ReadingQualityType : inherits from
```

Detailed description for a quality of a reading value, produced by an end device or a system. Values in attributes allow for creation of the recommended codes to be used for identifying reading value quality codes as follows: <systemId>.<category>.<subCategory>.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| category [0..1] | [String](#CIM17v40-String) | High-level nature of the reading value quality. | |
| subCategory [0..1] | [String](#CIM17v40-String) | More specific nature of the reading value quality, as a further sub-categorisation of 'category'. | |
| systemId [0..1] | [String](#CIM17v40-String) | Identification of the system which has declared the issue with the data or provided commentary on the data. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ReadingType}
### ReadingType

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ReadingType {

+ accumulation : enum:AccumulationKind [0..1]
+ aggregate : enum:AggregateKind [0..1]
+ commodity : enum:CommodityKind [0..1]
+ consumptionTier : Integer [0..1]
+ cpp : Integer [0..1]
+ currency : enum:Currency [0..1]
+ flowDirection : enum:FlowDirectionKind [0..1]
+ macroPeriod : enum:MacroPeriodKind [0..1]
+ measurementKind : enum:MeasurementKind [0..1]
+ measuringPeriod : enum:MeasuringPeriodKind [0..1]
+ multiplier : enum:UnitMultiplier [0..1]
+ phases : enum:PhaseCode [0..1]
+ tou : Integer [0..1]
+ unit : enum:UnitSymbol [0..1]
+ argument : RationalNumber [0..1]
+ interharmonic : ReadingInterharmonic [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ReadingType : inherits from
class Channel {

}

ReadingType --> "0..1" Channel : Channel
class MeterReadSchedule {

}

ReadingType --> "0..1" MeterReadSchedule : MeterReadSchedule
class PendingCalculation {

}

ReadingType --> "0..1" PendingCalculation : PendingCalculation
```

Detailed description for a type of a reading value. Values in attributes allow for the creation of recommended codes to be used for identifying reading value types as follows: <macroPeriod>.<aggregate>.<measuringPeriod>.<accumulation>.<flowDirection>.<commodity>.<measurementKind>.<interharmonic.numerator>.<interharmonic.denominator>.<argument.numerator>.<argument.denominator>.<tou>.<cpp>.<consumptionTier>.<phases>.<multiplier>.<unit>.<currency>.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| accumulation [0..1] | [AccumulationKind](#CIM17v40-AccumulationKind) | Accumulation behaviour of a reading over time, usually 'measuringPeriod', to be used with individual endpoints (as opposed to 'macroPeriod' and 'aggregate' that are used to describe aggregations of data from individual endpoints). | |
| aggregate [0..1] | [AggregateKind](#CIM17v40-AggregateKind) | Salient attribute of the reading data aggregated from individual endpoints. This is mainly used to define a mathematical operation carried out over 'macroPeriod', but may also be used to describe an attribute of the data when the 'macroPeriod' is not defined. | |
| commodity [0..1] | [CommodityKind](#CIM17v40-CommodityKind) | Commodity being measured. | |
| consumptionTier [0..1] | [Integer](#CIM17v40-Integer) | In case of common flat-rate pricing for power, in which all purchases are at a given rate, 'consumptionTier'=0. Otherwise, the value indicates the consumption tier, which can be used in conjunction with TOU or CPP pricing.Consumption tier pricing refers to the method of billing in which a certain "block" of energy is purchased/sold at one price, after which the next block of energy is purchased at another price, and so on, all throughout a defined period. At the start of the defined period, consumption is initially zero, and any usage is measured against the first consumption tier ('consumptionTier'=1). If this block of energy is consumed before the end of the period, energy consumption moves to be reconed against the second consumption tier ('consumptionTier'=2), and so on. At the end of the defined period, the consumption accumulator is reset, and usage within the 'consumptionTier'=1 restarts. | |
| cpp [0..1] | [Integer](#CIM17v40-Integer) | Critical peak period (CPP) bucket the reading value is attributed to. Value 0 means not applicable. Even though CPP is usually considered a specialised form of time of use 'tou', this attribute is defined explicitly for flexibility. | |
| currency [0..1] | [Currency](#CIM17v40-Currency) | Metering-specific currency. | |
| flowDirection [0..1] | [FlowDirectionKind](#CIM17v40-FlowDirectionKind) | Flow direction for a reading where the direction of flow of the commodity is important (for electricity measurements this includes current, energy, power, and demand). | |
| macroPeriod [0..1] | [MacroPeriodKind](#CIM17v40-MacroPeriodKind) | Time period of interest that reflects how the reading is viewed or captured over a long period of time. | |
| measurementKind [0..1] | [MeasurementKind](#CIM17v40-MeasurementKind) | Identifies "what" is being measured, as refinement of 'commodity'. When combined with 'unit', it provides detail to the unit of measure. For example, 'energy' with a unit of measure of 'kWh' indicates to the user that active energy is being measured, while with 'kVAh' or 'kVArh', it indicates apparent energy and reactive energy, respectively. 'power' can be combined in a similar way with various power units of measure: Distortion power ('distortionVoltAmperes') with 'kVA' is different from 'power' with 'kVA'. | |
| measuringPeriod [0..1] | [MeasuringPeriodKind](#CIM17v40-MeasuringPeriodKind) | Time attribute inherent or fundamental to the reading value (as opposed to 'macroPeriod' that supplies an "adjective" to describe aspects of a time period with regard to the measurement). It refers to the way the value was originally measured and not to the frequency at which it is reported or presented. For example, an hourly interval of consumption data would have value 'hourly' as an attribute. However in the case of an hourly sampled voltage value, the meterReadings schema would carry the 'hourly' interval size information.It is common for meters to report demand in a form that is measured over the course of a portion of an hour, while enterprise applications however commonly assume the demand (in kW or kVAr) normalised to 1 hour. The system that receives readings directly from the meter therefore shall perform this transformation before publishing readings for use by the other enterprise systems. The scalar used is chosen based on the block size (not any sub-interval size). | |
| multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | Metering-specific multiplier. | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | Metering-specific phase code. | |
| tou [0..1] | [Integer](#CIM17v40-Integer) | Time of use (TOU) bucket the reading value is attributed to. Value 0 means not applicable. | |
| unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | Metering-specific unit. | |
| argument [0..1] | [RationalNumber](#CIM17v40-RationalNumber) | Argument used to introduce numbers into the unit of measure description where they are needed (e.g., 4 where the measure needs an argument such as CEMI(n=4)). Most arguments used in practice however will be integers (i.e., 'denominator'=1).Value 0 in 'numerator' and 'denominator' means not applicable. | |
| Channel [0..1] | [Channel](#CIM17v40-Channel) | Channel reporting/collecting register values with this type information. | |
| interharmonic [0..1] | [ReadingInterharmonic](#CIM17v40-ReadingInterharmonic) | Indication of a "harmonic" or "interharmonic" basis for the measurement. Value 0 in 'numerator' and 'denominator' means not applicable. | |
| MeterReadSchedule [0..1] | [MeterReadSchedule](#CIM17v40-MeterReadSchedule) | Meter read schedule for which the reading type applies | |
| PendingCalculation [0..1] | [PendingCalculation](#CIM17v40-PendingCalculation) | Pending calculation that produced this reading type. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Reason}
### Reason


```mermaid
classDiagram
direction TB

class Reason {

+ code : String [0..1]
+ text : String [0..1]
}

```

The motivation of an act.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| code [0..1] | [String](#CIM17v40-String) | The motivation of an act in coded form. | |
| text [0..1] | [String](#CIM17v40-String) | The textual explanation corresponding to the reason code. | |

{#CIM17v40-Receipt}
### Receipt

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Receipt {

+ isBankable : Boolean [0..1]
+ line : LineDetail [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Receipt : inherits from
class CashierShift {

}

Receipt --> "0..1" CashierShift : CashierShift
class VendorShift {

}

Receipt --> "0..1" VendorShift : VendorShift
```

Record of total receipted payment from customer.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| isBankable [0..1] | [Boolean](#CIM17v40-Boolean) | True if this receipted payment is manually bankable, otherwise it is an electronic funds transfer. | |
| CashierShift [0..1] | [CashierShift](#CIM17v40-CashierShift) | Cashier shift during which this receipt was recorded. | |
| line [0..1] | [LineDetail](#CIM17v40-LineDetail) | Receipted amount with rounding, date and note. | |
| VendorShift [0..1] | [VendorShift](#CIM17v40-VendorShift) | Vendor shift during which this receipt was recorded. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RecloseSequence}
### RecloseSequence

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RecloseSequence {

+ recloseDelay : Seconds [0..1]
+ recloseStep : Integer [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- RecloseSequence : inherits from
class ProtectedSwitch {

}

RecloseSequence --> "1" ProtectedSwitch : ProtectedSwitch
```

A reclose sequence (open and close) is defined for each possible reclosure of a breaker.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| recloseDelay [0..1] | [Seconds](#CIM17v40-Seconds) | Indicates the time lapse before the reclose step will execute a reclose. | |
| recloseStep [0..1] | [Integer](#CIM17v40-Integer) | Indicates the ordinal position of the reclose step relative to other steps in the sequence. | |
| `ProtectedSwitch [1]` (OfAggregate) | [ProtectedSwitch](#CIM17v40-ProtectedSwitch) | A breaker may have zero or more automatic reclosures after a trip occurs. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Recloser}
### Recloser

Inheritance path = [ProtectedSwitch](#CIM17v40-ProtectedSwitch) => [Switch](#CIM17v40-Switch) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Recloser {

}

class ProtectedSwitch {

}

ProtectedSwitch <|-- Recloser : inherits from
```

Pole-mounted fault interrupter with built-in phase and ground relays, current transformer (CT), and supplemental controls.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| breakingCapacity [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [ProtectedSwitch](CIM17v40-ProtectedSwitch) | |
| locked [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| normalOpen [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| open [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [Switch](CIM17v40-Switch) | |
| retained [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| `switchOnCount [0..1]` (deprecated) | [Integer](#CIM17v40-Integer) | see [Switch](#CIM17v40-Switch) | |
| `switchOnDate [0..1]` (deprecated) | [DateTime](#CIM17v40-DateTime) | see [Switch](#CIM17v40-Switch) | |
| `CompositeSwitch [0..1]` (OfAggregate) | [CompositeSwitch](#CIM17v40-CompositeSwitch) | see [Switch](CIM17v40-Switch) | |
| SwitchAction [0..1] | [SwitchAction](#CIM17v40-SwitchAction) | see [Switch](CIM17v40-Switch) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RecloserInfo}
### RecloserInfo

Inheritance path = [OldSwitchInfo](#CIM17v40-OldSwitchInfo) => [SwitchInfo](#CIM17v40-SwitchInfo) => [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RecloserInfo {

+ groundTripCapable : Boolean [0..1]
+ groundTripNormalEnabled : Boolean [0..1]
+ groundTripRating : CurrentFlow [0..1]
+ phaseTripRating : CurrentFlow [0..1]
+ recloseLockoutCount : Integer [0..1]
}

class OldSwitchInfo {

}

OldSwitchInfo <|-- RecloserInfo : inherits from
```

Properties of recloser assets.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| groundTripCapable [0..1] | [Boolean](#CIM17v40-Boolean) | True if device has ground trip capability. | |
| groundTripNormalEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | True if normal status of ground trip is enabled. | |
| groundTripRating [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Ground trip rating. | |
| phaseTripRating [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Phase trip rating. | |
| recloseLockoutCount [0..1] | [Integer](#CIM17v40-Integer) | Total number of phase reclose operations. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dielectricStrength [0..1] | [Voltage](#CIM17v40-Voltage) | see [OldSwitchInfo](CIM17v40-OldSwitchInfo) | |
| loadBreak [0..1] | [Boolean](#CIM17v40-Boolean) | see [OldSwitchInfo](#CIM17v40-OldSwitchInfo) | |
| makingCapacity [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [OldSwitchInfo](CIM17v40-OldSwitchInfo) | |
| minimumCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [OldSwitchInfo](CIM17v40-OldSwitchInfo) | |
| poleCount [0..1] | [Integer](#CIM17v40-Integer) | see [OldSwitchInfo](#CIM17v40-OldSwitchInfo) | |
| remote [0..1] | [Boolean](#CIM17v40-Boolean) | see [OldSwitchInfo](#CIM17v40-OldSwitchInfo) | |
| withstandCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [OldSwitchInfo](CIM17v40-OldSwitchInfo) | |
| breakingCapacity [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| gasWeightPerTank [0..1] | [Mass](#CIM17v40-Mass) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| isSinglePhase [0..1] | [Boolean](#CIM17v40-Boolean) | see [SwitchInfo](#CIM17v40-SwitchInfo) | |
| isUnganged [0..1] | [Boolean](#CIM17v40-Boolean) | see [SwitchInfo](#CIM17v40-SwitchInfo) | |
| lowPressureAlarm [0..1] | [Pressure](#CIM17v40-Pressure) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| lowPressureLockOut [0..1] | [Pressure](#CIM17v40-Pressure) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| oilVolumePerTank [0..1] | [Volume](#CIM17v40-Volume) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| ratedFrequency [0..1] | [Frequency](#CIM17v40-Frequency) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| ratedImpulseWithstandVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| ratedInterruptingTime [0..1] | [Seconds](#CIM17v40-Seconds) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| ratedVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | see [SwitchInfo](CIM17v40-SwitchInfo) | |
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Reconditioning}
### (informative) Reconditioning

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Reconditioning {

+ dateTime : DateTime [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Reconditioning : inherits from
class Asset {

}

Reconditioning --> "0..1" Asset : Asset
```

Reconditioning information for an asset.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time this reconditioning (or a major overhaul) has been performed. | |
| `Asset [0..1]` (informative) | [Asset](#CIM17v40-Asset) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RedLine}
### RedLine

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RedLine {

+ status : Status [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- RedLine : inherits from
```

This class is used for handling the accompanying annotations, time stamp, author, etc. of designs, drawings and maps. A red line can be associated with any Location object.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Register}
### Register

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Register {

+ isVirtual : Boolean [0..1]
+ leftDigitCount : Integer [0..1]
+ rightDigitCount : Integer [0..1]
+ touTierName : String [0..1]
+ touTier : TimeInterval [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Register : inherits from
class EndDeviceFunction {

}

Register --> "0..1" EndDeviceFunction : EndDeviceFunction
class UsagePoint {

}

Register --> "0..1" UsagePoint : Usage Point
```

A device that indicates or records units of the commodity or other quantity measured.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| isVirtual [0..1] | [Boolean](#CIM17v40-Boolean) | If true, the data it produces is calculated or measured by a device other than a physical end device/meter. Otherwise, any data streams it produces are measured by the hardware of the end device/meter itself. | |
| leftDigitCount [0..1] | [Integer](#CIM17v40-Integer) | Number of digits (dials on a mechanical meter) to the left of the decimal place; default is normally 5. | |
| rightDigitCount [0..1] | [Integer](#CIM17v40-Integer) | Number of digits (dials on a mechanical meter) to the right of the decimal place. | |
| touTierName [0..1] | [String](#CIM17v40-String) | Name used for the time of use tier (also known as bin or bucket). For example, "peak", "off-peak", "TOU Category A", etc. | |
| EndDeviceFunction [0..1] | [EndDeviceFunction](#CIM17v40-EndDeviceFunction) | End device function metering quantities displayed by this register. | |
| touTier [0..1] | [TimeInterval](#CIM17v40-TimeInterval) | Clock time interval for register to beging/cease accumulating time of usage (e.g., start at 8:00 am, stop at 5:00 pm). | |
| Usage Point [0..1] | [UsagePoint](#CIM17v40-UsagePoint) | Usage Point, when metered, has these registers. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RegisteredControllableLoad}
### RegisteredControllableLoad


```mermaid
classDiagram
direction TB

class RegisteredControllableLoad {

+ maxBaseLoad : ActivePower [0..1]
+ maxDeploymentTime : Float [0..1]
+ maxLoadRedTimesPerDay : Integer [0..1]
+ maxLoadReduction : ActivePower [0..1]
+ maxReductionTime : Float [0..1]
+ maxWeeklyDeployment : Integer [0..1]
+ minLoadReduction : ActivePower [0..1]
+ minLoadReductionCost : CostPerEnergyUnit [0..1]
+ minLoadReductionInterval : Float [0..1]
+ minReductionTime : Float [0..1]
+ minTimeBetLoadRed : Float [0..1]
+ reqNoticeTime : Float [0..1]
}

```

Temporary holding for load reduction attributes removed from RegisteredLoad. Use for future use case when developing the RegisteredDistributedResource specialized classes.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maxBaseLoad [0..1] | [ActivePower](#CIM17v40-ActivePower) | Maximum Base Load (MW), per Participating Load Resource | |
| maxDeploymentTime [0..1] | [Float](#CIM17v40-Float) | Maximum Deployment time (seconds) | |
| maxLoadRedTimesPerDay [0..1] | [Integer](#CIM17v40-Integer) | Maximum Number of Daily Load Curtailments | |
| maxLoadReduction [0..1] | [ActivePower](#CIM17v40-ActivePower) | maximum load reduction | |
| maxReductionTime [0..1] | [Float](#CIM17v40-Float) | Maxiimum Load Reduction Time (min), per Participating Load Resource | |
| maxWeeklyDeployment [0..1] | [Integer](#CIM17v40-Integer) | Maximum weekly deployments | |
| minLoadReduction [0..1] | [ActivePower](#CIM17v40-ActivePower) | Minimum MW for a load reduction (e.g., MW rating of a discrete pump.This attribute may be used also in the LoadBid class. The reason that the attribute is also modeled in this class is that it is resource attribute and needs to be persistently stored. | |
| minLoadReductionCost [0..1] | [CostPerEnergyUnit](#CIM17v40-CostPerEnergyUnit) | minimum load reduction cost. Single number for the load | |
| minLoadReductionInterval [0..1] | [Float](#CIM17v40-Float) | Shortest period load reduction shall be maintained before load can be restored to normal levels.This attribute may be used also in the LoadBid class. The reason that the attribute is also modeled in this class is that it is resource attribute and needs to be persistently stored. | |
| minReductionTime [0..1] | [Float](#CIM17v40-Float) | Minimum Load Reduction Time (min), per Participating Load Resource | |
| minTimeBetLoadRed [0..1] | [Float](#CIM17v40-Float) | Shortest time that load shall be left at normal levels before a new load reduction.This attribute may be used also in the LoadBid class. The reason that the attribute is also modeled in this class is that it is resource attribute and needs to be persistently stored. | |
| reqNoticeTime [0..1] | [Float](#CIM17v40-Float) | Time period that is required from an order to reduce a load to the time that it takes to get to the minimum load reduction.This attribute may be used also in the LoadBid class. The reason that the attribute is also modeled in this class is that it is resource attribute and needs to be persistently stored. | |

{#CIM17v40-RegisteredDistributedResource}
### RegisteredDistributedResource

Inheritance path = [RegisteredResource](#CIM17v40-RegisteredResource) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RegisteredDistributedResource {

+ distributedResourceType : String [0..1]
}

class RegisteredResource {

}

RegisteredResource <|-- RegisteredDistributedResource : inherits from
```

A registered resource that represents a distributed energy resource, such as a micro-generator, fuel cell, photo-voltaic energy source, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| distributedResourceType [0..1] | [String](#CIM17v40-String) | The type of resource. Examples include: fuel cell, flywheel, photovoltaic, micro-turbine, CHP (combined heat power), V2G (vehicle to grid), DES (distributed energy storage), and others. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ACAFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| ASSPOptimizationFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| commercialOpDate [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| contingencyAvailFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| dispatchable [0..1] | [Boolean](#CIM17v40-Boolean) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| ECAFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| flexibleOfferFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| hourlyPredispatch [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| isAggregatedRes [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| lastModified [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| LMPMFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| marketParticipationFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| maxBaseSelfSchedQty [0..1] | [Float](#CIM17v40-Float) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| maxOnTime [0..1] | [Float](#CIM17v40-Float) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| minDispatchTime [0..1] | [Hours](#CIM17v40-Hours) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| minOffTime [0..1] | [Float](#CIM17v40-Float) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| minOnTime [0..1] | [Float](#CIM17v40-Float) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| mustOfferFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| nonMarket [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| pointOfDeliveryFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| priceSetFlagDA [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| priceSetFlagRT [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| registrationStatus [0..1] | [ResourceRegistrationStatus](#CIM17v40-ResourceRegistrationStatus) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| resourceAdequacyFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| SMPMFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| AdjacentCASet [0..1] | [AdjacentCASet](#CIM17v40-AdjacentCASet) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| AggregateNode [0..1] | [AggregateNode](#CIM17v40-AggregateNode) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| DefaultBid [0..1] | [DefaultBid](#CIM17v40-DefaultBid) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| HostControlArea [0..1] | [HostControlArea](#CIM17v40-HostControlArea) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| MarketParticipant [0..1] | [MarketParticipant](#CIM17v40-MarketParticipant) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| MktConnectivityNode [0..1] | [MktConnectivityNode](#CIM17v40-MktConnectivityNode) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| Pnode [0..1] | [Pnode](#CIM17v40-Pnode) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| ResourceVerifiableCosts [0..1] | [ResourceVerifiableCosts](#CIM17v40-ResourceVerifiableCosts) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RegisteredGenerator}
### RegisteredGenerator

Inheritance path = [RegisteredResource](#CIM17v40-RegisteredResource) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RegisteredGenerator {

+ capacityFactor : PerCent [0..1]
+ coldStartTime : Float [0..1]
+ combinedCycleOperatingMode : String [0..1]
+ commericialOperationDate : DateTime [0..1]
+ constrainedOutputFlag : enum:YesNo [0..1]
+ energyDownRampRate : ActivePowerChangeRate [0..1]
+ energyUpRampRate : ActivePowerChangeRate [0..1]
+ extremeLongStart : enum:YesNo [0..1]
+ fuelSource : enum:FuelSource [0..1]
+ highControlLimit : ActivePower [0..1]
+ hotIntTime : Float [0..1]
+ hotStartTime : Float [0..1]
+ intColdTime : Float [0..1]
+ intStartTime : Float [0..1]
+ loadFollowingDownMSS : enum:YesNo [0..1]
+ loadFollowingUpMSS : enum:YesNo [0..1]
+ lowControlLImit : ActivePower [0..1]
+ maxDependableCap : ActivePower [0..1]
+ maximumAllowableSpinningReserve : ActivePower [0..1]
+ maximumOperatingLimit : ActivePower [0..1]
+ maxMinLoadCost : CostRate [0..1]
+ maxPumpingLevel : ActivePower [0..1]
+ maxShutdownTime : DateTime [0..1]
+ maxStartUpsPerDay : Integer [0..1]
+ maxWeeklyEnergy : Float [0..1]
+ maxWeeklyStarts : Integer [0..1]
+ minimumLoadCostBasis : enum:CostBasis [0..1]
+ minimumLoadFuelCost : CostPerHeatUnit [0..1]
+ minimumOperatingLimit : ActivePower [0..1]
+ minLoadCost : CostRate [0..1]
+ mustOfferRA : enum:YesNo [0..1]
+ nameplateCapacity : ActivePower [0..1]
+ operatingMaintenanceCost : CostPerEnergyUnit [0..1]
+ pumpingCost : CostRate [0..1]
+ pumpingFactor : Float [0..1]
+ pumpMinDownTime : Float [0..1]
+ pumpMinUpTime : Float [0..1]
+ pumpShutdownCost : Float [0..1]
+ pumpShutdownTime : Integer [0..1]
+ quickStartFlag : enum:YesNo [0..1]
+ rampCurveType : enum:RampCurveType [0..1]
+ regulationDownRampRate : ActivePowerChangeRate [0..1]
+ regulationFlag : enum:UnitRegulationKind [0..1]
+ regulationUpRampRate : ActivePowerChangeRate [0..1]
+ resourceSubType : String [0..1]
+ riverSystem : String [0..1]
+ RMNRFlag : enum:YesNo [0..1]
+ RMRFlag : enum:FlagTypeRMR [0..1]
+ RMRManualIndicator : enum:YesNo [0..1]
+ RMTFlag : enum:YesNo [0..1]
+ spinRampRate : ActivePowerChangeRate [0..1]
+ startUpCostBasis : enum:CostBasis [0..1]
+ syncCondCapable : enum:YesNo [0..1]
+ unitType : enum:UnitType [0..1]
+ useLimitFlag : enum:YesNo [0..1]
+ variableEnergyResource : enum:YesNo [0..1]
}

class RegisteredResource {

}

RegisteredResource <|-- RegisteredGenerator : inherits from
class EnergyPriceIndex {

}

RegisteredGenerator --> "1" EnergyPriceIndex : EnergyPriceIndex
class FuelCostCurve {

}

RegisteredGenerator --> "0..1" FuelCostCurve : FuelCostCurve
class FuelRegion {

}

RegisteredGenerator --> "0..1" FuelRegion : FuelRegion
class LocalReliabilityArea {

}

RegisteredGenerator --> "0..1" LocalReliabilityArea : LocalReliabilityArea
class MktHeatRateCurve {

}

RegisteredGenerator --> "0..1" MktHeatRateCurve : MktHeatRateCurve
class RegulatingLimit {

}

RegisteredGenerator --> "0..1" RegulatingLimit : RegulatingLimit
class RMRHeatRateCurve {

}

RegisteredGenerator --> "0..1" RMRHeatRateCurve : RMRHeatRateCurve
class RMRStartUpCostCurve {

}

RegisteredGenerator --> "0..1" RMRStartUpCostCurve : RMRStartUpCostCurve
class RMRStartUpEnergyCurve {

}

RegisteredGenerator --> "0..1" RMRStartUpEnergyCurve : RMRStartUpEnergyCurve
class RMRStartUpFuelCurve {

}

RegisteredGenerator --> "0..1" RMRStartUpFuelCurve : RMRStartUpFuelCurve
class RMRStartUpTimeCurve {

}

RegisteredGenerator --> "0..1" RMRStartUpTimeCurve : RMRStartUpTimeCurve
class StartUpEnergyCurve {

}

RegisteredGenerator --> "0..1" StartUpEnergyCurve : StartUpEnergyCurve
class StartUpFuelCurve {

}

RegisteredGenerator --> "0..1" StartUpFuelCurve : StartUpFuelCurve
class StartUpTimeCurve {

}

RegisteredGenerator --> "0..1" StartUpTimeCurve : StartUpTimeCurve
```

Model of a generator that is registered to participate in the market.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| capacityFactor [0..1] | [PerCent](#CIM17v40-PerCent) | The ratio of actual energy produced by resource divided by the maximum potential energy if the resource is fully utilized. As an example, wind farms. | |
| coldStartTime [0..1] | [Float](#CIM17v40-Float) | Cold start time. | |
| combinedCycleOperatingMode [0..1] | [String](#CIM17v40-String) | Combined Cycle operating mode. | |
| commericialOperationDate [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| constrainedOutputFlag [0..1] | [YesNo](#CIM17v40-YesNo) | Constrained Output Generator (COG) Indicator (Yes/No), per Generating Resource | |
| energyDownRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | Response rate in MW per minute for ramping energy down. | |
| energyUpRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | Response rate in MW per minute for ramping energy up. | |
| extremeLongStart [0..1] | [YesNo](#CIM17v40-YesNo) | Some long-start up time units may need to receive start up instruction before DA market results are available. Long-Start resources may be either physical resources within the control with start-up times greater than 18 hours or the long-start contractual inter-tie commitment that shall be completed by 6 am one-day ahead. Therefore, there is a need for a process to determine the commitment of such resources before the DA market. | |
| fuelSource [0..1] | [FuelSource](#CIM17v40-FuelSource) | Values: Natural Gas Based Resource, Non Natural Gas Based Resource"NG" - Natural-Gas-Based Resource - a Resource that is powered by Natural Gas"NNG" - Non-Natural-Gas-Based Resource - a Resouce that is powered by some other fuel than Natural Gas | |
| highControlLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | High limit for secondary (AGC) control | |
| hotIntTime [0..1] | [Float](#CIM17v40-Float) | Hot-to-intermediate time (Seasonal) | |
| hotStartTime [0..1] | [Float](#CIM17v40-Float) | Hot start time. | |
| intColdTime [0..1] | [Float](#CIM17v40-Float) | Intermediate-to-cold time (Seasonal) | |
| intStartTime [0..1] | [Float](#CIM17v40-Float) | Intermediate start time. | |
| loadFollowingDownMSS [0..1] | [YesNo](#CIM17v40-YesNo) | Certifies resources for use in MSS Load Following Down | |
| loadFollowingUpMSS [0..1] | [YesNo](#CIM17v40-YesNo) | Certifies resources for use in MSS Load Following Up | |
| lowControlLImit [0..1] | [ActivePower](#CIM17v40-ActivePower) | Low limit for secondary (AGC) control | |
| maxDependableCap [0..1] | [ActivePower](#CIM17v40-ActivePower) | Maximum Dependable Capacity (MNDC). Maximun Net Dependable Capacity is used in association with an RMR contract. | |
| maximumAllowableSpinningReserve [0..1] | [ActivePower](#CIM17v40-ActivePower) | Maximum allowable spinning reserve. Spinning reserve will never be considered greater than this value regardless of the current operating point. | |
| maximumOperatingLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | This is the maximum operating MW limit the dispatcher can enter for this unit | |
| maxMinLoadCost [0..1] | [CostRate](#CIM17v40-CostRate) | The registered maximum Minimum Load Cost of a Generating Resource registered with a Cost Basis of "Bid Cost". | |
| maxPumpingLevel [0..1] | [ActivePower](#CIM17v40-ActivePower) | max pumping level of a hydro pump unit | |
| maxShutdownTime [0..1] | [DateTime](#CIM17v40-DateTime) | Maximum time this device can be shut down. | |
| maxStartUpsPerDay [0..1] | [Integer](#CIM17v40-Integer) | maximum start ups per day | |
| maxWeeklyEnergy [0..1] | [Float](#CIM17v40-Float) | Maximum weekly Energy (Seasonal) | |
| maxWeeklyStarts [0..1] | [Integer](#CIM17v40-Integer) | Maximum weekly starts (seasonal parameter) | |
| minimumLoadCostBasis [0..1] | [CostBasis](#CIM17v40-CostBasis) | The cost basis for minimum load. | |
| minimumLoadFuelCost [0..1] | [CostPerHeatUnit](#CIM17v40-CostPerHeatUnit) | The cost for the fuel required to get a Generating Resource to operate at the minimum load level | |
| minimumOperatingLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | This is the minimum operating MW limit the dispatcher can enter for this unit. | |
| minLoadCost [0..1] | [CostRate](#CIM17v40-CostRate) | minimum load cost. Value is (currency/hr) | |
| mustOfferRA [0..1] | [YesNo](#CIM17v40-YesNo) | Flag to indicate that this unit is a resource adequacy resource and must offer. | |
| nameplateCapacity [0..1] | [ActivePower](#CIM17v40-ActivePower) | MW value stated on the nameplate of the Generator -- the value it potentially could provide. | |
| operatingMaintenanceCost [0..1] | [CostPerEnergyUnit](#CIM17v40-CostPerEnergyUnit) | The portion of the Operating Cost of a Generating Resource that is not related to fuel cost. | |
| pumpingCost [0..1] | [CostRate](#CIM17v40-CostRate) | | |
| pumpingFactor [0..1] | [Float](#CIM17v40-Float) | Pumping factor for pump storage units, conversion factor between generating and pumping. | |
| pumpMinDownTime [0..1] | [Float](#CIM17v40-Float) | The minimum down time for the pump in a pump storage unit. | |
| pumpMinUpTime [0..1] | [Float](#CIM17v40-Float) | The minimum up time aspect for the pump in a pump storage unit | |
| pumpShutdownCost [0..1] | [Float](#CIM17v40-Float) | The cost to shutdown a pump during the pump aspect of a pump storage unit. | |
| pumpShutdownTime [0..1] | [Integer](#CIM17v40-Integer) | The shutdown time (minutes) of the pump aspect of a pump storage unit. | |
| quickStartFlag [0..1] | [YesNo](#CIM17v40-YesNo) | Quick start flag (Yes/No). Identifies the registered generator as a quick start unit. A quick start unit is a unit that has the ability to be available for load within a 30 minute period. | |
| rampCurveType [0..1] | [RampCurveType](#CIM17v40-RampCurveType) | Ramp curve type. Identifies the type of curve which may be a fixed, static or dynamic. | |
| regulationDownRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | Regulation down response rate in MW per minute | |
| regulationFlag [0..1] | [UnitRegulationKind](#CIM17v40-UnitRegulationKind) | Specifies if the unit is regulating or not regulating or expected to be regulating but is not. | |
| regulationUpRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | Regulation up response rate in MW per minute. | |
| resourceSubType [0..1] | [String](#CIM17v40-String) | Unit sub type used by Settlements or scheduling application. Application use of the unit sub type may define the necessary types as applicable. | |
| riverSystem [0..1] | [String](#CIM17v40-String) | River System the Resource is tied to. | |
| RMNRFlag [0..1] | [YesNo](#CIM17v40-YesNo) | Reliability must not run (RMNR) flag: indicated whether the RMR unit is set as an RMNR in the current market | |
| RMRFlag [0..1] | [FlagTypeRMR](#CIM17v40-FlagTypeRMR) | Reliability must run (RMR) flag: indicates whether the unit is RMR; Indicates whether the unit is RMR:N' - not an RMR unit'1' - RMR Condition 1 unit'2' - RMR Condition 2 unit | |
| RMRManualIndicator [0..1] | [YesNo](#CIM17v40-YesNo) | Indicates the RMR Manual pre-determination status [Y/N] | |
| RMTFlag [0..1] | [YesNo](#CIM17v40-YesNo) | Reliability must take (RMT) flag (Yes/No): indicates whether the unit is RMT | |
| spinRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | Response rate in MW per minute for spinning reserve. | |
| startUpCostBasis [0..1] | [CostBasis](#CIM17v40-CostBasis) | The cost basis for start up. | |
| syncCondCapable [0..1] | [YesNo](#CIM17v40-YesNo) | Is the Resource Synchronous Condenser capable Resource? | |
| unitType [0..1] | [UnitType](#CIM17v40-UnitType) | Generating unit type: Combined Cycle, Gas Turbine, Hydro Turbine, Other, Photovoltaic, Hydro Pump-Turbine, Reciprocating Engine, Steam Turbine, Synchronous Condenser, Wind Turbine | |
| useLimitFlag [0..1] | [YesNo](#CIM17v40-YesNo) | Use limit flag: indicates if the use-limited resource is fully scheduled (or has some slack for real-time dispatch) (Y/N) | |
| variableEnergyResource [0..1] | [YesNo](#CIM17v40-YesNo) | Provides an indication that this resource is intending to participate in an intermittent resource program. | |
| EnergyPriceIndex [1] | [EnergyPriceIndex](#CIM17v40-EnergyPriceIndex) | | |
| FuelCostCurve [0..1] | [FuelCostCurve](#CIM17v40-FuelCostCurve) | | |
| FuelRegion [0..1] | [FuelRegion](#CIM17v40-FuelRegion) | | |
| LocalReliabilityArea [0..1] | [LocalReliabilityArea](#CIM17v40-LocalReliabilityArea) | | |
| MktHeatRateCurve [0..1] | [MktHeatRateCurve](#CIM17v40-MktHeatRateCurve) | | |
| RegulatingLimit [0..1] | [RegulatingLimit](#CIM17v40-RegulatingLimit) | | |
| RMRHeatRateCurve [0..1] | [RMRHeatRateCurve](#CIM17v40-RMRHeatRateCurve) | | |
| RMRStartUpCostCurve [0..1] | [RMRStartUpCostCurve](#CIM17v40-RMRStartUpCostCurve) | | |
| RMRStartUpEnergyCurve [0..1] | [RMRStartUpEnergyCurve](#CIM17v40-RMRStartUpEnergyCurve) | | |
| RMRStartUpFuelCurve [0..1] | [RMRStartUpFuelCurve](#CIM17v40-RMRStartUpFuelCurve) | | |
| RMRStartUpTimeCurve [0..1] | [RMRStartUpTimeCurve](#CIM17v40-RMRStartUpTimeCurve) | | |
| StartUpEnergyCurve [0..1] | [StartUpEnergyCurve](#CIM17v40-StartUpEnergyCurve) | | |
| StartUpFuelCurve [0..1] | [StartUpFuelCurve](#CIM17v40-StartUpFuelCurve) | | |
| StartUpTimeCurve [0..1] | [StartUpTimeCurve](#CIM17v40-StartUpTimeCurve) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ACAFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| ASSPOptimizationFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| commercialOpDate [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| contingencyAvailFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| dispatchable [0..1] | [Boolean](#CIM17v40-Boolean) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| ECAFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| flexibleOfferFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| hourlyPredispatch [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| isAggregatedRes [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| lastModified [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| LMPMFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| marketParticipationFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| maxBaseSelfSchedQty [0..1] | [Float](#CIM17v40-Float) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| maxOnTime [0..1] | [Float](#CIM17v40-Float) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| minDispatchTime [0..1] | [Hours](#CIM17v40-Hours) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| minOffTime [0..1] | [Float](#CIM17v40-Float) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| minOnTime [0..1] | [Float](#CIM17v40-Float) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| mustOfferFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| nonMarket [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| pointOfDeliveryFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| priceSetFlagDA [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| priceSetFlagRT [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| registrationStatus [0..1] | [ResourceRegistrationStatus](#CIM17v40-ResourceRegistrationStatus) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| resourceAdequacyFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| SMPMFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| AdjacentCASet [0..1] | [AdjacentCASet](#CIM17v40-AdjacentCASet) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| AggregateNode [0..1] | [AggregateNode](#CIM17v40-AggregateNode) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| DefaultBid [0..1] | [DefaultBid](#CIM17v40-DefaultBid) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| HostControlArea [0..1] | [HostControlArea](#CIM17v40-HostControlArea) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| MarketParticipant [0..1] | [MarketParticipant](#CIM17v40-MarketParticipant) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| MktConnectivityNode [0..1] | [MktConnectivityNode](#CIM17v40-MktConnectivityNode) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| Pnode [0..1] | [Pnode](#CIM17v40-Pnode) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| ResourceVerifiableCosts [0..1] | [ResourceVerifiableCosts](#CIM17v40-ResourceVerifiableCosts) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RegisteredInterTie}
### RegisteredInterTie

Inheritance path = [RegisteredResource](#CIM17v40-RegisteredResource) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RegisteredInterTie {

+ direction : enum:InterTieDirection [0..1]
+ energyProductType : enum:EnergyProductType [0..1]
+ isDCTie : enum:YesNo [0..1]
+ isDynamicInterchange : enum:YesNo [0..1]
+ minHourlyBlockLimit : Integer [0..1]
}

class RegisteredResource {

}

RegisteredResource <|-- RegisteredInterTie : inherits from
class Flowgate {

}

RegisteredInterTie --> "1" Flowgate : Flowgate
class InterTieBid {

}

RegisteredInterTie --> "0..1" InterTieBid : InterTieBid
```

This class represents the inter tie resource.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| direction [0..1] | [InterTieDirection](#CIM17v40-InterTieDirection) | Indicates the direction (export/import) of an InterTie resource. | |
| energyProductType [0..1] | [EnergyProductType](#CIM17v40-EnergyProductType) | Under each major product type, the commodity type can be applied to further specify the type. | |
| isDCTie [0..1] | [YesNo](#CIM17v40-YesNo) | Flag to indicated whether this Inter-tie is a DC Tie. | |
| isDynamicInterchange [0..1] | [YesNo](#CIM17v40-YesNo) | Specifies whether the inter-tie resource is registered for the dynamic interchange. | |
| minHourlyBlockLimit [0..1] | [Integer](#CIM17v40-Integer) | The registered upper bound of minimum hourly block for an Inter-Tie Resource. | |
| Flowgate [1] | [Flowgate](#CIM17v40-Flowgate) | | |
| InterTieBid [0..1] | [InterTieBid](#CIM17v40-InterTieBid) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ACAFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| ASSPOptimizationFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| commercialOpDate [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| contingencyAvailFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| dispatchable [0..1] | [Boolean](#CIM17v40-Boolean) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| ECAFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| flexibleOfferFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| hourlyPredispatch [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| isAggregatedRes [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| lastModified [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| LMPMFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| marketParticipationFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| maxBaseSelfSchedQty [0..1] | [Float](#CIM17v40-Float) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| maxOnTime [0..1] | [Float](#CIM17v40-Float) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| minDispatchTime [0..1] | [Hours](#CIM17v40-Hours) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| minOffTime [0..1] | [Float](#CIM17v40-Float) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| minOnTime [0..1] | [Float](#CIM17v40-Float) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| mustOfferFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| nonMarket [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| pointOfDeliveryFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| priceSetFlagDA [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| priceSetFlagRT [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| registrationStatus [0..1] | [ResourceRegistrationStatus](#CIM17v40-ResourceRegistrationStatus) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| resourceAdequacyFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| SMPMFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| AdjacentCASet [0..1] | [AdjacentCASet](#CIM17v40-AdjacentCASet) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| AggregateNode [0..1] | [AggregateNode](#CIM17v40-AggregateNode) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| DefaultBid [0..1] | [DefaultBid](#CIM17v40-DefaultBid) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| HostControlArea [0..1] | [HostControlArea](#CIM17v40-HostControlArea) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| MarketParticipant [0..1] | [MarketParticipant](#CIM17v40-MarketParticipant) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| MktConnectivityNode [0..1] | [MktConnectivityNode](#CIM17v40-MktConnectivityNode) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| Pnode [0..1] | [Pnode](#CIM17v40-Pnode) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| ResourceVerifiableCosts [0..1] | [ResourceVerifiableCosts](#CIM17v40-ResourceVerifiableCosts) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RegisteredLoad}
### RegisteredLoad

Inheritance path = [RegisteredResource](#CIM17v40-RegisteredResource) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RegisteredLoad {

+ blockLoadTransfer : Boolean [0..1]
+ dynamicallyScheduledLoadResource : Boolean [0..1]
+ dynamicallyScheduledQualification : Boolean [0..1]
}

class RegisteredResource {

}

RegisteredResource <|-- RegisteredLoad : inherits from
```

Model of a load that is registered to participate in the market.

RegisteredLoad is used to model any load that is served by the wholesale market directly. RegisteredLoads may be dispatchable or non-dispatchable and may or may not have bid curves. Examples of RegisteredLoads would include: distribution company load, energy retailer load, large bulk power system connected facility load.

Loads that are served indirectly, for example - through an energy retailer or a vertical utility, should be modeled as RegisteredDistributedResources. Examples of RegisteredDistributedResources would include: distribution level storage, distribution level generation and distribution level demand response.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| blockLoadTransfer [0..1] | [Boolean](#CIM17v40-Boolean) | Emergency operating procedure - Flag to indicate that the Resource is Block Load pseudo resource. | |
| dynamicallyScheduledLoadResource [0..1] | [Boolean](#CIM17v40-Boolean) | Flag to indicate that a Load Resource is part of a DSR Load | |
| dynamicallyScheduledQualification [0..1] | [Boolean](#CIM17v40-Boolean) | Qualification status (used for DSR qualification). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ACAFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| ASSPOptimizationFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| commercialOpDate [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| contingencyAvailFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| dispatchable [0..1] | [Boolean](#CIM17v40-Boolean) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| ECAFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| flexibleOfferFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| hourlyPredispatch [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| isAggregatedRes [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| lastModified [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| LMPMFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| marketParticipationFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| maxBaseSelfSchedQty [0..1] | [Float](#CIM17v40-Float) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| maxOnTime [0..1] | [Float](#CIM17v40-Float) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| minDispatchTime [0..1] | [Hours](#CIM17v40-Hours) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| minOffTime [0..1] | [Float](#CIM17v40-Float) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| minOnTime [0..1] | [Float](#CIM17v40-Float) | see [RegisteredResource](#CIM17v40-RegisteredResource) | |
| mustOfferFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| nonMarket [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| pointOfDeliveryFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| priceSetFlagDA [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| priceSetFlagRT [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| registrationStatus [0..1] | [ResourceRegistrationStatus](#CIM17v40-ResourceRegistrationStatus) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| resourceAdequacyFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| SMPMFlag [0..1] | [YesNo](#CIM17v40-YesNo) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| AdjacentCASet [0..1] | [AdjacentCASet](#CIM17v40-AdjacentCASet) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| AggregateNode [0..1] | [AggregateNode](#CIM17v40-AggregateNode) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| DefaultBid [0..1] | [DefaultBid](#CIM17v40-DefaultBid) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| HostControlArea [0..1] | [HostControlArea](#CIM17v40-HostControlArea) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| MarketParticipant [0..1] | [MarketParticipant](#CIM17v40-MarketParticipant) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| MktConnectivityNode [0..1] | [MktConnectivityNode](#CIM17v40-MktConnectivityNode) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| Pnode [0..1] | [Pnode](#CIM17v40-Pnode) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| ResourceVerifiableCosts [0..1] | [ResourceVerifiableCosts](#CIM17v40-ResourceVerifiableCosts) | see [RegisteredResource](CIM17v40-RegisteredResource) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RegisteredResource}
### (informative) RegisteredResource

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RegisteredResource {

+ ACAFlag : enum:YesNo [0..1]
+ ASSPOptimizationFlag : enum:YesNo [0..1]
+ commercialOpDate : DateTime [0..1]
+ contingencyAvailFlag : enum:YesNo [0..1]
+ dispatchable : Boolean [0..1]
+ ECAFlag : enum:YesNo [0..1]
+ flexibleOfferFlag : enum:YesNo [0..1]
+ hourlyPredispatch : enum:YesNo [0..1]
+ isAggregatedRes : enum:YesNo [0..1]
+ lastModified : DateTime [0..1]
+ LMPMFlag : enum:YesNo [0..1]
+ marketParticipationFlag : enum:YesNo [0..1]
+ maxBaseSelfSchedQty : Float [0..1]
+ maxOnTime : Float [0..1]
+ minDispatchTime : Hours [0..1]
+ minOffTime : Float [0..1]
+ minOnTime : Float [0..1]
+ mustOfferFlag : enum:YesNo [0..1]
+ nonMarket : enum:YesNo [0..1]
+ pointOfDeliveryFlag : enum:YesNo [0..1]
+ priceSetFlagDA : enum:YesNo [0..1]
+ priceSetFlagRT : enum:YesNo [0..1]
+ registrationStatus : enum:ResourceRegistrationStatus [0..1]
+ resourceAdequacyFlag : enum:YesNo [0..1]
+ SMPMFlag : enum:YesNo [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- RegisteredResource : inherits from
class AdjacentCASet {

}

RegisteredResource --> "0..1" AdjacentCASet : AdjacentCASet
class AggregateNode {

}

RegisteredResource --> "0..1" AggregateNode : AggregateNode
class DefaultBid {

}

RegisteredResource --> "0..1" DefaultBid : DefaultBid
class HostControlArea {

}

RegisteredResource --> "0..1" HostControlArea : HostControlArea
class MarketParticipant {

}

RegisteredResource --> "0..1" MarketParticipant : MarketParticipant
class MktConnectivityNode {

}

RegisteredResource --> "0..1" MktConnectivityNode : MktConnectivityNode
class Pnode {

}

RegisteredResource --> "0..1" Pnode : Pnode
class ResourceVerifiableCosts {

}

RegisteredResource --> "0..1" ResourceVerifiableCosts : ResourceVerifiableCosts
```

A resource that is registered through the market participant registration system. Examples include generating unit, load, and non-physical generator or load.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ACAFlag [0..1] | [YesNo](#CIM17v40-YesNo) | Indication that this resource is associated with an Adjacent Control Area. | |
| ASSPOptimizationFlag [0..1] | [YesNo](#CIM17v40-YesNo) | Indication that the resource participates in the optimization process by default. | |
| commercialOpDate [0..1] | [DateTime](#CIM17v40-DateTime) | Resource Commercial Operation Date. | |
| contingencyAvailFlag [0..1] | [YesNo](#CIM17v40-YesNo) | Contingent operating reserve availiability (Yes/No). Resource is availiable to participate with capacity in contingency dispatch. | |
| dispatchable [0..1] | [Boolean](#CIM17v40-Boolean) | Dispatchable: indicates whether the resource is dispatchable. This implies that the resource intends to submit Energy bids/offers or Ancillary Services bids/offers, or self-provided schedules. | |
| ECAFlag [0..1] | [YesNo](#CIM17v40-YesNo) | Indication that this resource is associated with an Embedded Control area. | |
| flexibleOfferFlag [0..1] | [YesNo](#CIM17v40-YesNo) | Flexible offer flag (Y/N). | |
| hourlyPredispatch [0..1] | [YesNo](#CIM17v40-YesNo) | Indicates need to dispatch before the start of the operating hour. Only relevant in Real-Time Market. Applies to generation, intertie and participating load resource. Value (Y/N). | |
| isAggregatedRes [0..1] | [YesNo](#CIM17v40-YesNo) | A flag to indicate if a resource is an aggregated resource. | |
| lastModified [0..1] | [DateTime](#CIM17v40-DateTime) | Indication of the last time this item was modified/versioned. | |
| LMPMFlag [0..1] | [YesNo](#CIM17v40-YesNo) | LMPM flag: indicates whether the resource is subject to the LMPM test (Yes/No). | |
| marketParticipationFlag [0..1] | [YesNo](#CIM17v40-YesNo) | Market Participation flag: indicates whether the resource participate in the market. | |
| maxBaseSelfSchedQty [0..1] | [Float](#CIM17v40-Float) | Maximum base self schedule quantity. | |
| maxOnTime [0..1] | [Float](#CIM17v40-Float) | Maximum on time after start up. | |
| minDispatchTime [0..1] | [Hours](#CIM17v40-Hours) | Minimum number of consecutive hours a resource shall be dispatched if bid is accepted. | |
| minOffTime [0..1] | [Float](#CIM17v40-Float) | Minimum off time after shut down. | |
| minOnTime [0..1] | [Float](#CIM17v40-Float) | Minimum on time after start up. | |
| mustOfferFlag [0..1] | [YesNo](#CIM17v40-YesNo) | Must offer flag: indicates whether the unit is subject to the must offer provisions (Y/N). | |
| nonMarket [0..1] | [YesNo](#CIM17v40-YesNo) | Flag to indicate that the Resource is not participating in the Market Operations. | |
| pointOfDeliveryFlag [0..1] | [YesNo](#CIM17v40-YesNo) | Indication that the registered resource is a Point of Delivery (YES) resource which implies there is a POD Loss Factor. | |
| priceSetFlagDA [0..1] | [YesNo](#CIM17v40-YesNo) | Price setting flag: indicates whether a resource is capable of setting the Market Clearing Price (Y) for the DA market, and if not, indicates whether the resource shall submit bids for energy at $ 0 (S) or not (N).Initially in the RegisteredGenerator class. It was moved to the RegisteredResource class for the participating load dispatch purpose. | |
| priceSetFlagRT [0..1] | [YesNo](#CIM17v40-YesNo) | Price setting flag: indicates whether a resource is capable of setting the Market Clearing Price (Y) for the RT market, and if not, indicates whether the resource shall submit bids for energy at $ 0 (S) or not (N).Initially in the RegisteredGenerator class. It was moved to the RegisteredResource class for the participating load dispatch purpose. | |
| registrationStatus [0..1] | [ResourceRegistrationStatus](#CIM17v40-ResourceRegistrationStatus) | Registration Status of resource - Active, Mothballed, Planned, or Decommissioned. | |
| resourceAdequacyFlag [0..1] | [YesNo](#CIM17v40-YesNo) | Indication that this resource participates in the resource adequacy function. | |
| SMPMFlag [0..1] | [YesNo](#CIM17v40-YesNo) | SMPM flag: indicates whether the resource is subject to the SMPM test (Yes/No). | |
| AdjacentCASet [0..1] | [AdjacentCASet](#CIM17v40-AdjacentCASet) | | |
| AggregateNode [0..1] | [AggregateNode](#CIM17v40-AggregateNode) | An AggregateNode may be associated with up to many RegisteredResources. | |
| DefaultBid [0..1] | [DefaultBid](#CIM17v40-DefaultBid) | | |
| HostControlArea [0..1] | [HostControlArea](#CIM17v40-HostControlArea) | | |
| MarketParticipant [0..1] | [MarketParticipant](#CIM17v40-MarketParticipant) | | |
| MktConnectivityNode [0..1] | [MktConnectivityNode](#CIM17v40-MktConnectivityNode) | | |
| Pnode [0..1] | [Pnode](#CIM17v40-Pnode) | A registered resource injects power at one or more connectivity nodes related to a pnode | |
| ResourceVerifiableCosts [0..1] | [ResourceVerifiableCosts](#CIM17v40-ResourceVerifiableCosts) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RegularIntervalSchedule}
### RegularIntervalSchedule

Inheritance path = [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RegularIntervalSchedule {

+ endTime : DateTime [0..1]
+ timeStep : Seconds [0..1]
}

class BasicIntervalSchedule {

}

BasicIntervalSchedule <|-- RegularIntervalSchedule : inherits from
```

The schedule has time points where the time between them is constant.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | The time for the last time point. The value can be a time of day, not a specific date. | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | The time between each pair of subsequent regular time points in sequence order. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RegularTimePoint}
### RegularTimePoint


```mermaid
classDiagram
direction TB

class RegularTimePoint {

+ sequenceNumber : Integer [0..1]
+ value1 : Float [0..1]
+ value2 : Float [0..1]
}

class RegularIntervalSchedule {

}

RegularTimePoint --> "1" RegularIntervalSchedule : IntervalSchedule
```

Time point for a schedule where the time between the consecutive points is constant.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | The position of the regular time point in the sequence. Note that time points don't have to be sequential, i.e. time points may be omitted. The actual time for a RegularTimePoint is computed by multiplying the associated regular interval schedule's time step with the regular time point sequence number and adding the associated schedules start time. To specify values for the start time, use sequence number 0. The sequence number cannot be negative. | |
| value1 [0..1] | [Float](#CIM17v40-Float) | The first value at the time. The meaning of the value is defined by the derived type of the associated schedule. | |
| value2 [0..1] | [Float](#CIM17v40-Float) | The second value at the time. The meaning of the value is defined by the derived type of the associated schedule. | |
| `IntervalSchedule [1]` (OfAggregate) | [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | Regular interval schedule containing this time point. | |

{#CIM17v40-RegulatingCondEq}
### RegulatingCondEq

Inheritance path = [EnergyConnection](#CIM17v40-EnergyConnection) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RegulatingCondEq {

+ controlEnabled : Boolean [0..1]
}

class EnergyConnection {

}

EnergyConnection <|-- RegulatingCondEq : inherits from
class RegulatingControl {

}

RegulatingCondEq --> "0..1" RegulatingControl : RegulatingControl
```

A type of conducting equipment that can regulate a quantity (i.e. voltage or flow) at a specific point in the network.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| controlEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | Specifies the regulation status of the equipment. True is regulating, false is not regulating. | |
| RegulatingControl [0..1] | [RegulatingControl](#CIM17v40-RegulatingControl) | The regulating control scheme in which this equipment participates. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RegulatingControl}
### (informative) RegulatingControl

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RegulatingControl {

+ enabled : Boolean [0..1]
+ maxAllowedTargetValue : Float [0..1]
+ minAllowedTargetValue : Float [0..1]
+ mode : enum:RegulatingControlModeKind [0..1]
+ monitoredPhase : enum:PhaseCode [0..1]
+ targetDeadband : Float [0..1]
+ targetValue : Float [0..1]
+ targetValueUnitMultiplier : enum:UnitMultiplier [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- RegulatingControl : inherits from
class Terminal {

}

RegulatingControl --> "0..1" Terminal : Terminal
```

Specifies a set of equipment that works together to control a power system quantity such as voltage or flow.

Remote bus voltage control is possible by specifying the controlled terminal located at some place remote from the controlling equipment.

The specified terminal shall be associated with the connectivity node of the controlled point. The most specific subtype of RegulatingControl shall be used in case such equipment participate in the control, e.g. TapChangerControl for tap changers.

For flow control, load sign convention is used, i.e. positive sign means flow out from a TopologicalNode (bus) into the conducting equipment.

The attribute minAllowedTargetValue and maxAllowedTargetValue are required in the following cases:

- For a power generating module operated in power factor control mode to specify maximum and minimum power factor values;

- Whenever it is necessary to have an off center target voltage for the tap changer regulator. For instance, due to long cables to off shore wind farms and the need to have a simpler setup at the off shore transformer platform, the voltage is controlled from the land at the connection point for the off shore wind farm. Since there usually is a voltage rise along the cable, there is typical and overvoltage of up 3-4 kV compared to the on shore station. Thus in normal operation the tap changer on the on shore station is operated with a target set point, which is in the lower parts of the dead band.

The attributes minAllowedTargetValue and maxAllowedTargetValue are not related to the attribute targetDeadband and thus they are not treated as an alternative of the targetDeadband. They are needed due to limitations in the local substation controller. The attribute targetDeadband is used to prevent the power flow from move the tap position in circles (hunting) that is to be used regardless of the attributes minAllowedTargetValue and maxAllowedTargetValue.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | The flag tells if regulation is enabled. | |
| maxAllowedTargetValue [0..1] | [Float](#CIM17v40-Float) | Maximum allowed target value (RegulatingControl.targetValue). | |
| minAllowedTargetValue [0..1] | [Float](#CIM17v40-Float) | Minimum allowed target value (RegulatingControl.targetValue). | |
| mode [0..1] | [RegulatingControlModeKind](#CIM17v40-RegulatingControlModeKind) | The regulating control mode presently available. This specification allows for determining the kind of regulation without need for obtaining the units from a schedule. | |
| monitoredPhase [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | Phase voltage controlling this regulator, measured at regulator location. | |
| targetDeadband [0..1] | [Float](#CIM17v40-Float) | This is a deadband used with discrete control to avoid excessive update of controls like tap changers and shunt compensator banks while regulating. The units of those appropriate for the mode. The attribute shall be a positive value or zero. If RegulatingControl.discrete is set to "false", the RegulatingControl.targetDeadband is to be ignored.Note that for instance, if the targetValue is 100 kV and the targetDeadband is 2 kV the range is from 99 to 101 kV. | |
| targetValue [0..1] | [Float](#CIM17v40-Float) | The target value specified for case input. This value can be used for the target value without the use of schedules. The value has the units appropriate to the mode attribute. | |
| targetValueUnitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | Specify the multiplier for used for the targetValue. | |
| Terminal [0..1] | [Terminal](#CIM17v40-Terminal) | The terminal associated with this regulating control. The terminal is associated instead of a node, since the terminal could connect into either a topological node or a connectivity node. Sometimes it is useful to model regulation at a terminal of a bus bar object. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RegulatingLimit}
### RegulatingLimit

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RegulatingLimit {

+ highLimit : ActivePower [0..1]
+ lowLimit : ActivePower [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- RegulatingLimit : inherits from
class RegisteredGenerator {

}

RegulatingLimit --> "0..1" RegisteredGenerator : RegisteredGenerator
```

This class represents the physical characteristic of a generator regarding the regulating limit.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| highLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | | |
| lowLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | | |
| RegisteredGenerator [0..1] | [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Regulation}
### Regulation

Inheritance path = [WorkDocument](#CIM17v40-WorkDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Regulation {

+ referenceNumber : String [0..1]
}

class WorkDocument {

}

WorkDocument <|-- Regulation : inherits from
```

Special requirements and/or regulations may pertain to certain types of assets or work. For example, fire protection and scaffolding.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| referenceNumber [0..1] | [String](#CIM17v40-String) | External reference to regulation, if applicable. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RegulationSchedule}
### RegulationSchedule

Inheritance path = [SeasonDayTypeSchedule](#CIM17v40-SeasonDayTypeSchedule) => [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) => [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RegulationSchedule {

}

class SeasonDayTypeSchedule {

}

SeasonDayTypeSchedule <|-- RegulationSchedule : inherits from
class RegulatingControl {

}

RegulationSchedule --> "1" RegulatingControl : RegulatingControl
```

A pre-established pattern over time for a controlled variable, e.g., busbar voltage.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| RegulatingControl [1] | [RegulatingControl](#CIM17v40-RegulatingControl) | Regulating controls that have this schedule. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DayType [0..1] | [DayType](#CIM17v40-DayType) | see [SeasonDayTypeSchedule](CIM17v40-SeasonDayTypeSchedule) | |
| Season [0..1] | [Season](#CIM17v40-Season) | see [SeasonDayTypeSchedule](CIM17v40-SeasonDayTypeSchedule) | |
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | see [RegularIntervalSchedule](CIM17v40-RegularIntervalSchedule) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ReliabilityInfo}
### ReliabilityInfo

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ReliabilityInfo {

+ momFailureRate : PerCent [0..1]
+ mTTR : Hours [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ReliabilityInfo : inherits from
class Specification {

}

ReliabilityInfo --> "0..1" Specification : Specification
```

Information regarding the experienced and expected reliability of a specific asset, type of asset, or asset model.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| momFailureRate [0..1] | [PerCent](#CIM17v40-PerCent) | Momentary failure rate (temporary failures/kft-year). | |
| mTTR [0..1] | [Hours](#CIM17v40-Hours) | Mean time to repair (MTTR - hours). | |
| `Specification [0..1]` (informative) | [Specification](#CIM17v40-Specification) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RemedialActionScheme}
### (informative) RemedialActionScheme

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RemedialActionScheme {

+ armed : Boolean [0..1]
+ kind : enum:RemedialActionSchemeKind [0..1]
+ normalArmed : Boolean [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- RemedialActionScheme : inherits from
class Gate {

}

RemedialActionScheme --> "0..1" Gate : GateArmed
```

Remedial Action Scheme (RAS), Special Protection Schemes (SPS), System Protection Schemes (SPS) or System Integrity Protection Schemes (SIPS).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| armed [0..1] | [Boolean](#CIM17v40-Boolean) | The status of the class set by operation or by signal. Optional field that will override other status fields. | |
| kind [0..1] | [RemedialActionSchemeKind](#CIM17v40-RemedialActionSchemeKind) | Kind of Remedial Action Scheme (RAS). | |
| normalArmed [0..1] | [Boolean](#CIM17v40-Boolean) | The default/normal value used when other active signal/values are missing. | |
| `GateArmed [0..1]` (informative) | [Gate](#CIM17v40-Gate) | Gate that through a gate logic and input pin defines arming of the Remedial Action Schemes (RAS). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RemoteControl}
### RemoteControl

Inheritance path = [RemotePoint](#CIM17v40-RemotePoint) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RemoteControl {

+ actuatorMaximum : Float [0..1]
+ actuatorMinimum : Float [0..1]
+ remoteControlled : Boolean [0..1]
}

class RemotePoint {

}

RemotePoint <|-- RemoteControl : inherits from
class Control {

}

RemoteControl --> "1" Control : Control
```

Remote controls are outputs that are sent by the remote unit to actuators in the process.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| actuatorMaximum [0..1] | [Float](#CIM17v40-Float) | The maximum set point value accepted by the remote control point. | |
| actuatorMinimum [0..1] | [Float](#CIM17v40-Float) | The minimum set point value accepted by the remote control point. | |
| remoteControlled [0..1] | [Boolean](#CIM17v40-Boolean) | Set to true if the actuator is remotely controlled. | |
| Control [1] | [Control](#CIM17v40-Control) | The Control for the RemoteControl point. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `RemoteUnit [1]` (OfAggregate) | [RemoteUnit](#CIM17v40-RemoteUnit) | see [RemotePoint](CIM17v40-RemotePoint) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RemoteInputSignal}
### RemoteInputSignal

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RemoteInputSignal {

+ remoteSignalType : enum:RemoteSignalKind [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- RemoteInputSignal : inherits from
class DiscontinuousExcitationControlDynamics {

}

RemoteInputSignal --> "0..1" DiscontinuousExcitationControlDynamics : DiscontinuousExcitationControlDynamics
class PFVArControllerType1Dynamics {

}

RemoteInputSignal --> "0..1" PFVArControllerType1Dynamics : PFVArControllerType1Dynamics
class PowerSystemStabilizerDynamics {

}

RemoteInputSignal --> "0..1" PowerSystemStabilizerDynamics : PowerSystemStabilizerDynamics
class Terminal {

}

RemoteInputSignal --> "1" Terminal : Terminal
class UnderexcitationLimiterDynamics {

}

RemoteInputSignal --> "0..1" UnderexcitationLimiterDynamics : UnderexcitationLimiterDynamics
class VoltageCompensatorDynamics {

}

RemoteInputSignal --> "0..1" VoltageCompensatorDynamics : VoltageCompensatorDynamics
class WindPlantDynamics {

}

RemoteInputSignal --> "0..1" WindPlantDynamics : WindPlantDynamics
class WindTurbineType1or2Dynamics {

}

RemoteInputSignal --> "0..1" WindTurbineType1or2Dynamics : WindTurbineType1or2Dynamics
class WindTurbineType3or4Dynamics {

}

RemoteInputSignal --> "0..1" WindTurbineType3or4Dynamics : WindTurbineType3or4Dynamics
```

Supports connection to a terminal associated with a remote bus from which an input signal of a specific type is coming.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| remoteSignalType [0..1] | [RemoteSignalKind](#CIM17v40-RemoteSignalKind) | Type of input signal. | |
| DiscontinuousExcitationControlDynamics [0..1] | [DiscontinuousExcitationControlDynamics](#CIM17v40-DiscontinuousExcitationControlDynamics) | Discontinuous excitation control model using this remote input signal. | |
| PFVArControllerType1Dynamics [0..1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | Power factor or VAr controller type 1 model using this remote input signal. | |
| PowerSystemStabilizerDynamics [0..1] | [PowerSystemStabilizerDynamics](#CIM17v40-PowerSystemStabilizerDynamics) | Power system stabilizer model using this remote input signal. | |
| Terminal [1] | [Terminal](#CIM17v40-Terminal) | Remote terminal with which this input signal is associated. | |
| UnderexcitationLimiterDynamics [0..1] | [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) | Underexcitation limiter model using this remote input signal. | |
| VoltageCompensatorDynamics [0..1] | [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) | Voltage compensator model using this remote input signal. | |
| WindPlantDynamics [0..1] | [WindPlantDynamics](#CIM17v40-WindPlantDynamics) | The wind plant using the remote signal. | |
| WindTurbineType1or2Dynamics [0..1] | [WindTurbineType1or2Dynamics](#CIM17v40-WindTurbineType1or2Dynamics) | Wind generator type 1 or type 2 model using this remote input signal. | |
| WindTurbineType3or4Dynamics [0..1] | [WindTurbineType3or4Dynamics](#CIM17v40-WindTurbineType3or4Dynamics) | Wind turbine type 3 or type 4 models using this remote input signal. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RemotePoint}
### RemotePoint

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RemotePoint {

}

class IdentifiedObject {

}

IdentifiedObject <|-- RemotePoint : inherits from
class RemoteUnit {

}

RemotePoint --> "1" RemoteUnit : RemoteUnit
```

For an RTU, remote points correspond to telemetered values or control outputs. Other units (e.g. control centres) usually also contain calculated values.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `RemoteUnit [1]` (OfAggregate) | [RemoteUnit](#CIM17v40-RemoteUnit) | Remote unit this point belongs to. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RemoteSource}
### RemoteSource

Inheritance path = [RemotePoint](#CIM17v40-RemotePoint) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RemoteSource {

+ deadband : Float [0..1]
+ scanInterval : Seconds [0..1]
+ sensorMaximum : Float [0..1]
+ sensorMinimum : Float [0..1]
}

class RemotePoint {

}

RemotePoint <|-- RemoteSource : inherits from
class MeasurementValue {

}

RemoteSource --> "1" MeasurementValue : MeasurementValue
```

Remote sources are state variables that are telemetered or calculated within the remote unit.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| deadband [0..1] | [Float](#CIM17v40-Float) | The smallest change in value to be reported. | |
| scanInterval [0..1] | [Seconds](#CIM17v40-Seconds) | The time interval between scans. | |
| sensorMaximum [0..1] | [Float](#CIM17v40-Float) | The maximum value the telemetry item can return. | |
| sensorMinimum [0..1] | [Float](#CIM17v40-Float) | The minimum value the telemetry item can return. | |
| MeasurementValue [1] | [MeasurementValue](#CIM17v40-MeasurementValue) | Link to the physical telemetered point associated with this measurement. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `RemoteUnit [1]` (OfAggregate) | [RemoteUnit](#CIM17v40-RemoteUnit) | see [RemotePoint](CIM17v40-RemotePoint) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RemoteUnit}
### RemoteUnit

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RemoteUnit {

+ remoteUnitType : enum:RemoteUnitType [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- RemoteUnit : inherits from
```

A remote unit can be an RTU, IED, substation control system, control centre, etc. The communication with the remote unit can be through various standard protocols (e.g. IEC 61870, IEC 61850) or non standard protocols (e.g. DNP, RP570, etc.). A remote unit contains remote data points that might be telemetered, collected or calculated. The RemoteUnit class inherits PowerSystemResource. The intention is to allow RemoteUnits to have Measurements. These Measurements can be used to model unit status as operational, out of service, unit failure, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| remoteUnitType [0..1] | [RemoteUnitType](#CIM17v40-RemoteUnitType) | Type of remote unit. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RepairItem}
### RepairItem


```mermaid
classDiagram
direction TB

class RepairItem {

+ breakerRepairItem : enum:BreakerRepairItemKind [0..1]
+ transformerRepairItem : enum:TransformerRepairItemKind [0..1]
}

```

Asset component to be repaired or problem area to be corrected.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| breakerRepairItem [0..1] | [BreakerRepairItemKind](#CIM17v40-BreakerRepairItemKind) | Breaker component or problem area which is the focus of this maintenance work task (for work tasks related to breakers only). | |
| transformerRepairItem [0..1] | [TransformerRepairItemKind](#CIM17v40-TransformerRepairItemKind) | Transformer component or problem area which is the focus of this maintenance work task (for work tasks related to transformers only). | |

{#CIM17v40-RepairWorkTask}
### RepairWorkTask

Inheritance path = [WorkTask](#CIM17v40-WorkTask) => [BaseWork](#CIM17v40-BaseWork) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RepairWorkTask {

+ emergency : Boolean [0..1]
}

class WorkTask {

}

WorkTask <|-- RepairWorkTask : inherits from
```

Work task for asset repair. Costs associated with this are considered corrective maintenance (CM) costs.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| emergency [0..1] | [Boolean](#CIM17v40-Boolean) | Repair work is emergency. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| completedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [WorkTask](#CIM17v40-WorkTask) | |
| contractorCost [0..1] | [Money](#CIM17v40-Money) | see [WorkTask](CIM17v40-WorkTask) | |
| crewETA [0..1] | [DateTime](#CIM17v40-DateTime) | see [WorkTask](#CIM17v40-WorkTask) | |
| estimatedCompletionTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [WorkTask](#CIM17v40-WorkTask) | |
| instruction [0..1] | [String](#CIM17v40-String) | see [WorkTask](#CIM17v40-WorkTask) | |
| laborCost [0..1] | [Money](#CIM17v40-Money) | see [WorkTask](CIM17v40-WorkTask) | |
| laborHours [0..1] | [Hours](#CIM17v40-Hours) | see [WorkTask](CIM17v40-WorkTask) | |
| materiallCost [0..1] | [Money](#CIM17v40-Money) | see [WorkTask](CIM17v40-WorkTask) | |
| schedOverride [0..1] | [String](#CIM17v40-String) | see [WorkTask](#CIM17v40-WorkTask) | |
| startedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [WorkTask](#CIM17v40-WorkTask) | |
| taskKind [0..1] | [WorkTaskKind](#CIM17v40-WorkTaskKind) | see [WorkTask](CIM17v40-WorkTask) | |
| toolCost [0..1] | [Money](#CIM17v40-Money) | see [WorkTask](CIM17v40-WorkTask) | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | see [WorkTask](CIM17v40-WorkTask) | |
| TroubleOrder [0..1] | [TroubleOrder](#CIM17v40-TroubleOrder) | see [WorkTask](CIM17v40-WorkTask) | |
| Work [1] | [Work](#CIM17v40-Work) | see [WorkTask](CIM17v40-WorkTask) | |
| kind [0..1] | [ServiceRequestKind](#CIM17v40-ServiceRequestKind) | see [BaseWork](CIM17v40-BaseWork) | |
| statusKind [0..1] | [WorkStatusKind](#CIM17v40-WorkStatusKind) | see [BaseWork](CIM17v40-BaseWork) | |
| priority [0..1] | [Priority](#CIM17v40-Priority) | see [BaseWork](CIM17v40-BaseWork) | |
| WorkLocation [0..1] | [WorkLocation](#CIM17v40-WorkLocation) | see [BaseWork](CIM17v40-BaseWork) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ReportingCapability}
### ReportingCapability


```mermaid
classDiagram
direction TB

class ReportingCapability {

+ reportingIntervalPeriod : Integer [0..1]
+ reportingIntervalType : enum:CalculationIntervalUnitKind [0..1]
+ reportingMethod : enum:ReportingMethodKind [0..1]
}

class EnvironmentalMonitoringStation {

}

ReportingCapability --> "1" EnvironmentalMonitoringStation : EnvironmentalMonitoringStation
```

<font color="#0f0f0f">Definition of one set of reporting capabilities for this monitoring station. The associated EnvironmentalValueSets describe the maximum range of possible environmental values the station is capable of returning. This attribute is intended primarily to assist a utility in managing its stations. </font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| reportingIntervalPeriod [0..1] | [Integer](#CIM17v40-Integer) | Number of units of time making up reporting period. | |
| reportingIntervalType [0..1] | [CalculationIntervalUnitKind](#CIM17v40-CalculationIntervalUnitKind) | Unit of time in which reporting period is expressed. | |
| reportingMethod [0..1] | [ReportingMethodKind](#CIM17v40-ReportingMethodKind) | Indicates how the weather station reports observations. | |
| EnvironmentalMonitoringStation [1] | [EnvironmentalMonitoringStation](#CIM17v40-EnvironmentalMonitoringStation) | The environmental monitoring station to which this set of reporting capabilities belong. | |

{#CIM17v40-ReportingGroup}
### ReportingGroup

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ReportingGroup {

}

class IdentifiedObject {

}

IdentifiedObject <|-- ReportingGroup : inherits from
class ReportingSuperGroup {

}

ReportingGroup --> "0..1" ReportingSuperGroup : ReportingSuperGroup
```

A reporting group is used for various ad-hoc groupings used for reporting.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ReportingSuperGroup [0..1]` (OfAggregate) | [ReportingSuperGroup](#CIM17v40-ReportingSuperGroup) | Reporting super group to which this reporting group belongs. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ReportingSuperGroup}
### ReportingSuperGroup

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ReportingSuperGroup {

}

class IdentifiedObject {

}

IdentifiedObject <|-- ReportingSuperGroup : inherits from
```

A reporting super group, groups reporting groups for a higher level report.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ReserveDemandCurve}
### ReserveDemandCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ReserveDemandCurve {

+ reqMaxMW : Float [0..1]
+ reserveRequirementType : enum:ReserveRequirementType [0..1]
}

class Curve {

}

Curve <|-- ReserveDemandCurve : inherits from
class ASRequirements {

}

ReserveDemandCurve --> "1" ASRequirements : ASRequirements
class MarketRegion {

}

ReserveDemandCurve --> "1" MarketRegion : MarketRegion
```

Reserve demand curve. Models maximum quantities of reserve required per Market Region and models a reserve demand curve for the minimum quantities of reserve. The ReserveDemandCurve is a relationship between unit operating reserve price in $/MWhr (Y-axis) and unit reserves in MW (X-axis).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| reqMaxMW [0..1] | [Float](#CIM17v40-Float) | Region requirement maximum limit | |
| reserveRequirementType [0..1] | [ReserveRequirementType](#CIM17v40-ReserveRequirementType) | Reserve requirement type that the max and curve apply to. For example, operating reserve, regulation and contingency. | |
| ASRequirements [1] | [ASRequirements](#CIM17v40-ASRequirements) | | |
| MarketRegion [1] | [MarketRegion](#CIM17v40-MarketRegion) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ReserveReq}
### (informative) ReserveReq

Inheritance path = [ResourceGroupReq](#CIM17v40-ResourceGroupReq) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ReserveReq {

}

class ResourceGroupReq {

}

ResourceGroupReq <|-- ReserveReq : inherits from
class MarketProduct {

}

ReserveReq --> "1" MarketProduct : MarketProduct
class ReserveReqCurve {

}

ReserveReq --> "1" ReserveReqCurve : ReserveReqCurve
class SensitivityPriceCurve {

}

ReserveReq --> "0..1" SensitivityPriceCurve : SensitivityPriceCurve
```

Requirements for minimum amount of reserve and/or regulation to be supplied by a set of qualified resources.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `MarketProduct [1]` (informative) | [MarketProduct](#CIM17v40-MarketProduct) | Market product associated with reserve requirement must be a reserve or regulation product. | |
| `ReserveReqCurve [1]` (informative) | [ReserveReqCurve](#CIM17v40-ReserveReqCurve) | | |
| `SensitivityPriceCurve [0..1]` (informative) | [SensitivityPriceCurve](#CIM17v40-SensitivityPriceCurve) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ResourceGroup [1]` (informative) | [ResourceGroup](#CIM17v40-ResourceGroup) | see [ResourceGroupReq](CIM17v40-ResourceGroupReq) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ReserveReqCurve}
### (informative) ReserveReqCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ReserveReqCurve {

}

class Curve {

}

Curve <|-- ReserveReqCurve : inherits from
class ReserveReq {

}

ReserveReqCurve --> "1" ReserveReq : ReserveReq
```

A curve relating reserve requirement versus time, showing the values of a specific reserve requirement for each unit of the period covered. The curve can be based on "absolute" time or on "normalized' time.

X is time, typically expressed in absolute time

Y1 is reserve requirement, typically expressed in MW


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ReserveReq [1]` (informative) | [ReserveReq](#CIM17v40-ReserveReq) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Reservoir}
### Reservoir

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Reservoir {

+ activeStorageCapacity : Volume [0..1]
+ energyStorageRating : Float [0..1]
+ fullSupplyLevel : WaterLevel [0..1]
+ grossCapacity : Volume [0..1]
+ normalMinOperateLevel : WaterLevel [0..1]
+ riverOutletWorks : String [0..1]
+ spillTravelDelay : Seconds [0..1]
+ spillwayCapacity : Float [0..1]
+ spillwayCrestLength : Length [0..1]
+ spillwayCrestLevel : WaterLevel [0..1]
+ spillWayGateType : String [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- Reservoir : inherits from
class Reservoir {

}

Reservoir --> "0..1" Reservoir : SpillsFromReservoir
class TargetLevelSchedule {

}

Reservoir --> "0..1" TargetLevelSchedule : TargetLevelSchedule
```

A water storage facility within a hydro system, including: ponds, lakes, lagoons, and rivers. The storage is usually behind some type of dam.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| activeStorageCapacity [0..1] | [Volume](#CIM17v40-Volume) | Storage volume between the full supply level and the normal minimum operating level. | |
| energyStorageRating [0..1] | [Float](#CIM17v40-Float) | The reservoir's energy storage rating in energy for given head conditions. | |
| fullSupplyLevel [0..1] | [WaterLevel](#CIM17v40-WaterLevel) | Full supply level, above which water will spill. This can be the spillway crest level or the top of closed gates. | |
| grossCapacity [0..1] | [Volume](#CIM17v40-Volume) | Total capacity of reservoir. | |
| normalMinOperateLevel [0..1] | [WaterLevel](#CIM17v40-WaterLevel) | Normal minimum operating level below which the penstocks will draw air. | |
| riverOutletWorks [0..1] | [String](#CIM17v40-String) | River outlet works for riparian right releases or other purposes. | |
| spillTravelDelay [0..1] | [Seconds](#CIM17v40-Seconds) | The spillway water travel delay to the next downstream reservoir. | |
| spillwayCapacity [0..1] | [Float](#CIM17v40-Float) | The flow capacity of the spillway in cubic meters per second. | |
| spillwayCrestLength [0..1] | [Length](#CIM17v40-Length) | The length of the spillway crest. | |
| spillwayCrestLevel [0..1] | [WaterLevel](#CIM17v40-WaterLevel) | Spillway crest level above which water will spill. | |
| spillWayGateType [0..1] | [String](#CIM17v40-String) | Type of spillway gate, including parameters. | |
| SpillsFromReservoir [0..1] | [Reservoir](#CIM17v40-Reservoir) | A reservoir may spill into a downstream reservoir. | |
| `TargetLevelSchedule [0..1]` (AggregateOf) | [TargetLevelSchedule](#CIM17v40-TargetLevelSchedule) | A reservoir may have a water level target schedule. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ResourceAwardClearing}
### ResourceAwardClearing

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ResourceAwardClearing {

+ contingencyActive : enum:YesNo [0..1]
+ dispatchMode : enum:AutomaticDispatchMode [0..1]
}

class MarketFactors {

}

MarketFactors <|-- ResourceAwardClearing : inherits from
```

Models details of bid and offer market clearing. Class indicates whether a contingency is active and whether the automatic dispatching system is active for this interval of the market solution.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| contingencyActive [0..1] | [YesNo](#CIM17v40-YesNo) | Indication that the system is currently operating in a contingency mode. | |
| dispatchMode [0..1] | [AutomaticDispatchMode](#CIM17v40-AutomaticDispatchMode) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ResourceAwardInstruction}
### ResourceAwardInstruction


```mermaid
classDiagram
direction TB

class ResourceAwardInstruction {

+ awardMW : Float [0..1]
+ clearedMW : Float [0..1]
+ clearedPrice : Float [0..1]
+ congestLMP : Float [0..1]
+ costLMP : Float [0..1]
+ dispatcherAddedMW : Float [0..1]
+ economicMax : Float [0..1]
+ economicMin : Float [0..1]
+ effRegulationDownLimit : Float [0..1]
+ effRegulationUpLimit : Float [0..1]
+ lmp : Float [0..1]
+ lossLMP : Float [0..1]
+ manuallyBlocked : enum:YesNo [0..1]
+ marginalResourceIndicator : enum:YesNo [0..1]
+ mustRunInd : Boolean [0..1]
+ noLoadCost : Float [0..1]
+ optimalBidCost : Float [0..1]
+ optimalBidPay : Float [0..1]
+ optimalMargin : Float [0..1]
+ overrideTimeStamp : DateTime [0..1]
+ overrideValue : Float [0..1]
+ selfSchedMW : Float [0..1]
+ startUpCost : Float [0..1]
+ status : String [0..1]
+ totalRevenue : Float [0..1]
+ updateTimeStamp : DateTime [0..1]
+ updateType : enum:MQSCHGType [0..1]
+ updateUser : String [0..1]
}

class MarketProduct {

}

ResourceAwardInstruction --> "1" MarketProduct : MarketProduct
class RegisteredResource {

}

ResourceAwardInstruction --> "0..1" RegisteredResource : RegisteredResource
```

Model of market results, instruction for resource. Contains details of award as attributes.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| awardMW [0..1] | [Float](#CIM17v40-Float) | For DA Energy: Not Applicable;For DA AS: DA AS market award;For RT Energy: Not Applicable;For RT AS: RT AS market award (excluding DA AS market or self-proviison awards) | |
| clearedMW [0..1] | [Float](#CIM17v40-Float) | For DA Energy: Total Schedule = DA market schedule + DA self-schedule award;For DA AS: DA Ancillary Service Awards = DA AS market award + DA AS self-provision award;For RT Energy: Total Schedule = RT market schedule + RT self-schedule award;For RT AS: RT Ancillary Service Awards = RT AS self-provision award + RT AS market award + DA AS market award + DA AS self-provision award; | |
| clearedPrice [0..1] | [Float](#CIM17v40-Float) | Marginal Price ($/MW) for the commodity (Regulation Up, Regulation Down, Spinning Reserve, or Non-spinning reserve) for pricing run. | |
| congestLMP [0..1] | [Float](#CIM17v40-Float) | Congestion component of Location Marginal Price (LMP) in monetary units per MW. | |
| costLMP [0..1] | [Float](#CIM17v40-Float) | Cost component of Locational Marginal Pricing (LMP) in monetary units per MW. | |
| dispatcherAddedMW [0..1] | [Float](#CIM17v40-Float) | The tier2 mw added by dispatcher actionMarket results of the synchronized reserve market | |
| economicMax [0..1] | [Float](#CIM17v40-Float) | Unit max output for dispatch; bid in economic maximum | |
| economicMin [0..1] | [Float](#CIM17v40-Float) | Unit min output for dispatch; bid in economic minimum | |
| effRegulationDownLimit [0..1] | [Float](#CIM17v40-Float) | Effective Regulation Down Limit (MW) | |
| effRegulationUpLimit [0..1] | [Float](#CIM17v40-Float) | Effective Regulation Up Limit | |
| lmp [0..1] | [Float](#CIM17v40-Float) | Locational marginal price value | |
| lossLMP [0..1] | [Float](#CIM17v40-Float) | Loss component of Location Marginal Price (LMP) in monetary units per MW. | |
| manuallyBlocked [0..1] | [YesNo](#CIM17v40-YesNo) | Indicates if an award was manually blocked (Y/N). Valid for Spinning and Non-spinning. | |
| marginalResourceIndicator [0..1] | [YesNo](#CIM17v40-YesNo) | Indicator (Yes / No) that this resource set the price for this dispatch / schedule. | |
| mustRunInd [0..1] | [Boolean](#CIM17v40-Boolean) | Identifes if the unit was set to must run by the market participant responsible for bidding in the unit | |
| noLoadCost [0..1] | [Float](#CIM17v40-Float) | Unit no-load cost in case of energy commodity | |
| optimalBidCost [0..1] | [Float](#CIM17v40-Float) | Optimal Bid cost | |
| optimalBidPay [0..1] | [Float](#CIM17v40-Float) | Optimal Bid production payment based on LMP | |
| optimalMargin [0..1] | [Float](#CIM17v40-Float) | Optimal Bid production margin | |
| overrideTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | Time the manual data entry occured. | |
| overrideValue [0..1] | [Float](#CIM17v40-Float) | Provides the ability for the grid operator to override items, such as spin capacity requirements, prior to running the algorithm. This value is market product based (spin, non-spin, reg up, reg down, or RUC). | |
| selfSchedMW [0..1] | [Float](#CIM17v40-Float) | For DA Energy: DA total self-schedule award;For DA AS: DA AS self-provision award;For RT Energy: RT total self-schedule award;For RT AS: RT AS self-provision award (excluding DA AS market or self-provision awards) | |
| startUpCost [0..1] | [Float](#CIM17v40-Float) | Unit start up cost in case of energy commodity | |
| status [0..1] | [String](#CIM17v40-String) | In or out status of resource | |
| totalRevenue [0..1] | [Float](#CIM17v40-Float) | Total bid revenue (startup_cost + no_load_cost + bid_pay) | |
| updateTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| updateType [0..1] | [MQSCHGType](#CIM17v40-MQSCHGType) | | |
| updateUser [0..1] | [String](#CIM17v40-String) | | |
| MarketProduct [1] | [MarketProduct](#CIM17v40-MarketProduct) | | |
| RegisteredResource [0..1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |

{#CIM17v40-ResourceBid}
### ResourceBid

Inheritance path = [Bid](#CIM17v40-Bid) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ResourceBid {

+ aggregationFlag : Integer [0..1]
+ bidStatus : String [0..1]
+ commodityType : String [0..1]
+ contingencyAvailFlag : enum:YesNo [0..1]
+ createdISO : enum:YesNo [0..1]
+ energyMaxDay : Float [0..1]
+ energyMinDay : Float [0..1]
+ marketSepFlag : String [0..1]
+ minDispatchTime : Integer [0..1]
+ resourceLoadingType : Integer [0..1]
+ shutDownsMaxDay : Integer [0..1]
+ shutDownsMaxWeek : Integer [0..1]
+ startUpsMaxDay : Integer [0..1]
+ startUpsMaxWeek : Integer [0..1]
+ virtual : Boolean [0..1]
}

class Bid {

}

Bid <|-- ResourceBid : inherits from
```

Energy bid for generation, load, or virtual type for the whole of the market-trading period (i.e., one day in day ahead market or one hour in the real time market).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aggregationFlag [0..1] | [Integer](#CIM17v40-Integer) | Aggregation flag0: individual resource level1: Aggregated node location2: Aggregated price location) | |
| bidStatus [0..1] | [String](#CIM17v40-String) | | |
| commodityType [0..1] | [String](#CIM17v40-String) | Energy product (commodity) type:'En' - Energy'Ru' - Regulation Up'Rd' - Regulation Dn'Sr' - Spinning Reserve'Nr' - Non-Spinning Reserve'Or' - Operating Reserve | |
| contingencyAvailFlag [0..1] | [YesNo](#CIM17v40-YesNo) | contingent operating reserve availiability (Yes/No). Resource is availiable to participate with capacity only in contingency dispatch. | |
| createdISO [0..1] | [YesNo](#CIM17v40-YesNo) | A Yes indicates that this bid was created by the ISO. | |
| energyMaxDay [0..1] | [Float](#CIM17v40-Float) | Maximum amount of energy per day which can be produced during the trading period in MWh | |
| energyMinDay [0..1] | [Float](#CIM17v40-Float) | Minimum amount of energy per day which has to be produced during the trading period in MWh | |
| marketSepFlag [0..1] | [String](#CIM17v40-String) | Market Separation Flag'Y' - Enforce market separation constraints for this bid'N' - Don't enforce market separation constraints for this bid. | |
| minDispatchTime [0..1] | [Integer](#CIM17v40-Integer) | minimum number of consecutive hours a resource shall be dispatched if bid is accepted | |
| resourceLoadingType [0..1] | [Integer](#CIM17v40-Integer) | Resource loading curve type1 - step-wise continuous loading2 - piece-wise linear continuous loading3 - block loading | |
| shutDownsMaxDay [0..1] | [Integer](#CIM17v40-Integer) | Maximum number of shutdowns per day. | |
| shutDownsMaxWeek [0..1] | [Integer](#CIM17v40-Integer) | Maximum number of shutdowns per week. | |
| startUpsMaxDay [0..1] | [Integer](#CIM17v40-Integer) | Maximum number of startups per day. | |
| startUpsMaxWeek [0..1] | [Integer](#CIM17v40-Integer) | Maximum number of startups per week. | |
| virtual [0..1] | [Boolean](#CIM17v40-Boolean) | True if bid is virtual. Bid is assumed to be non-virtual if attribute is absent | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| marketType [0..1] | [MarketType](#CIM17v40-MarketType) | see [Bid](CIM17v40-Bid) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Bid](#CIM17v40-Bid) | |
| stopTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Bid](#CIM17v40-Bid) | |
| ActionRequest [1] | [ActionRequest](#CIM17v40-ActionRequest) | see [Bid](CIM17v40-Bid) | |
| EnergyMarket [1] | [EnergyMarket](#CIM17v40-EnergyMarket) | see [Bid](CIM17v40-Bid) | |
| MarketParticipant [0..1] | [MarketParticipant](#CIM17v40-MarketParticipant) | see [Bid](CIM17v40-Bid) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ResourceCapacity}
### ResourceCapacity


```mermaid
classDiagram
direction TB

class ResourceCapacity {

+ capacityType : enum:ResourceCapacityType [0..1]
+ defaultCapacity : Decimal [0..1]
+ maximumCapacity : Decimal [0..1]
+ minimumCapacity : Decimal [0..1]
+ unitSymbol : enum:UnitSymbol [0..1]
}

```

This class model the various capacities of a resource. A resource may have numbers of capacities related to operating, ancillary services, energy trade and so forth. Capacities may be defined for active power or reactive power.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| capacityType [0..1] | [ResourceCapacityType](#CIM17v40-ResourceCapacityType) | capacity typeThe types are but not limited to:Regulation UpRegulation DnSpinning ReserveNon-Spinning ReserveFOO capacityMOO capacity | |
| defaultCapacity [0..1] | [Decimal](#CIM17v40-Decimal) | default capacity | |
| maximumCapacity [0..1] | [Decimal](#CIM17v40-Decimal) | maximum capacity | |
| minimumCapacity [0..1] | [Decimal](#CIM17v40-Decimal) | minimum capacity | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | Unit selection for the capacity values. | |

{#CIM17v40-ResourceCertification}
### ResourceCertification


```mermaid
classDiagram
direction TB

class ResourceCertification {

+ certifiedDAM : enum:YesNo [0..1]
+ certifiedNonspinDAM : enum:YesNo [0..1]
+ certifiedNonspinDAMMw : Float [0..1]
+ certifiedNonspinRTM : enum:YesNo [0..1]
+ certifiedNonspinRTMMw : Float [0..1]
+ certifiedPIRP : enum:YesNo [0..1]
+ certifiedRegulation : enum:YesNo [0..1]
+ certifiedRegulationMw : Float [0..1]
+ certifiedReplaceAS : enum:YesNo [0..1]
+ certifiedRTM : enum:YesNo [0..1]
+ certifiedRUC : enum:YesNo [0..1]
+ certifiedSpin : enum:YesNo [0..1]
+ certifiedSpinMw : Float [0..1]
+ market : enum:MarketType [0..1]
+ qualificationFlag : enum:YesNo [0..1]
+ type : enum:ResourceCertificationKind [0..1]
}

class RegisteredResource {

}

ResourceCertification --> "1" RegisteredResource : RegisteredResource
```

Specifies certification for a resource to participate in a specific markets.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| certifiedDAM [0..1] | [YesNo](#CIM17v40-YesNo) | | |
| certifiedNonspinDAM [0..1] | [YesNo](#CIM17v40-YesNo) | | |
| certifiedNonspinDAMMw [0..1] | [Float](#CIM17v40-Float) | | |
| certifiedNonspinRTM [0..1] | [YesNo](#CIM17v40-YesNo) | | |
| certifiedNonspinRTMMw [0..1] | [Float](#CIM17v40-Float) | | |
| certifiedPIRP [0..1] | [YesNo](#CIM17v40-YesNo) | | |
| certifiedRegulation [0..1] | [YesNo](#CIM17v40-YesNo) | | |
| certifiedRegulationMw [0..1] | [Float](#CIM17v40-Float) | | |
| certifiedReplaceAS [0..1] | [YesNo](#CIM17v40-YesNo) | | |
| certifiedRTM [0..1] | [YesNo](#CIM17v40-YesNo) | | |
| certifiedRUC [0..1] | [YesNo](#CIM17v40-YesNo) | | |
| certifiedSpin [0..1] | [YesNo](#CIM17v40-YesNo) | | |
| certifiedSpinMw [0..1] | [Float](#CIM17v40-Float) | | |
| market [0..1] | [MarketType](#CIM17v40-MarketType) | market type | |
| qualificationFlag [0..1] | [YesNo](#CIM17v40-YesNo) | Status of the qualification ('Y' = Active, 'N' = Inactive) | |
| type [0..1] | [ResourceCertificationKind](#CIM17v40-ResourceCertificationKind) | Type of service based on ResourceAncillaryServiceType enumeration | |
| `RegisteredResource [1]` (informative) | [RegisteredResource](#CIM17v40-RegisteredResource) | RegisteredResources are qualified for resource ancillary service types (which include market product types as well as other types such as BlackStart) by the association to the class ResourceAncillaryServiceQualification. | |

{#CIM17v40-ResourceClearing}
### ResourceClearing

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ResourceClearing {

}

class MarketFactors {

}

MarketFactors <|-- ResourceClearing : inherits from
```

Model of market results, including cleaing result of resources. Associated with ResourceDispatchResults.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ResourceDeploymentStatus}
### ResourceDeploymentStatus


```mermaid
classDiagram
direction TB

class ResourceDeploymentStatus {

+ acceptComments : String [0..1]
+ acceptStatus : String [0..1]
+ resourceResponseMW : Float [0..1]
}

class InstructionClearing {

}

ResourceDeploymentStatus --> "0..1" InstructionClearing : InstructionClearing
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| acceptComments [0..1] | [String](#CIM17v40-String) | Commenst to explain why the acceptance status. For example, to explain why a request is accepted only partially, instead of fully. | |
| acceptStatus [0..1] | [String](#CIM17v40-String) | Status of the resource for this deployment. Values include (full compliance, partial compliance, opt-out, etc.) | |
| resourceResponseMW [0..1] | [Float](#CIM17v40-Float) | The MW amount the resource can contribute for this deployment. This is from the DR provider - as a response? Or actual? Does this belong in settlement? Discuss more. | |
| InstructionClearing [0..1] | [InstructionClearing](#CIM17v40-InstructionClearing) | | |

{#CIM17v40-ResourceDispatchResults}
### ResourceDispatchResults


```mermaid
classDiagram
direction TB

class ResourceDispatchResults {

+ blockedDispatch : String [0..1]
+ blockedPublishDOP : String [0..1]
+ contingencyFlag : enum:YesNo [0..1]
+ limitIndicator : String [0..1]
+ lowerLimit : Float [0..1]
+ maxRampRate : Float [0..1]
+ operatingLimitHigh : Float [0..1]
+ operatingLimitLow : Float [0..1]
+ penaltyDispatchIndicator : enum:YesNo [0..1]
+ regulatingLimitHigh : Float [0..1]
+ regulatingLimitLow : Float [0..1]
+ resourceStatus : String [0..1]
+ totalSchedule : Float [0..1]
+ updateTimeStamp : DateTime [0..1]
+ updateType : enum:MQSCHGType [0..1]
+ updateUser : String [0..1]
+ upperLimit : Float [0..1]
}

class RegisteredResource {

}

ResourceDispatchResults --> "0..1" RegisteredResource : RegisteredResource
class ResourceClearing {

}

ResourceDispatchResults --> "0..1" ResourceClearing : ResourceClearing
```

The ResourceDispatchResults class provides market results that can be provided to a SC. The specific data provided consists of several indicators such as contingency flags, blocked start up, and RMR dispatch. It also provides the projected overall and the regulating status of the resource.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| blockedDispatch [0..1] | [String](#CIM17v40-String) | Blocked Dispatch Indicator (Yes/No) | |
| blockedPublishDOP [0..1] | [String](#CIM17v40-String) | Block sending DOP to ADS (Y/N) | |
| contingencyFlag [0..1] | [YesNo](#CIM17v40-YesNo) | Contingent Operating Reserve Indicator (Yes/No). Resource participating with AS capacity in contingency dispatch. | |
| limitIndicator [0..1] | [String](#CIM17v40-String) | indicate which limit is the constraints | |
| lowerLimit [0..1] | [Float](#CIM17v40-Float) | resource energy ramping lower limit | |
| maxRampRate [0..1] | [Float](#CIM17v40-Float) | maximum ramp rate | |
| operatingLimitHigh [0..1] | [Float](#CIM17v40-Float) | The upper operating limit incorporating any derate used by the RTD for the Binding Interval. | |
| operatingLimitLow [0..1] | [Float](#CIM17v40-Float) | The lower operating limit incorporating any derate used by the RTD for the Binding Interval. | |
| penaltyDispatchIndicator [0..1] | [YesNo](#CIM17v40-YesNo) | Penalty Dispatch Indicator (Yes / No) indicating an un-economic adjustment. | |
| regulatingLimitHigh [0..1] | [Float](#CIM17v40-Float) | The upper regulating limit incorporating any derate used by the RTD for the Binding Interval. | |
| regulatingLimitLow [0..1] | [Float](#CIM17v40-Float) | The lower regulating limit incorporating any derate used by the RTD for the Binding Interval. | |
| resourceStatus [0..1] | [String](#CIM17v40-String) | Unit Commitment Status (On/Off/Starting) | |
| totalSchedule [0..1] | [Float](#CIM17v40-Float) | Resource total upward schedule. total schedule = En + all AS per resource per interval | |
| updateTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| updateType [0..1] | [MQSCHGType](#CIM17v40-MQSCHGType) | | |
| updateUser [0..1] | [String](#CIM17v40-String) | | |
| upperLimit [0..1] | [Float](#CIM17v40-Float) | resource energy ramping upper limit | |
| RegisteredResource [0..1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |
| ResourceClearing [0..1] | [ResourceClearing](#CIM17v40-ResourceClearing) | | |

{#CIM17v40-ResourceGroup}
### (informative) ResourceGroup

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ResourceGroup {

+ type : String [0..1]
+ status : Status [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ResourceGroup : inherits from
```

A logical grouping of resources that are used to model location of types of requirements for ancillary services such as spinning reserve zones, regulation zones, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| type [0..1] | [String](#CIM17v40-String) | Type of this group. | |
| status [0..1] | [Status](#CIM17v40-Status) | Status of this group. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ResourceGroupReq}
### ResourceGroupReq

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ResourceGroupReq {

}

class IdentifiedObject {

}

IdentifiedObject <|-- ResourceGroupReq : inherits from
class ResourceGroup {

}

ResourceGroupReq --> "1" ResourceGroup : ResourceGroup
```

Ancillary service requirements for a market.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ResourceGroup [1]` (informative) | [ResourceGroup](#CIM17v40-ResourceGroup) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ResourceLoadFollowingInst}
### ResourceLoadFollowingInst


```mermaid
classDiagram
direction TB

class ResourceLoadFollowingInst {

+ calcLoadFollowingMW : Float [0..1]
+ dispWindowHighLimt : Float [0..1]
+ dispWindowLowLimt : Float [0..1]
+ instructionID : String [0..1]
+ intervalStartTime : DateTime [0..1]
}

class RegisteredResource {

}

ResourceLoadFollowingInst --> "0..1" RegisteredResource : RegisteredResource
class ResourceClearing {

}

ResourceLoadFollowingInst --> "0..1" ResourceClearing : ResourceClearing
```

Model of market clearing results for resources that bid to follow load.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| calcLoadFollowingMW [0..1] | [Float](#CIM17v40-Float) | weighted average for RTPD and RTCD and same for RTID | |
| dispWindowHighLimt [0..1] | [Float](#CIM17v40-Float) | | |
| dispWindowLowLimt [0..1] | [Float](#CIM17v40-Float) | | |
| instructionID [0..1] | [String](#CIM17v40-String) | Unique instruction id per instruction, assigned by the SC and provided to ADS. ADS passes through. | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | The start of the time interval for which requirement is defined. | |
| RegisteredResource [0..1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |
| ResourceClearing [0..1] | [ResourceClearing](#CIM17v40-ResourceClearing) | | |

{#CIM17v40-ResourceOperationMaintenanceCost}
### ResourceOperationMaintenanceCost

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ResourceOperationMaintenanceCost {

+ gasPercentAboveLowSustainedLimit : PerCent [0..1]
+ oilPercentAboveLowSustainedLimit : PerCent [0..1]
+ omCostColdStartup : Float [0..1]
+ omCostHotStartup : Float [0..1]
+ omCostIntermediateStartup : Float [0..1]
+ omCostLowSustainedLimit : Float [0..1]
+ solidfuelPercentAboveLowSustainedLimit : PerCent [0..1]
}

class Curve {

}

Curve <|-- ResourceOperationMaintenanceCost : inherits from
class ResourceVerifiableCosts {

}

ResourceOperationMaintenanceCost --> "0..1" ResourceVerifiableCosts : ResourceVerifiableCosts
```

To model the Operation and Maintenance (O and M) costs of a generation resource.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| gasPercentAboveLowSustainedLimit [0..1] | [PerCent](#CIM17v40-PerCent) | Percentage of Fuel Index Price (gas) for operating above Low Sustained Limit (LSL) | |
| oilPercentAboveLowSustainedLimit [0..1] | [PerCent](#CIM17v40-PerCent) | Percentage of Fuel Oil Price (FOP) for operating above Low Sustained Limit (LSL) | |
| omCostColdStartup [0..1] | [Float](#CIM17v40-Float) | Verifiable O&amp;M Cost ($), Cold Startup | |
| omCostHotStartup [0..1] | [Float](#CIM17v40-Float) | Verifiable O&amp;M Cost ($), Hot Startup | |
| omCostIntermediateStartup [0..1] | [Float](#CIM17v40-Float) | Verifiable O&amp;M Cost ($), Intermediate Startup | |
| omCostLowSustainedLimit [0..1] | [Float](#CIM17v40-Float) | Verifiable O&amp;M Cost ($/MWh), LSL | |
| solidfuelPercentAboveLowSustainedLimit [0..1] | [PerCent](#CIM17v40-PerCent) | Percentage of Solid Fuel for operating above Low Sustained Limit (LSL) | |
| ResourceVerifiableCosts [0..1] | [ResourceVerifiableCosts](#CIM17v40-ResourceVerifiableCosts) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ResourcePerformanceEvaluation}
### ResourcePerformanceEvaluation

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ResourcePerformanceEvaluation {

+ effectiveEndTime : DateTime [0..1]
+ effectiveStartTime : DateTime [0..1]
+ evaluationDescription : String [0..1]
+ evaluationValue : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ResourcePerformanceEvaluation : inherits from
class DistributedResourceActualEvent {

}

ResourcePerformanceEvaluation --> "1" DistributedResourceActualEvent : DemandResponseActualEvent
```

Represents an the performance evaluation of a resource deployment. Every resource deployment may have many performance evaluations, using different evaluation metrics or algorithms, or produced by different evaluation authorities.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| effectiveEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| effectiveStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| evaluationDescription [0..1] | [String](#CIM17v40-String) | Description of the performance evaluation, e.g. the rating classification used (any is allowed), why the evaluation was performed, anything that describes the demand response performance evaluation. | |
| evaluationValue [0..1] | [String](#CIM17v40-String) | The value of the performance. as a String, any rating scheme is supported (e.g. "1","2","3" or "low", "medium", "high"). The rating scheme is described in the performanceValueDescription attribute. | |
| DemandResponseActualEvent [1] | [DistributedResourceActualEvent](#CIM17v40-DistributedResourceActualEvent) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ResourcePerformanceGlobalFactor}
### ResourcePerformanceGlobalFactor

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ResourcePerformanceGlobalFactor {

+ factorDescription : String [0..1]
+ factorValue : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ResourcePerformanceGlobalFactor : inherits from
```

Global factors are property/value pairs that are used to adjust resource performance values. Example include scale factors (e.g. scale a baseline up or down), adders (positive or negative), etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| factorDescription [0..1] | [String](#CIM17v40-String) | Description (name) of the property (factor). | |
| factorValue [0..1] | [String](#CIM17v40-String) | Value of the property (factor). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ResourcePerformanceRating}
### ResourcePerformanceRating

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ResourcePerformanceRating {

+ effectiveEndTime : DateTime [0..1]
+ effectiveStartTime : DateTime [0..1]
+ ratingDescription : String [0..1]
+ ratingType : String [0..1]
+ ratingValue : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ResourcePerformanceRating : inherits from
class RegisteredDistributedResource {

}

ResourcePerformanceRating --> "1" RegisteredDistributedResource : RegisteredResource
```

Rating of a resource for its demand response performance. e.g. given a set on monthly resource demand response performance evaluations, the resource may be rated with excellent, average, or poor performance for the sample set.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| effectiveEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | starting date time that the rating is valid for | |
| effectiveStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | ending date time that the rating is valid for | |
| ratingDescription [0..1] | [String](#CIM17v40-String) | the resource's demand response rating description | |
| ratingType [0..1] | [String](#CIM17v40-String) | the type of performance rating, e.g. which market or product the rating is for | |
| ratingValue [0..1] | [String](#CIM17v40-String) | the resource's demand response rating | |
| RegisteredResource [1] | [RegisteredDistributedResource](#CIM17v40-RegisteredDistributedResource) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ResourcePerformanceTimeSeriesFactor}
### ResourcePerformanceTimeSeriesFactor

Inheritance path = [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) => [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ResourcePerformanceTimeSeriesFactor {

+ timeSeriesDataType : String [0..1]
+ timeSeriesDescription : String [0..1]
+ value1Description : String [0..1]
+ value2Description : String [0..1]
}

class RegularIntervalSchedule {

}

RegularIntervalSchedule <|-- ResourcePerformanceTimeSeriesFactor : inherits from
class ResourcePerformanceEvaluation {

}

ResourcePerformanceTimeSeriesFactor --> "1" ResourcePerformanceEvaluation : ResourcePerformanceEvaluation
```

Represents the performance of a resource as time series data for a specified time period, time interval, and evaluation criteria.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| timeSeriesDataType [0..1] | [String](#CIM17v40-String) | Type of the time series data, e.g. baseline data, meter read data, computed performance data. | |
| timeSeriesDescription [0..1] | [String](#CIM17v40-String) | Optional description of the time series data, e.g. baseline data, meter read data, computed performance data. | |
| value1Description [0..1] | [String](#CIM17v40-String) | Description for the value1 contained within the TimeSeriesFactor. | |
| value2Description [0..1] | [String](#CIM17v40-String) | Description for the value2 contained within the TimeSeriesFactor. | |
| ResourcePerformanceEvaluation [1] | [ResourcePerformanceEvaluation](#CIM17v40-ResourcePerformanceEvaluation) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | see [RegularIntervalSchedule](CIM17v40-RegularIntervalSchedule) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ResourceStartupCost}
### ResourceStartupCost


```mermaid
classDiagram
direction TB

class ResourceStartupCost {

+ fuelColdStartup : Float [0..1]
+ fuelHotStartup : Float [0..1]
+ fuelIntermediateStartup : Float [0..1]
+ fuelLowSustainedLimit : Float [0..1]
+ gasPercentColdStartup : PerCent [0..1]
+ gasPercentHotStartup : PerCent [0..1]
+ gasPercentIntermediateStartup : PerCent [0..1]
+ gasPercentLowSustainedLimit : PerCent [0..1]
+ oilPercentColdStartup : PerCent [0..1]
+ oilPercentHotStartup : PerCent [0..1]
+ oilPercentIntermediateStartup : PerCent [0..1]
+ oilPercentLowSustainedLimit : PerCent [0..1]
+ solidfuelPercentColdStartup : PerCent [0..1]
+ solidfuelPercentHotStartup : PerCent [0..1]
+ solidfuelPercentIntermediateStartup : PerCent [0..1]
+ solidfuelPercentLowSustainedLimit : PerCent [0..1]
}

class ResourceVerifiableCosts {

}

ResourceStartupCost --> "1" ResourceVerifiableCosts : ResourceVerifiableCosts
```

To model the startup costs of a generation resource.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| fuelColdStartup [0..1] | [Float](#CIM17v40-Float) | Verifiable Cold Start Up Fuel (MMBtu per start) | |
| fuelHotStartup [0..1] | [Float](#CIM17v40-Float) | Verifiable Hot Start Up Fuel (MMBtu per start) | |
| fuelIntermediateStartup [0..1] | [Float](#CIM17v40-Float) | Verifiable Intermediate Start Up Fuel (MMBtu per start) | |
| fuelLowSustainedLimit [0..1] | [Float](#CIM17v40-Float) | Minimum-Energy fuel, MMBtu/MWh | |
| gasPercentColdStartup [0..1] | [PerCent](#CIM17v40-PerCent) | Percentage of Fuel Index Price (gas) for cold startup | |
| gasPercentHotStartup [0..1] | [PerCent](#CIM17v40-PerCent) | Percentage of Fuel Index Price (gas) for hot startup | |
| gasPercentIntermediateStartup [0..1] | [PerCent](#CIM17v40-PerCent) | Percentage of Fuel Index Price (gas) for intermediate startup | |
| gasPercentLowSustainedLimit [0..1] | [PerCent](#CIM17v40-PerCent) | Percentage of FIP (gas) for operating at LSL | |
| oilPercentColdStartup [0..1] | [PerCent](#CIM17v40-PerCent) | Percentage of Fuel Oil Price (FOP) for cold startup | |
| oilPercentHotStartup [0..1] | [PerCent](#CIM17v40-PerCent) | Percentage of Fuel Oil Price (FOP) for hot startup | |
| oilPercentIntermediateStartup [0..1] | [PerCent](#CIM17v40-PerCent) | Percentage of Fuel Oil Price (FOP) for intermediate startup | |
| oilPercentLowSustainedLimit [0..1] | [PerCent](#CIM17v40-PerCent) | Percentage of FOP (oil) for operating at LSL | |
| solidfuelPercentColdStartup [0..1] | [PerCent](#CIM17v40-PerCent) | Percentage of Solid Fuel for cold startup | |
| solidfuelPercentHotStartup [0..1] | [PerCent](#CIM17v40-PerCent) | Percentage of Solid Fuel for hot startup | |
| solidfuelPercentIntermediateStartup [0..1] | [PerCent](#CIM17v40-PerCent) | Percentage of Solid Fuel for intermedite startup | |
| solidfuelPercentLowSustainedLimit [0..1] | [PerCent](#CIM17v40-PerCent) | Percentage of Solid Fuel for operating at LSL | |
| `ResourceVerifiableCosts [1]` (OfAggregate) | [ResourceVerifiableCosts](#CIM17v40-ResourceVerifiableCosts) | | |

{#CIM17v40-ResourceVerifiableCosts}
### ResourceVerifiableCosts


```mermaid
classDiagram
direction TB

class ResourceVerifiableCosts {

}

class MktHeatRateCurve {

}

ResourceVerifiableCosts --> "1" MktHeatRateCurve : MktHeatRateCurve
class RegisteredResource {

}

ResourceVerifiableCosts --> "1" RegisteredResource : RegisteredResource
class ResourceOperationMaintenanceCost {

}

ResourceVerifiableCosts --> "1" ResourceOperationMaintenanceCost : ResourceOperationMaintenanceCost
```

This class is defined to describe the verifiable costs associated with a generation resource.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| MktHeatRateCurve [1] | [MktHeatRateCurve](#CIM17v40-MktHeatRateCurve) | | |
| RegisteredResource [1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |
| ResourceOperationMaintenanceCost [1] | [ResourceOperationMaintenanceCost](#CIM17v40-ResourceOperationMaintenanceCost) | | |

{#CIM17v40-ResponseMethod}
### ResponseMethod

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ResponseMethod {

+ activePower : Float [0..1]
+ activePowerUOM : String [0..1]
+ method : String [0..1]
+ siteMultiplier : Integer [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ResponseMethod : inherits from
class RegisteredDistributedResource {

}

ResponseMethod --> "1" RegisteredDistributedResource : RegisteredResource
```

Specifies a category of energy usage that the demand response applies for; e.g. energy from lighting, HVAC, other.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| activePower [0..1] | [Float](#CIM17v40-Float) | The active power value for the demand adjustment type. This supports requests to be made to a resource for some amount of active power provided by a particular response method, as specified by the method attribute (e.g. lighting, HVAC, wall mounted air conditioners, etc.). | |
| activePowerUOM [0..1] | [String](#CIM17v40-String) | The unit of measure of active power, e.g. kiloWatts (kW), megaWatts (mW), etc. | |
| method [0..1] | [String](#CIM17v40-String) | The response method (e.g. lighting, HVAC, wall mounted air conditioners, etc.). | |
| siteMultiplier [0..1] | [Integer](#CIM17v40-Integer) | This value provides for scaling of a response method's active power. For example, a response method of air conditioning could utilize a small amount of active power from each air conditioning unit (e.g. 0.1 kiloWatt), but the site multiplier could be used to produce a the total active power adjustment by multiplying the response method active power by this value (e.g. a building with 100 window air conditioning units, so 100 * 0.1 kW = 10 kW). | |
| RegisteredResource [1] | [RegisteredDistributedResource](#CIM17v40-RegisteredDistributedResource) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RevisionHistory}
### RevisionHistory


```mermaid
classDiagram
direction TB

class RevisionHistory {

+ kind : enum:RevisionKind [1]
+ revisionAuthor : String [0..1]
+ revisionDateTime : DateTime [0..1]
+ revisionReason : String [0..1]
}

class SwitchingStep {

}

RevisionHistory --> "0..1" SwitchingStep : SwitchingStep
```

History of changes made to a switching plan step after the switching plan has been approved.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [1] | [RevisionKind](#CIM17v40-RevisionKind) | Kind of change, either void or added. | |
| revisionAuthor [0..1] | [String](#CIM17v40-String) | Person who made the change | |
| revisionDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time of the change | |
| revisionReason [0..1] | [String](#CIM17v40-String) | Reason for making the change | |
| SwitchingStep [0..1] | [SwitchingStep](#CIM17v40-SwitchingStep) | | |

{#CIM17v40-RightOfWay}
### RightOfWay

Inheritance path = [Agreement](#CIM17v40-Agreement) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RightOfWay {

+ propertyData : String [0..1]
}

class Agreement {

}

Agreement <|-- RightOfWay : inherits from
```

A right-of-way (ROW) is for land where it is lawful to use for a public road, an electric power line, etc. Note that the association to Location, Asset, Organisation, etc. for the Grant is inherited from Agreement, a type of Document.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| propertyData [0..1] | [String](#CIM17v40-String) | Property related information that describes the ROW's land parcel. For example, it may be a deed book number, deed book page number, and parcel number. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| signDate [0..1] | [Date](#CIM17v40-Date) | see [Agreement](#CIM17v40-Agreement) | |
| validityInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [Agreement](CIM17v40-Agreement) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RiskScore}
### RiskScore

Inheritance path = [AggregateScore](#CIM17v40-AggregateScore) => [AnalyticScore](#CIM17v40-AnalyticScore) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RiskScore {

+ kind : enum:RiskScoreKind [0..1]
}

class AggregateScore {

}

AggregateScore <|-- RiskScore : inherits from
```

Score that is indicative of the risk associated with one or more assets.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [RiskScoreKind](#CIM17v40-RiskScoreKind) | The risk kind, such as CustomerRisk, FinancialRisk, SafetyRisk, etc. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| calculationDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [AnalyticScore](#CIM17v40-AnalyticScore) | |
| effectiveDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [AnalyticScore](#CIM17v40-AnalyticScore) | |
| value [0..1] | [Float](#CIM17v40-Float) | see [AnalyticScore](#CIM17v40-AnalyticScore) | |
| Analytic [0..1] | [Analytic](#CIM17v40-Analytic) | see [AnalyticScore](CIM17v40-AnalyticScore) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [AnalyticScore](CIM17v40-AnalyticScore) | |
| AssetAggregateScore [0..1] | [AggregateScore](#CIM17v40-AggregateScore) | see [AnalyticScore](CIM17v40-AnalyticScore) | |
| AssetGroup [0..1] | [AssetGroup](#CIM17v40-AssetGroup) | see [AnalyticScore](CIM17v40-AnalyticScore) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Role}
### Role

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Role {

+ type : String [0..1]
+ status : Status [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Role : inherits from
```

Enumeration of potential roles that might be played by one object relative to another.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| type [0..1] | [String](#CIM17v40-String) | Type of role. | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RotatingMachine}
### RotatingMachine

Inheritance path = [RegulatingCondEq](#CIM17v40-RegulatingCondEq) => [EnergyConnection](#CIM17v40-EnergyConnection) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RotatingMachine {

+ p : ActivePower [0..1]
+ q : ReactivePower [0..1]
+ ratedPowerFactor : Float [0..1]
+ ratedS : ApparentPower [0..1]
+ ratedU : Voltage [0..1]
}

class RegulatingCondEq {

}

RegulatingCondEq <|-- RotatingMachine : inherits from
class GeneratingUnit {

}

RotatingMachine --> "0..1" GeneratingUnit : GeneratingUnit
class HydroPump {

}

RotatingMachine --> "0..1" HydroPump : HydroPump
```

A rotating machine which may be used as a generator or motor.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| p [0..1] | [ActivePower](#CIM17v40-ActivePower) | Active power injection. Load sign convention is used, i.e. positive sign means flow out from a node.Starting value for a steady state solution. | |
| q [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Reactive power injection. Load sign convention is used, i.e. positive sign means flow out from a node.Starting value for a steady state solution. | |
| ratedPowerFactor [0..1] | [Float](#CIM17v40-Float) | Power factor (nameplate data). It is primarily used for short circuit data exchange according to IEC 60909. The attribute cannot be a negative value. | |
| ratedS [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | Nameplate apparent power rating for the unit.The attribute shall have a positive value. | |
| ratedU [0..1] | [Voltage](#CIM17v40-Voltage) | Rated voltage (nameplate data, Ur in IEC 60909-0). It is primarily used for short circuit data exchange according to IEC 60909.The attribute shall be a positive value. | |
| GeneratingUnit [0..1] | [GeneratingUnit](#CIM17v40-GeneratingUnit) | A synchronous machine may operate as a generator and as such becomes a member of a generating unit. | |
| HydroPump [0..1] | [HydroPump](#CIM17v40-HydroPump) | The synchronous machine drives the turbine which moves the water from a low elevation to a higher elevation. The direction of machine rotation for pumping may or may not be the same as for generating. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| controlEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [RegulatingCondEq](#CIM17v40-RegulatingCondEq) | |
| RegulatingControl [0..1] | [RegulatingControl](#CIM17v40-RegulatingControl) | see [RegulatingCondEq](CIM17v40-RegulatingCondEq) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-RotatingMachineDynamics}
### RotatingMachineDynamics

Inheritance path = [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class RotatingMachineDynamics {

+ damping : Float [0..1]
+ inertia : Seconds [0..1]
+ saturationFactor : Float [0..1]
+ saturationFactor120 : Float [0..1]
+ statorLeakageReactance : PU [0..1]
+ statorResistance : PU [0..1]
}

class DynamicsFunctionBlock {

}

DynamicsFunctionBlock <|-- RotatingMachineDynamics : inherits from
```

Abstract parent class for all synchronous and asynchronous machine standard models.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| damping [0..1] | [Float](#CIM17v40-Float) | Damping torque coefficient (<i>D</i>) (&gt;= 0). A proportionality constant that, when multiplied by the angular velocity of the rotor poles with respect to the magnetic field (frequency), results in the damping torque. This value is often zero when the sources of damping torques (generator damper windings, load damping effects, etc.) are modelled in detail. Typical value = 0. | |
| inertia [0..1] | [Seconds](#CIM17v40-Seconds) | Inertia constant of generator or motor and mechanical load (<i>H</i>) (&gt; 0). This is the specification for the stored energy in the rotating mass when operating at rated speed. For a generator, this includes the generator plus all other elements (turbine, exciter) on the same shaft and has units of MW x s. For a motor, it includes the motor plus its mechanical load. Conventional units are PU on the generator MVA base, usually expressed as MW x s / MVA or just s. This value is used in the accelerating power reference frame for operator training simulator solutions. Typical value = 3. | |
| saturationFactor [0..1] | [Float](#CIM17v40-Float) | Saturation factor at rated terminal voltage (<i>S1</i>) (&gt;= 0). Not used by simplified model. Defined by defined by <i>S</i>(<i>E1</i>) in the SynchronousMachineSaturationParameters diagram. Typical value = 0,02. | |
| saturationFactor120 [0..1] | [Float](#CIM17v40-Float) | Saturation factor at 120% of rated terminal voltage (<i>S12</i>) (&gt;= RotatingMachineDynamics.saturationFactor). Not used by the simplified model, defined by <i>S</i>(<i>E2</i>) in the SynchronousMachineSaturationParameters diagram. Typical value = 0,12. | |
| statorLeakageReactance [0..1] | [PU](#CIM17v40-PU) | Stator leakage reactance (<i>Xl</i>) (&gt;= 0). Typical value = 0,15. | |
| statorResistance [0..1] | [PU](#CIM17v40-PU) | Stator (armature) resistance (<i>Rs</i>) (&gt;= 0). Typical value = 0,005. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Route}
### (informative) Route

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Route {

+ type : String [0..1]
+ status : Status [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Route : inherits from
```

Route that is followed, for example by service crews.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| type [0..1] | [String](#CIM17v40-String) | Classification by utility's work management standards and practices. | |
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SCADAInformation}
### SCADAInformation


```mermaid
classDiagram
direction TB

class SCADAInformation {

+ timeStamp : DateTime [0..1]
}

```

Contains information about the update from SCADA.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| timeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | time of the update from SCADA | |

{#CIM17v40-SVC}
### SVC

Inheritance path = [ShuntCompensator](#CIM17v40-ShuntCompensator) => [RegulatingCondEq](#CIM17v40-RegulatingCondEq) => [EnergyConnection](#CIM17v40-EnergyConnection) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SVC {

+ capacitiveRating : Reactance [0..1]
+ inductiveRating : Reactance [0..1]
}

class ShuntCompensator {

}

ShuntCompensator <|-- SVC : inherits from
```

SVC asset allows the capacitive and inductive ratings for each phase to be specified individually if required.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| capacitiveRating [0..1] | [Reactance](#CIM17v40-Reactance) | Maximum capacitive reactive power. | |
| inductiveRating [0..1] | [Reactance](#CIM17v40-Reactance) | Maximum inductive reactive power. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aVRDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [ShuntCompensator](CIM17v40-ShuntCompensator) | |
| grounded [0..1] | [Boolean](#CIM17v40-Boolean) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| maximumSections [0..1] | [Integer](#CIM17v40-Integer) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| nomU [0..1] | [Voltage](#CIM17v40-Voltage) | see [ShuntCompensator](CIM17v40-ShuntCompensator) | |
| normalSections [0..1] | [Integer](#CIM17v40-Integer) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| phaseConnection [0..1] | [PhaseShuntConnectionKind](#CIM17v40-PhaseShuntConnectionKind) | see [ShuntCompensator](CIM17v40-ShuntCompensator) | |
| sections [0..1] | [Float](#CIM17v40-Float) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| `switchOnCount [0..1]` (deprecated) | [Integer](#CIM17v40-Integer) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| `switchOnDate [0..1]` (deprecated) | [DateTime](#CIM17v40-DateTime) | see [ShuntCompensator](#CIM17v40-ShuntCompensator) | |
| voltageSensitivity [0..1] | [VoltagePerReactivePower](#CIM17v40-VoltagePerReactivePower) | see [ShuntCompensator](CIM17v40-ShuntCompensator) | |
| ShuntCompensatorAction [0..1] | [ShuntCompensatorAction](#CIM17v40-ShuntCompensatorAction) | see [ShuntCompensator](CIM17v40-ShuntCompensator) | |
| controlEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [RegulatingCondEq](#CIM17v40-RegulatingCondEq) | |
| RegulatingControl [0..1] | [RegulatingControl](#CIM17v40-RegulatingControl) | see [RegulatingCondEq](CIM17v40-RegulatingCondEq) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SVCUserDefined}
### SVCUserDefined

Inheritance path = [StaticVarCompensatorDynamics](#CIM17v40-StaticVarCompensatorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SVCUserDefined {

+ proprietary : Boolean [0..1]
}

class StaticVarCompensatorDynamics {

}

StaticVarCompensatorDynamics <|-- SVCUserDefined : inherits from
```

Static var compensator (SVC) function block whose dynamic behaviour is described by <font color="#0f0f0f">a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| proprietary [0..1] | [Boolean](#CIM17v40-Boolean) | Behaviour is based on a proprietary model as opposed to a detailed model.true = user-defined model is proprietary with behaviour mutually understood by sending and receiving applications and parameters passed as general attributesfalse = user-defined model is explicitly defined in terms of control blocks and their input and output signals. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| StaticVarCompensator [1] | [StaticVarCompensator](#CIM17v40-StaticVarCompensator) | see [StaticVarCompensatorDynamics](CIM17v40-StaticVarCompensatorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SafetyDocument}
### SafetyDocument

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SafetyDocument {

+ issuedDateTime : DateTime [0..1]
+ releasedDateTime : DateTime [0..1]
}

class Document {

}

Document <|-- SafetyDocument : inherits from
class OperationsSafetySupervisor {

}

SafetyDocument --> "0..1" OperationsSafetySupervisor : IssuedBySupervisor
class FieldSafetySupervisor {

}

SafetyDocument --> "0..1" FieldSafetySupervisor : IssuedToSupervisor
class FieldSafetySupervisor {

}

SafetyDocument --> "0..1" FieldSafetySupervisor : ReleasedBySupervisor
class OperationsSafetySupervisor {

}

SafetyDocument --> "0..1" OperationsSafetySupervisor : ReleasedToSupervisor
class SwitchingPlan {

}

SafetyDocument --> "0..1" SwitchingPlan : SwitchingPlan
```

Document restricting or authorising works on electrical equipment (for example a permit to work, sanction for test, limitation of access, or certificate of isolation), defined based upon organisational practices.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| issuedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time this safety document has been issued. | |
| releasedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time this safety document has been released. | |
| IssuedBySupervisor [0..1] | [OperationsSafetySupervisor](#CIM17v40-OperationsSafetySupervisor) | Supervisor that issued this safety document. | |
| IssuedToSupervisor [0..1] | [FieldSafetySupervisor](#CIM17v40-FieldSafetySupervisor) | Supervisor to whom this safety document is issued. | |
| ReleasedBySupervisor [0..1] | [FieldSafetySupervisor](#CIM17v40-FieldSafetySupervisor) | Supervisor that released this safety document. | |
| ReleasedToSupervisor [0..1] | [OperationsSafetySupervisor](#CIM17v40-OperationsSafetySupervisor) | Supervisor to which this safety document is released. | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | Switching plan to which this safety document applies. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ScheduledActivePowerLimitValue}
### ScheduledActivePowerLimitValue

Inheritance path = [ScheduledLimitValue](#CIM17v40-ScheduledLimitValue) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ScheduledActivePowerLimitValue {

+ value : ActivePower [0..1]
}

class ScheduledLimitValue {

}

ScheduledLimitValue <|-- ScheduledActivePowerLimitValue : inherits from
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| value [0..1] | [ActivePower](#CIM17v40-ActivePower) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ScheduledLimitDependency [1]` (OfAggregate, informative) | [ScheduledLimitDependency](#CIM17v40-ScheduledLimitDependency) | see [ScheduledLimitValue](CIM17v40-ScheduledLimitValue) | |
| `Season [0..1]` (informative) | [Season](#CIM17v40-Season) | see [ScheduledLimitValue](CIM17v40-ScheduledLimitValue) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ScheduledApparentPowerLimitValue}
### ScheduledApparentPowerLimitValue

Inheritance path = [ScheduledLimitValue](#CIM17v40-ScheduledLimitValue) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ScheduledApparentPowerLimitValue {

+ value : ApparentPower [0..1]
}

class ScheduledLimitValue {

}

ScheduledLimitValue <|-- ScheduledApparentPowerLimitValue : inherits from
```

A time scheduled value for apparent power limit.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| value [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | The apparent power limit value for the scheduled time. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ScheduledLimitDependency [1]` (OfAggregate, informative) | [ScheduledLimitDependency](#CIM17v40-ScheduledLimitDependency) | see [ScheduledLimitValue](CIM17v40-ScheduledLimitValue) | |
| `Season [0..1]` (informative) | [Season](#CIM17v40-Season) | see [ScheduledLimitValue](CIM17v40-ScheduledLimitValue) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ScheduledCurrentLimitValue}
### ScheduledCurrentLimitValue

Inheritance path = [ScheduledLimitValue](#CIM17v40-ScheduledLimitValue) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ScheduledCurrentLimitValue {

+ value : CurrentFlow [0..1]
}

class ScheduledLimitValue {

}

ScheduledLimitValue <|-- ScheduledCurrentLimitValue : inherits from
```

A current limit that is scheduled.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| value [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | The current flow limit value applicable at the scheduled time. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ScheduledLimitDependency [1]` (OfAggregate, informative) | [ScheduledLimitDependency](#CIM17v40-ScheduledLimitDependency) | see [ScheduledLimitValue](CIM17v40-ScheduledLimitValue) | |
| `Season [0..1]` (informative) | [Season](#CIM17v40-Season) | see [ScheduledLimitValue](CIM17v40-ScheduledLimitValue) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ScheduledEvent}
### ScheduledEvent

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ScheduledEvent {

+ duration : Seconds [0..1]
+ type : String [0..1]
+ status : Status [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ScheduledEvent : inherits from
class ScheduledEventData {

}

ScheduledEvent --> "0..1" ScheduledEventData : ScheduledEventData
```

An event to trigger one or more activities, such as reading a meter, recalculating a bill, requesting work, when generating units must be scheduled for maintenance, when a transformer is scheduled to be refurbished, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| duration [0..1] | [Seconds](#CIM17v40-Seconds) | Duration of the scheduled event, for example, the time to ramp between values. | |
| type [0..1] | [String](#CIM17v40-String) | Type of scheduled event. | |
| ScheduledEventData [0..1] | [ScheduledEventData](#CIM17v40-ScheduledEventData) | Specification for this scheduled event. | |
| status [0..1] | [Status](#CIM17v40-Status) | Current status information relevant to a scheduled event | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ScheduledEventData}
### ScheduledEventData


```mermaid
classDiagram
direction TB

class ScheduledEventData {

+ estimatedWindow : DateTimeInterval [0..1]
+ requestedWindow : DateTimeInterval [0..1]
+ status : Status [0..1]
}

class InspectionDataSet {

}

ScheduledEventData --> "1" InspectionDataSet : InspectionDataSet
```

Schedule parameters for an activity that is to occur, is occurring, or has completed.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| estimatedWindow [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Estimated date and time for activity execution (with earliest possibility of activity initiation and latest possibility of activity completion). | |
| `InspectionDataSet [1]` (informative) | [InspectionDataSet](#CIM17v40-InspectionDataSet) | | |
| requestedWindow [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Requested date and time interval for activity execution. | |
| status [0..1] | [Status](#CIM17v40-Status) | Current status information relevant to the data for a scheduled event | |

{#CIM17v40-ScheduledLimitDependency}
### (informative) ScheduledLimitDependency

Inheritance path = [LimitDependency](#CIM17v40-LimitDependency) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ScheduledLimitDependency {

}

class LimitDependency {

}

LimitDependency <|-- ScheduledLimitDependency : inherits from
```


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Equipment [0..1]` (OfAggregate, informative) | [Equipment](#CIM17v40-Equipment) | see [LimitDependency](CIM17v40-LimitDependency) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ScheduledLimitValue}
### ScheduledLimitValue

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ScheduledLimitValue {

}

class IdentifiedObject {

}

IdentifiedObject <|-- ScheduledLimitValue : inherits from
class ScheduledLimitDependency {

}

ScheduledLimitValue --> "1" ScheduledLimitDependency : ScheduledLimitDependency
class Season {

}

ScheduledLimitValue --> "0..1" Season : Season
```

A limit that is applicable during a scheduled time period.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ScheduledLimitDependency [1]` (OfAggregate, informative) | [ScheduledLimitDependency](#CIM17v40-ScheduledLimitDependency) | | |
| `Season [0..1]` (informative) | [Season](#CIM17v40-Season) | The season for which the scheduled limits applies. If not specified, then applicable ot any season. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ScheduledVoltageLimitValue}
### ScheduledVoltageLimitValue

Inheritance path = [ScheduledLimitValue](#CIM17v40-ScheduledLimitValue) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ScheduledVoltageLimitValue {

+ value : Voltage [0..1]
}

class ScheduledLimitValue {

}

ScheduledLimitValue <|-- ScheduledVoltageLimitValue : inherits from
```

A voltage limit value for a scheduled time.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| value [0..1] | [Voltage](#CIM17v40-Voltage) | The voltage limit value for the scheduled time. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ScheduledLimitDependency [1]` (OfAggregate, informative) | [ScheduledLimitDependency](#CIM17v40-ScheduledLimitDependency) | see [ScheduledLimitValue](CIM17v40-ScheduledLimitValue) | |
| `Season [0..1]` (informative) | [Season](#CIM17v40-Season) | see [ScheduledLimitValue](CIM17v40-ScheduledLimitValue) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SchedulingCoordinator}
### SchedulingCoordinator

Inheritance path = [MarketParticipant](#CIM17v40-MarketParticipant) => [Organisation](#CIM17v40-Organisation) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SchedulingCoordinator {

+ creditFlag : enum:YesNo [0..1]
+ creditStartEffectiveDate : DateTime [0..1]
+ lastModified : DateTime [0..1]
+ qualificationStatus : String [0..1]
+ scid : String [0..1]
}

class MarketParticipant {

}

MarketParticipant <|-- SchedulingCoordinator : inherits from
class LoadRatio {

}

SchedulingCoordinator --> "1" LoadRatio : LoadRatio
class MarketParticipant {

}

SchedulingCoordinator --> "0..1" MarketParticipant : MarketParticipant
```

Market participants could be represented by Scheduling Coordinators (SCs) that are registered with the RTO/ISO. One participant could register multiple SCs with the RTO/ISO. Many market participants can do business with the RTO/ISO using a single SC. One SC could schedule multiple generators. A load scheduling point could be used by multiple SCs. Each SC could schedule load at multiple scheduling points. An inter-tie scheduling point can be used by multiple SCs. Each SC can schedule interchange at multiple inter-tie scheduling points.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| creditFlag [0..1] | [YesNo](#CIM17v40-YesNo) | Flag to indicate creditworthiness (Y, N) | |
| creditStartEffectiveDate [0..1] | [DateTime](#CIM17v40-DateTime) | Date that the scheduling coordinator becomes creditworthy. | |
| lastModified [0..1] | [DateTime](#CIM17v40-DateTime) | Indication of the last time this scheduling coordinator information was modified. | |
| qualificationStatus [0..1] | [String](#CIM17v40-String) | Scheduling coordinator qualification status, Qualified, Not Qualified, or Disqualified. | |
| scid [0..1] | [String](#CIM17v40-String) | This is the short name or Scheduling Coordinator ID field. | |
| LoadRatio [1] | [LoadRatio](#CIM17v40-LoadRatio) | | |
| MarketParticipant [0..1] | [MarketParticipant](#CIM17v40-MarketParticipant) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Organisation](CIM17v40-Organisation) | |
| ParentOrganisation [0..1] | [ParentOrganization](#CIM17v40-ParentOrganization) | see [Organisation](CIM17v40-Organisation) | |
| phone1 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Organisation](CIM17v40-Organisation) | |
| phone2 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Organisation](CIM17v40-Organisation) | |
| postalAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Organisation](CIM17v40-Organisation) | |
| streetAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Organisation](CIM17v40-Organisation) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SchedulingCoordinatorUser}
### SchedulingCoordinatorUser


```mermaid
classDiagram
direction TB

class SchedulingCoordinatorUser {

+ loginID : String [0..1]
+ loginRole : String [0..1]
}

```

Describing users of a Scheduling Coordinator.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| loginID [0..1] | [String](#CIM17v40-String) | Login ID | |
| loginRole [0..1] | [String](#CIM17v40-String) | Assigned roles (these are roles with either Read or Read/Write privileges on different Market Systems) | |

{#CIM17v40-SchedulingPoint}
### SchedulingPoint

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SchedulingPoint {

}

class IdentifiedObject {

}

IdentifiedObject <|-- SchedulingPoint : inherits from
class Flowgate {

}

SchedulingPoint --> "0..1" Flowgate : Flowgate
```

Connection to other organizations at the boundary of the ISO/RTO.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Flowgate [0..1] | [Flowgate](#CIM17v40-Flowgate) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Seal}
### Seal

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Seal {

+ appliedDateTime : DateTime [0..1]
+ condition : enum:SealConditionKind [0..1]
+ kind : enum:SealKind [0..1]
+ sealNumber : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Seal : inherits from
class AssetContainer {

}

Seal --> "0..1" AssetContainer : AssetContainer
```

Physically controls access to AssetContainers.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| appliedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time this seal has been applied. | |
| condition [0..1] | [SealConditionKind](#CIM17v40-SealConditionKind) | Condition of seal. | |
| kind [0..1] | [SealKind](#CIM17v40-SealKind) | Kind of seal. | |
| sealNumber [0..1] | [String](#CIM17v40-String) | (reserved word) Seal number. | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | Asset container to which this seal is applied. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Season}
### (informative) Season

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Season {

+ endDate : MonthDay [0..1]
+ startDate : MonthDay [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Season : inherits from
```

A specified time period of the year.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| endDate [0..1] | [MonthDay](#CIM17v40-MonthDay) | Date season ends. | |
| startDate [0..1] | [MonthDay](#CIM17v40-MonthDay) | Date season starts. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SeasonDayTypeSchedule}
### SeasonDayTypeSchedule

Inheritance path = [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) => [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SeasonDayTypeSchedule {

}

class RegularIntervalSchedule {

}

RegularIntervalSchedule <|-- SeasonDayTypeSchedule : inherits from
class DayType {

}

SeasonDayTypeSchedule --> "0..1" DayType : DayType
class Season {

}

SeasonDayTypeSchedule --> "0..1" Season : Season
```

A time schedule covering a 24 hour period, with curve data for a specific type of season and day.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DayType [0..1] | [DayType](#CIM17v40-DayType) | DayType for the Schedule. | |
| Season [0..1] | [Season](#CIM17v40-Season) | Season for the Schedule. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | see [RegularIntervalSchedule](CIM17v40-RegularIntervalSchedule) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Sectionaliser}
### Sectionaliser

Inheritance path = [Switch](#CIM17v40-Switch) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Sectionaliser {

}

class Switch {

}

Switch <|-- Sectionaliser : inherits from
```

Automatic switch that will lock open to isolate a faulted section. It may, or may not, have load breaking capability. Its primary purpose is to provide fault sectionalising at locations where the fault current is either too high, or too low, for proper coordination of fuses.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| locked [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| normalOpen [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| open [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [Switch](CIM17v40-Switch) | |
| retained [0..1] | [Boolean](#CIM17v40-Boolean) | see [Switch](#CIM17v40-Switch) | |
| `switchOnCount [0..1]` (deprecated) | [Integer](#CIM17v40-Integer) | see [Switch](#CIM17v40-Switch) | |
| `switchOnDate [0..1]` (deprecated) | [DateTime](#CIM17v40-DateTime) | see [Switch](#CIM17v40-Switch) | |
| `CompositeSwitch [0..1]` (OfAggregate) | [CompositeSwitch](#CIM17v40-CompositeSwitch) | see [Switch](CIM17v40-Switch) | |
| SwitchAction [0..1] | [SwitchAction](#CIM17v40-SwitchAction) | see [Switch](CIM17v40-Switch) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SecurityConstraintSum}
### SecurityConstraintSum

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SecurityConstraintSum {

}

class MarketFactors {

}

MarketFactors <|-- SecurityConstraintSum : inherits from
class BaseCaseConstraintLimit {

}

SecurityConstraintSum --> "0..1" BaseCaseConstraintLimit : BaseCaseConstraintLimit
class DefaultConstraintLimit {

}

SecurityConstraintSum --> "0..1" DefaultConstraintLimit : DefaultConstraintLimit
class RTO {

}

SecurityConstraintSum --> "0..1" RTO : RTO
```

Typically provided by RTO systems, constraints identified in both base case and critical contingency cases have to be transferred.

A constraint has N (&gt;=1) constraint terms. A term is represented by an instance of TerminalConstraintTerm.

The constraint expression is:

minValue &lt;= c1*x1 + c2*x2 + .... cn*xn + k &lt;= maxValue

where:

- cn is ConstraintTerm.factor

- xn is the flow at the terminal

Flow into the associated equipment is positive for the purpose of ConnectivityNode NodeConstraintTerm.

k is SecurityConstraintsLinear.resourceMW.

The units of k are assumed to be same as the units of the flows, xn. The constants, cn, are dimensionless.

With these conventions, cn and k are all positive for a typical constraint such as "weighted sum of generation shall be less than limit". Furthermore, cn are all 1.0 for a case such as "interface flow shall be less than limit", assuming the terminals are chosen on the importing side of the interface.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BaseCaseConstraintLimit [0..1] | [BaseCaseConstraintLimit](#CIM17v40-BaseCaseConstraintLimit) | | |
| DefaultConstraintLimit [0..1] | [DefaultConstraintLimit](#CIM17v40-DefaultConstraintLimit) | | |
| RTO [0..1] | [RTO](#CIM17v40-RTO) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SecurityConstraints}
### SecurityConstraints

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SecurityConstraints {

+ actualMW : ActivePower [0..1]
+ maxMW : ActivePower [0..1]
+ minMW : ActivePower [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- SecurityConstraints : inherits from
class Flowgate {

}

SecurityConstraints --> "0..1" Flowgate : Flowgate
class GeneratingBid {

}

SecurityConstraints --> "0..1" GeneratingBid : GeneratingBid
class RTO {

}

SecurityConstraints --> "0..1" RTO : RTO
```

Typical for regional transmission operators (RTOs), these constraints include transmission as well as generation group constraints identified in both base case and critical contingency cases.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| actualMW [0..1] | [ActivePower](#CIM17v40-ActivePower) | Actual branch or group of branches MW flow (only for transmission constraints) | |
| maxMW [0..1] | [ActivePower](#CIM17v40-ActivePower) | Maximum MW limit | |
| minMW [0..1] | [ActivePower](#CIM17v40-ActivePower) | Minimum MW limit (only for transmission constraints). | |
| Flowgate [0..1] | [Flowgate](#CIM17v40-Flowgate) | | |
| GeneratingBid [0..1] | [GeneratingBid](#CIM17v40-GeneratingBid) | | |
| RTO [0..1] | [RTO](#CIM17v40-RTO) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SecurityConstraintsClearing}
### SecurityConstraintsClearing

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SecurityConstraintsClearing {

+ mwFlow : ActivePower [0..1]
+ mwLimit : ActivePower [0..1]
+ shadowPrice : Money [0..1]
}

class MarketFactors {

}

MarketFactors <|-- SecurityConstraintsClearing : inherits from
```

Binding security constrained clearing results posted for a given settlement period.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mwFlow [0..1] | [ActivePower](#CIM17v40-ActivePower) | Optimal MW flow | |
| mwLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | Binding MW limit. | |
| shadowPrice [0..1] | [Money](#CIM17v40-Money) | Security constraint shadow price. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SelfScheduleBreakdown}
### SelfScheduleBreakdown


```mermaid
classDiagram
direction TB

class SelfScheduleBreakdown {

+ selfSchedMW : Float [0..1]
+ selfSchedType : enum:SelfScheduleBreakdownType [0..1]
}

class ResourceAwardInstruction {

}

SelfScheduleBreakdown --> "1" ResourceAwardInstruction : ResourceAwardInstruction
```

Model of Self Schedules Results. Includes self schedule MW,and type of self schedule for each self schedule type included in total self schedule MW value found in ResourceAwardInstruction.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| selfSchedMW [0..1] | [Float](#CIM17v40-Float) | Cleared value for the specific self schedule type listed. | |
| selfSchedType [0..1] | [SelfScheduleBreakdownType](#CIM17v40-SelfScheduleBreakdownType) | Self schedule breakdown type. | |
| ResourceAwardInstruction [1] | [ResourceAwardInstruction](#CIM17v40-ResourceAwardInstruction) | | |

{#CIM17v40-SensitivityPriceCurve}
### (informative) SensitivityPriceCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SensitivityPriceCurve {

}

class Curve {

}

Curve <|-- SensitivityPriceCurve : inherits from
class ReserveReq {

}

SensitivityPriceCurve --> "0..1" ReserveReq : ReserveReq
```

Optionally, this curve expresses elasticity of the associated requirement. For example, used to reduce requirements when clearing price exceeds reasonable values when the supply quantity becomes scarce. For example, a single point value of $1000/MW for a spinning reserve will cause a reduction in the required spinning reserve.

X axis is constrained quantity (e.g., MW)

Y1 axis is money per constrained quantity


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `ReserveReq [0..1]` (informative) | [ReserveReq](#CIM17v40-ReserveReq) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Sensor}
### Sensor

Inheritance path = [AuxiliaryEquipment](#CIM17v40-AuxiliaryEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Sensor {

}

class AuxiliaryEquipment {

}

AuxiliaryEquipment <|-- Sensor : inherits from
```

This class describe devices that transform a measured quantity into signals that can be presented at displays, used in control or be recorded.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Terminal [1] | [Terminal](#CIM17v40-Terminal) | see [AuxiliaryEquipment](CIM17v40-AuxiliaryEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Series}
### Series

Inheritance path = [TimeSeries](#CIM17v40-TimeSeries) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Series {

+ lastUpdateDate : Date [0..1]
+ methodType : String [0..1]
+ registrationDate : Date [0..1]
}

class TimeSeries {

}

TimeSeries <|-- Series : inherits from
```

A set of similar physical or conceptual objects defined for the same period or point of time.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| lastUpdateDate [0..1] | [Date](#CIM17v40-Date) | The date of the last update related to this market object. | |
| methodType [0..1] | [String](#CIM17v40-String) | Type of method used in the business process related to this Series, e.g. metering method. | |
| registrationDate [0..1] | [Date](#CIM17v40-Date) | For a market object, the date of registration of a contract, e.g. the date of change of supplier for a customer. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| businessType [0..1] | [String](#CIM17v40-String) | see [TimeSeries](#CIM17v40-TimeSeries) | |
| cancelledTS [0..1] | [String](#CIM17v40-String) | see [TimeSeries](#CIM17v40-TimeSeries) | |
| curveType [0..1] | [String](#CIM17v40-String) | see [TimeSeries](#CIM17v40-TimeSeries) | |
| objectAggregation [0..1] | [String](#CIM17v40-String) | see [TimeSeries](#CIM17v40-TimeSeries) | |
| product [0..1] | [String](#CIM17v40-String) | see [TimeSeries](#CIM17v40-TimeSeries) | |
| version [0..1] | [String](#CIM17v40-String) | see [TimeSeries](#CIM17v40-TimeSeries) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SeriesCompensator}
### SeriesCompensator

Inheritance path = [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SeriesCompensator {

+ r : Resistance [0..1]
+ r0 : Resistance [0..1]
+ varistorPresent : Boolean [0..1]
+ varistorRatedCurrent : CurrentFlow [0..1]
+ varistorVoltageThreshold : Voltage [0..1]
+ x : Reactance [0..1]
+ x0 : Reactance [0..1]
}

class ConductingEquipment {

}

ConductingEquipment <|-- SeriesCompensator : inherits from
```

A Series Compensator is a series capacitor or reactor or an AC transmission line without charging susceptance. It is a two terminal device.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| r [0..1] | [Resistance](#CIM17v40-Resistance) | Positive sequence resistance. | |
| r0 [0..1] | [Resistance](#CIM17v40-Resistance) | Zero sequence resistance. | |
| varistorPresent [0..1] | [Boolean](#CIM17v40-Boolean) | Describe if a metal oxide varistor (mov) for over voltage protection is configured in parallel with the series compensator. It is used for short circuit calculations. | |
| varistorRatedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | The maximum current the varistor is designed to handle at specified duration. It is used for short circuit calculations and exchanged only if SeriesCompensator.varistorPresent is true.The attribute shall be a positive value. | |
| varistorVoltageThreshold [0..1] | [Voltage](#CIM17v40-Voltage) | The dc voltage at which the varistor starts conducting. It is used for short circuit calculations and exchanged only if SeriesCompensator.varistorPresent is true. | |
| x [0..1] | [Reactance](#CIM17v40-Reactance) | Positive sequence reactance. | |
| x0 [0..1] | [Reactance](#CIM17v40-Reactance) | Zero sequence reactance. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SeriesEquipmentDependentLimit}
### (informative) SeriesEquipmentDependentLimit

Inheritance path = [LimitDependency](#CIM17v40-LimitDependency) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SeriesEquipmentDependentLimit {

}

class LimitDependency {

}

LimitDependency <|-- SeriesEquipmentDependentLimit : inherits from
```

Limit based on most restrictive series equipment limit.

A specification of of equipment that determines the calculated operational limit values based upon other equipment and their ratings. The most restrictive limit connected in series within the group is used. The physical connection based on switch status for example may also impact which elements in the group are considered. Any equipment in the group that are presently connected in series with the equipment of the directly associated operational limit are used. This provides a means to indicate which potentially series equipment limits are considered for a computed operational limit. The operational limit of the same operational limit type is assumed to be used from the grouped equipment. It is also possible to make assumptions or calculations regarding how flow might split if the equipment is not simply in series.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Equipment [0..1]` (OfAggregate, informative) | [Equipment](#CIM17v40-Equipment) | see [LimitDependency](CIM17v40-LimitDependency) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ServiceCategory}
### ServiceCategory

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ServiceCategory {

+ kind : enum:ServiceKind [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ServiceCategory : inherits from
```

Category of service provided to the customer.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [ServiceKind](#CIM17v40-ServiceKind) | Kind of service. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ServiceGuarantee}
### ServiceGuarantee

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ServiceGuarantee {

+ automaticPay : Boolean [0..1]
+ payAmount : Money [0..1]
+ serviceRequirement : String [0..1]
+ applicationPeriod : DateTimeInterval [0..1]
}

class Document {

}

Document <|-- ServiceGuarantee : inherits from
```

A service guarantee, often imposed by a regulator, defines conditions that, if not satisfied, will result in the utility making a monetary payment to the customer. Note that guarantee's identifier is in the 'name' attribute and the status of the guarantee is in the 'Status.status' attribute.

Example service requirements include:

1) If power is not restored within 24 hours, customers can claim $50 for residential customers or $100 for commercial and industrial customers. In addition for each extra period of 12 hours the customer's supply has not been activated, the customer can claim $25.

2) If a customer has a question about their electricity bill, the utility will investigate and respond to the inquiry within 15 working days. If utility fails to meet its guarantee, utility will automatically pay the customer $50.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| automaticPay [0..1] | [Boolean](#CIM17v40-Boolean) | True if utility must autmatically pay the specified amount whenever the condition is not satisified, otherwise customer must make a claim to receive payment. | |
| payAmount [0..1] | [Money](#CIM17v40-Money) | Amount to be paid by the service provider to the customer for each violation of the 'serviceRequirement'. | |
| serviceRequirement [0..1] | [String](#CIM17v40-String) | Explanation of the requirement and conditions for satisfying it. | |
| applicationPeriod [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Period in which this service guantee applies. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ServiceLocation}
### ServiceLocation

Inheritance path = [WorkLocation](#CIM17v40-WorkLocation) => [Location](#CIM17v40-Location) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ServiceLocation {

+ accessMethod : String [0..1]
+ needsInspection : Boolean [0..1]
+ siteAccessProblem : String [0..1]
}

class WorkLocation {

}

WorkLocation <|-- ServiceLocation : inherits from
```

A real estate location, commonly referred to as premises.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| accessMethod [0..1] | [String](#CIM17v40-String) | Method for the service person to access this service location. For example, a description of where to obtain a key if the facility is unmanned and secured. | |
| needsInspection [0..1] | [Boolean](#CIM17v40-Boolean) | True if inspection is needed of facilities at this service location. This could be requested by a customer, due to suspected tampering, environmental concerns (e.g., a fire in the vicinity), or to correct incompatible data. | |
| siteAccessProblem [0..1] | [String](#CIM17v40-String) | Problems previously encountered when visiting or performing work on this location. Examples include: bad dog, violent customer, verbally abusive occupant, obstructions, safety hazards, etc. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `OneCallRequest [0..1]` (informative) | [OneCallRequest](#CIM17v40-OneCallRequest) | see [WorkLocation](CIM17v40-WorkLocation) | |
| direction [0..1] | [String](#CIM17v40-String) | see [Location](#CIM17v40-Location) | |
| geoInfoReference [0..1] | [String](#CIM17v40-String) | see [Location](#CIM17v40-Location) | |
| type [0..1] | [String](#CIM17v40-String) | see [Location](#CIM17v40-Location) | |
| CoordinateSystem [0..1] | [CoordinateSystem](#CIM17v40-CoordinateSystem) | see [Location](CIM17v40-Location) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Location](CIM17v40-Location) | |
| Incident [0..1] | [Incident](#CIM17v40-Incident) | see [Location](CIM17v40-Location) | |
| mainAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Location](CIM17v40-Location) | |
| OutageOrder [0..1] | [OutageOrder](#CIM17v40-OutageOrder) | see [Location](CIM17v40-Location) | |
| phone1 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Location](CIM17v40-Location) | |
| phone2 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Location](CIM17v40-Location) | |
| secondaryAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Location](CIM17v40-Location) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Location](CIM17v40-Location) | |
| SwitchingOrder [0..1] | [SwitchingOrder](#CIM17v40-SwitchingOrder) | see [Location](CIM17v40-Location) | |
| TroubleOrder [0..1] | [TroubleOrder](#CIM17v40-TroubleOrder) | see [Location](CIM17v40-Location) | |
| TroubleTicket [0..1] | [TroubleTicket](#CIM17v40-TroubleTicket) | see [Location](CIM17v40-Location) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ServiceMultiplier}
### ServiceMultiplier

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ServiceMultiplier {

+ kind : enum:ServiceMultiplierKind [0..1]
+ value : Float [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ServiceMultiplier : inherits from
class UsagePoint {

}

ServiceMultiplier --> "0..1" UsagePoint : UsagePoint
```

Multiplier applied at the usage point.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [ServiceMultiplierKind](#CIM17v40-ServiceMultiplierKind) | Kind of multiplier. | |
| value [0..1] | [Float](#CIM17v40-Float) | Multiplier value. | |
| UsagePoint [0..1] | [UsagePoint](#CIM17v40-UsagePoint) | Usage point applying this multiplier. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ServiceOrder}
### ServiceOrder

Inheritance path = [WorkOrder](#CIM17v40-WorkOrder) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ServiceOrder {

}

class WorkOrder {

}

WorkOrder <|-- ServiceOrder : inherits from
```


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ServicePoint}
### ServicePoint

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ServicePoint {

}

class IdentifiedObject {

}

IdentifiedObject <|-- ServicePoint : inherits from
```

The defined termination points of a transmission path. Service points are defined from the viewpoint of the transmission service. Each service point is contained within (or on the boundary of) an interchange area. A service point is source or destination of a transaction.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ServiceRequest}
### ServiceRequest

Inheritance path = [WorkRequest](#CIM17v40-WorkRequest) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ServiceRequest {

+ appointmentRequested : Boolean [0..1]
+ kind : enum:ServiceRequestKind [1]
+ serviceKind : enum:ServiceKind [1]
+ serviceSize : String [0..1]
}

class WorkRequest {

}

WorkRequest <|-- ServiceRequest : inherits from
class Customer {

}

ServiceRequest --> "0..1" Customer : Customer
class ServiceLocation {

}

ServiceRequest --> "0..1" ServiceLocation : ServiceLocation
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| appointmentRequested [0..1] | [Boolean](#CIM17v40-Boolean) | | |
| kind [1] | [ServiceRequestKind](#CIM17v40-ServiceRequestKind) | | |
| serviceKind [1] | [ServiceKind](#CIM17v40-ServiceKind) | | |
| serviceSize [0..1] | [String](#CIM17v40-String) | The size or quantity requested by the customer; for example, 200 AMPS for electrical service, 50 MBits per second for internet service, etc. | |
| Customer [0..1] | [Customer](#CIM17v40-Customer) | The customer making the service request | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | The service location for the serivce request | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ServiceSupplier}
### (informative) ServiceSupplier

Inheritance path = [OrganisationRole](#CIM17v40-OrganisationRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ServiceSupplier {

+ issuerIdentificationNumber : String [0..1]
+ kind : enum:SupplierKind [0..1]
}

class OrganisationRole {

}

OrganisationRole <|-- ServiceSupplier : inherits from
```

Organisation that provides services to customers.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| issuerIdentificationNumber [0..1] | [String](#CIM17v40-String) | Unique transaction reference prefix number issued to an entity by the International Organization for Standardization for the purpose of tagging onto electronic financial transactions, as defined in ISO/IEC 7812-1 and ISO/IEC 7812-2. | |
| kind [0..1] | [SupplierKind](#CIM17v40-SupplierKind) | Kind of supplier. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Organisation [0..1] | [Organisation](#CIM17v40-Organisation) | see [OrganisationRole](CIM17v40-OrganisationRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SetPoint}
### SetPoint

Inheritance path = [AnalogControl](#CIM17v40-AnalogControl) => [Control](#CIM17v40-Control) => [IOPoint](#CIM17v40-IOPoint) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SetPoint {

+ normalValue : Float [0..1]
+ value : Float [0..1]
}

class AnalogControl {

}

AnalogControl <|-- SetPoint : inherits from
```

An analog control that issues a set point value.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| normalValue [0..1] | [Float](#CIM17v40-Float) | Normal value for Control.value e.g. used for percentage scaling. | |
| value [0..1] | [Float](#CIM17v40-Float) | The value representing the actuator output. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maxValue [0..1] | [Float](#CIM17v40-Float) | see [AnalogControl](#CIM17v40-AnalogControl) | |
| minValue [0..1] | [Float](#CIM17v40-Float) | see [AnalogControl](#CIM17v40-AnalogControl) | |
| AnalogValue [1] | [AnalogValue](#CIM17v40-AnalogValue) | see [AnalogControl](CIM17v40-AnalogControl) | |
| controlType [0..1] | [String](#CIM17v40-String) | see [Control](#CIM17v40-Control) | |
| operationInProgress [0..1] | [Boolean](#CIM17v40-Boolean) | see [Control](#CIM17v40-Control) | |
| timeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | see [Control](#CIM17v40-Control) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Control](CIM17v40-Control) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Control](CIM17v40-Control) | |
| ControlAction [0..1] | [ControlAction](#CIM17v40-ControlAction) | see [Control](CIM17v40-Control) | |
| PowerSystemResource [0..1] | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Control](CIM17v40-Control) | |
| RemoteControl [0..1] | [RemoteControl](#CIM17v40-RemoteControl) | see [Control](CIM17v40-Control) | |
| IOPointSource [0..1] | [IOPointSource](#CIM17v40-IOPointSource) | see [IOPoint](CIM17v40-IOPoint) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Settlement}
### Settlement

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Settlement {

+ tradeDate : DateTime [0..1]
}

class Document {

}

Document <|-- Settlement : inherits from
class EnergyMarket {

}

Settlement --> "0..1" EnergyMarket : EnergyMarket
```

Specifies a settlement run.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| tradeDate [0..1] | [DateTime](#CIM17v40-DateTime) | The trade date on which the settlement is run. | |
| EnergyMarket [0..1] | [EnergyMarket](#CIM17v40-EnergyMarket) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Shift}
### Shift

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Shift {

+ receiptsGrandTotalBankable : Money [0..1]
+ receiptsGrandTotalNonBankable : Money [0..1]
+ receiptsGrandTotalRounding : Money [0..1]
+ transactionsGrandTotal : Money [0..1]
+ transactionsGrandTotalRounding : Money [0..1]
+ activityInterval : DateTimeInterval [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Shift : inherits from
```

Generally referring to a period of operation or work performed. Whether the shift is open/closed can be derived from attributes 'activityInterval.start' and 'activityInterval.end'.

The grand total for receipts (i.e., cumulative total of all actual receipted amounts during this shift; bankable + non-bankable; excludes rounding error totals) can be derived from receipt:

=sum('Receipt.receiptAmount'); includes bankable and non-bankable receipts.

It also has to be reconciled against:

=sum('receiptsGrandTotalBankable' + 'receiptsGrandTotalNonBankable')

and against receipt summary:

=sum('ReceiptSummary.receiptsTotal').

The attributes with "GrandTotal" defined in this class may need to be used when the source data is periodically flushed from the system and then these cannot be derived.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| receiptsGrandTotalBankable [0..1] | [Money](#CIM17v40-Money) | Total of amounts receipted during this shift that can be manually banked (cash and cheques for example). Values are obtained from Receipt attributes:=sum(Receipt.receiptAmount) for all Receipt.bankable = true. | |
| receiptsGrandTotalNonBankable [0..1] | [Money](#CIM17v40-Money) | Total of amounts receipted during this shift that cannot be manually banked (card payments for example). Values are obtained from Receipt attributes:=sum(Receipt.receiptAmount) for all Receipt.bankable = false. | |
| receiptsGrandTotalRounding [0..1] | [Money](#CIM17v40-Money) | Cumulative amount in error due to process rounding not reflected in receiptsGrandTotal. Values are obtained from Receipt attributes:=sum(Receipt.receiptRounding). | |
| transactionsGrandTotal [0..1] | [Money](#CIM17v40-Money) | Cumulative total of transacted amounts during this shift. Values are obtained from transaction:=sum('Transaction.transactionAmount'). It also has to be reconciled against transaction summary:=sum('TransactionSummary.transactionsTotal'). | |
| transactionsGrandTotalRounding [0..1] | [Money](#CIM17v40-Money) | Cumulative amount in error due to process rounding not reflected in transactionsGandTotal. Values are obtained from Transaction attributes:=sum(Transaction.transactionRounding). | |
| activityInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Interval for activity of this shift. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ShiftPattern}
### ShiftPattern

Inheritance path = [WorkIdentifiedObject](#CIM17v40-WorkIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ShiftPattern {

+ assignmentType : String [0..1]
+ cycleCount : Integer [0..1]
+ status : Status [0..1]
+ validityInterval : DateTimeInterval [0..1]
}

class WorkIdentifiedObject {

}

WorkIdentifiedObject <|-- ShiftPattern : inherits from
```

The patterns of shifts worked by people or crews.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| assignmentType [0..1] | [String](#CIM17v40-String) | Type of assignement intended to be worked on this shift, for example, temporary, standard, etc. | |
| cycleCount [0..1] | [Integer](#CIM17v40-Integer) | Number of cycles for a temporary shift. | |
| status [0..1] | [Status](#CIM17v40-Status) | | |
| validityInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Date and time interval for which this shift pattern is valid (when it became effective and when it expires). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ShortCircuitTest}
### ShortCircuitTest

Inheritance path = [TransformerTest](#CIM17v40-TransformerTest) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ShortCircuitTest {

+ current : CurrentFlow [0..1]
+ energisedEndStep : Integer [0..1]
+ groundedEndStep : Integer [0..1]
+ leakageImpedance : Impedance [0..1]
+ leakageImpedanceZero : Impedance [0..1]
+ loss : KiloActivePower [0..1]
+ lossZero : KiloActivePower [0..1]
+ power : ApparentPower [0..1]
+ voltage : PerCent [0..1]
}

class TransformerTest {

}

TransformerTest <|-- ShortCircuitTest : inherits from
class TransformerEndInfo {

}

ShortCircuitTest --> "1" TransformerEndInfo : EnergisedEnd
class TransformerEndInfo {

}

ShortCircuitTest --> "0..*" TransformerEndInfo : GroundedEnds
```

Short-circuit test results determine mesh impedance parameters. They include load losses and leakage impedances. For three-phase windings, the excitation can be a positive sequence (the default) or a zero sequence. There shall be at least one grounded winding.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| current [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Short circuit current.. | |
| energisedEndStep [0..1] | [Integer](#CIM17v40-Integer) | Tap step number for the energised end of the test pair. | |
| groundedEndStep [0..1] | [Integer](#CIM17v40-Integer) | Tap step number for the grounded end of the test pair. | |
| leakageImpedance [0..1] | [Impedance](#CIM17v40-Impedance) | Leakage impedance measured from a positive-sequence or single-phase short-circuit test. | |
| leakageImpedanceZero [0..1] | [Impedance](#CIM17v40-Impedance) | Leakage impedance measured from a zero-sequence short-circuit test. | |
| loss [0..1] | [KiloActivePower](#CIM17v40-KiloActivePower) | Load losses from a positive-sequence or single-phase short-circuit test. | |
| lossZero [0..1] | [KiloActivePower](#CIM17v40-KiloActivePower) | Load losses from a zero-sequence short-circuit test. | |
| power [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | Short circuit apparent power. | |
| voltage [0..1] | [PerCent](#CIM17v40-PerCent) | Short circuit voltage.. | |
| EnergisedEnd [1] | [TransformerEndInfo](#CIM17v40-TransformerEndInfo) | Transformer end that voltage is applied to in this short-circuit test. The test voltage is chosen to induce rated current in the energised end. | |
| GroundedEnds [0..*] | [TransformerEndInfo](#CIM17v40-TransformerEndInfo) | All ends short-circuited in this short-circuit test. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| basePower [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | see [TransformerTest](CIM17v40-TransformerTest) | |
| temperature [0..1] | [Temperature](#CIM17v40-Temperature) | see [TransformerTest](CIM17v40-TransformerTest) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ShuntCompensator}
### ShuntCompensator

Inheritance path = [RegulatingCondEq](#CIM17v40-RegulatingCondEq) => [EnergyConnection](#CIM17v40-EnergyConnection) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ShuntCompensator {

+ aVRDelay : Seconds [0..1]
+ grounded : Boolean [0..1]
+ maximumSections : Integer [0..1]
+ nomU : Voltage [0..1]
+ normalSections : Integer [0..1]
+ phaseConnection : enum:PhaseShuntConnectionKind [0..1]
+ sections : Float [0..1]
+ switchOnCount : Integer [0..1]
+ switchOnDate : DateTime [0..1]
+ voltageSensitivity : VoltagePerReactivePower [0..1]
}

class RegulatingCondEq {

}

RegulatingCondEq <|-- ShuntCompensator : inherits from
class ShuntCompensatorAction {

}

ShuntCompensator --> "0..1" ShuntCompensatorAction : ShuntCompensatorAction
```

A shunt capacitor or reactor or switchable bank of shunt capacitors or reactors. A section of a shunt compensator is an individual capacitor or reactor. A negative value for bPerSection indicates that the compensator is a reactor. ShuntCompensator is a single terminal device. Ground is implied.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aVRDelay [0..1] | [Seconds](#CIM17v40-Seconds) | An automatic voltage regulation delay (AVRDelay) which is the time delay from a change in voltage to when the capacitor is allowed to change state. This filters out temporary changes in voltage. | |
| grounded [0..1] | [Boolean](#CIM17v40-Boolean) | Used for Yn and Zn connections. True if the neutral is solidly grounded. | |
| maximumSections [0..1] | [Integer](#CIM17v40-Integer) | The maximum number of sections that may be switched in. | |
| nomU [0..1] | [Voltage](#CIM17v40-Voltage) | The voltage at which the nominal reactive power may be calculated. This should normally be within 10% of the voltage at which the capacitor is connected to the network. | |
| normalSections [0..1] | [Integer](#CIM17v40-Integer) | The normal number of sections switched in. The value shall be between zero and ShuntCompensator.maximumSections. | |
| phaseConnection [0..1] | [PhaseShuntConnectionKind](#CIM17v40-PhaseShuntConnectionKind) | The type of phase connection, such as wye or delta. | |
| sections [0..1] | [Float](#CIM17v40-Float) | Shunt compensator sections in use. Starting value for steady state solution. The attribute shall be a positive value or zero. Non integer values are allowed to support continuous variables. The reasons for continuous value are to support study cases where no discrete shunt compensators has yet been designed, a solutions where a narrow voltage band force the sections to oscillate or accommodate for a continuous solution as input.For LinearShuntConpensator the value shall be between zero and ShuntCompensator.maximumSections. At value zero the shunt compensator conductance and admittance is zero. Linear interpolation of conductance and admittance between the previous and next integer section is applied in case of non-integer values.For NonlinearShuntCompensator-s shall only be set to one of the NonlinearShuntCompenstorPoint.sectionNumber. There is no interpolation between NonlinearShuntCompenstorPoint-s. | |
| `switchOnCount [0..1]` (deprecated) | [Integer](#CIM17v40-Integer) | The switch on count since the capacitor count was last reset or initialized. | |
| `switchOnDate [0..1]` (deprecated) | [DateTime](#CIM17v40-DateTime) | The date and time when the capacitor bank was last switched on. | |
| voltageSensitivity [0..1] | [VoltagePerReactivePower](#CIM17v40-VoltagePerReactivePower) | Voltage sensitivity required for the device to regulate the bus voltage, in voltage/reactive power. | |
| ShuntCompensatorAction [0..1] | [ShuntCompensatorAction](#CIM17v40-ShuntCompensatorAction) | The shunt compensator action that is performed on the shunt compensator | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| controlEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [RegulatingCondEq](#CIM17v40-RegulatingCondEq) | |
| RegulatingControl [0..1] | [RegulatingControl](#CIM17v40-RegulatingControl) | see [RegulatingCondEq](CIM17v40-RegulatingCondEq) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ShuntCompensatorAction}
### ShuntCompensatorAction

Inheritance path = [SwitchingAction](#CIM17v40-SwitchingAction) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ShuntCompensatorAction {

+ kind : enum:TempEquipActionKind [0..1]
}

class SwitchingAction {

}

SwitchingAction <|-- ShuntCompensatorAction : inherits from
class ShuntCompensator {

}

ShuntCompensatorAction --> "0..1" ShuntCompensator : ShuntCompensator
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [TempEquipActionKind](#CIM17v40-TempEquipActionKind) | Switching action to perform | |
| ShuntCompensator [0..1] | [ShuntCompensator](#CIM17v40-ShuntCompensator) | The shunt compensator that the shunt compensator action is performed on | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| executedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| issuedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| plannedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| Operator [0..1] | [Operator](#CIM17v40-Operator) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingEvent [0..1] | [SwitchingEvent](#CIM17v40-SwitchingEvent) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingStep [0..1] | [SwitchingStep](#CIM17v40-SwitchingStep) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ShuntCompensatorControl}
### (informative) ShuntCompensatorControl

Inheritance path = [RegulatingControl](#CIM17v40-RegulatingControl) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ShuntCompensatorControl {

+ branchDirect : Integer [0..1]
+ cellSize : ReactivePower [0..1]
+ controlKind : enum:ShuntImpedanceControlKind [0..1]
+ highVoltageOverride : PU [0..1]
+ localControlKind : enum:ShuntImpedanceLocalControlKind [0..1]
+ localOffLevel : String [0..1]
+ localOnLevel : String [0..1]
+ localOverride : Boolean [0..1]
+ lowVoltageOverride : PU [0..1]
+ maxSwitchOperationCount : Integer [0..1]
+ normalOpen : Boolean [0..1]
+ regBranch : String [0..1]
+ regBranchEnd : Integer [0..1]
+ regBranchKind : enum:RegulationBranchKind [0..1]
+ sensingPhaseCode : enum:PhaseCode [0..1]
+ switchOperationCycle : Hours [0..1]
+ vRegLineLine : Boolean [0..1]
}

class RegulatingControl {

}

RegulatingControl <|-- ShuntCompensatorControl : inherits from
class ShuntCompensatorInfo {

}

ShuntCompensatorControl --> "0..1" ShuntCompensatorInfo : ShuntCompensatorInfo
```

Distribution capacitor bank control settings.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| branchDirect [0..1] | [Integer](#CIM17v40-Integer) | For VAR, amp, or power factor locally controlled shunt impedances, the flow direction: in, out. | |
| cellSize [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | The size of the individual units that make up the bank. | |
| controlKind [0..1] | [ShuntImpedanceControlKind](#CIM17v40-ShuntImpedanceControlKind) | Kind of control (if any). | |
| highVoltageOverride [0..1] | [PU](#CIM17v40-PU) | For locally controlled shunt impedances which have a voltage override feature, the high voltage override value. If the voltage is above this value, the shunt impedance will be turned off regardless of the other local controller settings. | |
| localControlKind [0..1] | [ShuntImpedanceLocalControlKind](#CIM17v40-ShuntImpedanceLocalControlKind) | Kind of local controller. | |
| localOffLevel [0..1] | [String](#CIM17v40-String) | Upper control setting. | |
| localOnLevel [0..1] | [String](#CIM17v40-String) | Lower control setting. | |
| localOverride [0..1] | [Boolean](#CIM17v40-Boolean) | True if the locally controlled capacitor has voltage override capability. | |
| lowVoltageOverride [0..1] | [PU](#CIM17v40-PU) | For locally controlled shunt impedances which have a voltage override feature, the low voltage override value. If the voltage is below this value, the shunt impedance will be turned on regardless of the other local controller settings. | |
| maxSwitchOperationCount [0..1] | [Integer](#CIM17v40-Integer) | IdmsShuntImpedanceData.maxNumSwitchOps. | |
| normalOpen [0..1] | [Boolean](#CIM17v40-Boolean) | True if open is normal status for a fixed capacitor bank, otherwise normal status is closed. | |
| regBranch [0..1] | [String](#CIM17v40-String) | For VAR, amp, or power factor locally controlled shunt impedances, the index of the regulation branch. | |
| regBranchEnd [0..1] | [Integer](#CIM17v40-Integer) | For VAR, amp, or power factor locally controlled shunt impedances, the end of the branch that is regulated. The field has the following values: from side, to side, and tertiary (only if the branch is a transformer). | |
| regBranchKind [0..1] | [RegulationBranchKind](#CIM17v40-RegulationBranchKind) | (For VAR, amp, or power factor locally controlled shunt impedances) Kind of regulation branch. | |
| sensingPhaseCode [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | Phases that are measured for controlling the device. | |
| switchOperationCycle [0..1] | [Hours](#CIM17v40-Hours) | Time interval between consecutive switching operations. | |
| vRegLineLine [0..1] | [Boolean](#CIM17v40-Boolean) | True if regulated voltages are measured line to line, otherwise they are measured line to ground. | |
| `ShuntCompensatorInfo [0..1]` (informative) | [ShuntCompensatorInfo](#CIM17v40-ShuntCompensatorInfo) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [RegulatingControl](#CIM17v40-RegulatingControl) | |
| maxAllowedTargetValue [0..1] | [Float](#CIM17v40-Float) | see [RegulatingControl](#CIM17v40-RegulatingControl) | |
| minAllowedTargetValue [0..1] | [Float](#CIM17v40-Float) | see [RegulatingControl](#CIM17v40-RegulatingControl) | |
| mode [0..1] | [RegulatingControlModeKind](#CIM17v40-RegulatingControlModeKind) | see [RegulatingControl](CIM17v40-RegulatingControl) | |
| monitoredPhase [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [RegulatingControl](CIM17v40-RegulatingControl) | |
| targetDeadband [0..1] | [Float](#CIM17v40-Float) | see [RegulatingControl](#CIM17v40-RegulatingControl) | |
| targetValue [0..1] | [Float](#CIM17v40-Float) | see [RegulatingControl](#CIM17v40-RegulatingControl) | |
| targetValueUnitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [RegulatingControl](CIM17v40-RegulatingControl) | |
| Terminal [0..1] | [Terminal](#CIM17v40-Terminal) | see [RegulatingControl](CIM17v40-RegulatingControl) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ShuntCompensatorDynamicData}
### ShuntCompensatorDynamicData


```mermaid
classDiagram
direction TB

class ShuntCompensatorDynamicData {

+ connectionStatus : Integer [0..1]
+ desiredVoltage : Float [0..1]
+ mVARInjection : Float [0..1]
+ stepPosition : Integer [0..1]
+ voltageRegulationStatus : Boolean [0..1]
}

class MktShuntCompensator {

}

ShuntCompensatorDynamicData --> "1" MktShuntCompensator : MktShuntCompensator
```

Optimal Power Flow or State Estimator Filter Bank Data for OTS. This is used for RealTime, Study and Maintenance Users.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| connectionStatus [0..1] | [Integer](#CIM17v40-Integer) | The current status for the Voltage Control Capacitor 1= Connected 0 = Disconnected | |
| desiredVoltage [0..1] | [Float](#CIM17v40-Float) | The desired voltage for the Voltage Control Capacitor | |
| mVARInjection [0..1] | [Float](#CIM17v40-Float) | The injection of reactive power of the filter bank in the NA solution or VCS reactive power production | |
| stepPosition [0..1] | [Integer](#CIM17v40-Integer) | Voltage control capacitor step position | |
| voltageRegulationStatus [0..1] | [Boolean](#CIM17v40-Boolean) | Indicator if the voltage control this is regulating True = Yes, False = No | |
| MktShuntCompensator [1] | [MktShuntCompensator](#CIM17v40-MktShuntCompensator) | | |

{#CIM17v40-ShuntCompensatorInfo}
### (informative) ShuntCompensatorInfo

Inheritance path = [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ShuntCompensatorInfo {

+ maxPowerLoss : ApparentPower [0..1]
+ ratedCurrent : CurrentFlow [0..1]
+ ratedReactivePower : ReactivePower [0..1]
+ ratedVoltage : Voltage [0..1]
}

class AssetInfo {

}

AssetInfo <|-- ShuntCompensatorInfo : inherits from
class ShuntCompensatorControl {

}

ShuntCompensatorInfo --> "0..1" ShuntCompensatorControl : ShuntCompensatorControl
```

Properties of shunt capacitor, shunt reactor or switchable bank of shunt capacitor or reactor assets.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maxPowerLoss [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | Maximum allowed apparent power loss. | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Rated current. | |
| ratedReactivePower [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Rated reactive power. | |
| ratedVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Rated voltage. | |
| `ShuntCompensatorControl [0..1]` (informative) | [ShuntCompensatorControl](#CIM17v40-ShuntCompensatorControl) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ShuntCompensatorPhase}
### ShuntCompensatorPhase

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ShuntCompensatorPhase {

+ maximumSections : Integer [0..1]
+ normalSections : Integer [0..1]
+ phase : enum:SinglePhaseKind [0..1]
+ sections : Float [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- ShuntCompensatorPhase : inherits from
class ShuntCompensator {

}

ShuntCompensatorPhase --> "1" ShuntCompensator : ShuntCompensator
```

Single phase of a multi-phase shunt compensator when its attributes might be different per phase.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maximumSections [0..1] | [Integer](#CIM17v40-Integer) | The maximum number of sections that may be switched in for this phase. | |
| normalSections [0..1] | [Integer](#CIM17v40-Integer) | For the capacitor phase, the normal number of sections switched in. The value shall be between zero and ShuntCompensatorPhase.maximumSections. | |
| phase [0..1] | [SinglePhaseKind](#CIM17v40-SinglePhaseKind) | Phase of this shunt compensator component. If the shunt compensator is wye connected, the connection is from the indicated phase to the central ground or neutral point. If the shunt compensator is delta connected, the phase indicates a shunt compensator connected from the indicated phase to the next logical non-neutral phase. | |
| sections [0..1] | [Float](#CIM17v40-Float) | Shunt compensator sections in use. Starting value for steady state solution. The attribute shall be a positive value or zero. Non integer values are allowed to support continuous variables. The reasons for continuous value are to support study cases where no discrete shunt compensators has yet been designed, a solutions where a narrow voltage band force the sections to oscillate or accommodate for a continuous solution as input.For LinearShuntConpensator the value shall be between zero and ShuntCompensatorPhase.maximumSections. At value zero the shunt compensator conductance and admittance is zero. Linear interpolation of conductance and admittance between the previous and next integer section is applied in case of non-integer values.For NonlinearShuntCompensator-s shall only be set to one of the NonlinearShuntCompenstorPhasePoint.sectionNumber. There is no interpolation between NonlinearShuntCompenstorPhasePoint-s. | |
| ShuntCompensator [1] | [ShuntCompensator](#CIM17v40-ShuntCompensator) | Shunt compensator of this shunt compensator phase. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ShutdownCurve}
### ShutdownCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ShutdownCurve {

+ shutdownCost : Money [0..1]
+ shutdownDate : DateTime [0..1]
}

class Curve {

}

Curve <|-- ShutdownCurve : inherits from
class ThermalGeneratingUnit {

}

ShutdownCurve --> "1" ThermalGeneratingUnit : ThermalGeneratingUnit
```

Relationship between the rate in gross active power/minute (Y-axis) at which a unit should be shutdown and its present gross MW output (X-axis).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| shutdownCost [0..1] | [Money](#CIM17v40-Money) | Fixed shutdown cost. | |
| shutdownDate [0..1] | [DateTime](#CIM17v40-DateTime) | The date and time of the most recent generating unit shutdown. | |
| `ThermalGeneratingUnit [1]` (OfAggregate) | [ThermalGeneratingUnit](#CIM17v40-ThermalGeneratingUnit) | A thermal generating unit may have a shutdown curve. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SimpleEndDeviceFunction}
### SimpleEndDeviceFunction

Inheritance path = [EndDeviceFunction](#CIM17v40-EndDeviceFunction) => [AssetFunction](#CIM17v40-AssetFunction) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SimpleEndDeviceFunction {

+ kind : enum:EndDeviceFunctionKind [0..1]
}

class EndDeviceFunction {

}

EndDeviceFunction <|-- SimpleEndDeviceFunction : inherits from
```

Simple end device function distinguished by 'kind'. Use this class for instances that cannot be represented by another end device function specialisations.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [EndDeviceFunctionKind](#CIM17v40-EndDeviceFunctionKind) | Kind of this function. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [EndDeviceFunction](#CIM17v40-EndDeviceFunction) | |
| EndDevice [0..1] | [EndDevice](#CIM17v40-EndDevice) | see [EndDeviceFunction](CIM17v40-EndDeviceFunction) | |
| configID [0..1] | [String](#CIM17v40-String) | see [AssetFunction](#CIM17v40-AssetFunction) | |
| firmwareID [0..1] | [String](#CIM17v40-String) | see [AssetFunction](#CIM17v40-AssetFunction) | |
| hardwareID [0..1] | [String](#CIM17v40-String) | see [AssetFunction](#CIM17v40-AssetFunction) | |
| password [0..1] | [String](#CIM17v40-String) | see [AssetFunction](#CIM17v40-AssetFunction) | |
| programID [0..1] | [String](#CIM17v40-String) | see [AssetFunction](#CIM17v40-AssetFunction) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [AssetFunction](CIM17v40-AssetFunction) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Skill}
### Skill

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Skill {

+ effectiveDateTime : DateTime [0..1]
+ level : enum:SkillLevelKind [0..1]
+ certificationPeriod : DateTimeInterval [0..1]
}

class Document {

}

Document <|-- Skill : inherits from
class OldPerson {

}

Skill --> "0..1" OldPerson : ErpPerson
```

Proficiency level of a craft, which is required to operate or maintain a particular type of asset and/or perform certain types of work.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| effectiveDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time the skill became effective. | |
| level [0..1] | [SkillLevelKind](#CIM17v40-SkillLevelKind) | Level of skill for a Craft. | |
| certificationPeriod [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Interval between the certification and its expiry. | |
| `ErpPerson [0..1]` (informative) | [OldPerson](#CIM17v40-OldPerson) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SolarGeneratingUnit}
### SolarGeneratingUnit

Inheritance path = [GeneratingUnit](#CIM17v40-GeneratingUnit) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SolarGeneratingUnit {

}

class GeneratingUnit {

}

GeneratingUnit <|-- SolarGeneratingUnit : inherits from
```

A solar thermal generating unit, connected to the grid by means of a rotating machine. This class does not represent photovoltaic (PV) generation.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| allocSpinResP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| autoCntrlMarginP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| baseP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlDeadband [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlPulseHigh [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlPulseLow [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlResponseRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| efficiency [0..1] | [PerCent](#CIM17v40-PerCent) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| genControlMode [0..1] | [GeneratorControlMode](#CIM17v40-GeneratorControlMode) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| genControlSource [0..1] | [GeneratorControlSource](#CIM17v40-GeneratorControlSource) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| governorMPL [0..1] | [PU](#CIM17v40-PU) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| governorSCD [0..1] | [PerCent](#CIM17v40-PerCent) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| highControlLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| initialP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| longPF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| lowControlLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| lowerRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| maxEconomicP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| maximumAllowableSpinningReserve [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| maxOperatingP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| minEconomicP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| minimumOffTime [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| minOperatingP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| modelDetail [0..1] | [Classification](#CIM17v40-Classification) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| nominalP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| normalPF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| penaltyFactor [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| raiseRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| ratedGrossMaxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| ratedGrossMinP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| ratedNetMaxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| shortPF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| startupCost [0..1] | [Money](#CIM17v40-Money) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| startupTime [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| tieLinePF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| totalEfficiency [0..1] | [PerCent](#CIM17v40-PerCent) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| variableCost [0..1] | [Money](#CIM17v40-Money) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| `GenUnitOpSchedule [0..1]` (AggregateOf) | [GenUnitOpSchedule](#CIM17v40-GenUnitOpSchedule) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SpaceAnalog}
### SpaceAnalog

Inheritance path = [EnvironmentalAnalog](#CIM17v40-EnvironmentalAnalog) => [Analog](#CIM17v40-Analog) => [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SpaceAnalog {

+ kind : enum:SpaceAnalogKind [0..1]
}

class EnvironmentalAnalog {

}

EnvironmentalAnalog <|-- SpaceAnalog : inherits from
```

Analog (float) measuring a space (extra-terrestrial) condition.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [SpaceAnalogKind](#CIM17v40-SpaceAnalogKind) | Kind of space analog. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ClassificationCondition [0..1] | [ClassificationCondition](#CIM17v40-ClassificationCondition) | see [EnvironmentalAnalog](CIM17v40-EnvironmentalAnalog) | |
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | see [EnvironmentalAnalog](CIM17v40-EnvironmentalAnalog) | |
| EnvironmentalMonitoringStation [0..1] | [EnvironmentalMonitoringStation](#CIM17v40-EnvironmentalMonitoringStation) | see [EnvironmentalAnalog](CIM17v40-EnvironmentalAnalog) | |
| ReportingCapability [0..1] | [ReportingCapability](#CIM17v40-ReportingCapability) | see [EnvironmentalAnalog](CIM17v40-EnvironmentalAnalog) | |
| maxValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| minValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| normalValue [0..1] | [Float](#CIM17v40-Float) | see [Analog](#CIM17v40-Analog) | |
| positiveFlowIn [0..1] | [Boolean](#CIM17v40-Boolean) | see [Analog](#CIM17v40-Analog) | |
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SpacePhenomenon}
### SpacePhenomenon

Inheritance path = [EnvironmentalPhenomenon](#CIM17v40-EnvironmentalPhenomenon)

```mermaid
classDiagram
direction TB

class SpacePhenomenon {

}

class EnvironmentalPhenomenon {

}

EnvironmentalPhenomenon <|-- SpacePhenomenon : inherits from
```

An extra-terrestrial phenomenon.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| PhenomenonClassification [0..1] | [PhenomenonClassification](#CIM17v40-PhenomenonClassification) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| timeInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |

{#CIM17v40-Specification}
### (informative) Specification

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Specification {

}

class Document {

}

Document <|-- Specification : inherits from
```

Specification can be used for various purposes relative to an asset, a logical device (PowerSystemResource), location, etc. Examples include documents supplied by manufacturers such as asset installation instructions, asset maintenance instructions, etc.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Specimen}
### Specimen

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Specimen {

+ ambientTemperatureAtSampling : Temperature [0..1]
+ humidityAtSampling : PerCent [0..1]
+ specimenID : String [0..1]
+ specimenSampleDateTime : DateTime [0..1]
+ specimenToLabDateTime : DateTime [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Specimen : inherits from
class AssetTestSampleTaker {

}

Specimen --> "0..1" AssetTestSampleTaker : AssetTestSampleTaker
```

Sample or specimen of a material (fluid or solid).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ambientTemperatureAtSampling [0..1] | [Temperature](#CIM17v40-Temperature) | Operating ambient temperature (in �C). | |
| humidityAtSampling [0..1] | [PerCent](#CIM17v40-PerCent) | Operating ambient humidity (in percent). | |
| specimenID [0..1] | [String](#CIM17v40-String) | Identifier of specimen used in inspection or test. | |
| specimenSampleDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time sample specimen taken. | |
| specimenToLabDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time the specimen was received by the lab. | |
| AssetTestSampleTaker [0..1] | [AssetTestSampleTaker](#CIM17v40-AssetTestSampleTaker) | Test sampler taker who gathered this specimen. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Stage}
### (informative) Stage

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Stage {

+ priority : Integer [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Stage : inherits from
class RemedialActionScheme {

}

Stage --> "1" RemedialActionScheme : RemedialActionScheme
```

Stage of a remedial action scheme.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| priority [0..1] | [Integer](#CIM17v40-Integer) | The priority of the stage. 0 = don t care (default) 1 = highest priority. 2 is less than 1 and so on. A stage with higher priority needs be activated before a lower stage can be activated. | |
| `RemedialActionScheme [1]` (OfAggregate, informative) | [RemedialActionScheme](#CIM17v40-RemedialActionScheme) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-StageTrigger}
### StageTrigger

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class StageTrigger {

+ armed : Boolean [0..1]
+ normalArmed : Boolean [0..1]
+ priority : Integer [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- StageTrigger : inherits from
class Gate {

}

StageTrigger --> "0..1" Gate : GateArmed
class Gate {

}

StageTrigger --> "0..1" Gate : GateComCondition
class Gate {

}

StageTrigger --> "0..1" Gate : GateTrigger
class ProtectiveActionCollection {

}

StageTrigger --> "1" ProtectiveActionCollection : ProtectiveActionCollection
class Stage {

}

StageTrigger --> "1" Stage : Stage
```

Condition that is triggered either by TriggerCondition of by gate condition within a stage and has remedial action-s.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| armed [0..1] | [Boolean](#CIM17v40-Boolean) | The status of the class set by operation or by signal. Optional field that will override other status fields. | |
| normalArmed [0..1] | [Boolean](#CIM17v40-Boolean) | The default/normal value used when other active signal/values are missing. | |
| priority [0..1] | [Integer](#CIM17v40-Integer) | Priority of trigger. 0 = don t care (default) 1 = highest priority. 2 is less than 1 and so on. A trigger with the highest priority will trigger first. | |
| `GateArmed [0..1]` (informative) | [Gate](#CIM17v40-Gate) | Association to a Gate that through a gate logic and input pin defines arming of the StageTrigger. | |
| `GateComCondition [0..1]` (informative) | [Gate](#CIM17v40-Gate) | For the StageTrigger to active the set of protective actions the condition for communication needs to be met (true). | |
| `GateTrigger [0..1]` (informative) | [Gate](#CIM17v40-Gate) | The Gate result that trigger the StageTrigger and thereby executing the a set of protective actions. | |
| `ProtectiveActionCollection [1]` (informative) | [ProtectiveActionCollection](#CIM17v40-ProtectiveActionCollection) | | |
| `Stage [1]` (OfAggregate, informative) | [Stage](#CIM17v40-Stage) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-StandardIndustryCode}
### (informative) StandardIndustryCode

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class StandardIndustryCode {

+ code : String [0..1]
}

class Document {

}

Document <|-- StandardIndustryCode : inherits from
```

The Standard Industrial Classification (SIC) are the codes that identify the type of products/service an industry is involved in, and used for statutory reporting purposes. For example, in the USA these codes are located by the federal government, and then published in a book entitled "The Standard Industrial Classification Manual". The codes are arranged in a hierarchical structure.

Note that Residential Service Agreements are not classified according to the SIC codes.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| code [0..1] | [String](#CIM17v40-String) | Standard alphanumeric code assigned to a particular product/service within an industry. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-StartIgnFuelCurve}
### StartIgnFuelCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class StartIgnFuelCurve {

+ ignitionFuelType : enum:FuelType [0..1]
}

class Curve {

}

Curve <|-- StartIgnFuelCurve : inherits from
class StartupModel {

}

StartIgnFuelCurve --> "1" StartupModel : StartupModel
```

The quantity of ignition fuel (Y-axis) used to restart and repay the auxiliary power consumed versus the number of hours (X-axis) the unit was off line.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ignitionFuelType [0..1] | [FuelType](#CIM17v40-FuelType) | Type of ignition fuel. | |
| `StartupModel [1]` (OfAggregate) | [StartupModel](#CIM17v40-StartupModel) | The unit's startup model may have a startup ignition fuel curve. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-StartMainFuelCurve}
### StartMainFuelCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class StartMainFuelCurve {

+ mainFuelType : enum:FuelType [0..1]
}

class Curve {

}

Curve <|-- StartMainFuelCurve : inherits from
class StartupModel {

}

StartMainFuelCurve --> "1" StartupModel : StartupModel
```

The quantity of main fuel (Y-axis) used to restart and repay the auxiliary power consumed versus the number of hours (X-axis) the unit was off line.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mainFuelType [0..1] | [FuelType](#CIM17v40-FuelType) | Type of main fuel. | |
| `StartupModel [1]` (OfAggregate) | [StartupModel](#CIM17v40-StartupModel) | The unit's startup model may have a startup main fuel curve. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-StartRampCurve}
### StartRampCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class StartRampCurve {

+ hotStandbyRamp : ActivePowerChangeRate [0..1]
}

class Curve {

}

Curve <|-- StartRampCurve : inherits from
class StartupModel {

}

StartRampCurve --> "1" StartupModel : StartupModel
```

Rate in gross active power per minute (Y-axis) at which a unit can be loaded versus the number of hours (X-axis) the unit was off line.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| hotStandbyRamp [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | The startup ramp rate in gross for a unit that is on hot standby. | |
| `StartupModel [1]` (OfAggregate) | [StartupModel](#CIM17v40-StartupModel) | The unit's startup model may have a startup ramp curve. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-StartUpCostCurve}
### StartUpCostCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class StartUpCostCurve {

}

class Curve {

}

Curve <|-- StartUpCostCurve : inherits from
```

Startup costs and time as a function of down time. Relationship between unit startup cost (Y1-axis) vs. unit elapsed down time (X-axis).


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-StartUpEnergyCurve}
### StartUpEnergyCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class StartUpEnergyCurve {

}

class Curve {

}

Curve <|-- StartUpEnergyCurve : inherits from
class RegisteredGenerator {

}

StartUpEnergyCurve --> "0..1" RegisteredGenerator : RegisteredGenerator
```

The energy consumption of a generating resource to complete a start-up from the StartUpEnergyCurve. Definition of the StartUpEnergyCurve includes, xvalue as the cooling time and y1value as the MW value.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| RegisteredGenerator [0..1] | [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-StartUpFuelCurve}
### StartUpFuelCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class StartUpFuelCurve {

}

class Curve {

}

Curve <|-- StartUpFuelCurve : inherits from
class RegisteredGenerator {

}

StartUpFuelCurve --> "0..1" RegisteredGenerator : RegisteredGenerator
```

The fuel consumption of a Generating Resource to complete a Start-Up.(x=cooling time) Form Startup Fuel Curve. xAxisData -&gt; cooling time, y1AxisData -&gt; MBtu.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| RegisteredGenerator [0..1] | [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-StartUpTimeCurve}
### StartUpTimeCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class StartUpTimeCurve {

}

class Curve {

}

Curve <|-- StartUpTimeCurve : inherits from
class RegisteredGenerator {

}

StartUpTimeCurve --> "0..1" RegisteredGenerator : RegisteredGenerator
```

Startup time curve as a function of down time, where time is specified in minutes. Relationship between unit startup time (Y1-axis) vs. unit elapsed down time (X-axis).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| RegisteredGenerator [0..1] | [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-StartupModel}
### StartupModel

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class StartupModel {

+ fixedMaintCost : CostRate [0..1]
+ hotStandbyHeat : HeatRate [0..1]
+ incrementalMaintCost : CostPerEnergyUnit [0..1]
+ minimumDownTime : Hours [0..1]
+ minimumRunTime : Hours [0..1]
+ riskFactorCost : Money [0..1]
+ startupCost : Money [0..1]
+ startupDate : DateTime [0..1]
+ startupPriority : Integer [0..1]
+ stbyAuxP : ActivePower [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- StartupModel : inherits from
class StartIgnFuelCurve {

}

StartupModel --> "0..1" StartIgnFuelCurve : StartIgnFuelCurve
class StartMainFuelCurve {

}

StartupModel --> "0..1" StartMainFuelCurve : StartMainFuelCurve
class StartRampCurve {

}

StartupModel --> "0..1" StartRampCurve : StartRampCurve
class ThermalGeneratingUnit {

}

StartupModel --> "1" ThermalGeneratingUnit : ThermalGeneratingUnit
```

Unit start up characteristics depending on how long the unit has been off line.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| fixedMaintCost [0..1] | [CostRate](#CIM17v40-CostRate) | Fixed maintenance cost. | |
| hotStandbyHeat [0..1] | [HeatRate](#CIM17v40-HeatRate) | The amount of heat input per time unit required for hot standby operation. | |
| incrementalMaintCost [0..1] | [CostPerEnergyUnit](#CIM17v40-CostPerEnergyUnit) | Incremental maintenance cost. | |
| minimumDownTime [0..1] | [Hours](#CIM17v40-Hours) | The minimum number of hours the unit must be down before restart. | |
| minimumRunTime [0..1] | [Hours](#CIM17v40-Hours) | The minimum number of hours the unit must be operating before being allowed to shut down. | |
| riskFactorCost [0..1] | [Money](#CIM17v40-Money) | The opportunity cost associated with the return in monetary unit. This represents the restart's "share" of the unit depreciation and risk of an event which would damage the unit. | |
| startupCost [0..1] | [Money](#CIM17v40-Money) | Total miscellaneous start up costs. | |
| startupDate [0..1] | [DateTime](#CIM17v40-DateTime) | The date and time of the most recent generating unit startup. | |
| startupPriority [0..1] | [Integer](#CIM17v40-Integer) | Startup priority within control area where lower numbers indicate higher priorities. More than one unit in an area may be assigned the same priority. | |
| stbyAuxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | The unit's auxiliary active power consumption to maintain standby mode. | |
| `StartIgnFuelCurve [0..1]` (AggregateOf) | [StartIgnFuelCurve](#CIM17v40-StartIgnFuelCurve) | The unit's startup model may have a startup ignition fuel curve. | |
| `StartMainFuelCurve [0..1]` (AggregateOf) | [StartMainFuelCurve](#CIM17v40-StartMainFuelCurve) | The unit's startup model may have a startup main fuel curve. | |
| `StartRampCurve [0..1]` (AggregateOf) | [StartRampCurve](#CIM17v40-StartRampCurve) | The unit's startup model may have a startup ramp curve. | |
| `ThermalGeneratingUnit [1]` (OfAggregate) | [ThermalGeneratingUnit](#CIM17v40-ThermalGeneratingUnit) | A thermal generating unit may have a startup model. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-StateVariable}
### StateVariable


```mermaid
classDiagram
direction TB

class StateVariable {

}

```

An abstract class for state variables.


{#CIM17v40-StaticVarCompensator}
### StaticVarCompensator

Inheritance path = [RegulatingCondEq](#CIM17v40-RegulatingCondEq) => [EnergyConnection](#CIM17v40-EnergyConnection) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class StaticVarCompensator {

+ capacitiveRating : Reactance [0..1]
+ inductiveRating : Reactance [0..1]
+ q : ReactivePower [0..1]
+ slope : VoltagePerReactivePower [0..1]
+ sVCControlMode : enum:SVCControlMode [0..1]
+ voltageSetPoint : Voltage [0..1]
}

class RegulatingCondEq {

}

RegulatingCondEq <|-- StaticVarCompensator : inherits from
class StaticVarCompensatorDynamics {

}

StaticVarCompensator --> "0..1" StaticVarCompensatorDynamics : StaticVarCompensatorDynamics
```

A facility for providing variable and controllable shunt reactive power. The SVC typically consists of a stepdown transformer, filter, thyristor-controlled reactor, and thyristor-switched capacitor arms.

The SVC may operate in fixed MVar output mode or in voltage control mode. When in voltage control mode, the output of the SVC will be proportional to the deviation of voltage at the controlled bus from the voltage setpoint. The SVC characteristic slope defines the proportion. If the voltage at the controlled bus is equal to the voltage setpoint, the SVC MVar output is zero.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| capacitiveRating [0..1] | [Reactance](#CIM17v40-Reactance) | Capacitive reactance at maximum capacitive reactive power. Shall always be positive. | |
| inductiveRating [0..1] | [Reactance](#CIM17v40-Reactance) | Inductive reactance at maximum inductive reactive power. Shall always be negative. | |
| q [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Reactive power injection. Load sign convention is used, i.e. positive sign means flow out from a node.Starting value for a steady state solution. | |
| slope [0..1] | [VoltagePerReactivePower](#CIM17v40-VoltagePerReactivePower) | The characteristics slope of an SVC defines how the reactive power output changes in proportion to the difference between the regulated bus voltage and the voltage setpoint.The attribute shall be a positive value or zero. | |
| sVCControlMode [0..1] | [SVCControlMode](#CIM17v40-SVCControlMode) | SVC control mode. | |
| voltageSetPoint [0..1] | [Voltage](#CIM17v40-Voltage) | The reactive power output of the SVC is proportional to the difference between the voltage at the regulated bus and the voltage setpoint. When the regulated bus voltage is equal to the voltage setpoint, the reactive power output is zero. | |
| StaticVarCompensatorDynamics [0..1] | [StaticVarCompensatorDynamics](#CIM17v40-StaticVarCompensatorDynamics) | Static Var Compensator dynamics model used to describe dynamic behaviour of this Static Var Compensator. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| controlEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [RegulatingCondEq](#CIM17v40-RegulatingCondEq) | |
| RegulatingControl [0..1] | [RegulatingControl](#CIM17v40-RegulatingControl) | see [RegulatingCondEq](CIM17v40-RegulatingCondEq) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-StaticVarCompensatorDynamics}
### StaticVarCompensatorDynamics

Inheritance path = [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class StaticVarCompensatorDynamics {

}

class DynamicsFunctionBlock {

}

DynamicsFunctionBlock <|-- StaticVarCompensatorDynamics : inherits from
class StaticVarCompensator {

}

StaticVarCompensatorDynamics --> "1" StaticVarCompensator : StaticVarCompensator
```

Static var compensator whose behaviour is described by reference to a standard model <font color="#0f0f0f">or by definition of a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| StaticVarCompensator [1] | [StaticVarCompensator](#CIM17v40-StaticVarCompensator) | Static Var Compensator to which Static Var Compensator dynamics model applies. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-StationSupply}
### StationSupply

Inheritance path = [EnergyConsumer](#CIM17v40-EnergyConsumer) => [EnergyConnection](#CIM17v40-EnergyConnection) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class StationSupply {

}

class EnergyConsumer {

}

EnergyConsumer <|-- StationSupply : inherits from
```

Station supply with load derived from the station output.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| customerCount [0..1] | [Integer](#CIM17v40-Integer) | see [EnergyConsumer](#CIM17v40-EnergyConsumer) | |
| grounded [0..1] | [Boolean](#CIM17v40-Boolean) | see [EnergyConsumer](#CIM17v40-EnergyConsumer) | |
| p [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| pfixed [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| pfixedPct [0..1] | [PerCent](#CIM17v40-PerCent) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| phaseConnection [0..1] | [PhaseShuntConnectionKind](#CIM17v40-PhaseShuntConnectionKind) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| q [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| qfixed [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| qfixedPct [0..1] | [PerCent](#CIM17v40-PerCent) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| EnergyConsumerAction [0..1] | [EnergyConsumerAction](#CIM17v40-EnergyConsumerAction) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| LoadDynamics [0..1] | [LoadDynamics](#CIM17v40-LoadDynamics) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| LoadResponse [0..1] | [LoadResponseCharacteristic](#CIM17v40-LoadResponseCharacteristic) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| `PowerCutZone [0..1]` (OfAggregate) | [PowerCutZone](#CIM17v40-PowerCutZone) | see [EnergyConsumer](CIM17v40-EnergyConsumer) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-StatisticalCalculation}
### StatisticalCalculation

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class StatisticalCalculation {

+ calculationMode : enum:CalculationModeKind [0..1]
+ calculationTechnique : enum:CalculationTechniqueKind [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- StatisticalCalculation : inherits from
```

Description of statistical calculation performed.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| calculationMode [0..1] | [CalculationModeKind](#CIM17v40-CalculationModeKind) | Calculation mode. | |
| calculationTechnique [0..1] | [CalculationTechniqueKind](#CIM17v40-CalculationTechniqueKind) | Kind of statistical calculation, specifying how the measurement value is calculated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SteamSendoutSchedule}
### SteamSendoutSchedule

Inheritance path = [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) => [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SteamSendoutSchedule {

}

class RegularIntervalSchedule {

}

RegularIntervalSchedule <|-- SteamSendoutSchedule : inherits from
class CogenerationPlant {

}

SteamSendoutSchedule --> "1" CogenerationPlant : CogenerationPlant
```

The cogeneration plant's steam sendout schedule in volume per time unit.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `CogenerationPlant [1]` (OfAggregate) | [CogenerationPlant](#CIM17v40-CogenerationPlant) | A cogeneration plant has a steam sendout schedule. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | see [RegularIntervalSchedule](CIM17v40-RegularIntervalSchedule) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SteamSupply}
### SteamSupply

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SteamSupply {

+ steamSupplyRating : Float [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- SteamSupply : inherits from
```

Steam supply for steam turbine.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| steamSupplyRating [0..1] | [Float](#CIM17v40-Float) | Rating of steam supply. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SteamTurbine}
### SteamTurbine

Inheritance path = [PrimeMover](#CIM17v40-PrimeMover) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SteamTurbine {

+ crossoverTC : Seconds [0..1]
+ reheater1TC : Seconds [0..1]
+ reheater2TC : Seconds [0..1]
+ shaft1PowerHP : Float [0..1]
+ shaft1PowerIP : Float [0..1]
+ shaft1PowerLP1 : Float [0..1]
+ shaft1PowerLP2 : Float [0..1]
+ shaft2PowerHP : Float [0..1]
+ shaft2PowerIP : Float [0..1]
+ shaft2PowerLP1 : Float [0..1]
+ shaft2PowerLP2 : Float [0..1]
+ steamChestTC : Seconds [0..1]
}

class PrimeMover {

}

PrimeMover <|-- SteamTurbine : inherits from
```

Steam turbine.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| crossoverTC [0..1] | [Seconds](#CIM17v40-Seconds) | Crossover time constant. | |
| reheater1TC [0..1] | [Seconds](#CIM17v40-Seconds) | First reheater time constant. | |
| reheater2TC [0..1] | [Seconds](#CIM17v40-Seconds) | Second reheater time constant. | |
| shaft1PowerHP [0..1] | [Float](#CIM17v40-Float) | Fraction of power from shaft 1 high pressure turbine output. | |
| shaft1PowerIP [0..1] | [Float](#CIM17v40-Float) | Fraction of power from shaft 1 intermediate pressure turbine output. | |
| shaft1PowerLP1 [0..1] | [Float](#CIM17v40-Float) | Fraction of power from shaft 1 first low pressure turbine output. | |
| shaft1PowerLP2 [0..1] | [Float](#CIM17v40-Float) | Fraction of power from shaft 1 second low pressure turbine output. | |
| shaft2PowerHP [0..1] | [Float](#CIM17v40-Float) | Fraction of power from shaft 2 high pressure turbine output. | |
| shaft2PowerIP [0..1] | [Float](#CIM17v40-Float) | Fraction of power from shaft 2 intermediate pressure turbine output. | |
| shaft2PowerLP1 [0..1] | [Float](#CIM17v40-Float) | Fraction of power from shaft 2 first low pressure turbine output. | |
| shaft2PowerLP2 [0..1] | [Float](#CIM17v40-Float) | Fraction of power from shaft 2 second low pressure turbine output. | |
| steamChestTC [0..1] | [Seconds](#CIM17v40-Seconds) | Steam chest time constant. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| primeMoverRating [0..1] | [Float](#CIM17v40-Float) | see [PrimeMover](#CIM17v40-PrimeMover) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Streetlight}
### Streetlight

Inheritance path = [Asset](#CIM17v40-Asset) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Streetlight {

+ armLength : Length [0..1]
+ lampKind : enum:StreetlightLampKind [0..1]
+ lightRating : ActivePower [0..1]
}

class Asset {

}

Asset <|-- Streetlight : inherits from
class Pole {

}

Streetlight --> "0..1" Pole : Pole
```

Streetlight asset.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| armLength [0..1] | [Length](#CIM17v40-Length) | Length of arm. Note that a new light may be placed on an existing arm. | |
| lampKind [0..1] | [StreetlightLampKind](#CIM17v40-StreetlightLampKind) | Lamp kind. | |
| lightRating [0..1] | [ActivePower](#CIM17v40-ActivePower) | Power rating of light. | |
| `Pole [0..1]` (informative) | [Pole](#CIM17v40-Pole) | Pole to which thiss streetlight is attached. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | see [Asset](#CIM17v40-Asset) | |
| initialCondition [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | see [Asset](CIM17v40-Asset) | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | see [Asset](CIM17v40-Asset) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [Asset](CIM17v40-Asset) | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | see [Asset](CIM17v40-Asset) | |
| lotNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| position [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | see [Asset](CIM17v40-Asset) | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | see [Asset](CIM17v40-Asset) | |
| serialNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| type [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| utcNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | see [Asset](CIM17v40-Asset) | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | see [Asset](CIM17v40-Asset) | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | see [Asset](CIM17v40-Asset) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [Asset](CIM17v40-Asset) | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | see [Asset](CIM17v40-Asset) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Asset](CIM17v40-Asset) | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | see [Asset](CIM17v40-Asset) | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | see [Asset](CIM17v40-Asset) | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | see [Asset](CIM17v40-Asset) | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | see [Asset](CIM17v40-Asset) | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | see [Asset](CIM17v40-Asset) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Asset](CIM17v40-Asset) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [Asset](CIM17v40-Asset) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [Asset](CIM17v40-Asset) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Asset](CIM17v40-Asset) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-StringMeasurement}
### StringMeasurement

Inheritance path = [Measurement](#CIM17v40-Measurement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class StringMeasurement {

}

class Measurement {

}

Measurement <|-- StringMeasurement : inherits from
```

StringMeasurement represents a measurement with values of type string.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| measurementType [0..1] | [String](#CIM17v40-String) | see [Measurement](#CIM17v40-Measurement) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [Measurement](CIM17v40-Measurement) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Measurement](CIM17v40-Measurement) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Measurement](CIM17v40-Measurement) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [Measurement](CIM17v40-Measurement) | |
| CalculationMethodHierarchy [0..1] | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [Measurement](CIM17v40-Measurement) | |
| MeasurementAction [0..1] | [MeasurementAction](#CIM17v40-MeasurementAction) | see [Measurement](CIM17v40-Measurement) | |
| `PowerSystemResource [0..1]` (OfAggregate) | [PowerSystemResource](#CIM17v40-PowerSystemResource) | see [Measurement](CIM17v40-Measurement) | |
| Terminal [0..1] | [ACDCTerminal](#CIM17v40-ACDCTerminal) | see [Measurement](CIM17v40-Measurement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-StringMeasurementValue}
### StringMeasurementValue

Inheritance path = [MeasurementValue](#CIM17v40-MeasurementValue) => [IOPoint](#CIM17v40-IOPoint) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class StringMeasurementValue {

+ value : String [0..1]
}

class MeasurementValue {

}

MeasurementValue <|-- StringMeasurementValue : inherits from
class StringMeasurement {

}

StringMeasurementValue --> "1" StringMeasurement : StringMeasurement
```

StringMeasurementValue represents a measurement value of type string.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| value [0..1] | [String](#CIM17v40-String) | The value to supervise. | |
| StringMeasurement [1] | [StringMeasurement](#CIM17v40-StringMeasurement) | Measurement to which this value is connected. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| sensorAccuracy [0..1] | [PerCent](#CIM17v40-PerCent) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| timeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | see [MeasurementValue](#CIM17v40-MeasurementValue) | |
| `CalculationMethodHierarchy [0..1]` (harmonization) | [CalculationMethodHierarchy](#CIM17v40-CalculationMethodHierarchy) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| `ErpPerson [0..1]` (informative) | [OldPerson](#CIM17v40-OldPerson) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| `MeasurementValueQuality [0..1]` (AggregateOf) | [MeasurementValueQuality](#CIM17v40-MeasurementValueQuality) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| MeasurementValueSource [1] | [MeasurementValueSource](#CIM17v40-MeasurementValueSource) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| RemoteSource [0..1] | [RemoteSource](#CIM17v40-RemoteSource) | see [MeasurementValue](CIM17v40-MeasurementValue) | |
| IOPointSource [0..1] | [IOPointSource](#CIM17v40-IOPointSource) | see [IOPoint](CIM17v40-IOPoint) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Structure}
### Structure

Inheritance path = [AssetContainer](#CIM17v40-AssetContainer) => [Asset](#CIM17v40-Asset) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Structure {

+ fumigantAppliedDate : Date [0..1]
+ fumigantName : String [0..1]
+ height : Length [0..1]
+ materialKind : enum:StructureMaterialKind [0..1]
+ ratedVoltage : Voltage [0..1]
+ removeWeed : Boolean [0..1]
+ weedRemovedDate : Date [0..1]
}

class AssetContainer {

}

AssetContainer <|-- Structure : inherits from
```

Construction holding assets such as conductors, transformers, switchgear, etc. Where applicable, number of conductors can be derived from the number of associated wire spacing instances.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| fumigantAppliedDate [0..1] | [Date](#CIM17v40-Date) | Date fumigant was last applied. | |
| fumigantName [0..1] | [String](#CIM17v40-String) | Name of fumigant. | |
| height [0..1] | [Length](#CIM17v40-Length) | Visible height of structure above ground level for overhead construction (e.g., Pole or Tower) or below ground level for an underground vault, manhole, etc. Refer to associated DimensionPropertiesInfo for other types of dimensions. | |
| materialKind [0..1] | [StructureMaterialKind](#CIM17v40-StructureMaterialKind) | Material this structure is made of. | |
| ratedVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Maximum rated voltage of the equipment that can be mounted on/contained within the structure. | |
| removeWeed [0..1] | [Boolean](#CIM17v40-Boolean) | True if weeds are to be removed around asset. | |
| weedRemovedDate [0..1] | [Date](#CIM17v40-Date) | Date weed were last removed. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | see [Asset](#CIM17v40-Asset) | |
| initialCondition [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | see [Asset](CIM17v40-Asset) | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | see [Asset](CIM17v40-Asset) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [Asset](CIM17v40-Asset) | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | see [Asset](CIM17v40-Asset) | |
| lotNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| position [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | see [Asset](CIM17v40-Asset) | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | see [Asset](CIM17v40-Asset) | |
| serialNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| type [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| utcNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | see [Asset](CIM17v40-Asset) | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | see [Asset](CIM17v40-Asset) | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | see [Asset](CIM17v40-Asset) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [Asset](CIM17v40-Asset) | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | see [Asset](CIM17v40-Asset) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Asset](CIM17v40-Asset) | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | see [Asset](CIM17v40-Asset) | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | see [Asset](CIM17v40-Asset) | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | see [Asset](CIM17v40-Asset) | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | see [Asset](CIM17v40-Asset) | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | see [Asset](CIM17v40-Asset) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Asset](CIM17v40-Asset) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [Asset](CIM17v40-Asset) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [Asset](CIM17v40-Asset) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Asset](CIM17v40-Asset) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-StructureSupport}
### StructureSupport

Inheritance path = [Asset](#CIM17v40-Asset) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class StructureSupport {

+ anchorKind : enum:AnchorKind [0..1]
+ anchorRodCount : Integer [0..1]
+ anchorRodLength : Length [0..1]
+ direction : AngleDegrees [0..1]
+ kind : enum:StructureSupportKind [0..1]
+ length : Length [0..1]
+ size : String [0..1]
}

class Asset {

}

Asset <|-- StructureSupport : inherits from
class Structure {

}

StructureSupport --> "0..1" Structure : SecuredStructure
```

Support for structure assets.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| anchorKind [0..1] | [AnchorKind](#CIM17v40-AnchorKind) | (if anchor) Kind of anchor. | |
| anchorRodCount [0..1] | [Integer](#CIM17v40-Integer) | (if anchor) Number of rods used. | |
| anchorRodLength [0..1] | [Length](#CIM17v40-Length) | (if anchor) Length of rod used. | |
| direction [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Direction of this support structure. | |
| kind [0..1] | [StructureSupportKind](#CIM17v40-StructureSupportKind) | Kind of structure support. | |
| length [0..1] | [Length](#CIM17v40-Length) | Length of this support structure. | |
| size [0..1] | [String](#CIM17v40-String) | Size of this support structure. | |
| SecuredStructure [0..1] | [Structure](#CIM17v40-Structure) | The secured structure supported by this structure support. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | see [Asset](#CIM17v40-Asset) | |
| initialCondition [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | see [Asset](CIM17v40-Asset) | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | see [Asset](CIM17v40-Asset) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [Asset](CIM17v40-Asset) | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | see [Asset](CIM17v40-Asset) | |
| lotNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| position [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | see [Asset](CIM17v40-Asset) | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | see [Asset](CIM17v40-Asset) | |
| serialNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| type [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| utcNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | see [Asset](CIM17v40-Asset) | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | see [Asset](CIM17v40-Asset) | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | see [Asset](CIM17v40-Asset) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [Asset](CIM17v40-Asset) | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | see [Asset](CIM17v40-Asset) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Asset](CIM17v40-Asset) | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | see [Asset](CIM17v40-Asset) | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | see [Asset](CIM17v40-Asset) | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | see [Asset](CIM17v40-Asset) | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | see [Asset](CIM17v40-Asset) | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | see [Asset](CIM17v40-Asset) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Asset](CIM17v40-Asset) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [Asset](CIM17v40-Asset) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [Asset](CIM17v40-Asset) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Asset](CIM17v40-Asset) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SubControlArea}
### (informative) SubControlArea

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SubControlArea {

+ areaShortName : String [0..1]
+ constantCoefficient : Float [0..1]
+ embeddedControlArea : enum:YesNo [0..1]
+ internalCA : enum:YesNo [0..1]
+ linearCoefficient : Float [0..1]
+ localCA : enum:YesNo [0..1]
+ maxSelfSchedMW : Float [0..1]
+ minSelfSchedMW : Float [0..1]
+ quadraticCoefficient : Float [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- SubControlArea : inherits from
class AdjacentCASet {

}

SubControlArea --> "0..1" AdjacentCASet : AdjacentCASet
class AreaReserveSpec {

}

SubControlArea --> "1" AreaReserveSpec : AreaReserveSpecification
class HostControlArea {

}

SubControlArea --> "1" HostControlArea : HostControlArea
class RTO {

}

SubControlArea --> "1" RTO : RTO
```

An area defined for the purpose of tracking interchange with surrounding areas via tie points; may or may not serve as a control area.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| areaShortName [0..1] | [String](#CIM17v40-String) | Market area short name, which is the regulation zone. It references AGC regulation zone name. | |
| constantCoefficient [0..1] | [Float](#CIM17v40-Float) | Loss estimate constant coefficient | |
| embeddedControlArea [0..1] | [YesNo](#CIM17v40-YesNo) | Used in conjunction with the InternalCA flag. If the InternalCA flag is YES, this flag does not apply. If the InternaCA flag is NO, this flag provides an indication of AdjacentCA (NO) or Embedded CA (YES). | |
| internalCA [0..1] | [YesNo](#CIM17v40-YesNo) | A Yes/No indication that this control area is contained internal to the system. | |
| linearCoefficient [0..1] | [Float](#CIM17v40-Float) | Loss estimate linear coefficient | |
| localCA [0..1] | [YesNo](#CIM17v40-YesNo) | Indication that this control area is the local control area. | |
| maxSelfSchedMW [0..1] | [Float](#CIM17v40-Float) | Maximum amount of self schedule MWs allowed for an embedded control area. | |
| minSelfSchedMW [0..1] | [Float](#CIM17v40-Float) | Minimum amount of self schedule MW allowed for an embedded control area. | |
| quadraticCoefficient [0..1] | [Float](#CIM17v40-Float) | Loss estimate quadratic coefficient | |
| AdjacentCASet [0..1] | [AdjacentCASet](#CIM17v40-AdjacentCASet) | | |
| `AreaReserveSpecification [1]` (informative) | [AreaReserveSpec](#CIM17v40-AreaReserveSpec) | | |
| HostControlArea [1] | [HostControlArea](#CIM17v40-HostControlArea) | The interchange area may operate as a control area | |
| RTO [1] | [RTO](#CIM17v40-RTO) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SubGeographicalRegion}
### SubGeographicalRegion

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SubGeographicalRegion {

}

class IdentifiedObject {

}

IdentifiedObject <|-- SubGeographicalRegion : inherits from
class GeographicalRegion {

}

SubGeographicalRegion --> "0..1" GeographicalRegion : Region
```

A subset of a geographical region of a power system network model.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Region [0..1]` (OfAggregate) | [GeographicalRegion](#CIM17v40-GeographicalRegion) | The geographical region which this sub-geographical region is within. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SubLoadArea}
### SubLoadArea

Inheritance path = [EnergyArea](#CIM17v40-EnergyArea) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SubLoadArea {

}

class EnergyArea {

}

EnergyArea <|-- SubLoadArea : inherits from
class LoadArea {

}

SubLoadArea --> "1" LoadArea : LoadArea
```

The class is the second level in a hierarchical structure for grouping of loads for the purpose of load flow load scaling.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `LoadArea [1]` (OfAggregate) | [LoadArea](#CIM17v40-LoadArea) | The LoadArea where the SubLoadArea belongs. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ControlArea [0..1] | [ControlArea](#CIM17v40-ControlArea) | see [EnergyArea](CIM17v40-EnergyArea) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Subcritical}
### Subcritical

Inheritance path = [FossilSteamSupply](#CIM17v40-FossilSteamSupply) => [SteamSupply](#CIM17v40-SteamSupply) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Subcritical {

}

class FossilSteamSupply {

}

FossilSteamSupply <|-- Subcritical : inherits from
```

Once-through subcritical boiler.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| auxPowerVersusFrequency [0..1] | [PU](#CIM17v40-PU) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| auxPowerVersusVoltage [0..1] | [PU](#CIM17v40-PU) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| boilerControlMode [0..1] | [BoilerControlMode](#CIM17v40-BoilerControlMode) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| controlErrorBiasP [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| controlIC [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| controlPC [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| controlPEB [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| controlPED [0..1] | [PU](#CIM17v40-PU) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| controlTC [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| feedWaterIG [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| feedWaterPG [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| feedWaterTC [0..1] | [Seconds](#CIM17v40-Seconds) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| fuelDemandLimit [0..1] | [PU](#CIM17v40-PU) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| fuelSupplyDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| fuelSupplyTC [0..1] | [Seconds](#CIM17v40-Seconds) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| maxErrorRateP [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| mechPowerSensorLag [0..1] | [Seconds](#CIM17v40-Seconds) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| minErrorRateP [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| pressureCtrlDG [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| pressureCtrlIG [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| pressureCtrlPG [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| pressureFeedback [0..1] | [Integer](#CIM17v40-Integer) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| superHeater1Capacity [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| superHeater2Capacity [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| superHeaterPipePD [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| throttlePressureSP [0..1] | [PU](#CIM17v40-PU) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| steamSupplyRating [0..1] | [Float](#CIM17v40-Float) | see [SteamSupply](#CIM17v40-SteamSupply) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SubscribePowerCurve}
### SubscribePowerCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SubscribePowerCurve {

}

class Curve {

}

Curve <|-- SubscribePowerCurve : inherits from
```

Price curve for specifying the cost of energy (X) at points in time (y1) according to a prcing structure, which is based on a tariff.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Substation}
### Substation

Inheritance path = [EquipmentContainer](#CIM17v40-EquipmentContainer) => [ConnectivityNodeContainer](#CIM17v40-ConnectivityNodeContainer) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Substation {

}

class EquipmentContainer {

}

EquipmentContainer <|-- Substation : inherits from
class Feeder {

}

Substation --> "0..1" Feeder : NamingFeeder
class SubGeographicalRegion {

}

Substation --> "0..1" SubGeographicalRegion : Region
```

A collection of equipment for purposes other than generation or utilization, through which electric energy in bulk is passed for the purposes of switching or modifying its characteristics.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `NamingFeeder [0..1]` (OfAggregate) | [Feeder](#CIM17v40-Feeder) | The primary feeder that normally energizes the secondary substation. Used for naming purposes. Either this association or the substation to subgeographical region should be used for hierarchical containment specification. | |
| `Region [0..1]` (OfAggregate) | [SubGeographicalRegion](#CIM17v40-SubGeographicalRegion) | The SubGeographicalRegion containing the substation. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SubstitutionResourceList}
### SubstitutionResourceList


```mermaid
classDiagram
direction TB

class SubstitutionResourceList {

+ precedence : Integer [0..1]
}

class RegisteredResource {

}

SubstitutionResourceList --> "0..1" RegisteredResource : RegisteredResource
class ContractRight {

}

SubstitutionResourceList --> "0..1" ContractRight : TransmissionContractRight
```

List of resources that can be substituted for within the bounds of a Contract definition. This class has a precedence and a resource.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| precedence [0..1] | [Integer](#CIM17v40-Integer) | An indicator of the order a resource should be substituted. The lower the number the higher the precedence. | |
| RegisteredResource [0..1] | [RegisteredResource](#CIM17v40-RegisteredResource) | | |
| TransmissionContractRight [0..1] | [ContractRight](#CIM17v40-ContractRight) | | |

{#CIM17v40-Supercritical}
### Supercritical

Inheritance path = [FossilSteamSupply](#CIM17v40-FossilSteamSupply) => [SteamSupply](#CIM17v40-SteamSupply) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Supercritical {

}

class FossilSteamSupply {

}

FossilSteamSupply <|-- Supercritical : inherits from
```

Once-through supercritical boiler.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| auxPowerVersusFrequency [0..1] | [PU](#CIM17v40-PU) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| auxPowerVersusVoltage [0..1] | [PU](#CIM17v40-PU) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| boilerControlMode [0..1] | [BoilerControlMode](#CIM17v40-BoilerControlMode) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| controlErrorBiasP [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| controlIC [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| controlPC [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| controlPEB [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| controlPED [0..1] | [PU](#CIM17v40-PU) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| controlTC [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| feedWaterIG [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| feedWaterPG [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| feedWaterTC [0..1] | [Seconds](#CIM17v40-Seconds) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| fuelDemandLimit [0..1] | [PU](#CIM17v40-PU) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| fuelSupplyDelay [0..1] | [Seconds](#CIM17v40-Seconds) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| fuelSupplyTC [0..1] | [Seconds](#CIM17v40-Seconds) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| maxErrorRateP [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| mechPowerSensorLag [0..1] | [Seconds](#CIM17v40-Seconds) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| minErrorRateP [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| pressureCtrlDG [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| pressureCtrlIG [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| pressureCtrlPG [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| pressureFeedback [0..1] | [Integer](#CIM17v40-Integer) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| superHeater1Capacity [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| superHeater2Capacity [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| superHeaterPipePD [0..1] | [Float](#CIM17v40-Float) | see [FossilSteamSupply](#CIM17v40-FossilSteamSupply) | |
| throttlePressureSP [0..1] | [PU](#CIM17v40-PU) | see [FossilSteamSupply](CIM17v40-FossilSteamSupply) | |
| steamSupplyRating [0..1] | [Float](#CIM17v40-Float) | see [SteamSupply](#CIM17v40-SteamSupply) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SurgeArrester}
### SurgeArrester

Inheritance path = [AuxiliaryEquipment](#CIM17v40-AuxiliaryEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SurgeArrester {

}

class AuxiliaryEquipment {

}

AuxiliaryEquipment <|-- SurgeArrester : inherits from
```

Shunt device, installed on the network, usually in the proximity of electrical equipment in order to protect the said equipment against transient voltage transients caused by lightning or switching activity.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Terminal [1] | [Terminal](#CIM17v40-Terminal) | see [AuxiliaryEquipment](CIM17v40-AuxiliaryEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SurgeArresterInfo}
### SurgeArresterInfo

Inheritance path = [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SurgeArresterInfo {

+ continuousOperatingVoltage : Voltage [0..1]
+ isPolymer : Boolean [0..1]
+ lightningImpulseDischargeVoltage : Voltage [0..1]
+ lineDischargeClass : Integer [0..1]
+ nominalDischargeCurrent : CurrentFlow [0..1]
+ pressureReliefClass : CurrentFlow [0..1]
+ ratedVoltage : Voltage [0..1]
+ steepFrontDischargeVoltage : Voltage [0..1]
+ switchingImpulseDischargeVoltage : Voltage [0..1]
}

class AssetInfo {

}

AssetInfo <|-- SurgeArresterInfo : inherits from
```

Properties of surge arrester.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| continuousOperatingVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Maximum continuous power frequency voltage allowed on the surge arrester. | |
| isPolymer [0..1] | [Boolean](#CIM17v40-Boolean) | If true, the arrester has a polymer housing, porcelain otherwise. | |
| lightningImpulseDischargeVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Residual voltage during an 8x20 microsecond current impulse at the nominal discharge current level. | |
| lineDischargeClass [0..1] | [Integer](#CIM17v40-Integer) | Determines the arrester energy discharge capability. Choices are limited to 0 (none) through 5 (highest) by IEC 60099. Classes 1..3 require a 10-kA nominal discharge current. Classes 4..5 require a 20-kA nominal discharge current. Lower nominal discharge currents must use class 0. | |
| nominalDischargeCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | The lightning discharge current used to classify the arrester. Choices are limited to 1.5, 2.5, 5, 10, and 20 kA by IEC 60099. | |
| pressureReliefClass [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Fault current level at which all parts of the failed arrester lie within a circle prescribed by IEC 60099. | |
| ratedVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | The temporary overvoltage (TOV) level at power frequency that the surge arrester withstands for 10 seconds. | |
| steepFrontDischargeVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Residual voltage during a current impulse with front time of 1 microsecond, and magnitude equal to the nominal discharge current level. | |
| switchingImpulseDischargeVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Residual voltage during a current impulse with front time of at least 30 microseconds, and magnitude specified in IEC 60099 for the line discharge class. Does not apply to line discharge class 0. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SvInjection}
### SvInjection

Inheritance path = [StateVariable](#CIM17v40-StateVariable)

```mermaid
classDiagram
direction TB

class SvInjection {

+ phase : enum:SinglePhaseKind [0..1]
+ pInjection : ActivePower [0..1]
+ qInjection : ReactivePower [0..1]
}

class StateVariable {

}

StateVariable <|-- SvInjection : inherits from
class TopologicalNode {

}

SvInjection --> "1" TopologicalNode : TopologicalNode
```

The SvInjection reports the calculated bus injection minus the sum of the terminal flows. The terminal flow is positive out from the bus (load sign convention) and bus injection has positive flow into the bus. SvInjection may have the remainder after state estimation or slack after power flow calculation.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| phase [0..1] | [SinglePhaseKind](#CIM17v40-SinglePhaseKind) | The terminal phase at which the connection is applied. If missing, the injection is assumed to be balanced among non-neutral phases. | |
| pInjection [0..1] | [ActivePower](#CIM17v40-ActivePower) | The active power mismatch between calculated injection and initial injection. Positive sign means injection into the TopologicalNode (bus). | |
| qInjection [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | The reactive power mismatch between calculated injection and initial injection. Positive sign means injection into the TopologicalNode (bus). | |
| TopologicalNode [1] | [TopologicalNode](#CIM17v40-TopologicalNode) | The topological node associated with the flow injection state variable. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|

{#CIM17v40-SvPowerFlow}
### SvPowerFlow

Inheritance path = [StateVariable](#CIM17v40-StateVariable)

```mermaid
classDiagram
direction TB

class SvPowerFlow {

+ p : ActivePower [0..1]
+ phase : enum:SinglePhaseKind [0..1]
+ q : ReactivePower [0..1]
}

class StateVariable {

}

StateVariable <|-- SvPowerFlow : inherits from
class Terminal {

}

SvPowerFlow --> "1" Terminal : Terminal
```

State variable for power flow. Load convention is used for flow direction. This means flow out from the TopologicalNode into the equipment is positive.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| p [0..1] | [ActivePower](#CIM17v40-ActivePower) | The active power flow. Load sign convention is used, i.e. positive sign means flow out from a TopologicalNode (bus) into the conducting equipment. | |
| phase [0..1] | [SinglePhaseKind](#CIM17v40-SinglePhaseKind) | The individual phase of the flow. If unspecified, then assumed to be balanced among phases. | |
| q [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | The reactive power flow. Load sign convention is used, i.e. positive sign means flow out from a TopologicalNode (bus) into the conducting equipment. | |
| Terminal [1] | [Terminal](#CIM17v40-Terminal) | The terminal associated with the power flow state variable. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|

{#CIM17v40-SvShuntCompensatorSections}
### SvShuntCompensatorSections

Inheritance path = [StateVariable](#CIM17v40-StateVariable)

```mermaid
classDiagram
direction TB

class SvShuntCompensatorSections {

+ phase : enum:SinglePhaseKind [0..1]
+ sections : Float [0..1]
}

class StateVariable {

}

StateVariable <|-- SvShuntCompensatorSections : inherits from
class ShuntCompensator {

}

SvShuntCompensatorSections --> "1" ShuntCompensator : ShuntCompensator
```

State variable for the number of sections in service for a shunt compensator.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| phase [0..1] | [SinglePhaseKind](#CIM17v40-SinglePhaseKind) | The terminal phase at which the connection is applied. If missing, the injection is assumed to be balanced among non-neutral phases. | |
| sections [0..1] | [Float](#CIM17v40-Float) | The number of sections in service as a continuous variable. The attribute shall be a positive value or zero. To get integer value scale with ShuntCompensator.bPerSection. | |
| ShuntCompensator [1] | [ShuntCompensator](#CIM17v40-ShuntCompensator) | The shunt compensator for which the state applies. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|

{#CIM17v40-SvStatus}
### SvStatus

Inheritance path = [StateVariable](#CIM17v40-StateVariable)

```mermaid
classDiagram
direction TB

class SvStatus {

+ inService : Boolean [0..1]
+ phase : enum:SinglePhaseKind [0..1]
}

class StateVariable {

}

StateVariable <|-- SvStatus : inherits from
class ConductingEquipment {

}

SvStatus --> "1" ConductingEquipment : ConductingEquipment
```

State variable for status.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | The in service status as a result of topology processing. It indicates if the equipment is considered as energized by the power flow. It reflects if the equipment is connected within a solvable island. It does not necessarily reflect whether or not the island was solved by the power flow. | |
| phase [0..1] | [SinglePhaseKind](#CIM17v40-SinglePhaseKind) | The individual phase status. If the attribute is unspecified, then three phase model is assumed. | |
| ConductingEquipment [1] | [ConductingEquipment](#CIM17v40-ConductingEquipment) | The conducting equipment associated with the status state variable. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|

{#CIM17v40-SvSwitch}
### SvSwitch

Inheritance path = [StateVariable](#CIM17v40-StateVariable)

```mermaid
classDiagram
direction TB

class SvSwitch {

+ open : Boolean [0..1]
+ phase : enum:SinglePhaseKind [0..1]
}

class StateVariable {

}

StateVariable <|-- SvSwitch : inherits from
class Switch {

}

SvSwitch --> "1" Switch : Switch
```

State variable for switch.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| open [0..1] | [Boolean](#CIM17v40-Boolean) | The attribute tells if the computed state of the switch is considered open. | |
| phase [0..1] | [SinglePhaseKind](#CIM17v40-SinglePhaseKind) | The terminal phase at which the connection is applied. If missing, the injection is assumed to be balanced among non-neutral phases. | |
| Switch [1] | [Switch](#CIM17v40-Switch) | The switch associated with the switch state. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|

{#CIM17v40-SvTapStep}
### SvTapStep

Inheritance path = [StateVariable](#CIM17v40-StateVariable)

```mermaid
classDiagram
direction TB

class SvTapStep {

+ position : Float [0..1]
}

class StateVariable {

}

StateVariable <|-- SvTapStep : inherits from
class TapChanger {

}

SvTapStep --> "1" TapChanger : TapChanger
```

State variable for transformer tap step.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| position [0..1] | [Float](#CIM17v40-Float) | The floating point tap position. This is not the tap ratio, but rather the tap step position as defined by the related tap changer model and normally is constrained to be within the range of minimum and maximum tap positions. | |
| TapChanger [1] | [TapChanger](#CIM17v40-TapChanger) | The tap changer associated with the tap step state. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|

{#CIM17v40-SvVoltage}
### SvVoltage

Inheritance path = [StateVariable](#CIM17v40-StateVariable)

```mermaid
classDiagram
direction TB

class SvVoltage {

+ angle : AngleDegrees [0..1]
+ phase : enum:SinglePhaseKind [0..1]
+ v : Voltage [0..1]
}

class StateVariable {

}

StateVariable <|-- SvVoltage : inherits from
class TopologicalNode {

}

SvVoltage --> "1" TopologicalNode : TopologicalNode
```

State variable for voltage.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| angle [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | The voltage angle of the topological node complex voltage with respect to system reference. | |
| phase [0..1] | [SinglePhaseKind](#CIM17v40-SinglePhaseKind) | If specified the voltage is the line to ground voltage of the individual phase. If unspecified, then the voltage is assumed balanced. | |
| v [0..1] | [Voltage](#CIM17v40-Voltage) | The voltage magnitude at the topological node. The attribute shall be a positive value. | |
| TopologicalNode [1] | [TopologicalNode](#CIM17v40-TopologicalNode) | The topological node associated with the voltage state. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|

{#CIM17v40-Switch}
### Switch

Inheritance path = [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Switch {

+ locked : Boolean [0..1]
+ normalOpen : Boolean [0..1]
+ open : Boolean [0..1]
+ ratedCurrent : CurrentFlow [0..1]
+ retained : Boolean [0..1]
+ switchOnCount : Integer [0..1]
+ switchOnDate : DateTime [0..1]
}

class ConductingEquipment {

}

ConductingEquipment <|-- Switch : inherits from
class CompositeSwitch {

}

Switch --> "0..1" CompositeSwitch : CompositeSwitch
class SwitchAction {

}

Switch --> "0..1" SwitchAction : SwitchAction
```

A generic device designed to close, or open, or both, one or more electric circuits. All switches are two terminal devices including grounding switches. The ACDCTerminal.connected at the two sides of the switch shall not be considered for assessing switch connectivity, i.e. only Switch.open, .normalOpen and .locked are relevant.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| locked [0..1] | [Boolean](#CIM17v40-Boolean) | If true, the switch is locked. The resulting switch state is a combination of locked and Switch.open attributes as follows:<ul> <li>locked=true and Switch.open=true. The resulting state is open and locked;</li> <li>locked=false and Switch.open=true. The resulting state is open;</li> <li>locked=false and Switch.open=false. The resulting state is closed.</li></ul> | |
| normalOpen [0..1] | [Boolean](#CIM17v40-Boolean) | The attribute is used in cases when no Measurement for the status value is present. If the Switch has a status measurement the Discrete.normalValue is expected to match with the Switch.normalOpen. | |
| open [0..1] | [Boolean](#CIM17v40-Boolean) | The attribute tells if the switch is considered open when used as input to topology processing. | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | The maximum continuous current carrying capacity in amps governed by the device material and construction.The attribute shall be a positive value. | |
| retained [0..1] | [Boolean](#CIM17v40-Boolean) | Branch is retained in the topological solution. The flow through retained switches will normally be calculated in power flow. | |
| `switchOnCount [0..1]` (deprecated) | [Integer](#CIM17v40-Integer) | The switch on count since the switch was last reset or initialized. | |
| `switchOnDate [0..1]` (deprecated) | [DateTime](#CIM17v40-DateTime) | The date and time when the switch was last switched on. | |
| `CompositeSwitch [0..1]` (OfAggregate) | [CompositeSwitch](#CIM17v40-CompositeSwitch) | Composite switch to which this Switch belongs. | |
| SwitchAction [0..1] | [SwitchAction](#CIM17v40-SwitchAction) | Action changing status of this switch. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SwitchAction}
### SwitchAction

Inheritance path = [SwitchingAction](#CIM17v40-SwitchingAction) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SwitchAction {

+ kind : enum:SwitchActionKind [0..1]
}

class SwitchingAction {

}

SwitchingAction <|-- SwitchAction : inherits from
class Switch {

}

SwitchAction --> "0..1" Switch : OperatedSwitch
class Outage {

}

SwitchAction --> "0..1" Outage : PlannedOutage
```

Action on switch as a switching step.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [SwitchActionKind](#CIM17v40-SwitchActionKind) | Switching action to perform. | |
| OperatedSwitch [0..1] | [Switch](#CIM17v40-Switch) | Switch that is the object of this switch action. | |
| PlannedOutage [0..1] | [Outage](#CIM17v40-Outage) | Planned outage for whose scope this switch action applies. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| executedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| issuedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| plannedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| Operator [0..1] | [Operator](#CIM17v40-Operator) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingEvent [0..1] | [SwitchingEvent](#CIM17v40-SwitchingEvent) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingStep [0..1] | [SwitchingStep](#CIM17v40-SwitchingStep) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SwitchInfo}
### SwitchInfo

Inheritance path = [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SwitchInfo {

+ breakingCapacity : CurrentFlow [0..1]
+ gasWeightPerTank : Mass [0..1]
+ isSinglePhase : Boolean [0..1]
+ isUnganged : Boolean [0..1]
+ lowPressureAlarm : Pressure [0..1]
+ lowPressureLockOut : Pressure [0..1]
+ oilVolumePerTank : Volume [0..1]
+ ratedCurrent : CurrentFlow [0..1]
+ ratedFrequency : Frequency [0..1]
+ ratedImpulseWithstandVoltage : Voltage [0..1]
+ ratedInterruptingTime : Seconds [0..1]
+ ratedVoltage : Voltage [0..1]
}

class AssetInfo {

}

AssetInfo <|-- SwitchInfo : inherits from
```

<was Switch data.>

Switch datasheet information.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| breakingCapacity [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | The maximum fault current a breaking device can break safely under prescribed conditions of use. | |
| gasWeightPerTank [0..1] | [Mass](#CIM17v40-Mass) | Weight of gas in each tank of SF6 dead tank breaker. | |
| isSinglePhase [0..1] | [Boolean](#CIM17v40-Boolean) | If true, it is a single phase switch. | |
| isUnganged [0..1] | [Boolean](#CIM17v40-Boolean) | If true, the switch is not ganged (i.e., a switch phase may be operated separately from other phases). | |
| lowPressureAlarm [0..1] | [Pressure](#CIM17v40-Pressure) | Gas or air pressure at or below which a low pressure alarm is generated. | |
| lowPressureLockOut [0..1] | [Pressure](#CIM17v40-Pressure) | Gas or air pressure below which the breaker will not open. | |
| oilVolumePerTank [0..1] | [Volume](#CIM17v40-Volume) | Volume of oil in each tank of bulk oil breaker. | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Rated current. | |
| ratedFrequency [0..1] | [Frequency](#CIM17v40-Frequency) | Frequency for which switch is rated. | |
| ratedImpulseWithstandVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Rated impulse withstand voltage, also known as BIL (Basic Impulse Level). | |
| ratedInterruptingTime [0..1] | [Seconds](#CIM17v40-Seconds) | Switch rated interrupting time in seconds. | |
| ratedVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Rated voltage. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SwitchOperationSummary}
### SwitchOperationSummary

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SwitchOperationSummary {

+ lifetimeFaultOperations : Integer [0..1]
+ lifetimeMotorStarts : Integer [0..1]
+ lifetimeTotalOperations : Integer [0..1]
+ mostRecentFaultOperationDate : Date [0..1]
+ mostRecentMotorStartDate : Date [0..1]
+ mostRecentOperationDate : Date [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- SwitchOperationSummary : inherits from
class Asset {

}

SwitchOperationSummary --> "1" Asset : Breaker
```

Up-to-date, of-record summary of switch operation information, distilled from a variety of sources (real-time data or real-time data historian, field inspections, etc.) of use to asset health analytics.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| lifetimeFaultOperations [0..1] | [Integer](#CIM17v40-Integer) | Total breaker fault operations to date. | |
| lifetimeMotorStarts [0..1] | [Integer](#CIM17v40-Integer) | Total motor starts to date. | |
| lifetimeTotalOperations [0..1] | [Integer](#CIM17v40-Integer) | Total breaker operations to date (including fault and non-fault). | |
| mostRecentFaultOperationDate [0..1] | [Date](#CIM17v40-Date) | Date of most recent breaker fault operation. | |
| mostRecentMotorStartDate [0..1] | [Date](#CIM17v40-Date) | Date of most recent motor start. | |
| mostRecentOperationDate [0..1] | [Date](#CIM17v40-Date) | Date of most recent breaker operation (fault or non-fault). | |
| Breaker [1] | [Asset](#CIM17v40-Asset) | Breaker asset to which this operation information applies. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SwitchPhase}
### SwitchPhase

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SwitchPhase {

+ closed : Boolean [0..1]
+ normalOpen : Boolean [0..1]
+ phaseSide1 : enum:SinglePhaseKind [0..1]
+ phaseSide2 : enum:SinglePhaseKind [0..1]
+ ratedCurrent : CurrentFlow [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- SwitchPhase : inherits from
class Switch {

}

SwitchPhase --> "1" Switch : Switch
```

Single phase of a multi-phase switch when its attributes might be different per phase.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| closed [0..1] | [Boolean](#CIM17v40-Boolean) | The attribute tells if the switch is considered closed when used as input to topology processing. | |
| normalOpen [0..1] | [Boolean](#CIM17v40-Boolean) | Used in cases when no Measurement for the status value is present. If the SwitchPhase has a status measurement the Discrete.normalValue is expected to match with this value. | |
| phaseSide1 [0..1] | [SinglePhaseKind](#CIM17v40-SinglePhaseKind) | Phase of this SwitchPhase on the side with terminal sequence number equal to 1. Should be a phase contained in that terminal�s phases attribute. | |
| phaseSide2 [0..1] | [SinglePhaseKind](#CIM17v40-SinglePhaseKind) | Phase of this SwitchPhase on the side with terminal sequence number equal to 2. Should be a phase contained in that terminal�s Terminal.phases attribute. | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | The maximum continuous current carrying capacity in amps governed by the device material and construction.The attribute shall be a positive value. | |
| Switch [1] | [Switch](#CIM17v40-Switch) | The switch of the switch phase. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SwitchSchedule}
### SwitchSchedule

Inheritance path = [SeasonDayTypeSchedule](#CIM17v40-SeasonDayTypeSchedule) => [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) => [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SwitchSchedule {

}

class SeasonDayTypeSchedule {

}

SeasonDayTypeSchedule <|-- SwitchSchedule : inherits from
class Switch {

}

SwitchSchedule --> "1" Switch : Switch
```

A schedule of switch positions. If RegularTimePoint.value1 is 0, the switch is open. If 1, the switch is closed.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Switch [1] | [Switch](#CIM17v40-Switch) | A SwitchSchedule is associated with a Switch. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DayType [0..1] | [DayType](#CIM17v40-DayType) | see [SeasonDayTypeSchedule](CIM17v40-SeasonDayTypeSchedule) | |
| Season [0..1] | [Season](#CIM17v40-Season) | see [SeasonDayTypeSchedule](CIM17v40-SeasonDayTypeSchedule) | |
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | see [RegularIntervalSchedule](CIM17v40-RegularIntervalSchedule) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SwitchStatus}
### SwitchStatus


```mermaid
classDiagram
direction TB

class SwitchStatus {

+ switchStatus : enum:SwitchStatusType [0..1]
}

class MktSwitch {

}

SwitchStatus --> "1" MktSwitch : MktSwitch
```

Optimal Power Flow or State Estimator Circuit Breaker Status.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| switchStatus [0..1] | [SwitchStatusType](#CIM17v40-SwitchStatusType) | Circuit Breaker Status (closed or open) of the circuit breaker from the power flow. | |
| MktSwitch [1] | [MktSwitch](#CIM17v40-MktSwitch) | | |

{#CIM17v40-SwitchingAction}
### SwitchingAction

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SwitchingAction {

+ executedDateTime : DateTime [0..1]
+ issuedDateTime : DateTime [0..1]
+ phases : enum:PhaseCode [0..1]
+ plannedDateTime : DateTime [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- SwitchingAction : inherits from
class Operator {

}

SwitchingAction --> "0..1" Operator : Operator
class SwitchingEvent {

}

SwitchingAction --> "0..1" SwitchingEvent : SwitchingEvent
class SwitchingPlan {

}

SwitchingAction --> "0..1" SwitchingPlan : SwitchingPlan
class SwitchingStep {

}

SwitchingAction --> "0..1" SwitchingStep : SwitchingStep
```

Atomic switching action.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| executedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Actual date and time of this switching step. | |
| issuedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time when the crew was given the instruction to execute the action; not applicable if the action is performed by operator remote control. | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | Phases of the Switching Action | |
| plannedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Planned date and time of this switching step. | |
| Operator [0..1] | [Operator](#CIM17v40-Operator) | Operator responsible for this switching step. | |
| SwitchingEvent [0..1] | [SwitchingEvent](#CIM17v40-SwitchingEvent) | The switching event that the switching action is performed on | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | The switching plan that is associated with the switching actions. | |
| SwitchingStep [0..1] | [SwitchingStep](#CIM17v40-SwitchingStep) | The switching step that is associated to the switching action. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SwitchingEvent}
### SwitchingEvent

Inheritance path = [ActivityRecord](#CIM17v40-ActivityRecord) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SwitchingEvent {

}

class ActivityRecord {

}

ActivityRecord <|-- SwitchingEvent : inherits from
class SwitchingAction {

}

SwitchingEvent --> "1" SwitchingAction : SwitchingAction
```

Event indicating the completion (success or fail) of any switching action (jumper action, cut action, tag action, etc). The switching action may or may not be a consequential event in response to a request to complete the action.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| SwitchingAction [1] | [SwitchingAction](#CIM17v40-SwitchingAction) | The switching action that is performed on the switching event | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| reason [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| severity [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| type [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| Document [0..1] | [Document](#CIM17v40-Document) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SwitchingOrder}
### SwitchingOrder

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SwitchingOrder {

+ comment : String [0..1]
+ plannedExecutionInterval : DateTimeInterval [0..1]
}

class Document {

}

Document <|-- SwitchingOrder : inherits from
class SwitchingPlan {

}

SwitchingOrder --> "0..1" SwitchingPlan : SwitchingPlan
```

Transmits a switching plan to a crew in order for the plan to be executed.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| comment [0..1] | [String](#CIM17v40-String) | Free-form comment associated with the switching order. | |
| plannedExecutionInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | The planned start and end time for the switching order. | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | The switching plan that is defined in the switching order. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SwitchingPlan}
### SwitchingPlan

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SwitchingPlan {

+ approvedDateTime : DateTime [0..1]
+ cancelledDateTime : DateTime [0..1]
+ purpose : String [0..1]
+ rank : Integer [0..1]
+ plannedPeriod : DateTimeInterval [0..1]
}

class Document {

}

Document <|-- SwitchingPlan : inherits from
class Outage {

}

SwitchingPlan --> "0..1" Outage : Outage
class OutagePlan {

}

SwitchingPlan --> "0..1" OutagePlan : OutagePlan
class PlannedOutageNotification {

}

SwitchingPlan --> "0..1" PlannedOutageNotification : PlannedOutageNotification
class SwitchingOrder {

}

SwitchingPlan --> "0..1" SwitchingOrder : SwitchingOrder
class SwitchingPlanRequest {

}

SwitchingPlan --> "0..1" SwitchingPlanRequest : SwitchingPlanRequest
```

A sequence of grouped or atomic steps intended to:

- de-energise equipment or part of the network for safe work, and/or

- bring back in service previously de-energised equipment or part of the network.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| approvedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | The date and time the switching plan was approved | |
| cancelledDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and Time the switching plan was cancelled. | |
| purpose [0..1] | [String](#CIM17v40-String) | Purpose of this plan, such as whether it is to move the state from normal to some abnormal condition, or to restore the normal state after an abnormal condition, or to perform some kind of optimisation such as correction of overload, voltage control, etc. | |
| rank [0..1] | [Integer](#CIM17v40-Integer) | Ranking in comparison to other switching plans. | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | Outage that will be activated or eliminated when this switching plan gets executed. | |
| OutagePlan [0..1] | [OutagePlan](#CIM17v40-OutagePlan) | The outage plan for which the switching plan is defined. | |
| PlannedOutageNotification [0..1] | [PlannedOutageNotification](#CIM17v40-PlannedOutageNotification) | The planned outage notification that is associated to the switching plan. | |
| plannedPeriod [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | the planned start and end times for the switching plan. | |
| SwitchingOrder [0..1] | [SwitchingOrder](#CIM17v40-SwitchingOrder) | The switching order that specified the switching plan to be implemented. | |
| SwitchingPlanRequest [0..1] | [SwitchingPlanRequest](#CIM17v40-SwitchingPlanRequest) | The request for the specified switching plan. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SwitchingPlanRequest}
### SwitchingPlanRequest

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SwitchingPlanRequest {

+ comment : String [0..1]
+ equipmentToBeIsolated : String [0..1]
+ groundingPoints : String [0..1]
+ isolationArea : String [0..1]
+ isolationPoints : String [0..1]
+ purpose : String [0..1]
+ switchingRequestDetails : String [0..1]
+ forwardSwitchingDateTimeInterval : DateTimeInterval [1]
+ outageDateTimeInterval : DateTimeInterval [0..1]
+ reverseSwitchingDateTimeInterval : DateTimeInterval [1]
}

class Document {

}

Document <|-- SwitchingPlanRequest : inherits from
class Organisation {

}

SwitchingPlanRequest --> "0..1" Organisation : RequestingOrganization
```

A document used to request that a switching plan be created for a particular purpose.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| comment [0..1] | [String](#CIM17v40-String) | Free-form text to describe the request | |
| equipmentToBeIsolated [0..1] | [String](#CIM17v40-String) | free-form list of the equipment to be isolated by the switching | |
| groundingPoints [0..1] | [String](#CIM17v40-String) | free-form list of equipment to be grounded or other actions to be taken in order to accomplish the required grounding. | |
| isolationArea [0..1] | [String](#CIM17v40-String) | free-form description of the area to be isolated by the switching | |
| isolationPoints [0..1] | [String](#CIM17v40-String) | free-form list of equipment to be operated or other actions to be taken in order to accomplish the required isolation. | |
| purpose [0..1] | [String](#CIM17v40-String) | The purpose of this switching plan request. | |
| switchingRequestDetails [0..1] | [String](#CIM17v40-String) | The details of this switching plan request. | |
| forwardSwitchingDateTimeInterval [1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | The date when the switching to isolate equipment is performed. | |
| outageDateTimeInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | The window of time during which one or more customers will be de-energized during execution of the switching plan. | |
| RequestingOrganization [0..1] | [Organisation](#CIM17v40-Organisation) | The organization that requested the switching plan. | |
| reverseSwitchingDateTimeInterval [1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | The date when the switching to energize equipment is performed. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SwitchingStep}
### SwitchingStep


```mermaid
classDiagram
direction TB

class SwitchingStep {

+ isFreeSequence : Boolean [0..1]
+ sequenceNumber : Integer [0..1]
+ subStepSequenceNumber : Integer [0..1]
}

class RevisionHistory {

}

SwitchingStep --> "1" RevisionHistory : RevisionHistory
class SwitchingAction {

}

SwitchingStep --> "1" SwitchingAction : SwitchingAction
class SwitchingStepGroup {

}

SwitchingStep --> "0..1" SwitchingStepGroup : SwitchingStepGroup
```

Atomic switching step; can be part of a switching step group, or part of a switching plan.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| isFreeSequence [0..1] | [Boolean](#CIM17v40-Boolean) | For a step, if isFreeSequence is set to false or is not specified, all of the steps in the group must be executed in the order defined by the sequenceNumber attribute. The sequenceNumber for a step has a different meaning when there are two or more sequential steps that have the isFreeSequence attribute set to true. Execution must still be performed in sequenceNumber order until a set of two or more steps that have isFreeSequence set to true is encountered. In this case, these steps can be executed in any sequence, until a step is encountered that has isFreeSequence set to false. All of the steps preceding this step must be executed before the step can be executed. | |
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | Order of this activity in the sequence of activities within the switching plan. | |
| subStepSequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | Supports compound switching steps that are made up of several sub steps. | |
| RevisionHistory [1] | [RevisionHistory](#CIM17v40-RevisionHistory) | | |
| SwitchingAction [1] | [SwitchingAction](#CIM17v40-SwitchingAction) | The switching action that is associated to the switching step. | |
| SwitchingStepGroup [0..1] | [SwitchingStepGroup](#CIM17v40-SwitchingStepGroup) | The switching step group that contains the switching steps. | |

{#CIM17v40-SwitchingStepGroup}
### SwitchingStepGroup


```mermaid
classDiagram
direction TB

class SwitchingStepGroup {

+ description : String [0..1]
+ isFreeSequence : Boolean [0..1]
+ purpose : String [0..1]
+ sequenceNumber : Integer [0..1]
}

class SwitchingPlan {

}

SwitchingStepGroup --> "0..1" SwitchingPlan : SwitchingPlan
```

A logical step, grouping atomic switching steps that are important to distinguish when they may change topology (e.g. placing a jumper between two cuts).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| description [0..1] | [String](#CIM17v40-String) | Descriptive information concerning the switching step group. | |
| isFreeSequence [0..1] | [Boolean](#CIM17v40-Boolean) | If true, the sequence number serves for presentation purposes only, and the activity itself may be executed at any time. | |
| purpose [0..1] | [String](#CIM17v40-String) | Describes the overall purpose of the steps in this switching step group. | |
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | Order of this activity in the sequence of activities within the switching plan. | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | Switching plan to which this group belongs. | |

{#CIM17v40-SynchrocheckRelay}
### SynchrocheckRelay

Inheritance path = [ProtectionEquipment](#CIM17v40-ProtectionEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SynchrocheckRelay {

+ maxAngleDiff : AngleRadians [0..1]
+ maxFreqDiff : Frequency [0..1]
+ maxVoltDiff : Voltage [0..1]
}

class ProtectionEquipment {

}

ProtectionEquipment <|-- SynchrocheckRelay : inherits from
```

A device that operates when two AC circuits are within the desired limits of frequency, phase angle, and voltage, to permit or to cause the paralleling of these two circuits. Used to prevent the paralleling of non-synchronous topological islands.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| maxAngleDiff [0..1] | [AngleRadians](#CIM17v40-AngleRadians) | The maximum allowable voltage vector phase angle difference across the open device. | |
| maxFreqDiff [0..1] | [Frequency](#CIM17v40-Frequency) | The maximum allowable frequency difference across the open device. | |
| maxVoltDiff [0..1] | [Voltage](#CIM17v40-Voltage) | The maximum allowable difference voltage across the open device. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| highLimit [0..1] | [Float](#CIM17v40-Float) | see [ProtectionEquipment](#CIM17v40-ProtectionEquipment) | |
| lowLimit [0..1] | [Float](#CIM17v40-Float) | see [ProtectionEquipment](#CIM17v40-ProtectionEquipment) | |
| powerDirectionFlag [0..1] | [Boolean](#CIM17v40-Boolean) | see [ProtectionEquipment](#CIM17v40-ProtectionEquipment) | |
| relayDelayTime [0..1] | [Seconds](#CIM17v40-Seconds) | see [ProtectionEquipment](CIM17v40-ProtectionEquipment) | |
| unitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [ProtectionEquipment](CIM17v40-ProtectionEquipment) | |
| unitSymbol [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [ProtectionEquipment](CIM17v40-ProtectionEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SynchronousMachine}
### SynchronousMachine

Inheritance path = [RotatingMachine](#CIM17v40-RotatingMachine) => [RegulatingCondEq](#CIM17v40-RegulatingCondEq) => [EnergyConnection](#CIM17v40-EnergyConnection) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SynchronousMachine {

+ aVRToManualLag : Seconds [0..1]
+ aVRToManualLead : Seconds [0..1]
+ baseQ : ReactivePower [0..1]
+ condenserP : ActivePower [0..1]
+ coolantCondition : Float [0..1]
+ coolantType : enum:CoolantType [0..1]
+ earthing : Boolean [0..1]
+ earthingStarPointR : Resistance [0..1]
+ earthingStarPointX : Reactance [0..1]
+ ikk : CurrentFlow [0..1]
+ manualToAVR : Seconds [0..1]
+ maxQ : ReactivePower [0..1]
+ maxU : Voltage [0..1]
+ minQ : ReactivePower [0..1]
+ minU : Voltage [0..1]
+ mu : Float [0..1]
+ operatingMode : enum:SynchronousMachineOperatingMode [0..1]
+ qPercent : PerCent [0..1]
+ r : Resistance [0..1]
+ r0 : Resistance [0..1]
+ r2 : Resistance [0..1]
+ referencePriority : Integer [0..1]
+ satDirectSubtransX : PU [0..1]
+ satDirectSyncX : PU [0..1]
+ satDirectTransX : PU [0..1]
+ shortCircuitRotorType : enum:ShortCircuitRotorKind [0..1]
+ type : enum:SynchronousMachineKind [0..1]
+ voltageRegulationRange : PerCent [0..1]
+ x0 : Reactance [0..1]
+ x2 : Reactance [0..1]
}

class RotatingMachine {

}

RotatingMachine <|-- SynchronousMachine : inherits from
class ReactiveCapabilityCurve {

}

SynchronousMachine --> "0..1" ReactiveCapabilityCurve : InitialReactiveCapabilityCurve
class SynchronousMachineDynamics {

}

SynchronousMachine --> "0..1" SynchronousMachineDynamics : SynchronousMachineDynamics
```

An electromechanical device that operates with shaft rotating synchronously with the network. It is a single machine operating either as a generator or synchronous condenser or pump.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aVRToManualLag [0..1] | [Seconds](#CIM17v40-Seconds) | Time delay required when switching from Automatic Voltage Regulation (AVR) to Manual for a lagging MVAr violation. | |
| aVRToManualLead [0..1] | [Seconds](#CIM17v40-Seconds) | Time delay required when switching from Automatic Voltage Regulation (AVR) to Manual for a leading MVAr violation. | |
| baseQ [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Default base reactive power value. This value represents the initial reactive power that can be used by any application function. | |
| condenserP [0..1] | [ActivePower](#CIM17v40-ActivePower) | Active power consumed when in condenser mode operation. | |
| coolantCondition [0..1] | [Float](#CIM17v40-Float) | Temperature or pressure of coolant medium. | |
| coolantType [0..1] | [CoolantType](#CIM17v40-CoolantType) | Method of cooling the machine. | |
| earthing [0..1] | [Boolean](#CIM17v40-Boolean) | Indicates whether or not the generator is earthed. Used for short circuit data exchange according to IEC 60909. | |
| earthingStarPointR [0..1] | [Resistance](#CIM17v40-Resistance) | Generator star point earthing resistance (Re). Used for short circuit data exchange according to IEC 60909. | |
| earthingStarPointX [0..1] | [Reactance](#CIM17v40-Reactance) | Generator star point earthing reactance (Xe). Used for short circuit data exchange according to IEC 60909. | |
| ikk [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Steady-state short-circuit current (in A for the profile) of generator with compound excitation during 3-phase short circuit.- Ikk=0: Generator with no compound excitation.- Ikk&lt;&gt;0: Generator with compound excitation.Ikk is used to calculate the minimum steady-state short-circuit current for generators with compound excitation.(4.6.1.2 in IEC 60909-0:2001).Used only for single fed short circuit on a generator. (4.3.4.2. in IEC 60909-0:2001). | |
| manualToAVR [0..1] | [Seconds](#CIM17v40-Seconds) | Time delay required when switching from Manual to Automatic Voltage Regulation. This value is used in the accelerating power reference frame for powerflow solutions. | |
| maxQ [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Maximum reactive power limit. This is the maximum (nameplate) limit for the unit. | |
| maxU [0..1] | [Voltage](#CIM17v40-Voltage) | Maximum voltage limit for the unit. | |
| minQ [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Minimum reactive power limit for the unit. | |
| minU [0..1] | [Voltage](#CIM17v40-Voltage) | Minimum voltage limit for the unit. | |
| mu [0..1] | [Float](#CIM17v40-Float) | Factor to calculate the breaking current (Section 4.5.2.1 in IEC 60909-0).Used only for single fed short circuit on a generator (Section 4.3.4.2. in IEC 60909-0). | |
| operatingMode [0..1] | [SynchronousMachineOperatingMode](#CIM17v40-SynchronousMachineOperatingMode) | Current mode of operation. | |
| qPercent [0..1] | [PerCent](#CIM17v40-PerCent) | Part of the coordinated reactive control that comes from this machine. The attribute is used as a participation factor not necessarily summing up to 100% for the participating devices in the control. | |
| r [0..1] | [Resistance](#CIM17v40-Resistance) | Equivalent resistance (RG) of generator. RG is considered for the calculation of all currents, except for the calculation of the peak current ip. Used for short circuit data exchange according to IEC 60909. | |
| r0 [0..1] | [Resistance](#CIM17v40-Resistance) | Zero sequence resistance of the synchronous machine. | |
| r2 [0..1] | [Resistance](#CIM17v40-Resistance) | Negative sequence resistance. | |
| referencePriority [0..1] | [Integer](#CIM17v40-Integer) | Priority of unit for use as powerflow voltage phase angle reference bus selection. 0 = don t care (default) 1 = highest priority. 2 is less than 1 and so on. | |
| satDirectSubtransX [0..1] | [PU](#CIM17v40-PU) | Direct-axis subtransient reactance saturated, also known as Xd"sat. | |
| satDirectSyncX [0..1] | [PU](#CIM17v40-PU) | Direct-axes saturated synchronous reactance (xdsat); reciprocal of short-circuit ration. Used for short circuit data exchange, only for single fed short circuit on a generator. (4.3.4.2. in IEC 60909-0:2001). | |
| satDirectTransX [0..1] | [PU](#CIM17v40-PU) | Saturated Direct-axis transient reactance. The attribute is primarily used for short circuit calculations according to ANSI. | |
| shortCircuitRotorType [0..1] | [ShortCircuitRotorKind](#CIM17v40-ShortCircuitRotorKind) | Type of rotor, used by short circuit applications, only for single fed short circuit according to IEC 60909. | |
| type [0..1] | [SynchronousMachineKind](#CIM17v40-SynchronousMachineKind) | Modes that this synchronous machine can operate in. | |
| voltageRegulationRange [0..1] | [PerCent](#CIM17v40-PerCent) | Range of generator voltage regulation (PG in IEC 60909-0) used for calculation of the impedance correction factor KG defined in IEC 60909-0.This attribute is used to describe the operating voltage of the generating unit. | |
| x0 [0..1] | [Reactance](#CIM17v40-Reactance) | Zero sequence reactance of the synchronous machine. | |
| x2 [0..1] | [Reactance](#CIM17v40-Reactance) | Negative sequence reactance. | |
| InitialReactiveCapabilityCurve [0..1] | [ReactiveCapabilityCurve](#CIM17v40-ReactiveCapabilityCurve) | The default reactive capability curve for use by a synchronous machine. | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | Synchronous machine dynamics model used to describe dynamic behaviour of this synchronous machine. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| p [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [RotatingMachine](CIM17v40-RotatingMachine) | |
| q [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | see [RotatingMachine](CIM17v40-RotatingMachine) | |
| ratedPowerFactor [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachine](#CIM17v40-RotatingMachine) | |
| ratedS [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | see [RotatingMachine](CIM17v40-RotatingMachine) | |
| ratedU [0..1] | [Voltage](#CIM17v40-Voltage) | see [RotatingMachine](CIM17v40-RotatingMachine) | |
| GeneratingUnit [0..1] | [GeneratingUnit](#CIM17v40-GeneratingUnit) | see [RotatingMachine](CIM17v40-RotatingMachine) | |
| HydroPump [0..1] | [HydroPump](#CIM17v40-HydroPump) | see [RotatingMachine](CIM17v40-RotatingMachine) | |
| controlEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [RegulatingCondEq](#CIM17v40-RegulatingCondEq) | |
| RegulatingControl [0..1] | [RegulatingControl](#CIM17v40-RegulatingControl) | see [RegulatingCondEq](CIM17v40-RegulatingCondEq) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SynchronousMachineDetailed}
### SynchronousMachineDetailed

Inheritance path = [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) => [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SynchronousMachineDetailed {

+ efdBaseRatio : Float [0..1]
+ ifdBaseType : enum:IfdBaseKind [0..1]
+ saturationFactor120QAxis : Float [0..1]
+ saturationFactorQAxis : Float [0..1]
}

class SynchronousMachineDynamics {

}

SynchronousMachineDynamics <|-- SynchronousMachineDetailed : inherits from
```

All synchronous machine detailed types use a subset of the same data parameters and input/output variables.

The several variations differ in the following ways:

- the number of equivalent windings that are included;

- the way in which saturation is incorporated into the model;

- whether or not �subtransient saliency� (<i>X''q</i> not = <i>X''d</i>) is represented.

It is not necessary for each simulation tool to have separate models for each of the model types. The same model can often be used for several types by alternative logic within the model. Also, differences in saturation representation might not result in significant model performance differences so model substitutions are often acceptable.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efdBaseRatio [0..1] | [Float](#CIM17v40-Float) | Ratio (exciter voltage/generator voltage) of <i>Efd</i> bases of exciter and generator models (&gt; 0). Typical value = 1. | |
| ifdBaseType [0..1] | [IfdBaseKind](#CIM17v40-IfdBaseKind) | Excitation base system mode. It should be equal to the value of <i>WLMDV</i> given by the user. <i>WLMDV</i> is the PU ratio between the field voltage and the excitation current: <i>Efd</i> = <i>WLMDV</i> x <i>Ifd</i>. Typical value = ifag. | |
| saturationFactor120QAxis [0..1] | [Float](#CIM17v40-Float) | Quadrature-axis saturation factor at 120% of rated terminal voltage (<i>S12q</i>) (&gt;= SynchonousMachineDetailed.saturationFactorQAxis). Typical value = 0,12. | |
| saturationFactorQAxis [0..1] | [Float](#CIM17v40-Float) | Quadrature-axis saturation factor at rated terminal voltage (<i>S1q</i>) (&gt;= 0). Typical value = 0,02. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CrossCompoundTurbineGovernorDyanmics [0..1] | [CrossCompoundTurbineGovernorDynamics](#CIM17v40-CrossCompoundTurbineGovernorDynamics) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| CrossCompoundTurbineGovernorDynamics [0..1] | [CrossCompoundTurbineGovernorDynamics](#CIM17v40-CrossCompoundTurbineGovernorDynamics) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| ExcitationSystemDynamics [0..1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| MechanicalLoadDynamics [0..1] | [MechanicalLoadDynamics](#CIM17v40-MechanicalLoadDynamics) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| SynchronousMachine [1] | [SynchronousMachine](#CIM17v40-SynchronousMachine) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| damping [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| inertia [0..1] | [Seconds](#CIM17v40-Seconds) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| saturationFactor [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| saturationFactor120 [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| statorLeakageReactance [0..1] | [PU](#CIM17v40-PU) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| statorResistance [0..1] | [PU](#CIM17v40-PU) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SynchronousMachineDynamics}
### SynchronousMachineDynamics

Inheritance path = [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SynchronousMachineDynamics {

}

class RotatingMachineDynamics {

}

RotatingMachineDynamics <|-- SynchronousMachineDynamics : inherits from
class CrossCompoundTurbineGovernorDynamics {

}

SynchronousMachineDynamics --> "0..1" CrossCompoundTurbineGovernorDynamics : CrossCompoundTurbineGovernorDyanmics
class CrossCompoundTurbineGovernorDynamics {

}

SynchronousMachineDynamics --> "0..1" CrossCompoundTurbineGovernorDynamics : CrossCompoundTurbineGovernorDynamics
class ExcitationSystemDynamics {

}

SynchronousMachineDynamics --> "0..1" ExcitationSystemDynamics : ExcitationSystemDynamics
class MechanicalLoadDynamics {

}

SynchronousMachineDynamics --> "0..1" MechanicalLoadDynamics : MechanicalLoadDynamics
class SynchronousMachine {

}

SynchronousMachineDynamics --> "1" SynchronousMachine : SynchronousMachine
```

Synchronous machine whose behaviour is described by reference to a standard model expressed in one of the following forms:

- simplified (or classical), where a group of generators or motors is not modelled in detail;

- detailed, in equivalent circuit form;

- detailed, in time constant reactance form; or

<font color="#0f0f0f">- by definition of a user-defined model.</font>

<font color="#0f0f0f">It is a common practice to represent small generators by a negative load rather than by a dynamic generator model when performing dynamics simulations. In this case, a SynchronousMachine in the static model is not represented by anything in the dynamics model, instead it is treated as an ordinary load.</font>

<font color="#0f0f0f">Parameter details:</font>

<ol>

<li><font color="#0f0f0f">Synchronous machine parameters such as <i>Xl, Xd, Xp</i> etc. are actually used as inductances in the models,</font> but are commonly referred to as reactances since, at nominal frequency, the PU values are the same. However, some references use the symbol <i>L</i> instead of <i>X</i>.</li>

</ol>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CrossCompoundTurbineGovernorDyanmics [0..1] | [CrossCompoundTurbineGovernorDynamics](#CIM17v40-CrossCompoundTurbineGovernorDynamics) | The cross-compound turbine governor with which this high-pressure synchronous machine is associated. | |
| CrossCompoundTurbineGovernorDynamics [0..1] | [CrossCompoundTurbineGovernorDynamics](#CIM17v40-CrossCompoundTurbineGovernorDynamics) | The cross-compound turbine governor with which this low-pressure synchronous machine is associated. | |
| ExcitationSystemDynamics [0..1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | Excitation system model associated with this synchronous machine model. | |
| MechanicalLoadDynamics [0..1] | [MechanicalLoadDynamics](#CIM17v40-MechanicalLoadDynamics) | Mechanical load model associated with this synchronous machine model. | |
| SynchronousMachine [1] | [SynchronousMachine](#CIM17v40-SynchronousMachine) | Synchronous machine to which synchronous machine dynamics model applies. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| damping [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| inertia [0..1] | [Seconds](#CIM17v40-Seconds) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| saturationFactor [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| saturationFactor120 [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| statorLeakageReactance [0..1] | [PU](#CIM17v40-PU) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| statorResistance [0..1] | [PU](#CIM17v40-PU) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SynchronousMachineEquivalentCircuit}
### SynchronousMachineEquivalentCircuit

Inheritance path = [SynchronousMachineDetailed](#CIM17v40-SynchronousMachineDetailed) => [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) => [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SynchronousMachineEquivalentCircuit {

+ r1d : PU [0..1]
+ r1q : PU [0..1]
+ r2q : PU [0..1]
+ rfd : PU [0..1]
+ x1d : PU [0..1]
+ x1q : PU [0..1]
+ x2q : PU [0..1]
+ xad : PU [0..1]
+ xaq : PU [0..1]
+ xf1d : PU [0..1]
+ xfd : PU [0..1]
}

class SynchronousMachineDetailed {

}

SynchronousMachineDetailed <|-- SynchronousMachineEquivalentCircuit : inherits from
```

The electrical equations for all variations of the synchronous models are based on the SynchronousEquivalentCircuit diagram for the direct- and quadrature- axes.

Equations for conversion between equivalent circuit and time constant reactance forms:

<i>Xd</i> = <i>Xad </i>+<i> Xl</i>

<i>X�d</i> = <i>Xl</i> + <i>Xad</i> x <i>Xfd</i> / (<i>Xad</i> + <i>Xfd</i>)

<i>X�d</i> = <i>Xl</i> + <i>Xad</i> x <i>Xfd</i> x <i>X1d</i> / (<i>Xad</i> x <i>Xfd</i> + <i>Xad</i> x <i>X1d</i> + <i>Xfd</i> x <i>X1d</i>)

<i>Xq</i> = <i>Xaq</i> + <i>Xl</i>

<i>X�q</i> = <i>Xl</i> + <i>Xaq</i> x <i>X1q</i> / (<i>Xaq</i> + <i>X1q</i>)

<i>X�q</i> = <i>Xl</i> + <i>Xaq</i> x <i>X1q</i> x <i>X2q</i> / (<i>Xaq</i> x <i>X1q</i> + <i>Xaq</i> x <i>X2q</i> + <i>X1q</i> x <i>X2q</i>)

<i>T�do</i> = (<i>Xad</i> + <i>Xfd</i>) / (<i>omega</i><i><sub>0</sub></i> x <i>Rfd</i>)

<i>T�do</i> = (<i>Xad</i> x <i>Xfd</i> + <i>Xad</i> x <i>X1d</i> + <i>Xfd</i> x <i>X1d</i>) / (<i>omega</i><i><sub>0</sub></i> x <i>R1d</i> x (<i>Xad</i> + <i>Xfd</i>)

<i>T�qo</i> = (<i>Xaq</i> + <i>X1q</i>) / (<i>omega</i><i><sub>0</sub></i> x <i>R1q</i>)

<i>T�qo</i> = (<i>Xaq</i> x <i>X1q</i> + <i>Xaq</i> x <i>X2q</i> + <i>X1q</i> x <i>X2q</i>) / (<i>omega</i><i><sub>0</sub></i> x <i>R2q</i> x (<i>Xaq</i> + <i>X1q</i>)

Same equations using CIM attributes from SynchronousMachineTimeConstantReactance class on left of "=" and SynchronousMachineEquivalentCircuit class on right (except as noted):

xDirectSync = xad + RotatingMachineDynamics.statorLeakageReactance

xDirectTrans = RotatingMachineDynamics.statorLeakageReactance + xad x xfd / (xad + xfd)

xDirectSubtrans = RotatingMachineDynamics.statorLeakageReactance + xad x xfd x x1d / (xad x xfd + xad x x1d + xfd x x1d)

xQuadSync = xaq + RotatingMachineDynamics.statorLeakageReactance

xQuadTrans = RotatingMachineDynamics.statorLeakageReactance + xaq x x1q / (xaq+ x1q)

xQuadSubtrans = RotatingMachineDynamics.statorLeakageReactance + xaq x x1q x x2q / (xaq x x1q + xaq x x2q + x1q x x2q)

tpdo = (xad + xfd) / (2 x pi x nominal frequency x rfd)

tppdo = (xad x xfd + xad x x1d + xfd x x1d) / (2 x pi x nominal frequency x r1d x (xad + xfd)

tpqo = (xaq + x1q) / (2 x pi x nominal frequency x r1q)

tppqo = (xaq x x1q + xaq x x2q + x1q x x2q) / (2 x pi x nominal frequency x r2q x (xaq + x1q)

These are only valid for a simplified model where "Canay" reactance is zero.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| r1d [0..1] | [PU](#CIM17v40-PU) | Direct-axis damper 1 winding resistance. | |
| r1q [0..1] | [PU](#CIM17v40-PU) | Quadrature-axis damper 1 winding resistance. | |
| r2q [0..1] | [PU](#CIM17v40-PU) | Quadrature-axis damper 2 winding resistance. | |
| rfd [0..1] | [PU](#CIM17v40-PU) | Field winding resistance. | |
| x1d [0..1] | [PU](#CIM17v40-PU) | Direct-axis damper 1 winding leakage reactance. | |
| x1q [0..1] | [PU](#CIM17v40-PU) | Quadrature-axis damper 1 winding leakage reactance. | |
| x2q [0..1] | [PU](#CIM17v40-PU) | Quadrature-axis damper 2 winding leakage reactance. | |
| xad [0..1] | [PU](#CIM17v40-PU) | Direct-axis mutual reactance. | |
| xaq [0..1] | [PU](#CIM17v40-PU) | Quadrature-axis mutual reactance. | |
| xf1d [0..1] | [PU](#CIM17v40-PU) | Differential mutual (�Canay�) reactance. | |
| xfd [0..1] | [PU](#CIM17v40-PU) | Field winding leakage reactance. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efdBaseRatio [0..1] | [Float](#CIM17v40-Float) | see [SynchronousMachineDetailed](#CIM17v40-SynchronousMachineDetailed) | |
| ifdBaseType [0..1] | [IfdBaseKind](#CIM17v40-IfdBaseKind) | see [SynchronousMachineDetailed](CIM17v40-SynchronousMachineDetailed) | |
| saturationFactor120QAxis [0..1] | [Float](#CIM17v40-Float) | see [SynchronousMachineDetailed](#CIM17v40-SynchronousMachineDetailed) | |
| saturationFactorQAxis [0..1] | [Float](#CIM17v40-Float) | see [SynchronousMachineDetailed](#CIM17v40-SynchronousMachineDetailed) | |
| CrossCompoundTurbineGovernorDyanmics [0..1] | [CrossCompoundTurbineGovernorDynamics](#CIM17v40-CrossCompoundTurbineGovernorDynamics) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| CrossCompoundTurbineGovernorDynamics [0..1] | [CrossCompoundTurbineGovernorDynamics](#CIM17v40-CrossCompoundTurbineGovernorDynamics) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| ExcitationSystemDynamics [0..1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| MechanicalLoadDynamics [0..1] | [MechanicalLoadDynamics](#CIM17v40-MechanicalLoadDynamics) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| SynchronousMachine [1] | [SynchronousMachine](#CIM17v40-SynchronousMachine) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| damping [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| inertia [0..1] | [Seconds](#CIM17v40-Seconds) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| saturationFactor [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| saturationFactor120 [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| statorLeakageReactance [0..1] | [PU](#CIM17v40-PU) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| statorResistance [0..1] | [PU](#CIM17v40-PU) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SynchronousMachineSimplified}
### SynchronousMachineSimplified

Inheritance path = [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) => [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SynchronousMachineSimplified {

}

class SynchronousMachineDynamics {

}

SynchronousMachineDynamics <|-- SynchronousMachineSimplified : inherits from
```

The simplified model represents a synchronous generator as a constant internal voltage behind an impedance<i> </i>(<i>Rs + jXp</i>) as shown in the Simplified diagram.

Since internal voltage is held constant, there is no <i>Efd</i> input and any excitation system model will be ignored. There is also no <i>Ifd</i> output.

This model should not be used for representing a real generator except, perhaps, small generators whose response is insignificant.

The parameters used for the simplified model include:

- RotatingMachineDynamics.damping (<i>D</i>);

- RotatingMachineDynamics.inertia (<i>H</i>);

- RotatingMachineDynamics.statorLeakageReactance (used to exchange <i>jXp </i>for SynchronousMachineSimplified);

- RotatingMachineDynamics.statorResistance (<i>Rs</i>).


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CrossCompoundTurbineGovernorDyanmics [0..1] | [CrossCompoundTurbineGovernorDynamics](#CIM17v40-CrossCompoundTurbineGovernorDynamics) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| CrossCompoundTurbineGovernorDynamics [0..1] | [CrossCompoundTurbineGovernorDynamics](#CIM17v40-CrossCompoundTurbineGovernorDynamics) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| ExcitationSystemDynamics [0..1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| MechanicalLoadDynamics [0..1] | [MechanicalLoadDynamics](#CIM17v40-MechanicalLoadDynamics) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| SynchronousMachine [1] | [SynchronousMachine](#CIM17v40-SynchronousMachine) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| damping [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| inertia [0..1] | [Seconds](#CIM17v40-Seconds) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| saturationFactor [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| saturationFactor120 [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| statorLeakageReactance [0..1] | [PU](#CIM17v40-PU) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| statorResistance [0..1] | [PU](#CIM17v40-PU) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SynchronousMachineTimeConstantReactance}
### SynchronousMachineTimeConstantReactance

Inheritance path = [SynchronousMachineDetailed](#CIM17v40-SynchronousMachineDetailed) => [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) => [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SynchronousMachineTimeConstantReactance {

+ ks : Float [0..1]
+ modelType : enum:SynchronousMachineModelKind [0..1]
+ rotorType : enum:RotorKind [0..1]
+ tc : Seconds [0..1]
+ tpdo : Seconds [0..1]
+ tppdo : Seconds [0..1]
+ tppqo : Seconds [0..1]
+ tpqo : Seconds [0..1]
+ xDirectSubtrans : PU [0..1]
+ xDirectSync : PU [0..1]
+ xDirectTrans : PU [0..1]
+ xQuadSubtrans : PU [0..1]
+ xQuadSync : PU [0..1]
+ xQuadTrans : PU [0..1]
}

class SynchronousMachineDetailed {

}

SynchronousMachineDetailed <|-- SynchronousMachineTimeConstantReactance : inherits from
```

Synchronous machine detailed modelling types are defined by the combination of the attributes SynchronousMachineTimeConstantReactance.modelType and SynchronousMachineTimeConstantReactance.rotorType.

Parameter details:

<ol>

<li>The �p� in the time-related attribute names is a substitution for a �prime� in the usual parameter notation, e.g. tpdo refers to <i>T'do</i>.</li>

<li>The parameters used for models expressed in time constant reactance form include:</li>

</ol>

- RotatingMachine.ratedS (<i>MVAbase</i>);

- RotatingMachineDynamics.damping (<i>D</i>);

- RotatingMachineDynamics.inertia (<i>H</i>);

- RotatingMachineDynamics.saturationFactor (<i>S1</i>);

- RotatingMachineDynamics.saturationFactor120 (<i>S12</i>);

- RotatingMachineDynamics.statorLeakageReactance (<i>Xl</i>);

- RotatingMachineDynamics.statorResistance (<i>Rs</i>);

- SynchronousMachineTimeConstantReactance.ks (<i>Ks</i>);

- SynchronousMachineDetailed.saturationFactorQAxis (<i>S1q</i>);

- SynchronousMachineDetailed.saturationFactor120QAxis (<i>S12q</i>);

- SynchronousMachineDetailed.efdBaseRatio;

- SynchronousMachineDetailed.ifdBaseType;

- .xDirectSync (<i>Xd</i>);

- .xDirectTrans (<i>X'd</i>);

- .xDirectSubtrans (<i>X''d</i>);

- .xQuadSync (<i>Xq</i>);

- .xQuadTrans (<i>X'q</i>);

- .xQuadSubtrans (<i>X''q</i>);

- .tpdo (<i>T'do</i>);

- .tppdo (<i>T''do</i>);

- .tpqo (<i>T'qo</i>);

- .tppqo (<i>T''qo</i>);

- .tc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ks [0..1] | [Float](#CIM17v40-Float) | Saturation loading correction factor (<i>Ks</i>) (&gt;= 0). Used only by type J model. Typical value = 0. | |
| modelType [0..1] | [SynchronousMachineModelKind](#CIM17v40-SynchronousMachineModelKind) | Type of synchronous machine model used in dynamic simulation applications. | |
| rotorType [0..1] | [RotorKind](#CIM17v40-RotorKind) | Type of rotor on physical machine. | |
| tc [0..1] | [Seconds](#CIM17v40-Seconds) | Damping time constant for �Canay� reactance (&gt;= 0). Typical value = 0. | |
| tpdo [0..1] | [Seconds](#CIM17v40-Seconds) | Direct-axis transient rotor time constant (<i>T'do</i>) (&gt; SynchronousMachineTimeConstantReactance.tppdo). Typical value = 5. | |
| tppdo [0..1] | [Seconds](#CIM17v40-Seconds) | Direct-axis subtransient rotor time constant (<i>T''do</i>) (&gt; 0). Typical value = 0,03. | |
| tppqo [0..1] | [Seconds](#CIM17v40-Seconds) | Quadrature-axis subtransient rotor time constant (<i>T''qo</i>) (&gt; 0). Typical value = 0,03. | |
| tpqo [0..1] | [Seconds](#CIM17v40-Seconds) | Quadrature-axis transient rotor time constant (<i>T'qo</i>) (&gt; SynchronousMachineTimeConstantReactance.tppqo). Typical value = 0,5. | |
| xDirectSubtrans [0..1] | [PU](#CIM17v40-PU) | Direct-axis subtransient reactance (unsaturated) (<i>X''d</i>) (&gt; RotatingMachineDynamics.statorLeakageReactance). Typical value = 0,2. | |
| xDirectSync [0..1] | [PU](#CIM17v40-PU) | Direct-axis synchronous reactance (<i>Xd</i>) (&gt;= SynchronousMachineTimeConstantReactance.xDirectTrans). The quotient of a sustained value of that AC component of armature voltage that is produced by the total direct-axis flux due to direct-axis armature current and the value of the AC component of this current, the machine running at rated speed. Typical value = 1,8. | |
| xDirectTrans [0..1] | [PU](#CIM17v40-PU) | Direct-axis transient reactance (unsaturated) (<i>X'd</i>) (&gt;= SynchronousMachineTimeConstantReactance.xDirectSubtrans). Typical value = 0,5. | |
| xQuadSubtrans [0..1] | [PU](#CIM17v40-PU) | Quadrature-axis subtransient reactance (<i>X''q</i>) (&gt; RotatingMachineDynamics.statorLeakageReactance). Typical value = 0,2. | |
| xQuadSync [0..1] | [PU](#CIM17v40-PU) | Quadrature-axis synchronous reactance (<i>Xq</i>) (&gt;= SynchronousMachineTimeConstantReactance.xQuadTrans).The ratio of the component of reactive armature voltage, due to the quadrature-axis component of armature current, to this component of current, under steady state conditions and at rated frequency. Typical value = 1,6. | |
| xQuadTrans [0..1] | [PU](#CIM17v40-PU) | Quadrature-axis transient reactance (<i>X'q</i>) (&gt;= SynchronousMachineTimeConstantReactance.xQuadSubtrans). Typical value = 0,3. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| efdBaseRatio [0..1] | [Float](#CIM17v40-Float) | see [SynchronousMachineDetailed](#CIM17v40-SynchronousMachineDetailed) | |
| ifdBaseType [0..1] | [IfdBaseKind](#CIM17v40-IfdBaseKind) | see [SynchronousMachineDetailed](CIM17v40-SynchronousMachineDetailed) | |
| saturationFactor120QAxis [0..1] | [Float](#CIM17v40-Float) | see [SynchronousMachineDetailed](#CIM17v40-SynchronousMachineDetailed) | |
| saturationFactorQAxis [0..1] | [Float](#CIM17v40-Float) | see [SynchronousMachineDetailed](#CIM17v40-SynchronousMachineDetailed) | |
| CrossCompoundTurbineGovernorDyanmics [0..1] | [CrossCompoundTurbineGovernorDynamics](#CIM17v40-CrossCompoundTurbineGovernorDynamics) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| CrossCompoundTurbineGovernorDynamics [0..1] | [CrossCompoundTurbineGovernorDynamics](#CIM17v40-CrossCompoundTurbineGovernorDynamics) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| ExcitationSystemDynamics [0..1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| MechanicalLoadDynamics [0..1] | [MechanicalLoadDynamics](#CIM17v40-MechanicalLoadDynamics) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| SynchronousMachine [1] | [SynchronousMachine](#CIM17v40-SynchronousMachine) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| damping [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| inertia [0..1] | [Seconds](#CIM17v40-Seconds) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| saturationFactor [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| saturationFactor120 [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| statorLeakageReactance [0..1] | [PU](#CIM17v40-PU) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| statorResistance [0..1] | [PU](#CIM17v40-PU) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SynchronousMachineUserDefined}
### SynchronousMachineUserDefined

Inheritance path = [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) => [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class SynchronousMachineUserDefined {

+ proprietary : Boolean [0..1]
}

class SynchronousMachineDynamics {

}

SynchronousMachineDynamics <|-- SynchronousMachineUserDefined : inherits from
```

Synchronous machine whose dynamic behaviour is described by a user-defined model.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| proprietary [0..1] | [Boolean](#CIM17v40-Boolean) | Behaviour is based on a proprietary model as opposed to a detailed model.true = user-defined model is proprietary with behaviour mutually understood by sending and receiving applications and parameters passed as general attributesfalse = user-defined model is explicitly defined in terms of control blocks and their input and output signals. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CrossCompoundTurbineGovernorDyanmics [0..1] | [CrossCompoundTurbineGovernorDynamics](#CIM17v40-CrossCompoundTurbineGovernorDynamics) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| CrossCompoundTurbineGovernorDynamics [0..1] | [CrossCompoundTurbineGovernorDynamics](#CIM17v40-CrossCompoundTurbineGovernorDynamics) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| ExcitationSystemDynamics [0..1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| MechanicalLoadDynamics [0..1] | [MechanicalLoadDynamics](#CIM17v40-MechanicalLoadDynamics) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| SynchronousMachine [1] | [SynchronousMachine](#CIM17v40-SynchronousMachine) | see [SynchronousMachineDynamics](CIM17v40-SynchronousMachineDynamics) | |
| damping [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| inertia [0..1] | [Seconds](#CIM17v40-Seconds) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| saturationFactor [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| saturationFactor120 [0..1] | [Float](#CIM17v40-Float) | see [RotatingMachineDynamics](#CIM17v40-RotatingMachineDynamics) | |
| statorLeakageReactance [0..1] | [PU](#CIM17v40-PU) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| statorResistance [0..1] | [PU](#CIM17v40-PU) | see [RotatingMachineDynamics](CIM17v40-RotatingMachineDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-SysLoadDistributionFactor}
### SysLoadDistributionFactor


```mermaid
classDiagram
direction TB

class SysLoadDistributionFactor {

+ factor : Float [0..1]
}

class HostControlArea {

}

SysLoadDistributionFactor --> "1" HostControlArea : HostControlArea
class MktConnectivityNode {

}

SysLoadDistributionFactor --> "1" MktConnectivityNode : MktConnectivityNode
```

This class models the system distribution factors. This class needs to be used along with the HostControlArea and the ConnectivityNode to show the distribution of each individual party.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| factor [0..1] | [Float](#CIM17v40-Float) | Used to calculate load "participation" of a connectivity node in an host control area | |
| HostControlArea [1] | [HostControlArea](#CIM17v40-HostControlArea) | | |
| MktConnectivityNode [1] | [MktConnectivityNode](#CIM17v40-MktConnectivityNode) | | |

{#CIM17v40-TACArea}
### TACArea

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TACArea {

}

class IdentifiedObject {

}

IdentifiedObject <|-- TACArea : inherits from
```

Transmission Access Charge Area. Charges assessed, on behalf of the Participating Transmission Owner, to parties who require access to the controlled grid.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TASE2BilateralTable}
### TASE2BilateralTable

Inheritance path = [BilateralExchangeAgreement](#CIM17v40-BilateralExchangeAgreement) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TASE2BilateralTable {

+ bilateralTableID : String [0..1]
+ bilateralTableVersion : String [0..1]
+ tase2version : String [0..1]
}

class BilateralExchangeAgreement {

}

BilateralExchangeAgreement <|-- TASE2BilateralTable : inherits from
```

This class describe the sending (providing) side in a bilateral ICCP data exchange. Hence the ICCP bilateral (table) descriptions are created by exchanging ICCP Provider data between the parties.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| bilateralTableID [0..1] | [String](#CIM17v40-String) | Specifies the version of the Bilateral Table configuration that is being exchanged. | |
| bilateralTableVersion [0..1] | [String](#CIM17v40-String) | The Version attribute identifies a unique version of the Bilateral Table. If any changes are made to a Bilateral Table, then a new unique value for this attribute shall be generated. | |
| tase2version [0..1] | [String](#CIM17v40-String) | Specifies the version of the TASE.2 that is needed to access the Bilateral Table information via TASE.2.In order for a link to be established, both sides must have the same value. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Consumer [0..1] | [BilateralExchangeActor](#CIM17v40-BilateralExchangeActor) | see [BilateralExchangeAgreement](CIM17v40-BilateralExchangeAgreement) | |
| Provider [1] | [BilateralExchangeActor](#CIM17v40-BilateralExchangeActor) | see [BilateralExchangeAgreement](CIM17v40-BilateralExchangeAgreement) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TCPAccessPoint}
### TCPAccessPoint

Inheritance path = [IPAccessPoint](#CIM17v40-IPAccessPoint) => [CommunicationLink](#CIM17v40-CommunicationLink) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TCPAccessPoint {

+ keepAliveTime : Integer [0..1]
+ port : Integer [0..1]
}

class IPAccessPoint {

}

IPAccessPoint <|-- TCPAccessPoint : inherits from
```

Allows addressing and behavioural information regarding the use of TCP by ICCP links.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| keepAliveTime [0..1] | [Integer](#CIM17v40-Integer) | Indicates the default interval at which TCP will check if the TCP connection is still valid. | |
| port [0..1] | [Integer](#CIM17v40-Integer) | This value is only needed to be specified for called nodes (e.g. those that respond to a TCP.Open request).This value specifies the TCP port to be used. Well known and "registered" ports are preferred and can be found at:http://www.iana.org/assignments/service-names-port-numbers/service-names-port-numbers.xhtmlFor IEC 60870-6 TASE.2 (e.g. ICCP) and IEC 61850, the value used shall be 102 for non-TLS protected exchanges. The value shall be 3782 for TLS transported ICCP and 61850 exchanges. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| address [0..1] | [String](#CIM17v40-String) | see [IPAccessPoint](#CIM17v40-IPAccessPoint) | |
| addressType [0..1] | [IPAddressKind](#CIM17v40-IPAddressKind) | see [IPAccessPoint](CIM17v40-IPAccessPoint) | |
| gateway [0..1] | [String](#CIM17v40-String) | see [IPAccessPoint](#CIM17v40-IPAccessPoint) | |
| subnet [0..1] | [String](#CIM17v40-String) | see [IPAccessPoint](#CIM17v40-IPAccessPoint) | |
| BilateralExchangeActor [0..1] | [BilateralExchangeActor](#CIM17v40-BilateralExchangeActor) | see [CommunicationLink](CIM17v40-CommunicationLink) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TREntitlement}
### TREntitlement


```mermaid
classDiagram
direction TB

class TREntitlement {

+ entitlement : Float [0..1]
+ startOperatingDate : DateTime [0..1]
}

class ContractRight {

}

TREntitlement --> "1" ContractRight : TransmissionContractRight
```

A Transmission Right(TR) can be a chain of TR's or on individual.

When a transmission right is not a chain, this is formally the ETC/TOR Entitlement for each ETC/TOR contract with the inclusion of CVR(Converted Rights) as an ETC. This is the sum of all entitlements on all related transmission interfaces for the same TR.

When TR is a chain, its entitlement is the minimum of all entitlements for the individual TRs in the chain.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| entitlement [0..1] | [Float](#CIM17v40-Float) | The entitlement | |
| startOperatingDate [0..1] | [DateTime](#CIM17v40-DateTime) | Operating date and hour when the entitlement applies | |
| TransmissionContractRight [1] | [ContractRight](#CIM17v40-ContractRight) | | |

{#CIM17v40-TagAction}
### TagAction

Inheritance path = [SwitchingAction](#CIM17v40-SwitchingAction) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TagAction {

+ kind : enum:TagActionKind [0..1]
}

class SwitchingAction {

}

SwitchingAction <|-- TagAction : inherits from
class OperationalTag {

}

TagAction --> "0..1" OperationalTag : OperationalTag
```

Action on operation tag as a switching step.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [TagActionKind](#CIM17v40-TagActionKind) | Kind of tag action. | |
| OperationalTag [0..1] | [OperationalTag](#CIM17v40-OperationalTag) | Tag associated with this tag action. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| executedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| issuedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| plannedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| Operator [0..1] | [Operator](#CIM17v40-Operator) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingEvent [0..1] | [SwitchingEvent](#CIM17v40-SwitchingEvent) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingStep [0..1] | [SwitchingStep](#CIM17v40-SwitchingStep) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TailbayLossCurve}
### TailbayLossCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TailbayLossCurve {

}

class Curve {

}

Curve <|-- TailbayLossCurve : inherits from
class HydroGeneratingUnit {

}

TailbayLossCurve --> "1" HydroGeneratingUnit : HydroGeneratingUnit
```

Relationship between tailbay head loss height (Y-axis) and the total discharge into the power station's tailbay volume per time unit (X-axis) . There could be more than one curve depending on the level of the tailbay reservoir or river level.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `HydroGeneratingUnit [1]` (OfAggregate) | [HydroGeneratingUnit](#CIM17v40-HydroGeneratingUnit) | A hydro generating unit has a tailbay loss curve. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TapChanger}
### TapChanger

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TapChanger {

+ controlEnabled : Boolean [0..1]
+ highStep : Integer [0..1]
+ initialDelay : Seconds [0..1]
+ lowStep : Integer [0..1]
+ ltcFlag : Boolean [0..1]
+ neutralStep : Integer [0..1]
+ neutralU : Voltage [0..1]
+ normalStep : Integer [0..1]
+ step : Float [0..1]
+ subsequentDelay : Seconds [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- TapChanger : inherits from
class SvTapStep {

}

TapChanger --> "0..1" SvTapStep : SvTapStep
class TapChangerControl {

}

TapChanger --> "0..1" TapChangerControl : TapChangerControl
```

Mechanism for changing transformer winding tap positions.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| controlEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | Specifies the regulation status of the equipment. True is regulating, false is not regulating. | |
| highStep [0..1] | [Integer](#CIM17v40-Integer) | Highest possible tap step position, advance from neutral.The attribute shall be greater than lowStep. | |
| initialDelay [0..1] | [Seconds](#CIM17v40-Seconds) | For an LTC, the delay for initial tap changer operation (first step change). | |
| lowStep [0..1] | [Integer](#CIM17v40-Integer) | Lowest possible tap step position, retard from neutral. | |
| ltcFlag [0..1] | [Boolean](#CIM17v40-Boolean) | Specifies whether or not a TapChanger has load tap changing capabilities. | |
| neutralStep [0..1] | [Integer](#CIM17v40-Integer) | The neutral tap step position for this winding.The attribute shall be equal to or greater than lowStep and equal or less than highStep.It is the step position where the voltage is neutralU when the other terminals of the transformer are at the ratedU. If there are other tap changers on the transformer those taps are kept constant at their neutralStep. | |
| neutralU [0..1] | [Voltage](#CIM17v40-Voltage) | Voltage at which the winding operates at the neutral tap setting. It is the voltage at the terminal of the PowerTransformerEnd associated with the tap changer when all tap changers on the transformer are at their neutralStep position. Normally neutralU of the tap changer is the same as ratedU of the PowerTransformerEnd, but it can differ in special cases such as when the tapping mechanism is separate from the winding more common on lower voltage transformers.This attribute is not relevant for PhaseTapChangerAsymmetrical, PhaseTapChangerSymmetrical and PhaseTapChangerLinear. | |
| normalStep [0..1] | [Integer](#CIM17v40-Integer) | The tap step position used in "normal" network operation for this winding. For a "Fixed" tap changer indicates the current physical tap setting.The attribute shall be equal to or greater than lowStep and equal to or less than highStep. | |
| step [0..1] | [Float](#CIM17v40-Float) | Tap changer position.Starting step for a steady state solution. Non integer values are allowed to support continuous tap variables. The reasons for continuous value are to support study cases where no discrete tap changer has yet been designed, a solution where a narrow voltage band forces the tap step to oscillate or to accommodate for a continuous solution as input.The attribute shall be equal to or greater than lowStep and equal to or less than highStep. | |
| subsequentDelay [0..1] | [Seconds](#CIM17v40-Seconds) | For an LTC, the delay for subsequent tap changer operation (second and later step changes). | |
| SvTapStep [0..1] | [SvTapStep](#CIM17v40-SvTapStep) | The tap step state associated with the tap changer. | |
| TapChangerControl [0..1] | [TapChangerControl](#CIM17v40-TapChangerControl) | The regulating control scheme in which this tap changer participates. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TapChangerControl}
### TapChangerControl

Inheritance path = [RegulatingControl](#CIM17v40-RegulatingControl) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TapChangerControl {

+ limitVoltage : Voltage [0..1]
+ lineDropCompensation : Boolean [0..1]
+ lineDropR : Resistance [0..1]
+ lineDropX : Reactance [0..1]
+ reverseLineDropR : Resistance [0..1]
+ reverseLineDropX : Reactance [0..1]
}

class RegulatingControl {

}

RegulatingControl <|-- TapChangerControl : inherits from
```

Describes behaviour specific to tap changers, e.g. how the voltage at the end of a line varies with the load level and compensation of the voltage drop by tap adjustment.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| limitVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Maximum allowed regulated voltage on the PT secondary, regardless of line drop compensation. Sometimes referred to as first-house protection. | |
| lineDropCompensation [0..1] | [Boolean](#CIM17v40-Boolean) | If true, the line drop compensation is to be applied. | |
| lineDropR [0..1] | [Resistance](#CIM17v40-Resistance) | Line drop compensator resistance setting for normal (forward) power flow. | |
| lineDropX [0..1] | [Reactance](#CIM17v40-Reactance) | Line drop compensator reactance setting for normal (forward) power flow. | |
| reverseLineDropR [0..1] | [Resistance](#CIM17v40-Resistance) | Line drop compensator resistance setting for reverse power flow. | |
| reverseLineDropX [0..1] | [Reactance](#CIM17v40-Reactance) | Line drop compensator reactance setting for reverse power flow. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [RegulatingControl](#CIM17v40-RegulatingControl) | |
| maxAllowedTargetValue [0..1] | [Float](#CIM17v40-Float) | see [RegulatingControl](#CIM17v40-RegulatingControl) | |
| minAllowedTargetValue [0..1] | [Float](#CIM17v40-Float) | see [RegulatingControl](#CIM17v40-RegulatingControl) | |
| mode [0..1] | [RegulatingControlModeKind](#CIM17v40-RegulatingControlModeKind) | see [RegulatingControl](CIM17v40-RegulatingControl) | |
| monitoredPhase [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [RegulatingControl](CIM17v40-RegulatingControl) | |
| targetDeadband [0..1] | [Float](#CIM17v40-Float) | see [RegulatingControl](#CIM17v40-RegulatingControl) | |
| targetValue [0..1] | [Float](#CIM17v40-Float) | see [RegulatingControl](#CIM17v40-RegulatingControl) | |
| targetValueUnitMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [RegulatingControl](CIM17v40-RegulatingControl) | |
| Terminal [0..1] | [Terminal](#CIM17v40-Terminal) | see [RegulatingControl](CIM17v40-RegulatingControl) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TapChangerDynamicData}
### TapChangerDynamicData


```mermaid
classDiagram
direction TB

class TapChangerDynamicData {

+ angleRegulationStatus : Boolean [0..1]
+ desiredMW : Float [0..1]
+ desiredVoltage : Float [0..1]
+ maximumAngle : Float [0..1]
+ minimumAngle : Float [0..1]
+ solvedAngle : Float [0..1]
+ tapPosition : Float [0..1]
+ voltageRegulationStatus : Boolean [0..1]
}

class MktTapChanger {

}

TapChangerDynamicData --> "1" MktTapChanger : MktTapChanger
```

Optimal Power Flow or State Estimator Phase Shifter Data. This is used for RealTime, Study and Maintenance Users. SE Solution Phase Shifter Measurements from the last run of SE.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| angleRegulationStatus [0..1] | [Boolean](#CIM17v40-Boolean) | True means the phase shifter is regulating. | |
| desiredMW [0..1] | [Float](#CIM17v40-Float) | Phase Shifter Desired MW. The active power regulation setpoint of the phase shifter | |
| desiredVoltage [0..1] | [Float](#CIM17v40-Float) | The desired voltage for the LTC | |
| maximumAngle [0..1] | [Float](#CIM17v40-Float) | The maximum phase angle shift of the phase shifter | |
| minimumAngle [0..1] | [Float](#CIM17v40-Float) | The minimum phase angle shift of the phase shifter | |
| solvedAngle [0..1] | [Float](#CIM17v40-Float) | Phase Shifter Angle. The solved phase angle shift of the phase shifter | |
| tapPosition [0..1] | [Float](#CIM17v40-Float) | Tap position of the phase shifter, high-side tap position of the transformer, or low-side tap position of the transformer | |
| voltageRegulationStatus [0..1] | [Boolean](#CIM17v40-Boolean) | Indicator if the LTC transformer is regulating True = Yes, False = No | |
| MktTapChanger [1] | [MktTapChanger](#CIM17v40-MktTapChanger) | | |

{#CIM17v40-TapChangerInfo}
### TapChangerInfo

Inheritance path = [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TapChangerInfo {

+ bil : Voltage [0..1]
+ ctRating : CurrentFlow [0..1]
+ ctRatio : Float [0..1]
+ frequency : Frequency [0..1]
+ highStep : Integer [0..1]
+ isTcul : Boolean [0..1]
+ lowStep : Integer [0..1]
+ neutralStep : Integer [0..1]
+ neutralU : Voltage [0..1]
+ ptRatio : Float [0..1]
+ ratedApparentPower : ApparentPower [0..1]
+ ratedCurrent : CurrentFlow [0..1]
+ ratedVoltage : Voltage [0..1]
+ stepPhaseIncrement : AngleDegrees [0..1]
+ stepVoltageIncrement : PerCent [0..1]
}

class AssetInfo {

}

AssetInfo <|-- TapChangerInfo : inherits from
```

Tap changer data.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| bil [0..1] | [Voltage](#CIM17v40-Voltage) | Basic Insulation Level (BIL) expressed as the impulse crest voltage of a nominal wave, typically 1.2 X 50 microsecond. This is a measure of the ability of the insulation to withstand very high voltage surges. | |
| ctRating [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Built-in current transformer primary rating. | |
| ctRatio [0..1] | [Float](#CIM17v40-Float) | Built-in current transducer ratio. | |
| frequency [0..1] | [Frequency](#CIM17v40-Frequency) | Frequency at which the ratings apply. | |
| highStep [0..1] | [Integer](#CIM17v40-Integer) | Highest possible tap step position, advance from neutral. | |
| isTcul [0..1] | [Boolean](#CIM17v40-Boolean) | Whether this tap changer has under load tap changing capabilities. | |
| lowStep [0..1] | [Integer](#CIM17v40-Integer) | Lowest possible tap step position, retard from neutral. | |
| neutralStep [0..1] | [Integer](#CIM17v40-Integer) | The neutral tap step position for the winding. | |
| neutralU [0..1] | [Voltage](#CIM17v40-Voltage) | Voltage at which the winding operates at the neutral tap setting. | |
| ptRatio [0..1] | [Float](#CIM17v40-Float) | Built-in voltage transducer ratio. | |
| ratedApparentPower [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | Rated apparent power. | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Rated current. | |
| ratedVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Rated voltage. | |
| stepPhaseIncrement [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Phase shift per step position. | |
| stepVoltageIncrement [0..1] | [PerCent](#CIM17v40-PerCent) | Tap step increment, in per cent of rated voltage, per step position. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TapChangerTablePoint}
### TapChangerTablePoint


```mermaid
classDiagram
direction TB

class TapChangerTablePoint {

+ b : PerCent [0..1]
+ g : PerCent [0..1]
+ r : PerCent [0..1]
+ ratio : Float [0..1]
+ step : Integer [0..1]
+ x : PerCent [0..1]
}

```

Describes each tap step in the tabular curve.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| b [0..1] | [PerCent](#CIM17v40-PerCent) | The magnetizing branch susceptance deviation as a percentage of nominal value. The actual susceptance is calculated as follows:calculated magnetizing susceptance = b(nominal) * (1 + b(from this class)/100). The b(nominal) is defined as the static magnetizing susceptance on the associated power transformer end or ends. This model assumes the star impedance (pi model) form. | |
| g [0..1] | [PerCent](#CIM17v40-PerCent) | The magnetizing branch conductance deviation as a percentage of nominal value. The actual conductance is calculated as follows:calculated magnetizing conductance = g(nominal) * (1 + g(from this class)/100). The g(nominal) is defined as the static magnetizing conductance on the associated power transformer end or ends. This model assumes the star impedance (pi model) form. | |
| r [0..1] | [PerCent](#CIM17v40-PerCent) | The resistance deviation as a percentage of nominal value. The actual reactance is calculated as follows:calculated resistance = r(nominal) * (1 + r(from this class)/100). The r(nominal) is defined as the static resistance on the associated power transformer end or ends. This model assumes the star impedance (pi model) form. | |
| ratio [0..1] | [Float](#CIM17v40-Float) | The voltage at the tap step divided by rated voltage of the transformer end having the tap changer. Hence this is a value close to one.For example, if the ratio at step 1 is 1.01, and the rated voltage of the transformer end is 110kV, then the voltage obtained by setting the tap changer to step 1 to is 111.1kV. | |
| step [0..1] | [Integer](#CIM17v40-Integer) | The tap step. | |
| x [0..1] | [PerCent](#CIM17v40-PerCent) | The series reactance deviation as a percentage of nominal value. The actual reactance is calculated as follows:calculated reactance = x(nominal) * (1 + x(from this class)/100). The x(nominal) is defined as the static series reactance on the associated power transformer end or ends. This model assumes the star impedance (pi model) form. | |

{#CIM17v40-TapSchedule}
### TapSchedule

Inheritance path = [SeasonDayTypeSchedule](#CIM17v40-SeasonDayTypeSchedule) => [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) => [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TapSchedule {

}

class SeasonDayTypeSchedule {

}

SeasonDayTypeSchedule <|-- TapSchedule : inherits from
class TapChanger {

}

TapSchedule --> "1" TapChanger : TapChanger
```

A pre-established pattern over time for a tap step.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| TapChanger [1] | [TapChanger](#CIM17v40-TapChanger) | A TapSchedule is associated with a TapChanger. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| DayType [0..1] | [DayType](#CIM17v40-DayType) | see [SeasonDayTypeSchedule](CIM17v40-SeasonDayTypeSchedule) | |
| Season [0..1] | [Season](#CIM17v40-Season) | see [SeasonDayTypeSchedule](CIM17v40-SeasonDayTypeSchedule) | |
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | see [RegularIntervalSchedule](CIM17v40-RegularIntervalSchedule) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TapeShieldCableInfo}
### TapeShieldCableInfo

Inheritance path = [CableInfo](#CIM17v40-CableInfo) => [WireInfo](#CIM17v40-WireInfo) => [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TapeShieldCableInfo {

+ tapeLap : PerCent [0..1]
+ tapeThickness : Length [0..1]
}

class CableInfo {

}

CableInfo <|-- TapeShieldCableInfo : inherits from
```

Tape shield cable data.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| tapeLap [0..1] | [PerCent](#CIM17v40-PerCent) | Percentage of the tape shield width that overlaps in each wrap, typically 10% to 25%. | |
| tapeThickness [0..1] | [Length](#CIM17v40-Length) | Thickness of the tape shield, before wrapping. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| constructionKind [0..1] | [CableConstructionKind](#CIM17v40-CableConstructionKind) | see [CableInfo](CIM17v40-CableInfo) | |
| diameterOverCore [0..1] | [Length](#CIM17v40-Length) | see [CableInfo](CIM17v40-CableInfo) | |
| diameterOverInsulation [0..1] | [Length](#CIM17v40-Length) | see [CableInfo](CIM17v40-CableInfo) | |
| diameterOverJacket [0..1] | [Length](#CIM17v40-Length) | see [CableInfo](CIM17v40-CableInfo) | |
| diameterOverScreen [0..1] | [Length](#CIM17v40-Length) | see [CableInfo](CIM17v40-CableInfo) | |
| isStrandFill [0..1] | [Boolean](#CIM17v40-Boolean) | see [CableInfo](#CIM17v40-CableInfo) | |
| nominalTemperature [0..1] | [Temperature](#CIM17v40-Temperature) | see [CableInfo](CIM17v40-CableInfo) | |
| outerJacketKind [0..1] | [CableOuterJacketKind](#CIM17v40-CableOuterJacketKind) | see [CableInfo](CIM17v40-CableInfo) | |
| sheathAsNeutral [0..1] | [Boolean](#CIM17v40-Boolean) | see [CableInfo](#CIM17v40-CableInfo) | |
| shieldMaterial [0..1] | [CableShieldMaterialKind](#CIM17v40-CableShieldMaterialKind) | see [CableInfo](CIM17v40-CableInfo) | |
| coreRadius [0..1] | [Length](#CIM17v40-Length) | see [WireInfo](CIM17v40-WireInfo) | |
| coreStrandCount [0..1] | [Integer](#CIM17v40-Integer) | see [WireInfo](#CIM17v40-WireInfo) | |
| gmr [0..1] | [Length](#CIM17v40-Length) | see [WireInfo](CIM17v40-WireInfo) | |
| insulated [0..1] | [Boolean](#CIM17v40-Boolean) | see [WireInfo](#CIM17v40-WireInfo) | |
| insulationMaterial [0..1] | [WireInsulationKind](#CIM17v40-WireInsulationKind) | see [WireInfo](CIM17v40-WireInfo) | |
| insulationThickness [0..1] | [Length](#CIM17v40-Length) | see [WireInfo](CIM17v40-WireInfo) | |
| material [0..1] | [WireMaterialKind](#CIM17v40-WireMaterialKind) | see [WireInfo](CIM17v40-WireInfo) | |
| rAC25 [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | see [WireInfo](CIM17v40-WireInfo) | |
| rAC50 [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | see [WireInfo](CIM17v40-WireInfo) | |
| rAC75 [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | see [WireInfo](CIM17v40-WireInfo) | |
| radius [0..1] | [Length](#CIM17v40-Length) | see [WireInfo](CIM17v40-WireInfo) | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [WireInfo](CIM17v40-WireInfo) | |
| rDC20 [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | see [WireInfo](CIM17v40-WireInfo) | |
| sizeDescription [0..1] | [String](#CIM17v40-String) | see [WireInfo](#CIM17v40-WireInfo) | |
| strandCount [0..1] | [Integer](#CIM17v40-Integer) | see [WireInfo](#CIM17v40-WireInfo) | |
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TargetLevelSchedule}
### TargetLevelSchedule

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TargetLevelSchedule {

+ highLevelLimit : WaterLevel [0..1]
+ lowLevelLimit : WaterLevel [0..1]
}

class Curve {

}

Curve <|-- TargetLevelSchedule : inherits from
class Reservoir {

}

TargetLevelSchedule --> "1" Reservoir : Reservoir
```

Reservoir water level targets from advanced studies or "rule curves". Typically in one hour increments for up to 10 days.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| highLevelLimit [0..1] | [WaterLevel](#CIM17v40-WaterLevel) | High target level limit, above which the reservoir operation will be penalized. | |
| lowLevelLimit [0..1] | [WaterLevel](#CIM17v40-WaterLevel) | Low target level limit, below which the reservoir operation will be penalized. | |
| `Reservoir [1]` (OfAggregate) | [Reservoir](#CIM17v40-Reservoir) | A reservoir may have a water level target schedule. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Tariff}
### Tariff

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Tariff {

+ endDate : Date [0..1]
+ startDate : Date [0..1]
}

class Document {

}

Document <|-- Tariff : inherits from
```

Document, approved by the responsible regulatory agency, listing the terms and conditions, including a schedule of prices, under which utility services will be provided. It has a unique number within the state or province. For rate schedules it is frequently allocated by the affiliated Public utilities commission (PUC).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| endDate [0..1] | [Date](#CIM17v40-Date) | (if tariff became inactive) Date tariff was terminated. | |
| startDate [0..1] | [Date](#CIM17v40-Date) | Date tariff was activated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TariffProfile}
### TariffProfile

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TariffProfile {

+ tariffCycle : String [0..1]
}

class Document {

}

Document <|-- TariffProfile : inherits from
```

A schedule of charges; structure associated with Tariff that allows the definition of complex tarif structures such as step and time of use when used in conjunction with TimeTariffInterval and Charge. Inherited 'status.value' is defined in the context of the utility's business rules, for example: active, inactive, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| tariffCycle [0..1] | [String](#CIM17v40-String) | The frequency at which the tariff charge schedule is repeated. Examples are: once off on a specified date and time; hourly; daily; weekly; monthly; 3-monthly; 6-monthly; 12-monthly; etc. At the end of each cycle, the business rules are reset to start from the beginning again. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TemperatureDependentLimitPoint}
### TemperatureDependentLimitPoint


```mermaid
classDiagram
direction TB

class TemperatureDependentLimitPoint {

+ limitPercent : PerCent [0..1]
+ temperature : Temperature [0..1]
}

class TemperatureDependentLimitTable {

}

TemperatureDependentLimitPoint --> "1" TemperatureDependentLimitTable : TemperatureDependentLimitTable
```

A point on a table of limit verses temperature.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| limitPercent [0..1] | [PerCent](#CIM17v40-PerCent) | The scaling of the operational limit in percent. | |
| temperature [0..1] | [Temperature](#CIM17v40-Temperature) | The temperature of the table point. | |
| `TemperatureDependentLimitTable [1]` (OfAggregate, informative) | [TemperatureDependentLimitTable](#CIM17v40-TemperatureDependentLimitTable) | | |

{#CIM17v40-TemperatureDependentLimitTable}
### (informative) TemperatureDependentLimitTable

Inheritance path = [EnvironmentalDependentLimit](#CIM17v40-EnvironmentalDependentLimit) => [LimitDependency](#CIM17v40-LimitDependency) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TemperatureDependentLimitTable {

}

class EnvironmentalDependentLimit {

}

EnvironmentalDependentLimit <|-- TemperatureDependentLimitTable : inherits from
```

This is a table lookup that provides limit values corresponding to a temperature input.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Equipment [0..1]` (OfAggregate, informative) | [Equipment](#CIM17v40-Equipment) | see [LimitDependency](CIM17v40-LimitDependency) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TemperaturePolynomialLimit}
### TemperaturePolynomialLimit

Inheritance path = [EnvironmentalDependentLimit](#CIM17v40-EnvironmentalDependentLimit) => [LimitDependency](#CIM17v40-LimitDependency) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TemperaturePolynomialLimit {

+ coefficient0 : Float [0..1]
+ coefficient1 : Float [0..1]
+ coefficient2 : Float [0..1]
+ coefficient3 : Float [0..1]
+ coefficient4 : Float [0..1]
}

class EnvironmentalDependentLimit {

}

EnvironmentalDependentLimit <|-- TemperaturePolynomialLimit : inherits from
```

This describes the coefficients of a polynomial function that has temperature as input and calculates limit values as output.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| coefficient0 [0..1] | [Float](#CIM17v40-Float) | The polinomial coefficent of power 0. | |
| coefficient1 [0..1] | [Float](#CIM17v40-Float) | The polinomial coefficent of power 1. | |
| coefficient2 [0..1] | [Float](#CIM17v40-Float) | The polinomial coefficent of power 2. | |
| coefficient3 [0..1] | [Float](#CIM17v40-Float) | The polinomial coefficent of power 3. | |
| coefficient4 [0..1] | [Float](#CIM17v40-Float) | The polinomial coefficent of power 4. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Equipment [0..1]` (OfAggregate, informative) | [Equipment](#CIM17v40-Equipment) | see [LimitDependency](CIM17v40-LimitDependency) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TenMinAuxiliaryData}
### TenMinAuxiliaryData


```mermaid
classDiagram
direction TB

class TenMinAuxiliaryData {

+ intervalStartTime : DateTime [0..1]
+ updateTimeStamp : DateTime [0..1]
+ updateUser : String [0..1]
}

```

Models 10-Minutes Auxiliary Data.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| updateTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| updateUser [0..1] | [String](#CIM17v40-String) | | |

{#CIM17v40-Tender}
### Tender

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Tender {

+ amount : Money [0..1]
+ change : Money [0..1]
+ kind : enum:TenderKind [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Tender : inherits from
class Card {

}

Tender --> "0..1" Card : Card
class Cheque {

}

Tender --> "0..1" Cheque : Cheque
class Receipt {

}

Tender --> "1" Receipt : Receipt
```

Tender is what is "offered" by the customer towards making a payment and is often more than the required payment (hence the need for 'change'). The payment is thus that part of the Tender that goes towards settlement of a particular transaction.

Tender is modelled as an aggregation of Cheque and Card. Both these tender types can exist in a single tender bid thus 'accountHolderName' has to exist separately in each of Cheque and Card as each could have a different account holder name.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| amount [0..1] | [Money](#CIM17v40-Money) | Amount tendered by customer. | |
| change [0..1] | [Money](#CIM17v40-Money) | Difference between amount tendered by customer and the amount charged by point of sale. | |
| kind [0..1] | [TenderKind](#CIM17v40-TenderKind) | Kind of tender from customer. | |
| Card [0..1] | [Card](#CIM17v40-Card) | Card used to tender payment. | |
| Cheque [0..1] | [Cheque](#CIM17v40-Cheque) | Cheque used to tender payment. | |
| Receipt [1] | [Receipt](#CIM17v40-Receipt) | Receipt that recorded this receiving of a payment in the form of tenders. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Terminal}
### (informative) Terminal

Inheritance path = [ACDCTerminal](#CIM17v40-ACDCTerminal) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Terminal {

+ phases : enum:PhaseCode [0..1]
}

class ACDCTerminal {

}

ACDCTerminal <|-- Terminal : inherits from
class Bushing {

}

Terminal --> "0..1" Bushing : Bushing
class Circuit {

}

Terminal --> "0..1" Circuit : Circuit
class ConductingEquipment {

}

Terminal --> "1" ConductingEquipment : ConductingEquipment
class ConnectivityNode {

}

Terminal --> "0..1" ConnectivityNode : ConnectivityNode
class Feeder {

}

Terminal --> "0..1" Feeder : NormalHeadFeeder
class TopologicalNode {

}

Terminal --> "0..1" TopologicalNode : TopologicalNode
```

An AC electrical connection point to a piece of conducting equipment. Terminals are connected at physical connection points called connectivity nodes.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | Represents the normal network phasing condition. If the attribute is missing, three phases (ABC) shall be assumed, except for terminals of grounding classes (specializations of EarthFaultCompensator, GroundDisconnector, and Ground) which will be assumed to be N. Therefore, phase code ABCN is explicitly declared when needed, e.g. for star point grounding equipment.The phase code on terminals connecting same ConnectivityNode or same TopologicalNode as well as for equipment between two terminals shall be consistent. | |
| Bushing [0..1] | [Bushing](#CIM17v40-Bushing) | | |
| `Circuit [0..1]` (informative) | [Circuit](#CIM17v40-Circuit) | | |
| ConductingEquipment [1] | [ConductingEquipment](#CIM17v40-ConductingEquipment) | The conducting equipment of the terminal. Conducting equipment have terminals that may be connected to other conducting equipment terminals via connectivity nodes or topological nodes. | |
| ConnectivityNode [0..1] | [ConnectivityNode](#CIM17v40-ConnectivityNode) | The connectivity node to which this terminal connects with zero impedance. | |
| NormalHeadFeeder [0..1] | [Feeder](#CIM17v40-Feeder) | The feeder that this terminal normally feeds. Only specified for the terminals at head of feeders. | |
| `TopologicalNode [0..1]` (OfAggregate) | [TopologicalNode](#CIM17v40-TopologicalNode) | The topological node associated with the terminal. This can be used as an alternative to the connectivity node path to topological node, thus making it unnecessary to model connectivity nodes in some cases. Note that the if connectivity nodes are in the model, this association would probably not be used as an input specification. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| connected [0..1] | [Boolean](#CIM17v40-Boolean) | see [ACDCTerminal](#CIM17v40-ACDCTerminal) | |
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | see [ACDCTerminal](#CIM17v40-ACDCTerminal) | |
| BusNameMarker [0..1] | [BusNameMarker](#CIM17v40-BusNameMarker) | see [ACDCTerminal](CIM17v40-ACDCTerminal) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TerminalConstraintTerm}
### TerminalConstraintTerm

Inheritance path = [ConstraintTerm](#CIM17v40-ConstraintTerm) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TerminalConstraintTerm {

}

class ConstraintTerm {

}

ConstraintTerm <|-- TerminalConstraintTerm : inherits from
class MktTerminal {

}

TerminalConstraintTerm --> "1" MktTerminal : MktTerminal
```

A constraint term associated with a specific terminal on a physical piece of equipment.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| MktTerminal [1] | [MktTerminal](#CIM17v40-MktTerminal) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| factor [0..1] | [String](#CIM17v40-String) | see [ConstraintTerm](#CIM17v40-ConstraintTerm) | |
| function [0..1] | [String](#CIM17v40-String) | see [ConstraintTerm](#CIM17v40-ConstraintTerm) | |
| SecurityConstraintSum [1] | [SecurityConstraintSum](#CIM17v40-SecurityConstraintSum) | see [ConstraintTerm](CIM17v40-ConstraintTerm) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TestDataSet}
### TestDataSet

Inheritance path = [ProcedureDataSet](#CIM17v40-ProcedureDataSet) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TestDataSet {

+ conclusion : String [0..1]
+ specimenID : String [0..1]
+ specimenToLabDateTime : DateTime [0..1]
}

class ProcedureDataSet {

}

ProcedureDataSet <|-- TestDataSet : inherits from
```

Test results, usually obtained by a lab or other independent organisation.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| conclusion [0..1] | [String](#CIM17v40-String) | Conclusion drawn from test results. | |
| specimenID [0..1] | [String](#CIM17v40-String) | Identifier of specimen used in inspection or test. | |
| specimenToLabDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time the specimen was received by the lab. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| completedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [ProcedureDataSet](#CIM17v40-ProcedureDataSet) | |
| Asset [0..1] | [Asset](#CIM17v40-Asset) | see [ProcedureDataSet](CIM17v40-ProcedureDataSet) | |
| Procedure [0..1] | [Procedure](#CIM17v40-Procedure) | see [ProcedureDataSet](CIM17v40-ProcedureDataSet) | |
| WorkTask [0..1] | [WorkTask](#CIM17v40-WorkTask) | see [ProcedureDataSet](CIM17v40-ProcedureDataSet) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TestStandard}
### TestStandard

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TestStandard {

+ testMethod : enum:TestMethod [0..1]
+ testVariant : enum:TestVariantKind [0..1]
+ testStandardASTM : ASTMStandard [0..1]
+ testStandardCIGRE : CIGREStandard [0..1]
+ testStandardDIN : DINStandard [0..1]
+ testStandardDoble : DobleStandard [0..1]
+ testStandardEPA : EPAStandard [0..1]
+ testStandardIEC : IECStandard [0..1]
+ testStandardIEEE : IEEEStandard [0..1]
+ testStandardISO : ISOStandard [0..1]
+ testStandardLaborelec : LaborelecStandard [0..1]
+ testStandardTAPPI : TAPPIStandard [0..1]
+ testStandardUKMinistryOfDefence : UKMinistryOfDefenceStandard [0..1]
+ testStandardWEP : WEPStandard [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- TestStandard : inherits from
```

The precise standard used in executing a lab test, including the standard, and standard version, test method and variant, if needed.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| testMethod [0..1] | [TestMethod](#CIM17v40-TestMethod) | Identification of test method used if multiple methods specified by test standard. | |
| testVariant [0..1] | [TestVariantKind](#CIM17v40-TestVariantKind) | Identification of variant of test method or standard if one is specified by the standard. | |
| testStandardASTM [0..1] | [ASTMStandard](#CIM17v40-ASTMStandard) | Which ASTM standard used to determine analog value result. Applies only if ASTM standard used. | |
| testStandardCIGRE [0..1] | [CIGREStandard](#CIM17v40-CIGREStandard) | Which CIGRE standard used to determine analog value result. Applies only if CIGRE standard used. | |
| testStandardDIN [0..1] | [DINStandard](#CIM17v40-DINStandard) | Which DIN standard used to determine analog value result. Applies only if DIN standard used. | |
| testStandardDoble [0..1] | [DobleStandard](#CIM17v40-DobleStandard) | Which Doble standard used to determine analog value result. Applies only if Doble standard used. | |
| testStandardEPA [0..1] | [EPAStandard](#CIM17v40-EPAStandard) | Which EPA standard used to determine analog value result. Applies only if EPA standard used. | |
| testStandardIEC [0..1] | [IECStandard](#CIM17v40-IECStandard) | Which IEC standard used to determine analog value result. Applies only if IEC standard used. | |
| testStandardIEEE [0..1] | [IEEEStandard](#CIM17v40-IEEEStandard) | Which IEEE standard used to determine analog value result. Applies only if IEEE standard used. | |
| testStandardISO [0..1] | [ISOStandard](#CIM17v40-ISOStandard) | Which ISO standard used to determine analog value result. Applies only if ISO standard used. | |
| testStandardLaborelec [0..1] | [LaborelecStandard](#CIM17v40-LaborelecStandard) | Which Laborelec standard used to determine analog value result. Applies only if Laborelec standard used. | |
| testStandardTAPPI [0..1] | [TAPPIStandard](#CIM17v40-TAPPIStandard) | Which TAPPI standard used to determine analog value result. Applies only if TAPPI standard used. | |
| testStandardUKMinistryOfDefence [0..1] | [UKMinistryOfDefenceStandard](#CIM17v40-UKMinistryOfDefenceStandard) | Which UK Ministry of Defence standard used to determine analog value result. Applies only if UK Ministry of Defence standard used. | |
| testStandardWEP [0..1] | [WEPStandard](#CIM17v40-WEPStandard) | Which WEP standard used to determine analog value result. Applies only if WEP standard used. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TextDiagramObject}
### TextDiagramObject

Inheritance path = [DiagramObject](#CIM17v40-DiagramObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TextDiagramObject {

+ text : String [0..1]
}

class DiagramObject {

}

DiagramObject <|-- TextDiagramObject : inherits from
```

A diagram object for placing free-text or text derived from an associated domain object.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| text [0..1] | [String](#CIM17v40-String) | The text that is displayed by this text diagram object. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| drawingOrder [0..1] | [Integer](#CIM17v40-Integer) | see [DiagramObject](#CIM17v40-DiagramObject) | |
| isPolygon [0..1] | [Boolean](#CIM17v40-Boolean) | see [DiagramObject](#CIM17v40-DiagramObject) | |
| offsetX [0..1] | [Float](#CIM17v40-Float) | see [DiagramObject](#CIM17v40-DiagramObject) | |
| offsetY [0..1] | [Float](#CIM17v40-Float) | see [DiagramObject](#CIM17v40-DiagramObject) | |
| rotation [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | see [DiagramObject](CIM17v40-DiagramObject) | |
| Diagram [0..1] | [Diagram](#CIM17v40-Diagram) | see [DiagramObject](CIM17v40-DiagramObject) | |
| DiagramObjectStyle [0..1] | [DiagramObjectStyle](#CIM17v40-DiagramObjectStyle) | see [DiagramObject](CIM17v40-DiagramObject) | |
| IdentifiedObject [0..1] | [IdentifiedObject](#CIM17v40-IdentifiedObject) | see [DiagramObject](CIM17v40-DiagramObject) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ThermalGeneratingUnit}
### ThermalGeneratingUnit

Inheritance path = [GeneratingUnit](#CIM17v40-GeneratingUnit) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ThermalGeneratingUnit {

+ oMCost : CostPerHeatUnit [0..1]
}

class GeneratingUnit {

}

GeneratingUnit <|-- ThermalGeneratingUnit : inherits from
class CAESPlant {

}

ThermalGeneratingUnit --> "0..1" CAESPlant : CAESPlant
class CogenerationPlant {

}

ThermalGeneratingUnit --> "0..1" CogenerationPlant : CogenerationPlant
class CombinedCyclePlant {

}

ThermalGeneratingUnit --> "0..1" CombinedCyclePlant : CombinedCyclePlant
class HeatInputCurve {

}

ThermalGeneratingUnit --> "0..1" HeatInputCurve : HeatInputCurve
class HeatRateCurve {

}

ThermalGeneratingUnit --> "0..1" HeatRateCurve : HeatRateCurve
class IncrementalHeatRateCurve {

}

ThermalGeneratingUnit --> "0..1" IncrementalHeatRateCurve : IncrementalHeatRateCurve
class ShutdownCurve {

}

ThermalGeneratingUnit --> "0..1" ShutdownCurve : ShutdownCurve
class StartupModel {

}

ThermalGeneratingUnit --> "0..1" StartupModel : StartupModel
```

A generating unit whose prime mover could be a steam turbine, combustion turbine, or diesel engine.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| oMCost [0..1] | [CostPerHeatUnit](#CIM17v40-CostPerHeatUnit) | Operating and maintenance cost for the thermal unit. | |
| CAESPlant [0..1] | [CAESPlant](#CIM17v40-CAESPlant) | A thermal generating unit may be a member of a compressed air energy storage plant. | |
| CogenerationPlant [0..1] | [CogenerationPlant](#CIM17v40-CogenerationPlant) | A thermal generating unit may be a member of a cogeneration plant. | |
| CombinedCyclePlant [0..1] | [CombinedCyclePlant](#CIM17v40-CombinedCyclePlant) | A thermal generating unit may be a member of a combined cycle plant. | |
| `HeatInputCurve [0..1]` (AggregateOf) | [HeatInputCurve](#CIM17v40-HeatInputCurve) | A thermal generating unit may have a heat input curve. | |
| `HeatRateCurve [0..1]` (AggregateOf) | [HeatRateCurve](#CIM17v40-HeatRateCurve) | A thermal generating unit may have a heat rate curve. | |
| `IncrementalHeatRateCurve [0..1]` (AggregateOf) | [IncrementalHeatRateCurve](#CIM17v40-IncrementalHeatRateCurve) | A thermal generating unit may have an incremental heat rate curve. | |
| `ShutdownCurve [0..1]` (AggregateOf) | [ShutdownCurve](#CIM17v40-ShutdownCurve) | A thermal generating unit may have a shutdown curve. | |
| `StartupModel [0..1]` (AggregateOf) | [StartupModel](#CIM17v40-StartupModel) | A thermal generating unit may have a startup model. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| allocSpinResP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| autoCntrlMarginP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| baseP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlDeadband [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlPulseHigh [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlPulseLow [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlResponseRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| efficiency [0..1] | [PerCent](#CIM17v40-PerCent) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| genControlMode [0..1] | [GeneratorControlMode](#CIM17v40-GeneratorControlMode) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| genControlSource [0..1] | [GeneratorControlSource](#CIM17v40-GeneratorControlSource) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| governorMPL [0..1] | [PU](#CIM17v40-PU) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| governorSCD [0..1] | [PerCent](#CIM17v40-PerCent) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| highControlLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| initialP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| longPF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| lowControlLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| lowerRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| maxEconomicP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| maximumAllowableSpinningReserve [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| maxOperatingP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| minEconomicP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| minimumOffTime [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| minOperatingP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| modelDetail [0..1] | [Classification](#CIM17v40-Classification) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| nominalP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| normalPF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| penaltyFactor [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| raiseRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| ratedGrossMaxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| ratedGrossMinP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| ratedNetMaxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| shortPF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| startupCost [0..1] | [Money](#CIM17v40-Money) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| startupTime [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| tieLinePF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| totalEfficiency [0..1] | [PerCent](#CIM17v40-PerCent) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| variableCost [0..1] | [Money](#CIM17v40-Money) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| `GenUnitOpSchedule [0..1]` (AggregateOf) | [GenUnitOpSchedule](#CIM17v40-GenUnitOpSchedule) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TieFlow}
### TieFlow

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TieFlow {

+ positiveFlowIn : Boolean [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- TieFlow : inherits from
class ControlArea {

}

TieFlow --> "1" ControlArea : ControlArea
class Terminal {

}

TieFlow --> "1" Terminal : Terminal
```

Defines the structure (in terms of location and direction) of the net interchange constraint for a control area. This constraint may be used by either AGC or power flow.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| positiveFlowIn [0..1] | [Boolean](#CIM17v40-Boolean) | Specifies the sign of the tie flow associated with a control area. True if positive flow into the terminal (load convention) is also positive flow into the control area. See the description of ControlArea for further explanation of how TieFlow.positiveFlowIn is used. | |
| `ControlArea [1]` (OfAggregate) | [ControlArea](#CIM17v40-ControlArea) | The control area of the tie flows. | |
| Terminal [1] | [Terminal](#CIM17v40-Terminal) | The terminal to which this tie flow belongs. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TieLine}
### TieLine

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TieLine {

}

class IdentifiedObject {

}

IdentifiedObject <|-- TieLine : inherits from
class EnergyTransaction {

}

TieLine --> "0..1" EnergyTransaction : EnergyTransaction
class CustomerConsumer {

}

TieLine --> "0..1" CustomerConsumer : ParentOfB
class SubControlArea {

}

TieLine --> "1" SubControlArea : SideA_SubControlArea
class SubControlArea {

}

TieLine --> "1" SubControlArea : SideB_SubControlArea
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `EnergyTransaction [0..1]` (informative) | [EnergyTransaction](#CIM17v40-EnergyTransaction) | A dynamic energy transaction can act as a pseudo tie line. | |
| `ParentOfB [0..1]` (informative) | [CustomerConsumer](#CIM17v40-CustomerConsumer) | A CustomerConsumer may ring its perimeter with metering, which can create a unique SubControlArea at the collection of metering points, called a TieLine. | |
| `SideA_SubControlArea [1]` (informative) | [SubControlArea](#CIM17v40-SubControlArea) | The SubControlArea is on the A side of a collection of metered points which define the SubControlArea's boundary for a ControlAreaOperator or CustomerConsumer. | |
| `SideB_SubControlArea [1]` (informative) | [SubControlArea](#CIM17v40-SubControlArea) | The SubControlArea is on the B side of a collection of metered points which define the SubControlArea's boundary for a ControlAreaOperator or CustomerConsumer. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TiePoint}
### (informative) TiePoint

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TiePoint {

+ tiePointMWRating : ActivePower [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- TiePoint : inherits from
```

Site of an interface between interchange areas. The tie point can be a network branch (e.g., transmission line or transformer) or a switching device. For transmission lines, the interchange area boundary is usually at a designated point such as the middle of the line. Line end metering is then corrected for line losses.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| tiePointMWRating [0..1] | [ActivePower](#CIM17v40-ActivePower) | The MW rating of the tie point. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TimePoint}
### TimePoint

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TimePoint {

+ dateTime : DateTime [0..1]
+ relativeTimeInterval : Seconds [0..1]
+ sequenceNumber : Integer [0..1]
+ status : Status [0..1]
+ window : DateTimeInterval [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- TimePoint : inherits from
class TimeSchedule {

}

TimePoint --> "1" TimeSchedule : TimeSchedule
```

A point in time within a sequence of points in time relative to a time schedule.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Absolute date and time for this time point. For calendar-based time point, it is typically manually entered, while for interval-based or sequence-based time point it is derived. | |
| relativeTimeInterval [0..1] | [Seconds](#CIM17v40-Seconds) | (if interval-based) A point in time relative to scheduled start time in 'TimeSchedule.scheduleInterval.start'. | |
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | (if sequence-based) Relative sequence number for this time point. | |
| status [0..1] | [Status](#CIM17v40-Status) | Status of this time point. | |
| TimeSchedule [1] | [TimeSchedule](#CIM17v40-TimeSchedule) | Time schedule owning this time point. | |
| window [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Interval defining the window of time for which this time point is valid. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TimeSchedule}
### TimeSchedule

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TimeSchedule {

+ disabled : Boolean [0..1]
+ offset : Seconds [0..1]
+ recurrencePattern : String [0..1]
+ recurrencePeriod : Seconds [0..1]
+ scheduleInterval : DateTimeInterval [0..1]
}

class Document {

}

Document <|-- TimeSchedule : inherits from
class MeterReadSchedule {

}

TimeSchedule --> "0..1" MeterReadSchedule : MeterReadSchedule
```

Description of anything that changes through time. Time schedule is used to perform a single-valued function of time. Use inherited 'type' attribute to give additional information on this schedule, such as: periodic (hourly, daily, weekly, monthly, etc.), day of the month, by date, calendar (specific times and dates).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| disabled [0..1] | [Boolean](#CIM17v40-Boolean) | True if this schedule is deactivated (disabled). | |
| offset [0..1] | [Seconds](#CIM17v40-Seconds) | The offset from midnight (i.e., 0 h, 0 min, 0 s) for the periodic time points to begin. For example, for an interval meter that is set up for five minute intervals ('recurrencePeriod'=300=5 min), setting 'offset'=120=2 min would result in scheduled events to read the meter executing at 2 min, 7 min, 12 min, 17 min, 22 min, 27 min, 32 min, 37 min, 42 min, 47 min, 52 min, and 57 min past each hour. | |
| recurrencePattern [0..1] | [String](#CIM17v40-String) | Interval at which the scheduled action repeats (e.g., first Monday of every month, last day of the month, etc.). | |
| recurrencePeriod [0..1] | [Seconds](#CIM17v40-Seconds) | Duration between time points, from the beginning of one period to the beginning of the next period. Note that a device like a meter may have multiple interval periods (e.g., 1 min, 5 min, 15 min, 30 min, or 60 min). | |
| MeterReadSchedule [0..1] | [MeterReadSchedule](#CIM17v40-MeterReadSchedule) | Meter read schedule for which the time schedule applies | |
| scheduleInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Schedule date and time interval. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TimeSeries}
### TimeSeries

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TimeSeries {

+ businessType : String [0..1]
+ cancelledTS : String [0..1]
+ curveType : String [0..1]
+ objectAggregation : String [0..1]
+ product : String [0..1]
+ version : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- TimeSeries : inherits from
```

A set of regular time-ordered measurements or values of quantitative nature of an individual or collective phenomenon taken at successive, in most cases equidistant, periods / points of time.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| businessType [0..1] | [String](#CIM17v40-String) | The identification of the nature of the time series. | |
| cancelledTS [0..1] | [String](#CIM17v40-String) | An indicator stating that the TimeSeries, identified by the mRID, is cancelled as well as all the values sent in a previous version of the TimeSeries in a previous document. | |
| curveType [0..1] | [String](#CIM17v40-String) | The coded representation of the type of curve being described. | |
| objectAggregation [0..1] | [String](#CIM17v40-String) | Identification of the object that is the common denominator used to aggregate a time series. | |
| product [0..1] | [String](#CIM17v40-String) | The type of the product such as Power, energy, reactive power, transport capacity that is the subject of the time series. | |
| version [0..1] | [String](#CIM17v40-String) | Version of the time series. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TimeTariffInterval}
### TimeTariffInterval


```mermaid
classDiagram
direction TB

class TimeTariffInterval {

+ sequenceNumber : Integer [0..1]
+ startTime : Time [0..1]
}

```

One of a sequence of time intervals defined in terms of real time. It is typically used in association with TariffProfile to define the intervals in a time of use tariff structure, where startDateTime simultaneously determines the starting point of this interval and the ending point of the previous interval.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | A sequential reference that defines the identity of this interval and its relative position with respect to other intervals in a sequence of intervals. | |
| startTime [0..1] | [Time](#CIM17v40-Time) | A real time marker that defines the starting time (typically it is the time of day) for this interval. The interval extends to the start of the next interval or until it is reset to the start of the first interval by TariffProfile.tariffCycle. | |

{#CIM17v40-Tool}
### Tool

Inheritance path = [WorkAsset](#CIM17v40-WorkAsset) => [Asset](#CIM17v40-Asset) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Tool {

+ lastCalibrationDate : Date [0..1]
}

class WorkAsset {

}

WorkAsset <|-- Tool : inherits from
```

Tool asset.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| lastCalibrationDate [0..1] | [Date](#CIM17v40-Date) | (if applicable) Date the tool was last calibrated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Crew [0..1] | [Crew](#CIM17v40-Crew) | see [WorkAsset](CIM17v40-WorkAsset) | |
| `CUWorkEquipmentAsset [0..1]` (informative) | [CUWorkEquipmentItem](#CIM17v40-CUWorkEquipmentItem) | see [WorkAsset](CIM17v40-WorkAsset) | |
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | see [Asset](#CIM17v40-Asset) | |
| initialCondition [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | see [Asset](CIM17v40-Asset) | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | see [Asset](CIM17v40-Asset) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [Asset](CIM17v40-Asset) | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | see [Asset](CIM17v40-Asset) | |
| lotNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| position [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | see [Asset](CIM17v40-Asset) | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | see [Asset](CIM17v40-Asset) | |
| serialNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| type [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| utcNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | see [Asset](CIM17v40-Asset) | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | see [Asset](CIM17v40-Asset) | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | see [Asset](CIM17v40-Asset) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [Asset](CIM17v40-Asset) | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | see [Asset](CIM17v40-Asset) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Asset](CIM17v40-Asset) | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | see [Asset](CIM17v40-Asset) | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | see [Asset](CIM17v40-Asset) | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | see [Asset](CIM17v40-Asset) | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | see [Asset](CIM17v40-Asset) | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | see [Asset](CIM17v40-Asset) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Asset](CIM17v40-Asset) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [Asset](CIM17v40-Asset) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [Asset](CIM17v40-Asset) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Asset](CIM17v40-Asset) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TopologicalIsland}
### TopologicalIsland

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TopologicalIsland {

}

class IdentifiedObject {

}

IdentifiedObject <|-- TopologicalIsland : inherits from
class TopologicalNode {

}

TopologicalIsland --> "0..1" TopologicalNode : AngleRefTopologicalNode
```

An electrically connected subset of the network. Topological islands can change as the current network state changes, e.g. due to:

- disconnect switches or breakers changing state in a SCADA/EMS.

- manual creation, change or deletion of topological nodes in a planning tool.

Only energised TopologicalNode-s shall be part of the topological island.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AngleRefTopologicalNode [0..1] | [TopologicalNode](#CIM17v40-TopologicalNode) | The angle reference for the island. Normally there is one TopologicalNode that is selected as the angle reference for each island. Other reference schemes exist, so the association is typically optional. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TopologicalNode}
### TopologicalNode

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TopologicalNode {

+ pInjection : ActivePower [0..1]
+ qInjection : ReactivePower [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- TopologicalNode : inherits from
class TopologicalIsland {

}

TopologicalNode --> "0..1" TopologicalIsland : AngleRefTopologicalIsland
class BaseVoltage {

}

TopologicalNode --> "0..1" BaseVoltage : BaseVoltage
class ConnectivityNodeContainer {

}

TopologicalNode --> "0..1" ConnectivityNodeContainer : ConnectivityNodeContainer
class ReportingGroup {

}

TopologicalNode --> "0..1" ReportingGroup : ReportingGroup
class TopologicalIsland {

}

TopologicalNode --> "0..1" TopologicalIsland : TopologicalIsland
```

For a detailed substation model a topological node is a set of connectivity nodes that, in the current network state, are connected together through any type of closed switches, including jumpers. Topological nodes change as the current network state changes (i.e., switches, breakers, etc. change state).

For a planning model, switch statuses are not used to form topological nodes. Instead they are manually created or deleted in a model builder tool. Topological nodes maintained this way are also called "busses".


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| pInjection [0..1] | [ActivePower](#CIM17v40-ActivePower) | The active power injected into the bus at this location in addition to injections from equipment. Positive sign means injection into the TopologicalNode (bus).Starting value for a steady state solution. | |
| qInjection [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | The reactive power injected into the bus at this location in addition to injections from equipment. Positive sign means injection into the TopologicalNode (bus).Starting value for a steady state solution. | |
| AngleRefTopologicalIsland [0..1] | [TopologicalIsland](#CIM17v40-TopologicalIsland) | The island for which the node is an angle reference. Normally there is one angle reference node for each island. | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | The base voltage of the topological node. | |
| ConnectivityNodeContainer [0..1] | [ConnectivityNodeContainer](#CIM17v40-ConnectivityNodeContainer) | The connectivity node container to which the topological node belongs. | |
| ReportingGroup [0..1] | [ReportingGroup](#CIM17v40-ReportingGroup) | The reporting group to which the topological node belongs. | |
| `TopologicalIsland [0..1]` (OfAggregate) | [TopologicalIsland](#CIM17v40-TopologicalIsland) | A topological node belongs to a topological island. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Tornado}
### Tornado

Inheritance path = [AtmosphericPhenomenon](#CIM17v40-AtmosphericPhenomenon) => [EnvironmentalPhenomenon](#CIM17v40-EnvironmentalPhenomenon)

```mermaid
classDiagram
direction TB

class Tornado {

+ fScale : enum:FScale [0..1]
+ width : Length [0..1]
}

class AtmosphericPhenomenon {

}

AtmosphericPhenomenon <|-- Tornado : inherits from
```

A tornado, a violent destructive whirling wind accompanied by a funnel-shaped cloud that progresses in a narrow path over the land.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| fScale [0..1] | [FScale](#CIM17v40-FScale) | Fujita scale (referred to as EF-scale starting in 2007) for the tornado. | |
| width [0..1] | [Length](#CIM17v40-Length) | Width of the tornado during the time interval. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| direction [0..1] | [Bearing](#CIM17v40-Bearing) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| maxCoverage [0..1] | [PerCent](#CIM17v40-PerCent) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| minCoverage [0..1] | [PerCent](#CIM17v40-PerCent) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| speed [0..1] | [Speed](#CIM17v40-Speed) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| altitude [0..1] | [RelativeDisplacement](#CIM17v40-RelativeDisplacement) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| base [0..1] | [RelativeDisplacement](#CIM17v40-RelativeDisplacement) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| PhenomenonClassification [0..1] | [PhenomenonClassification](#CIM17v40-PhenomenonClassification) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| timeInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |

{#CIM17v40-Tower}
### Tower

Inheritance path = [Structure](#CIM17v40-Structure) => [AssetContainer](#CIM17v40-AssetContainer) => [Asset](#CIM17v40-Asset) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Tower {

+ constructionKind : enum:TowerConstructionKind [0..1]
}

class Structure {

}

Structure <|-- Tower : inherits from
```

Tower asset. Dimensions of the Tower are specified in associated DimensionsInfo class.

When used for planning purposes, a transmission tower carrying two 3-phase circuits will have 2 instances of Connection, each of which will have 3 MountingPoint instances, one for each phase all with coordinates relative to a common origin on the tower. (It may also have a 3rd Connection with a single MountingPoint for the Neutral line).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| constructionKind [0..1] | [TowerConstructionKind](#CIM17v40-TowerConstructionKind) | Construction structure on the tower. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| fumigantAppliedDate [0..1] | [Date](#CIM17v40-Date) | see [Structure](#CIM17v40-Structure) | |
| fumigantName [0..1] | [String](#CIM17v40-String) | see [Structure](#CIM17v40-Structure) | |
| height [0..1] | [Length](#CIM17v40-Length) | see [Structure](CIM17v40-Structure) | |
| materialKind [0..1] | [StructureMaterialKind](#CIM17v40-StructureMaterialKind) | see [Structure](CIM17v40-Structure) | |
| ratedVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | see [Structure](CIM17v40-Structure) | |
| removeWeed [0..1] | [Boolean](#CIM17v40-Boolean) | see [Structure](#CIM17v40-Structure) | |
| weedRemovedDate [0..1] | [Date](#CIM17v40-Date) | see [Structure](#CIM17v40-Structure) | |
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | see [Asset](#CIM17v40-Asset) | |
| initialCondition [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | see [Asset](CIM17v40-Asset) | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | see [Asset](CIM17v40-Asset) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [Asset](CIM17v40-Asset) | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | see [Asset](CIM17v40-Asset) | |
| lotNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| position [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | see [Asset](CIM17v40-Asset) | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | see [Asset](CIM17v40-Asset) | |
| serialNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| type [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| utcNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | see [Asset](CIM17v40-Asset) | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | see [Asset](CIM17v40-Asset) | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | see [Asset](CIM17v40-Asset) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [Asset](CIM17v40-Asset) | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | see [Asset](CIM17v40-Asset) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Asset](CIM17v40-Asset) | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | see [Asset](CIM17v40-Asset) | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | see [Asset](CIM17v40-Asset) | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | see [Asset](CIM17v40-Asset) | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | see [Asset](CIM17v40-Asset) | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | see [Asset](CIM17v40-Asset) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Asset](CIM17v40-Asset) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [Asset](CIM17v40-Asset) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [Asset](CIM17v40-Asset) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Asset](CIM17v40-Asset) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Trade}
### Trade

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Trade {

+ adjustedTradeQuantity : Float [0..1]
+ counterTradeQuantity : Float [0..1]
+ dependOnTradeName : String [0..1]
+ lastModified : DateTime [0..1]
+ marketType : enum:MarketType [0..1]
+ startTime : DateTime [0..1]
+ stopTime : DateTime [0..1]
+ submitFromTimeStamp : DateTime [0..1]
+ submitFromUser : String [0..1]
+ submitToTimeStamp : DateTime [0..1]
+ submitToUser : String [0..1]
+ tradeQuantity : Float [0..1]
+ tradeStatus : String [0..1]
+ updateTimeStamp : DateTime [0..1]
+ updateUser : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Trade : inherits from
class ActionRequest {

}

Trade --> "1" ActionRequest : ActionRequest
class SchedulingCoordinator {

}

Trade --> "1" SchedulingCoordinator : From_SC
class Pnode {

}

Trade --> "0..1" Pnode : Pnode
class RegisteredGenerator {

}

Trade --> "0..1" RegisteredGenerator : RegisteredGenerator
class SchedulingCoordinator {

}

Trade --> "0..1" SchedulingCoordinator : submitFromSchedulingCoordinator
class SchedulingCoordinator {

}

Trade --> "0..1" SchedulingCoordinator : submitToSchedulingCoordinator
class SchedulingCoordinator {

}

Trade --> "1" SchedulingCoordinator : To_SC
class TradeProduct {

}

Trade --> "1" TradeProduct : TradeProduct
```

Inter Scheduling Coordinator Trades to model financial trades which may impact settlement.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| adjustedTradeQuantity [0..1] | [Float](#CIM17v40-Float) | The validated and current market accepted trade amount of a physical energy trade. | |
| counterTradeQuantity [0..1] | [Float](#CIM17v40-Float) | MW quantity submitted by counter SC for the same trade | |
| dependOnTradeName [0..1] | [String](#CIM17v40-String) | The Depend On IST Name points to the unique IST Name in the chain of physical energy trades. | |
| lastModified [0..1] | [DateTime](#CIM17v40-DateTime) | Time and date the trade was last modified. | |
| marketType [0..1] | [MarketType](#CIM17v40-MarketType) | | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | Start time and date for which trade applies. | |
| stopTime [0..1] | [DateTime](#CIM17v40-DateTime) | Stop time and date for which trade is applicable. | |
| submitFromTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | Timestamp of submittal of submit From Scheduling Coordinator Trade to Market Participant Bid Submittal | |
| submitFromUser [0..1] | [String](#CIM17v40-String) | Userid of the submit From Scheduling Coordinator trade | |
| submitToTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | Timestamp of submittal of submit To Scheduling Coordinator Trade to Market Participant Bid Submittal | |
| submitToUser [0..1] | [String](#CIM17v40-String) | Userid of the submit To Scheduling Coordinator trade | |
| tradeQuantity [0..1] | [Float](#CIM17v40-Float) | tradeQuantity:If tradeType = IST, The amount of an Energy Trade.If tradeType = AST, The amount of an Ancillary Service Obligation Trade.If tradeType = UCT, The amount of a Unit Commitment Obligation Trade. | |
| tradeStatus [0..1] | [String](#CIM17v40-String) | Resulting status of the trade following the rule engine processing. | |
| updateTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| updateUser [0..1] | [String](#CIM17v40-String) | | |
| ActionRequest [1] | [ActionRequest](#CIM17v40-ActionRequest) | | |
| From_SC [1] | [SchedulingCoordinator](#CIM17v40-SchedulingCoordinator) | | |
| Pnode [0..1] | [Pnode](#CIM17v40-Pnode) | | |
| RegisteredGenerator [0..1] | [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | | |
| submitFromSchedulingCoordinator [0..1] | [SchedulingCoordinator](#CIM17v40-SchedulingCoordinator) | | |
| submitToSchedulingCoordinator [0..1] | [SchedulingCoordinator](#CIM17v40-SchedulingCoordinator) | | |
| To_SC [1] | [SchedulingCoordinator](#CIM17v40-SchedulingCoordinator) | | |
| TradeProduct [1] | [TradeProduct](#CIM17v40-TradeProduct) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TradeError}
### TradeError

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TradeError {

+ endTime : DateTime [0..1]
+ errMessage : String [0..1]
+ errPriority : Integer [0..1]
+ logTimeStamp : DateTime [0..1]
+ ruleID : Integer [0..1]
+ startTime : DateTime [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- TradeError : inherits from
class Trade {

}

TradeError --> "0..1" Trade : Trade
```

Trade error and warning messages associated with the rule engine processing of the submitted trade.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | hour wihthin the trade for which the error applies | |
| errMessage [0..1] | [String](#CIM17v40-String) | error message | |
| errPriority [0..1] | [Integer](#CIM17v40-Integer) | Priority number for the error message | |
| logTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | Timestamp of logged error/warning message | |
| ruleID [0..1] | [Integer](#CIM17v40-Integer) | Rule identifier which triggered the error/warning message | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | hour wihthin the trade for which the error applies | |
| Trade [0..1] | [Trade](#CIM17v40-Trade) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TradeProduct}
### TradeProduct


```mermaid
classDiagram
direction TB

class TradeProduct {

+ tradeProductType : String [0..1]
+ tradeType : enum:TradeType [0..1]
}

```

<b>TradeType</b> <b>TradeProduct</b>

IST (InterSC Trade) PHY (Physical Energy Trade)

IST APN (Energy Trades at Aggregated Pricing Nodes)

IST CPT (Converted Physical Energy Trade)

AST (Ancilliary Services Trade) RUT (Regulation Up Trade)

AST RDT (Regulation Down Trade)

AST SRT (Spinning Reserve Trade)

AST NRT (Non-Spinning Reserve Trade)

UCT (Unit Commitment Trade) null


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| tradeProductType [0..1] | [String](#CIM17v40-String) | PHY (Physical Energy Trade);APN (Energy Trades at Aggregated Pricing Nodes);CPT (Converted Physical Energy Trade);RUT (Regulation Up Trade);RDT (Regulation Down Trade);SRT (Spinning Reserve Trade);NRT (Non-Spinning Reserve Trade) | |
| tradeType [0..1] | [TradeType](#CIM17v40-TradeType) | IST - InterSC Trade;AST - Ancilliary Services Trade;UCT - Unit Commitment Trade | |

{#CIM17v40-TradingHubPrice}
### TradingHubPrice


```mermaid
classDiagram
direction TB

class TradingHubPrice {

+ intervalStartTime : DateTime [0..1]
+ marketType : enum:MarketType [0..1]
+ updateTimeStamp : DateTime [0..1]
+ updateUser : String [0..1]
}

```

Models prices at Trading Hubs, interval based.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| marketType [0..1] | [MarketType](#CIM17v40-MarketType) | | |
| updateTimeStamp [0..1] | [DateTime](#CIM17v40-DateTime) | | |
| updateUser [0..1] | [String](#CIM17v40-String) | | |

{#CIM17v40-TradingHubValues}
### TradingHubValues


```mermaid
classDiagram
direction TB

class TradingHubValues {

+ price : Float [0..1]
}

class AggregatedPnode {

}

TradingHubValues --> "1" AggregatedPnode : AggregatedPnode
class TradingHubPrice {

}

TradingHubValues --> "1" TradingHubPrice : TradingHubPrice
```

Models prices at Trading Hubs.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| price [0..1] | [Float](#CIM17v40-Float) | Utilizes the Market type. For DA, the price is hourly. For RTM the price is a 5 minute price. | |
| AggregatedPnode [1] | [AggregatedPnode](#CIM17v40-AggregatedPnode) | | |
| `TradingHubPrice [1]` (OfAggregate) | [TradingHubPrice](#CIM17v40-TradingHubPrice) | | |

{#CIM17v40-Transaction}
### Transaction

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Transaction {

+ diverseReference : String [0..1]
+ donorReference : String [0..1]
+ kind : enum:TransactionKind [0..1]
+ receiverReference : String [0..1]
+ reversedId : String [0..1]
+ serviceUnitsEnergy : RealEnergy [0..1]
+ serviceUnitsError : RealEnergy [0..1]
+ line : LineDetail [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- Transaction : inherits from
class AuxiliaryAccount {

}

Transaction --> "0..1" AuxiliaryAccount : AuxiliaryAccount
class CashierShift {

}

Transaction --> "0..1" CashierShift : CashierShift
class CustomerAccount {

}

Transaction --> "0..1" CustomerAccount : CustomerAccount
class Meter {

}

Transaction --> "0..1" Meter : Meter
class PricingStructure {

}

Transaction --> "0..1" PricingStructure : PricingStructure
class Receipt {

}

Transaction --> "0..1" Receipt : Receipt
class VendorShift {

}

Transaction --> "0..1" VendorShift : VendorShift
```

The record of details of payment for service or token sale.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| diverseReference [0..1] | [String](#CIM17v40-String) | Formal reference for use with diverse payment (traffic fine for example). | |
| donorReference [0..1] | [String](#CIM17v40-String) | Reference to the entity that is the source of 'amount' (for example: customer for token purchase; or supplier for free issue token). | |
| kind [0..1] | [TransactionKind](#CIM17v40-TransactionKind) | Kind of transaction. | |
| receiverReference [0..1] | [String](#CIM17v40-String) | Reference to the entity that is the recipient of 'amount' (for example, supplier for service charge payment; or tax receiver for VAT). | |
| reversedId [0..1] | [String](#CIM17v40-String) | (if 'kind' is transactionReversal) Reference to the original transaction that is being reversed by this transaction. | |
| serviceUnitsEnergy [0..1] | [RealEnergy](#CIM17v40-RealEnergy) | Actual amount of service units that is being paid for. | |
| serviceUnitsError [0..1] | [RealEnergy](#CIM17v40-RealEnergy) | Number of service units not reflected in 'serviceUnitsEnergy' due to process rounding or truncating errors. | |
| AuxiliaryAccount [0..1] | [AuxiliaryAccount](#CIM17v40-AuxiliaryAccount) | Auxiliary account for this payment transaction. | |
| CashierShift [0..1] | [CashierShift](#CIM17v40-CashierShift) | Cashier shift during which this transaction was recorded. | |
| CustomerAccount [0..1] | [CustomerAccount](#CIM17v40-CustomerAccount) | Customer account for this payment transaction. | |
| line [0..1] | [LineDetail](#CIM17v40-LineDetail) | Transaction amount, rounding, date and note for this transaction line. | |
| Meter [0..1] | [Meter](#CIM17v40-Meter) | Meter for this vending transaction. | |
| PricingStructure [0..1] | [PricingStructure](#CIM17v40-PricingStructure) | Pricing structure applicable for this transaction. | |
| Receipt [0..1] | [Receipt](#CIM17v40-Receipt) | The receipted payment for which this transaction has been recorded. | |
| VendorShift [0..1] | [VendorShift](#CIM17v40-VendorShift) | Vendor shift during which this transaction was recorded. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TransactionBid}
### TransactionBid

Inheritance path = [Bid](#CIM17v40-Bid) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TransactionBid {

+ demandTransaction : Boolean [0..1]
+ dispatchable : Boolean [0..1]
+ payCongestion : Boolean [0..1]
}

class Bid {

}

Bid <|-- TransactionBid : inherits from
class Pnode {

}

TransactionBid --> "0..1" Pnode : Delivery_Pnode
class Pnode {

}

TransactionBid --> "0..1" Pnode : Receipt_Pnode
class TransmissionReservation {

}

TransactionBid --> "0..1" TransmissionReservation : TransmissionReservation
```

Bilateral or scheduled transactions for energy and ancillary services considered by market clearing process.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| demandTransaction [0..1] | [Boolean](#CIM17v40-Boolean) | Set true if this is a demand transaction. | |
| dispatchable [0..1] | [Boolean](#CIM17v40-Boolean) | Set true if this is a dispatchable transaction. | |
| payCongestion [0..1] | [Boolean](#CIM17v40-Boolean) | Set true if this is a willing to pay transaction. This flag is used to determine whether a schedule is willing-to-pay-congestion or not. | |
| Delivery_Pnode [0..1] | [Pnode](#CIM17v40-Pnode) | | |
| Receipt_Pnode [0..1] | [Pnode](#CIM17v40-Pnode) | | |
| TransmissionReservation [0..1] | [TransmissionReservation](#CIM17v40-TransmissionReservation) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| marketType [0..1] | [MarketType](#CIM17v40-MarketType) | see [Bid](CIM17v40-Bid) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Bid](#CIM17v40-Bid) | |
| stopTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Bid](#CIM17v40-Bid) | |
| ActionRequest [1] | [ActionRequest](#CIM17v40-ActionRequest) | see [Bid](CIM17v40-Bid) | |
| EnergyMarket [1] | [EnergyMarket](#CIM17v40-EnergyMarket) | see [Bid](CIM17v40-Bid) | |
| MarketParticipant [0..1] | [MarketParticipant](#CIM17v40-MarketParticipant) | see [Bid](CIM17v40-Bid) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TransactionBidClearing}
### TransactionBidClearing

Inheritance path = [MarketFactors](#CIM17v40-MarketFactors) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TransactionBidClearing {

}

class MarketFactors {

}

MarketFactors <|-- TransactionBidClearing : inherits from
```

Contains the intervals relavent for the associated TransactionBidResults. For example, Day Ahead cleared results for the transaction bids for each interval of the market day.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intervalEndTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| intervalStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [MarketFactors](#CIM17v40-MarketFactors) | |
| Market [0..1] | [Market](#CIM17v40-Market) | see [MarketFactors](CIM17v40-MarketFactors) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TransactionBidResults}
### TransactionBidResults

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TransactionBidResults {

+ clearedMW : Float [0..1]
+ clearedPrice : Float [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- TransactionBidResults : inherits from
class TransactionBid {

}

TransactionBidResults --> "0..1" TransactionBid : TransactionBid
class TransactionBidClearing {

}

TransactionBidResults --> "1" TransactionBidClearing : TransactionBidClearing
```

Contains the cleared results for each TransactionBid submitted to and accepted by the market.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| clearedMW [0..1] | [Float](#CIM17v40-Float) | The market transaction megawatt | |
| clearedPrice [0..1] | [Float](#CIM17v40-Float) | The price of the market transaction | |
| TransactionBid [0..1] | [TransactionBid](#CIM17v40-TransactionBid) | | |
| TransactionBidClearing [1] | [TransactionBidClearing](#CIM17v40-TransactionBidClearing) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Transactor}
### Transactor

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Transactor {

}

class IdentifiedObject {

}

IdentifiedObject <|-- Transactor : inherits from
```

The entity that ultimately executes the transaction and which is in control of the process; typically this is embodied in secure software running on a server that may employ secure hardware encryption devices for secure transaction processing.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TransferInterface}
### TransferInterface

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TransferInterface {

}

class IdentifiedObject {

}

IdentifiedObject <|-- TransferInterface : inherits from
class HostControlArea {

}

TransferInterface --> "0..1" HostControlArea : HostControlArea
class TransferInterfaceSolution {

}

TransferInterface --> "1" TransferInterfaceSolution : TransferInterfaceSolution
```

A Transfer Interface is made up of branches such as transmission lines and transformers.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| HostControlArea [0..1] | [HostControlArea](#CIM17v40-HostControlArea) | | |
| TransferInterfaceSolution [1] | [TransferInterfaceSolution](#CIM17v40-TransferInterfaceSolution) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TransferInterfaceSolution}
### TransferInterfaceSolution


```mermaid
classDiagram
direction TB

class TransferInterfaceSolution {

+ interfaceMargin : Float [0..1]
+ postTransferMW : Float [0..1]
+ transferLimit : Float [0..1]
}

class MktContingency {

}

TransferInterfaceSolution --> "0..1" MktContingency : MktContingencyA
class MktContingency {

}

TransferInterfaceSolution --> "0..1" MktContingency : MktContingencyB
class TransferInterface {

}

TransferInterfaceSolution --> "1" TransferInterface : TransferInterface
```

TNA Interface Definitions from OPF for VSA.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| interfaceMargin [0..1] | [Float](#CIM17v40-Float) | The margin for the interface | |
| postTransferMW [0..1] | [Float](#CIM17v40-Float) | Post Transfer MW for step | |
| transferLimit [0..1] | [Float](#CIM17v40-Float) | Transfer Interface + LimitAttribute Usage: The absoloute of the maximum flow on the transfer interface. This is a positive MW value. | |
| MktContingencyA [0..1] | [MktContingency](#CIM17v40-MktContingency) | | |
| MktContingencyB [0..1] | [MktContingency](#CIM17v40-MktContingency) | | |
| TransferInterface [1] | [TransferInterface](#CIM17v40-TransferInterface) | | |

{#CIM17v40-TransformerCoreAdmittance}
### TransformerCoreAdmittance

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TransformerCoreAdmittance {

+ b : Susceptance [0..1]
+ b0 : Susceptance [0..1]
+ g : Conductance [0..1]
+ g0 : Conductance [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- TransformerCoreAdmittance : inherits from
class TransformerEndInfo {

}

TransformerCoreAdmittance --> "0..1" TransformerEndInfo : TransformerEndInfo
```

The transformer core admittance. Used to specify the core admittance of a transformer in a manner that can be shared among power transformers.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| b [0..1] | [Susceptance](#CIM17v40-Susceptance) | Magnetizing branch susceptance (B mag). The value can be positive or negative. | |
| b0 [0..1] | [Susceptance](#CIM17v40-Susceptance) | Zero sequence magnetizing branch susceptance. | |
| g [0..1] | [Conductance](#CIM17v40-Conductance) | Magnetizing branch conductance (G mag). | |
| g0 [0..1] | [Conductance](#CIM17v40-Conductance) | Zero sequence magnetizing branch conductance. | |
| TransformerEndInfo [0..1] | [TransformerEndInfo](#CIM17v40-TransformerEndInfo) | Transformer end datasheet used to calculate this core admittance. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TransformerEnd}
### (informative) TransformerEnd

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TransformerEnd {

+ bmagSat : PerCent [0..1]
+ endNumber : Integer [0..1]
+ grounded : Boolean [0..1]
+ magBaseU : Voltage [0..1]
+ magSatFlux : PerCent [0..1]
+ rground : Resistance [0..1]
+ xground : Reactance [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- TransformerEnd : inherits from
class BaseVoltage {

}

TransformerEnd --> "0..1" BaseVoltage : BaseVoltage
class TransformerCoreAdmittance {

}

TransformerEnd --> "0..1" TransformerCoreAdmittance : CoreAdmittance
class PhaseTapChanger {

}

TransformerEnd --> "0..1" PhaseTapChanger : PhaseTapChanger
class RatioTapChanger {

}

TransformerEnd --> "0..1" RatioTapChanger : RatioTapChanger
class TransformerStarImpedance {

}

TransformerEnd --> "0..1" TransformerStarImpedance : StarImpedance
class Terminal {

}

TransformerEnd --> "0..1" Terminal : Terminal
```

A conducting connection point of a power transformer. It corresponds to a physical transformer winding terminal. In earlier CIM versions, the TransformerWinding class served a similar purpose, but this class is more flexible because it associates to terminal but is not a specialization of ConductingEquipment.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| bmagSat [0..1] | [PerCent](#CIM17v40-PerCent) | Core shunt magnetizing susceptance in the saturation region. | |
| endNumber [0..1] | [Integer](#CIM17v40-Integer) | Number for this transformer end, corresponding to the end's order in the power transformer vector group or phase angle clock number. Highest voltage winding should be 1. Each end within a power transformer should have a unique subsequent end number. Note the transformer end number need not match the terminal sequence number. | |
| grounded [0..1] | [Boolean](#CIM17v40-Boolean) | (for Yn and Zn connections) True if the neutral is solidly grounded. | |
| magBaseU [0..1] | [Voltage](#CIM17v40-Voltage) | The reference voltage at which the magnetizing saturation measurements were made. | |
| magSatFlux [0..1] | [PerCent](#CIM17v40-PerCent) | Core magnetizing saturation curve knee flux level. | |
| rground [0..1] | [Resistance](#CIM17v40-Resistance) | (for Yn and Zn connections) Resistance part of neutral impedance where 'grounded' is true. | |
| xground [0..1] | [Reactance](#CIM17v40-Reactance) | (for Yn and Zn connections) Reactive part of neutral impedance where 'grounded' is true. | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | Base voltage of the transformer end. This is essential for PU calculation. | |
| CoreAdmittance [0..1] | [TransformerCoreAdmittance](#CIM17v40-TransformerCoreAdmittance) | Core admittance of this transformer end, representing magnetising current and core losses. The full values of the transformer should be supplied for one transformer end only. | |
| PhaseTapChanger [0..1] | [PhaseTapChanger](#CIM17v40-PhaseTapChanger) | Phase tap changer associated with this transformer end. | |
| RatioTapChanger [0..1] | [RatioTapChanger](#CIM17v40-RatioTapChanger) | Ratio tap changer associated with this transformer end. | |
| StarImpedance [0..1] | [TransformerStarImpedance](#CIM17v40-TransformerStarImpedance) | (accurate for 2- or 3-winding transformers only) Pi-model impedances of this transformer end. By convention, for a two winding transformer, the full values of the transformer should be entered on the high voltage end (endNumber=1). | |
| Terminal [0..1] | [Terminal](#CIM17v40-Terminal) | Terminal of the power transformer to which this transformer end belongs. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TransformerEndInfo}
### TransformerEndInfo

Inheritance path = [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TransformerEndInfo {

+ connectionKind : enum:WindingConnection [0..1]
+ emergencyS : ApparentPower [0..1]
+ endNumber : Integer [0..1]
+ insulationU : Voltage [0..1]
+ phaseAngleClock : Integer [0..1]
+ r : Resistance [0..1]
+ ratedS : ApparentPower [0..1]
+ ratedU : Voltage [0..1]
+ shortTermS : ApparentPower [0..1]
}

class AssetInfo {

}

AssetInfo <|-- TransformerEndInfo : inherits from
class TransformerCoreAdmittance {

}

TransformerEndInfo --> "0..1" TransformerCoreAdmittance : CoreAdmittance
class TransformerStarImpedance {

}

TransformerEndInfo --> "0..1" TransformerStarImpedance : TransformerStarImpedance
class TransformerTankInfo {

}

TransformerEndInfo --> "1" TransformerTankInfo : TransformerTankInfo
```

Transformer end data.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| connectionKind [0..1] | [WindingConnection](#CIM17v40-WindingConnection) | Kind of connection. | |
| emergencyS [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | Apparent power that the winding can carry under emergency conditions (also called long-term emergency power). | |
| endNumber [0..1] | [Integer](#CIM17v40-Integer) | Number for this transformer end, corresponding to the end's order in the PowerTransformer.vectorGroup attribute. Highest voltage winding should be 1. | |
| insulationU [0..1] | [Voltage](#CIM17v40-Voltage) | Basic insulation level voltage rating. | |
| phaseAngleClock [0..1] | [Integer](#CIM17v40-Integer) | Winding phase angle where 360 degrees are represented with clock hours, so the valid values are {0, ..., 11}. For example, to express the second winding in code 'Dyn11', set attributes as follows: 'endNumber'=2, 'connectionKind' = Yn and 'phaseAngleClock' = 11. | |
| r [0..1] | [Resistance](#CIM17v40-Resistance) | DC resistance. | |
| ratedS [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | Normal apparent power rating. | |
| ratedU [0..1] | [Voltage](#CIM17v40-Voltage) | Rated voltage: phase-phase for three-phase windings, and either phase-phase or phase-neutral for single-phase windings. | |
| shortTermS [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | Apparent power that this winding can carry for a short period of time (in emergency). | |
| CoreAdmittance [0..1] | [TransformerCoreAdmittance](#CIM17v40-TransformerCoreAdmittance) | Core admittance calculated from this transformer end datasheet, representing magnetising current and core losses. The full values of the transformer should be supplied for one transformer end info only. | |
| TransformerStarImpedance [0..1] | [TransformerStarImpedance](#CIM17v40-TransformerStarImpedance) | Transformer star impedance calculated from this transformer end datasheet. | |
| TransformerTankInfo [1] | [TransformerTankInfo](#CIM17v40-TransformerTankInfo) | Transformer tank data that this end description is part of. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TransformerMeshImpedance}
### TransformerMeshImpedance

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TransformerMeshImpedance {

+ r : Resistance [0..1]
+ r0 : Resistance [0..1]
+ x : Reactance [0..1]
+ x0 : Reactance [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- TransformerMeshImpedance : inherits from
class TransformerEnd {

}

TransformerMeshImpedance --> "1" TransformerEnd : FromTransformerEnd
class TransformerEndInfo {

}

TransformerMeshImpedance --> "0..1" TransformerEndInfo : FromTransformerEndInfo
class TransformerEnd {

}

TransformerMeshImpedance --> "0..*" TransformerEnd : ToTransformerEnd
class TransformerEndInfo {

}

TransformerMeshImpedance --> "0..*" TransformerEndInfo : ToTransformerEndInfos
```

Transformer mesh impedance (Delta-model) between transformer ends.

The typical case is that this class describes the impedance between two transformer ends pair-wise, i.e. the cardinalities at both transformer end associations are 1. However, in cases where two or more transformer ends are modelled the cardinalities are larger than 1.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| r [0..1] | [Resistance](#CIM17v40-Resistance) | Resistance between the 'from' and the 'to' end, seen from the 'from' end. | |
| r0 [0..1] | [Resistance](#CIM17v40-Resistance) | Zero-sequence resistance between the 'from' and the 'to' end, seen from the 'from' end. | |
| x [0..1] | [Reactance](#CIM17v40-Reactance) | Reactance between the 'from' and the 'to' end, seen from the 'from' end. | |
| x0 [0..1] | [Reactance](#CIM17v40-Reactance) | Zero-sequence reactance between the 'from' and the 'to' end, seen from the 'from' end. | |
| FromTransformerEnd [1] | [TransformerEnd](#CIM17v40-TransformerEnd) | From end this mesh impedance is connected to. It determines the voltage reference. | |
| FromTransformerEndInfo [0..1] | [TransformerEndInfo](#CIM17v40-TransformerEndInfo) | 'from' transformer end datasheet this mesh impedance is calculated from. It determines the voltage reference. | |
| ToTransformerEnd [0..*] | [TransformerEnd](#CIM17v40-TransformerEnd) | All transformer ends this mesh impedance is connected to. | |
| ToTransformerEndInfos [0..*] | [TransformerEndInfo](#CIM17v40-TransformerEndInfo) | All 'to' transformer end datasheets this mesh impedance for 'from' transformer end is calculated from. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TransformerObservation}
### (informative) TransformerObservation

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TransformerObservation {

+ bushingTemp : Temperature [0..1]
+ dga : String [0..1]
+ freqResp : String [0..1]
+ furfuralDP : String [0..1]
+ hotSpotTemp : Temperature [0..1]
+ oilColor : String [0..1]
+ oilDielectricStrength : Voltage [0..1]
+ oilIFT : String [0..1]
+ oilLevel : String [0..1]
+ oilNeutralizationNumber : String [0..1]
+ pumpVibration : String [0..1]
+ topOilTemp : Temperature [0..1]
+ waterContent : String [0..1]
+ status : Status [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- TransformerObservation : inherits from
class Reconditioning {

}

TransformerObservation --> "1" Reconditioning : Reconditioning
class TransformerTank {

}

TransformerObservation --> "0..1" TransformerTank : Transformer
```

Common information captured during transformer inspections and/or diagnostics. Note that some properties may be measured through other means and therefore have measurement values in addition to the observed values recorded here.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| bushingTemp [0..1] | [Temperature](#CIM17v40-Temperature) | Bushing temperature. | |
| dga [0..1] | [String](#CIM17v40-String) | Dissolved Gas Analysis. Typical values are: Acceptable, Overheating, Corona, Sparking, Arcing. | |
| freqResp [0..1] | [String](#CIM17v40-String) | Frequency Response Analysis. Typical values are: acceptable, slight movement, significant movement, failed, near failure. A graphic of the response diagram, which is a type of document, may be associated with this analysis through the recursive document relationship of the ProcedureDataSet. | |
| furfuralDP [0..1] | [String](#CIM17v40-String) | Overall measure of furfural in oil and mechanical strength of paper. DP, the degree of polymerization, is the strength of the paper. Furfural is a measure of furfural compounds, often expressed in parts per million. | |
| hotSpotTemp [0..1] | [Temperature](#CIM17v40-Temperature) | Hotspot oil temperature. | |
| oilColor [0..1] | [String](#CIM17v40-String) | Oil Quality Analysis-Color. | |
| oilDielectricStrength [0..1] | [Voltage](#CIM17v40-Voltage) | Oil Quality Analysis-Dielectric Strength. | |
| oilIFT [0..1] | [String](#CIM17v40-String) | Oil Quality Analysis- inter facial tension (IFT) - number-Dynes/CM. | |
| oilLevel [0..1] | [String](#CIM17v40-String) | The level of oil in the transformer. | |
| oilNeutralizationNumber [0..1] | [String](#CIM17v40-String) | Oil Quality Analysis-Neutralization Number - Number - Mg KOH. | |
| pumpVibration [0..1] | [String](#CIM17v40-String) | Pump vibration, with typical values being: nominal, high. | |
| topOilTemp [0..1] | [Temperature](#CIM17v40-Temperature) | Top oil temperature. | |
| waterContent [0..1] | [String](#CIM17v40-String) | Water Content expressed in parts per million. | |
| `Reconditioning [1]` (informative) | [Reconditioning](#CIM17v40-Reconditioning) | | |
| status [0..1] | [Status](#CIM17v40-Status) | | |
| `Transformer [0..1]` (informative) | [TransformerTank](#CIM17v40-TransformerTank) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TransformerStarImpedance}
### TransformerStarImpedance

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TransformerStarImpedance {

+ r : Resistance [0..1]
+ r0 : Resistance [0..1]
+ x : Reactance [0..1]
+ x0 : Reactance [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- TransformerStarImpedance : inherits from
class TransformerEndInfo {

}

TransformerStarImpedance --> "0..1" TransformerEndInfo : TransformerEndInfo
```

Transformer star impedance (Pi-model) that accurately reflects impedance for transformers with 2 or 3 windings. For transformers with 4 or more windings, TransformerMeshImpedance class shall be used.

For transmission networks use PowerTransformerEnd impedances (r, r0, x, x0, b, b0, g and g0).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| r [0..1] | [Resistance](#CIM17v40-Resistance) | Resistance of the transformer end. | |
| r0 [0..1] | [Resistance](#CIM17v40-Resistance) | Zero sequence series resistance of the transformer end. | |
| x [0..1] | [Reactance](#CIM17v40-Reactance) | Positive sequence series reactance of the transformer end. | |
| x0 [0..1] | [Reactance](#CIM17v40-Reactance) | Zero sequence series reactance of the transformer end. | |
| TransformerEndInfo [0..1] | [TransformerEndInfo](#CIM17v40-TransformerEndInfo) | Transformer end datasheet used to calculate this transformer star impedance. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TransformerTank}
### (informative) TransformerTank

Inheritance path = [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TransformerTank {

}

class Equipment {

}

Equipment <|-- TransformerTank : inherits from
class PowerTransformer {

}

TransformerTank --> "0..1" PowerTransformer : PowerTransformer
```

An assembly of two or more coupled windings that transform electrical power between voltage levels. These windings are bound on a common core and placed in the same tank. Transformer tank can be used to model both single-phase and 3-phase transformers.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| PowerTransformer [0..1] | [PowerTransformer](#CIM17v40-PowerTransformer) | Bank this transformer belongs to. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TransformerTankEnd}
### TransformerTankEnd

Inheritance path = [TransformerEnd](#CIM17v40-TransformerEnd) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TransformerTankEnd {

+ phases : enum:PhaseCode [0..1]
}

class TransformerEnd {

}

TransformerEnd <|-- TransformerTankEnd : inherits from
class TransformerTank {

}

TransformerTankEnd --> "0..1" TransformerTank : TransformerTank
```

Transformer tank end represents an individual winding for unbalanced models or for transformer tanks connected into a bank (and bank is modelled with the PowerTransformer).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | Describes the phases carried by a conducting equipment. | |
| TransformerTank [0..1] | [TransformerTank](#CIM17v40-TransformerTank) | Transformer this winding belongs to. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| bmagSat [0..1] | [PerCent](#CIM17v40-PerCent) | see [TransformerEnd](CIM17v40-TransformerEnd) | |
| endNumber [0..1] | [Integer](#CIM17v40-Integer) | see [TransformerEnd](#CIM17v40-TransformerEnd) | |
| grounded [0..1] | [Boolean](#CIM17v40-Boolean) | see [TransformerEnd](#CIM17v40-TransformerEnd) | |
| magBaseU [0..1] | [Voltage](#CIM17v40-Voltage) | see [TransformerEnd](CIM17v40-TransformerEnd) | |
| magSatFlux [0..1] | [PerCent](#CIM17v40-PerCent) | see [TransformerEnd](CIM17v40-TransformerEnd) | |
| rground [0..1] | [Resistance](#CIM17v40-Resistance) | see [TransformerEnd](CIM17v40-TransformerEnd) | |
| xground [0..1] | [Reactance](#CIM17v40-Reactance) | see [TransformerEnd](CIM17v40-TransformerEnd) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [TransformerEnd](CIM17v40-TransformerEnd) | |
| CoreAdmittance [0..1] | [TransformerCoreAdmittance](#CIM17v40-TransformerCoreAdmittance) | see [TransformerEnd](CIM17v40-TransformerEnd) | |
| PhaseTapChanger [0..1] | [PhaseTapChanger](#CIM17v40-PhaseTapChanger) | see [TransformerEnd](CIM17v40-TransformerEnd) | |
| RatioTapChanger [0..1] | [RatioTapChanger](#CIM17v40-RatioTapChanger) | see [TransformerEnd](CIM17v40-TransformerEnd) | |
| StarImpedance [0..1] | [TransformerStarImpedance](#CIM17v40-TransformerStarImpedance) | see [TransformerEnd](CIM17v40-TransformerEnd) | |
| Terminal [0..1] | [Terminal](#CIM17v40-Terminal) | see [TransformerEnd](CIM17v40-TransformerEnd) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TransformerTankInfo}
### TransformerTankInfo

Inheritance path = [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TransformerTankInfo {

}

class AssetInfo {

}

AssetInfo <|-- TransformerTankInfo : inherits from
class PowerTransformerInfo {

}

TransformerTankInfo --> "1" PowerTransformerInfo : PowerTransformerInfo
```

Set of transformer tank data, from an equipment library.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| PowerTransformerInfo [1] | [PowerTransformerInfo](#CIM17v40-PowerTransformerInfo) | Power transformer data that this tank description is part of. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TransformerTest}
### TransformerTest

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TransformerTest {

+ basePower : ApparentPower [0..1]
+ temperature : Temperature [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- TransformerTest : inherits from
```

Test result for transformer ends, such as short-circuit, open-circuit (excitation) or no-load test.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| basePower [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | Base power at which the tests are conducted, usually equal to the rateds of one of the involved transformer ends. | |
| temperature [0..1] | [Temperature](#CIM17v40-Temperature) | Temperature at which the test is conducted. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TransmissionCapacity}
### TransmissionCapacity


```mermaid
classDiagram
direction TB

class TransmissionCapacity {

+ capacityBenefitMargin : Float [0..1]
+ operationalTransmissionCapacity : Float [0..1]
+ OTC15min_emergency : Float [0..1]
+ OTCemergency : Float [0..1]
+ POD : String [0..1]
+ POR : String [0..1]
+ startOperatingDate : DateTime [0..1]
+ totalTransmissionCapacity : Float [0..1]
}

class Flowgate {

}

TransmissionCapacity --> "0..1" Flowgate : Flowgate
class GenericConstraints {

}

TransmissionCapacity --> "0..1" GenericConstraints : GenericConstraints
```

This class models the transmission (either a transmission interface or a POR/POD pair) capacity including Total Transfer Capacity (TTC), Operating Transfer Capacity (OTC), and Capacity Benefit Margin (CBM).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| capacityBenefitMargin [0..1] | [Float](#CIM17v40-Float) | Capacity Benefit Margin (CBM) is used by Markets to calculate the transmission interface limits. This number could be manually or procedurally determined. The CBM is defined per transmission interface (branch group). | |
| operationalTransmissionCapacity [0..1] | [Float](#CIM17v40-Float) | The Operational Transmission Capacity (OTC) is the transmission capacity under the operating condition during a specific time period, incorporating the effects of derates and current settings of operation controls. The OTCs for all transmission interface (branch group) are always provided regardless of outage or switching conditions. | |
| OTC15min_emergency [0..1] | [Float](#CIM17v40-Float) | The Operational Transmission Capacity (OTC) 15 minute Emergency Limit | |
| OTCemergency [0..1] | [Float](#CIM17v40-Float) | The Operational Transmission Capacity (OTC) Emergency Limit. | |
| POD [0..1] | [String](#CIM17v40-String) | point of delivery | |
| POR [0..1] | [String](#CIM17v40-String) | point of receipt | |
| startOperatingDate [0..1] | [DateTime](#CIM17v40-DateTime) | Operating date &amp; hour when the entitlement applies | |
| totalTransmissionCapacity [0..1] | [Float](#CIM17v40-Float) | Total Transmission Capacity | |
| Flowgate [0..1] | [Flowgate](#CIM17v40-Flowgate) | | |
| GenericConstraints [0..1] | [GenericConstraints](#CIM17v40-GenericConstraints) | | |

{#CIM17v40-TransmissionCorridor}
### (informative) TransmissionCorridor

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TransmissionCorridor {

}

class PowerSystemResource {

}

PowerSystemResource <|-- TransmissionCorridor : inherits from
```

A corridor containing one or more rights of way


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TransmissionInterfaceRightEntitlement}
### TransmissionInterfaceRightEntitlement


```mermaid
classDiagram
direction TB

class TransmissionInterfaceRightEntitlement {

+ entitlement : Float [0..1]
+ POD : String [0..1]
+ POR : String [0..1]
+ startOperatingDate : DateTime [0..1]
}

class ContractRight {

}

TransmissionInterfaceRightEntitlement --> "1" ContractRight : ContractRight
class Flowgate {

}

TransmissionInterfaceRightEntitlement --> "0..1" Flowgate : Flowgate
```

This is formally called the branch group ETC/TOR entitlement with the inclusion of CVR as ETC. This could be also used to represent the TR entitlement on a POR/POD.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| entitlement [0..1] | [Float](#CIM17v40-Float) | the entitlement | |
| POD [0..1] | [String](#CIM17v40-String) | point of delivery | |
| POR [0..1] | [String](#CIM17v40-String) | point of receipt | |
| startOperatingDate [0..1] | [DateTime](#CIM17v40-DateTime) | Operating date and hour when the entitlement applies | |
| ContractRight [1] | [ContractRight](#CIM17v40-ContractRight) | | |
| Flowgate [0..1] | [Flowgate](#CIM17v40-Flowgate) | | |

{#CIM17v40-TransmissionPath}
### TransmissionPath

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TransmissionPath {

+ availTransferCapability : ActivePower [0..1]
+ parallelPathFlag : Boolean [0..1]
+ totalTransferCapability : ActivePower [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- TransmissionPath : inherits from
class ServicePoint {

}

TransmissionPath --> "1" ServicePoint : DeliveryPoint
class TransmissionCorridor {

}

TransmissionPath --> "1" TransmissionCorridor : For
class ServicePoint {

}

TransmissionPath --> "1" ServicePoint : PointOfReceipt
```

An electrical connection, link, or line consisting of one or more parallel transmission elements between two areas of the interconnected electric systems, or portions thereof. TransmissionCorridor and TransmissionRightOfWay refer to legal aspects. The TransmissionPath refers to the segments between a TransmissionProvider's ServicePoints.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| availTransferCapability [0..1] | [ActivePower](#CIM17v40-ActivePower) | The available transmission capability of a transmission path for the reference direction. | |
| parallelPathFlag [0..1] | [Boolean](#CIM17v40-Boolean) | Flag which indicates if the transmission path is also a designated interconnection "parallel path". | |
| totalTransferCapability [0..1] | [ActivePower](#CIM17v40-ActivePower) | The total transmission capability of a transmission path in the reference direction. | |
| DeliveryPoint [1] | [ServicePoint](#CIM17v40-ServicePoint) | A transmission path has a "point-of-delivery" service point | |
| `For [1]` (informative) | [TransmissionCorridor](#CIM17v40-TransmissionCorridor) | A TransmissionPath is contained in a TransmissionCorridor. | |
| PointOfReceipt [1] | [ServicePoint](#CIM17v40-ServicePoint) | A transmission path has a "point-of-receipt" service point | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TransmissionProduct}
### TransmissionProduct

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TransmissionProduct {

+ transmissionProductType : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- TransmissionProduct : inherits from
class TransmissionProvider {

}

TransmissionProduct --> "1" TransmissionProvider : TransmissionProvider
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| transmissionProductType [0..1] | [String](#CIM17v40-String) | Type of the transmission product. This could be a transmission service class (firm, total transmission capability, or non-firm), transmission service period (on-peak, full-period, off-peak), transmission service increments (yearly extended, hourly fixed, monthly sliding, etc.), transmission service type (network, available transmission capability, or point-to-point, or a transmission service window (fixed hourly, sliding weekly, extended monthly, etc.). | |
| `TransmissionProvider [1]` (informative) | [TransmissionProvider](#CIM17v40-TransmissionProvider) | A TransmissionProvider offers a TransmissionProduct. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TransmissionProvider}
### (informative) TransmissionProvider

Inheritance path = [Organisation](#CIM17v40-Organisation) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TransmissionProvider {

}

class Organisation {

}

Organisation <|-- TransmissionProvider : inherits from
```

Provider of the transmission capacity (interconnecting wires between Generation and Consumption) required to fulfill and Energy Transaction's energy exchange. Posts information for transmission paths and AvailableTransmissionCapacities on a reservation node. Buys and sells its products and services on the same reservation node.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Organisation](CIM17v40-Organisation) | |
| ParentOrganisation [0..1] | [ParentOrganization](#CIM17v40-ParentOrganization) | see [Organisation](CIM17v40-Organisation) | |
| phone1 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Organisation](CIM17v40-Organisation) | |
| phone2 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Organisation](CIM17v40-Organisation) | |
| postalAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Organisation](CIM17v40-Organisation) | |
| streetAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Organisation](CIM17v40-Organisation) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TransmissionReservation}
### TransmissionReservation


```mermaid
classDiagram
direction TB

class TransmissionReservation {

}

class EnergyTransaction {

}

TransmissionReservation --> "0..1" EnergyTransaction : EnergyTransaction
class ServicePoint {

}

TransmissionReservation --> "0..1" ServicePoint : Sink
class ServicePoint {

}

TransmissionReservation --> "0..1" ServicePoint : Source
class TransactionBid {

}

TransmissionReservation --> "0..1" TransactionBid : TransactionBid
class TransmissionPath {

}

TransmissionReservation --> "1" TransmissionPath : TransmissionPath
```

A transmission reservation is obtained from the OASIS system to reserve transmission for a specified time period, transmission path and transmission product.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| EnergyTransaction [0..1] | [EnergyTransaction](#CIM17v40-EnergyTransaction) | | |
| Sink [0..1] | [ServicePoint](#CIM17v40-ServicePoint) | | |
| Source [0..1] | [ServicePoint](#CIM17v40-ServicePoint) | | |
| TransactionBid [0..1] | [TransactionBid](#CIM17v40-TransactionBid) | | |
| TransmissionPath [1] | [TransmissionPath](#CIM17v40-TransmissionPath) | | |

{#CIM17v40-TransmissionRightChain}
### TransmissionRightChain

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TransmissionRightChain {

}

class IdentifiedObject {

}

IdentifiedObject <|-- TransmissionRightChain : inherits from
class ContractRight {

}

TransmissionRightChain --> "1" ContractRight : Chain_ContractRight
class RTO {

}

TransmissionRightChain --> "1" RTO : RTO
```

Allows chaining of TransmissionContractRights. Many individual contract rights can be included in the definition of a TransmissionRightChain. A TransmissionRightChain is also defined as a TransmissionContractRight itself.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Chain_ContractRight [1] | [ContractRight](#CIM17v40-ContractRight) | | |
| RTO [1] | [RTO](#CIM17v40-RTO) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TransmissionRightOfWay}
### (informative) TransmissionRightOfWay

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TransmissionRightOfWay {

}

class PowerSystemResource {

}

PowerSystemResource <|-- TransmissionRightOfWay : inherits from
class TransmissionCorridor {

}

TransmissionRightOfWay --> "1" TransmissionCorridor : TransmissionCorridor
```

A collection of transmission lines that are close proximity to each other.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `TransmissionCorridor [1]` (OfAggregate, informative) | [TransmissionCorridor](#CIM17v40-TransmissionCorridor) | A transmission right-of-way is a member of a transmission corridor | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TriggerCondition}
### TriggerCondition

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TriggerCondition {

}

class IdentifiedObject {

}

IdentifiedObject <|-- TriggerCondition : inherits from
class Gate {

}

TriggerCondition --> "1" Gate : GateTrigger
class RemedialActionScheme {

}

TriggerCondition --> "1" RemedialActionScheme : RemedialActionScheme
```

A conditions that can trigger remedial actions.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `GateTrigger [1]` (informative) | [Gate](#CIM17v40-Gate) | The resulting Gate that is the condition for the Trigger. | |
| `RemedialActionScheme [1]` (informative) | [RemedialActionScheme](#CIM17v40-RemedialActionScheme) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TropicalCycloneAustralia}
### TropicalCycloneAustralia

Inheritance path = [Cyclone](#CIM17v40-Cyclone) => [AtmosphericPhenomenon](#CIM17v40-AtmosphericPhenomenon) => [EnvironmentalPhenomenon](#CIM17v40-EnvironmentalPhenomenon)

```mermaid
classDiagram
direction TB

class TropicalCycloneAustralia {

+ category : Integer [0..1]
}

class Cyclone {

}

Cyclone <|-- TropicalCycloneAustralia : inherits from
```

A tropical cyclone, a subtype of cyclone that forms to the east of 90�E in the Southern Hemisphere whose intensity is measured by the Australian tropical cyclone intensity scale.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| category [0..1] | [Integer](#CIM17v40-Integer) | Strength of tropical cyclone during the time interval, based on Australian Bureau of Meteorology Category System where:1 - tropical cyclone, with typical gusts over flat land 90-125 km/h2 - tropical cyclone, with typical gusts over flat land 125-164 km/h3 - severe tropical cyclone, with typical gusts over flat land 165-224 km/h4 - severe tropical cyclone, with typical gusts over flat land 225-279 km/h5 - severe tropical cyclone, with typical gusts over flat land greater than 280 km/h. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| centralPressure [0..1] | [Pressure](#CIM17v40-Pressure) | see [Cyclone](CIM17v40-Cyclone) | |
| maxSurfaceWindSpeed [0..1] | [Speed](#CIM17v40-Speed) | see [Cyclone](CIM17v40-Cyclone) | |
| windForce [0..1] | [Integer](#CIM17v40-Integer) | see [Cyclone](#CIM17v40-Cyclone) | |
| direction [0..1] | [Bearing](#CIM17v40-Bearing) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| maxCoverage [0..1] | [PerCent](#CIM17v40-PerCent) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| minCoverage [0..1] | [PerCent](#CIM17v40-PerCent) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| speed [0..1] | [Speed](#CIM17v40-Speed) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| altitude [0..1] | [RelativeDisplacement](#CIM17v40-RelativeDisplacement) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| base [0..1] | [RelativeDisplacement](#CIM17v40-RelativeDisplacement) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| PhenomenonClassification [0..1] | [PhenomenonClassification](#CIM17v40-PhenomenonClassification) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| timeInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |

{#CIM17v40-TroubleOrder}
### TroubleOrder

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TroubleOrder {

+ comment : String [0..1]
+ plannedExecutionInterval : DateTimeInterval [0..1]
}

class Document {

}

Document <|-- TroubleOrder : inherits from
class Incident {

}

TroubleOrder --> "0..1" Incident : Incident
class Location {

}

TroubleOrder --> "0..1" Location : Location
class UnplannedOutage {

}

TroubleOrder --> "0..1" UnplannedOutage : UnplannedOutage
```

Trouble order sends an incident to a crew to initiate a response to an unplanned outage.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| comment [0..1] | [String](#CIM17v40-String) | Free-form comment associated with the trouble order. | |
| Incident [0..1] | [Incident](#CIM17v40-Incident) | The incident that may be associated with the trouble order. | |
| Location [0..1] | [Location](#CIM17v40-Location) | The location of this trouble order | |
| plannedExecutionInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | The planned start and end time for the trouble order. | |
| UnplannedOutage [0..1] | [UnplannedOutage](#CIM17v40-UnplannedOutage) | The unplanned outage that is associated to the Trouble Order. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TroubleReporter}
### TroubleReporter

Inheritance path = [OperationPersonRole](#CIM17v40-OperationPersonRole) => [PersonRole](#CIM17v40-PersonRole) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TroubleReporter {

+ troubleReporterType : String [0..1]
}

class OperationPersonRole {

}

OperationPersonRole <|-- TroubleReporter : inherits from
```

Type of Person reporting the Trouble - Customer, First Responder, Passer-by, etc.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| troubleReporterType [0..1] | [String](#CIM17v40-String) | The type of person reporting the trouble | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Person [0..1] | [Person](#CIM17v40-Person) | see [PersonRole](CIM17v40-PersonRole) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TroubleSymptoms}
### TroubleSymptoms


```mermaid
classDiagram
direction TB

class TroubleSymptoms {

+ troubleSymptomsExtent : enum:TroubleSymptomsExtentKind [1]
+ troubleSymptomsExtentOther : String [0..1]
+ troubleSymptomsLight : enum:TroubleSymptomsLightKind [1]
+ troubleSymptomsLightOther : String [0..1]
+ troubleSymptomsPole : enum:TroubleSymptomsPoleKind [1]
+ troubleSymptomsPoleOther : String [0..1]
+ troubleSymptomsTransformer : enum:TroubleSymptomsTransformerKind [1]
+ troubleSymptomsTransformerOther : String [0..1]
+ troubleSymptomsTree : enum:TroubleSymptomsTree_Kind [1]
+ troubleSymptomsTreeOther : String [0..1]
+ troubleSymptomsWire : enum:TroubleSymptomsWireKind [1]
+ troubleSymptomsWireOther : String [0..1]
}

class TroubleTicket {

}

TroubleSymptoms --> "0..1" TroubleTicket : TroubleTicket
```

Trouble symptoms reported by person reporting the trouble. The symptoms provide clues to utility personnel analyzing the ticket to help identify the root cause of the problem.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| troubleSymptomsExtent [1] | [TroubleSymptomsExtentKind](#CIM17v40-TroubleSymptomsExtentKind) | The extent of the problem being reported. | |
| troubleSymptomsExtentOther [0..1] | [String](#CIM17v40-String) | The extent of the problem being reported that does not fit any of the enumeration values. | |
| troubleSymptomsLight [1] | [TroubleSymptomsLightKind](#CIM17v40-TroubleSymptomsLightKind) | The problem with lights being reported. | |
| troubleSymptomsLightOther [0..1] | [String](#CIM17v40-String) | The problem with lights being reported that does not fit any of the enumeration values | |
| troubleSymptomsPole [1] | [TroubleSymptomsPoleKind](#CIM17v40-TroubleSymptomsPoleKind) | The problem with pole being reported. | |
| troubleSymptomsPoleOther [0..1] | [String](#CIM17v40-String) | The problem with pole being reported that does not fit any of the enumeration values | |
| troubleSymptomsTransformer [1] | [TroubleSymptomsTransformerKind](#CIM17v40-TroubleSymptomsTransformerKind) | The problem with transformer being reported. | |
| troubleSymptomsTransformerOther [0..1] | [String](#CIM17v40-String) | The problem with transformer being reported that does not fit any of the enumeration values | |
| troubleSymptomsTree [1] | [TroubleSymptomsTree_Kind](#CIM17v40-TroubleSymptomsTree_Kind) | The problem with tree being reported. | |
| troubleSymptomsTreeOther [0..1] | [String](#CIM17v40-String) | The problem with tree being reported that does not fit any of the enumeration values | |
| troubleSymptomsWire [1] | [TroubleSymptomsWireKind](#CIM17v40-TroubleSymptomsWireKind) | The problem with wire being reported. | |
| troubleSymptomsWireOther [0..1] | [String](#CIM17v40-String) | The problem with wire being reported that does not fit any of the enumeration values | |
| TroubleTicket [0..1] | [TroubleTicket](#CIM17v40-TroubleTicket) | | |

{#CIM17v40-TroubleTicket}
### TroubleTicket

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TroubleTicket {

+ comment : String [0..1]
+ dateTimeOfReport : DateTime [0..1]
+ firstResponderStatus : String [0..1]
+ multiplePremises : Boolean [0..1]
+ reportingKind : enum:TroubleReportingKind [0..1]
+ resolvedDateTime : DateTime [0..1]
+ troubleCode : String [0..1]
}

class Document {

}

Document <|-- TroubleTicket : inherits from
class Customer {

}

TroubleTicket --> "0..1" Customer : Customer
class Incident {

}

TroubleTicket --> "0..1" Incident : Incident
class Location {

}

TroubleTicket --> "0..1" Location : Location
class ServiceLocation {

}

TroubleTicket --> "1" ServiceLocation : ServiceLocation
class TroubleOrder {

}

TroubleTicket --> "0..1" TroubleOrder : TroubleOrder
class TroubleReporter {

}

TroubleTicket --> "0..1" TroubleReporter : TroubleReporter
class TroubleSymptoms {

}

TroubleTicket --> "0..1" TroubleSymptoms : TroubleSymptoms
class UnplannedOutage {

}

TroubleTicket --> "0..1" UnplannedOutage : UnplannedOutage
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| comment [0..1] | [String](#CIM17v40-String) | Free-form comment associated with the trouble call for example, "customer reported a large flash", etc. | |
| dateTimeOfReport [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time the trouble has been reported. | |
| firstResponderStatus [0..1] | [String](#CIM17v40-String) | Indicates whether the first responder such as police, fire department etc.has been notified and whether they are on site or en route. | |
| multiplePremises [0..1] | [Boolean](#CIM17v40-Boolean) | Set to true if the outage report indicated that other neighbors are also out of power. | |
| reportingKind [0..1] | [TroubleReportingKind](#CIM17v40-TroubleReportingKind) | Indicates how the customer reported trouble. | |
| resolvedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time this trouble ticket has been resolved. | |
| troubleCode [0..1] | [String](#CIM17v40-String) | Trouble code (e.g., power down, flickering lights, partial power, etc). | |
| Customer [0..1] | [Customer](#CIM17v40-Customer) | Customer for whom this trouble ticket is relevant. | |
| Incident [0..1] | [Incident](#CIM17v40-Incident) | Incident reported in this trouble ticket | |
| Location [0..1] | [Location](#CIM17v40-Location) | | |
| ServiceLocation [1] | [ServiceLocation](#CIM17v40-ServiceLocation) | The service location to which one or more trouble tickets are associated. | |
| TroubleOrder [0..1] | [TroubleOrder](#CIM17v40-TroubleOrder) | The order to which one or more trouble tickets are associated. | |
| TroubleReporter [0..1] | [TroubleReporter](#CIM17v40-TroubleReporter) | | |
| TroubleSymptoms [0..1] | [TroubleSymptoms](#CIM17v40-TroubleSymptoms) | | |
| UnplannedOutage [0..1] | [UnplannedOutage](#CIM17v40-UnplannedOutage) | The unplanned outage to which one or more trouble tickets are associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Tsunami}
### Tsunami

Inheritance path = [HydrosphericPhenomenon](#CIM17v40-HydrosphericPhenomenon) => [EnvironmentalPhenomenon](#CIM17v40-EnvironmentalPhenomenon)

```mermaid
classDiagram
direction TB

class Tsunami {

+ intensity : Integer [0..1]
+ magnitude : Float [0..1]
}

class HydrosphericPhenomenon {

}

HydrosphericPhenomenon <|-- Tsunami : inherits from
```

A tsunami (tidal wave), a long high sea wave caused by an earthquake, submarine landslide, or other disturbance.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| intensity [0..1] | [Integer](#CIM17v40-Integer) | Tsunami intensity on the Papadopoulos-Imamura tsunami intensity scale. Possible values are 1-12, corresponding to I-XII. | |
| magnitude [0..1] | [Float](#CIM17v40-Float) | Tsunami magnitude in the Tsunami Magnitude Scale (Mt). Is greater than zero. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| PhenomenonClassification [0..1] | [PhenomenonClassification](#CIM17v40-PhenomenonClassification) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| timeInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |

{#CIM17v40-TurbLCFB1}
### TurbLCFB1

Inheritance path = [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TurbLCFB1 {

+ db : PU [0..1]
+ emax : PU [0..1]
+ fb : PU [0..1]
+ fbf : Boolean [0..1]
+ irmax : PU [0..1]
+ ki : PU [0..1]
+ kp : PU [0..1]
+ mwbase : ActivePower [0..1]
+ pbf : Boolean [0..1]
+ pmwset : ActivePower [0..1]
+ speedReferenceGovernor : Boolean [0..1]
+ tpelec : Seconds [0..1]
}

class TurbineLoadControllerDynamics {

}

TurbineLoadControllerDynamics <|-- TurbLCFB1 : inherits from
```

Turbine load controller model developed by WECC. This model represents a supervisory turbine load controller that acts to maintain turbine power at a set value by continuous adjustment of the turbine governor speed-load reference. This model is intended to represent slow reset 'outer loop' controllers managing the action of the turbine governor.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| db [0..1] | [PU](#CIM17v40-PU) | Controller deadband (<i>db</i>). Typical value = 0. | |
| emax [0..1] | [PU](#CIM17v40-PU) | Maximum control error (<i>Emax</i>) (see parameter detail 4). Typical value = 0,02. | |
| fb [0..1] | [PU](#CIM17v40-PU) | Frequency bias gain (<i>Fb</i>). Typical value = 0. | |
| fbf [0..1] | [Boolean](#CIM17v40-Boolean) | Frequency bias flag (<i>Fbf</i>).true = enable frequency biasfalse = disable frequency bias.Typical value = false. | |
| irmax [0..1] | [PU](#CIM17v40-PU) | Maximum turbine speed/load reference bias (<i>Irmax</i>) (see parameter detail 3). Typical value = 0. | |
| ki [0..1] | [PU](#CIM17v40-PU) | Integral gain (<i>Ki</i>). Typical value = 0. | |
| kp [0..1] | [PU](#CIM17v40-PU) | Proportional gain (<i>Kp</i>). Typical value = 0. | |
| mwbase [0..1] | [ActivePower](#CIM17v40-ActivePower) | Base for power values (<i>MWbase</i>) (&gt; 0). Unit = MW. | |
| pbf [0..1] | [Boolean](#CIM17v40-Boolean) | Power controller flag (<i>Pbf</i>).true = enable load controllerfalse = disable load controller.Typical value = false. | |
| pmwset [0..1] | [ActivePower](#CIM17v40-ActivePower) | Power controller setpoint (<i>Pmwset</i>) (see parameter detail 1). Unit = MW. Typical value = 0. | |
| speedReferenceGovernor [0..1] | [Boolean](#CIM17v40-Boolean) | Type of turbine governor reference (<i>Type</i>).true = speed reference governorfalse = load reference governor.Typical value = true. | |
| tpelec [0..1] | [Seconds](#CIM17v40-Seconds) | Power transducer time constant (<i>Tpelec</i>) (&gt;= 0). Typical value = 0. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| TurbineGovernorDynamics [1] | [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) | see [TurbineLoadControllerDynamics](CIM17v40-TurbineLoadControllerDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TurbineGovernorDynamics}
### TurbineGovernorDynamics

Inheritance path = [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TurbineGovernorDynamics {

}

class DynamicsFunctionBlock {

}

DynamicsFunctionBlock <|-- TurbineGovernorDynamics : inherits from
class AsynchronousMachineDynamics {

}

TurbineGovernorDynamics --> "0..1" AsynchronousMachineDynamics : AsynchronousMachineDynamics
class SynchronousMachineDynamics {

}

TurbineGovernorDynamics --> "0..1" SynchronousMachineDynamics : SynchronousMachineDynamics
class TurbineLoadControllerDynamics {

}

TurbineGovernorDynamics --> "0..1" TurbineLoadControllerDynamics : TurbineLoadControllerDynamics
```

Turbine-governor function block whose behaviour is described by reference to a standard model <font color="#0f0f0f">or by definition of a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | Asynchronous machine model with which this turbine-governor model is associated. TurbineGovernorDynamics shall have either an association to SynchronousMachineDynamics or to AsynchronousMachineDynamics. | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | Synchronous machine model with which this turbine-governor model is associated. TurbineGovernorDynamics shall have either an association to SynchronousMachineDynamics or to AsynchronousMachineDynamics. | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | Turbine load controller providing input to this turbine-governor. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TurbineGovernorUserDefined}
### TurbineGovernorUserDefined

Inheritance path = [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TurbineGovernorUserDefined {

+ proprietary : Boolean [0..1]
}

class TurbineGovernorDynamics {

}

TurbineGovernorDynamics <|-- TurbineGovernorUserDefined : inherits from
```

Turbine-governor function block whose dynamic behaviour is described by <font color="#0f0f0f">a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| proprietary [0..1] | [Boolean](#CIM17v40-Boolean) | Behaviour is based on a proprietary model as opposed to a detailed model.true = user-defined model is proprietary with behaviour mutually understood by sending and receiving applications and parameters passed as general attributesfalse = user-defined model is explicitly defined in terms of control blocks and their input and output signals. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [0..1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| SynchronousMachineDynamics [0..1] | [SynchronousMachineDynamics](#CIM17v40-SynchronousMachineDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| TurbineLoadControllerDynamics [0..1] | [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) | see [TurbineGovernorDynamics](CIM17v40-TurbineGovernorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TurbineLoadControllerDynamics}
### TurbineLoadControllerDynamics

Inheritance path = [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TurbineLoadControllerDynamics {

}

class DynamicsFunctionBlock {

}

DynamicsFunctionBlock <|-- TurbineLoadControllerDynamics : inherits from
class TurbineGovernorDynamics {

}

TurbineLoadControllerDynamics --> "1" TurbineGovernorDynamics : TurbineGovernorDynamics
```

Turbine load controller function block whose behaviour is described by reference to a standard model <font color="#0f0f0f">or by definition of a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| TurbineGovernorDynamics [1] | [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) | Turbine-governor controlled by this turbine load controller. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TurbineLoadControllerUserDefined}
### TurbineLoadControllerUserDefined

Inheritance path = [TurbineLoadControllerDynamics](#CIM17v40-TurbineLoadControllerDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TurbineLoadControllerUserDefined {

+ proprietary : Boolean [0..1]
}

class TurbineLoadControllerDynamics {

}

TurbineLoadControllerDynamics <|-- TurbineLoadControllerUserDefined : inherits from
```

Turbine load controller function block whose dynamic behaviour is described by <font color="#0f0f0f">a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| proprietary [0..1] | [Boolean](#CIM17v40-Boolean) | Behaviour is based on a proprietary model as opposed to a detailed model.true = user-defined model is proprietary with behaviour mutually understood by sending and receiving applications and parameters passed as general attributesfalse = user-defined model is explicitly defined in terms of control blocks and their input and output signals. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| TurbineGovernorDynamics [1] | [TurbineGovernorDynamics](#CIM17v40-TurbineGovernorDynamics) | see [TurbineLoadControllerDynamics](CIM17v40-TurbineLoadControllerDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TypeAssetCatalogue}
### (informative) TypeAssetCatalogue

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TypeAssetCatalogue {

+ status : Status [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- TypeAssetCatalogue : inherits from
```

Catalogue of generic types of assets (TypeAsset) that may be used for design purposes. It is not associated with a particular manufacturer.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| status [0..1] | [Status](#CIM17v40-Status) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-TypeMaterial}
### (informative) TypeMaterial

Inheritance path = [WorkDocument](#CIM17v40-WorkDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class TypeMaterial {

+ costType : String [0..1]
+ estUnitCost : Money [0..1]
+ quantity : String [0..1]
+ stockItem : Boolean [0..1]
}

class WorkDocument {

}

WorkDocument <|-- TypeMaterial : inherits from
```

Documentation for a generic material item that may be used for design, work and other purposes. Any number of MaterialItems manufactured by various vendors may be used to perform this TypeMaterial.

Note that class analagous to "AssetModel" is not used for material items. This is because in some cases, for example, a utility sets up a Master material record for a 3 inch long half inch diameter steel bolt and they do not necessarily care what specific supplier is providing the material item. As different vendors are used to supply the part, the Stock Code of the material item can stay the same. In other cases, each time the vendor changes, a new stock code is set up so they can track material used by vendor. Therefore a Material Item "Model" is not typically needed.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| costType [0..1] | [String](#CIM17v40-String) | The type of cost to which this Material Item belongs. | |
| estUnitCost [0..1] | [Money](#CIM17v40-Money) | The estimated unit cost of this type of material, either for a unit cost or cost per unit length. Cost is for material or asset only and does not include labor to install/construct or configure it. | |
| quantity [0..1] | [String](#CIM17v40-String) | The value, unit of measure, and multiplier for the quantity. | |
| stockItem [0..1] | [Boolean](#CIM17v40-Boolean) | True if item is a stock item (default). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Umode}
### (informative) Umode


```mermaid
classDiagram
direction TB

class Umode {

}

class Delay {

}

Umode --> "1" Delay : Delay
class VSCtype1 {

}

Umode --> "0..1" VSCtype1 : VSCtype1
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `Delay [1]` (informative) | [Delay](#CIM17v40-Delay) | | |
| `VSCtype1 [0..1]` (informative) | [VSCtype1](#CIM17v40-VSCtype1) | | |

{#CIM17v40-UnavailabilityScheduleDependency}
### UnavailabilityScheduleDependency

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class UnavailabilityScheduleDependency {

}

class IdentifiedObject {

}

IdentifiedObject <|-- UnavailabilityScheduleDependency : inherits from
class UnavailablitySchedule {

}

UnavailabilityScheduleDependency --> "1" UnavailablitySchedule : UnavailabilityScheduleDependsOn
class UnavailablitySchedule {

}

UnavailabilityScheduleDependency --> "1" UnavailablitySchedule : UnavailabilityScheduleImpacts
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `UnavailabilityScheduleDependsOn [1]` (informative) | [UnavailablitySchedule](#CIM17v40-UnavailablitySchedule) | | |
| `UnavailabilityScheduleImpacts [1]` (informative) | [UnavailablitySchedule](#CIM17v40-UnavailablitySchedule) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-UnavailabilitySwitchAction}
### UnavailabilitySwitchAction

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class UnavailabilitySwitchAction {

+ open : Boolean [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- UnavailabilitySwitchAction : inherits from
```

Relevant switching action for supporting the availability (or unavailability) plans. This could open or close a switch that is not directly connected to the unavailable equipment .


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| open [0..1] | [Boolean](#CIM17v40-Boolean) | The switch is to be open during the scheduled period. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-UnavailablitySchedule}
### (informative) UnavailablitySchedule

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class UnavailablitySchedule {

}

class IdentifiedObject {

}

IdentifiedObject <|-- UnavailablitySchedule : inherits from
```

A schedule of unavailability for one or more specified equipment that need to follow the same scheduling periods.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-UnderexcLim2Simplified}
### UnderexcLim2Simplified

Inheritance path = [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class UnderexcLim2Simplified {

+ kui : PU [0..1]
+ p0 : PU [0..1]
+ p1 : PU [0..1]
+ q0 : PU [0..1]
+ q1 : PU [0..1]
+ vuimax : PU [0..1]
+ vuimin : PU [0..1]
}

class UnderexcitationLimiterDynamics {

}

UnderexcitationLimiterDynamics <|-- UnderexcLim2Simplified : inherits from
```

Simplified type UEL2 underexcitation limiter. This model can be derived from UnderexcLimIEEE2. The limit characteristic (look �up table) is a single straight-line, the same as UnderexcLimIEEE2 (see Figure 10.4 (p 32), IEEE 421.5-2005 Section 10.2).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kui [0..1] | [PU](#CIM17v40-PU) | Gain Under excitation limiter (<i>K</i><i><sub>UI</sub></i>). Typical value = 0,1. | |
| p0 [0..1] | [PU](#CIM17v40-PU) | Segment P initial point (<i>P</i><i><sub>0</sub></i>). Typical value = 0. | |
| p1 [0..1] | [PU](#CIM17v40-PU) | Segment P end point (<i>P</i><i><sub>1</sub></i>). Typical value = 1. | |
| q0 [0..1] | [PU](#CIM17v40-PU) | Segment Q initial point (<i>Q</i><i><sub>0</sub></i>). Typical value = -0,31. | |
| q1 [0..1] | [PU](#CIM17v40-PU) | Segment Q end point (<i>Q</i><i><sub>1</sub></i>). Typical value = -0,1. | |
| vuimax [0..1] | [PU](#CIM17v40-PU) | Maximum error signal (<i>V</i><i><sub>UIMAX</sub></i>) (&gt; UnderexcLim2Simplified.vuimin). Typical value = 1. | |
| vuimin [0..1] | [PU](#CIM17v40-PU) | Minimum error signal (<i>V</i><i><sub>UIMIN</sub></i>) (&lt; UnderexcLim2Simplified.vuimax). Typical value = 0. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [UnderexcitationLimiterDynamics](CIM17v40-UnderexcitationLimiterDynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [UnderexcitationLimiterDynamics](CIM17v40-UnderexcitationLimiterDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-UnderexcLimIEEE1}
### UnderexcLimIEEE1

Inheritance path = [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class UnderexcLimIEEE1 {

+ kuc : PU [0..1]
+ kuf : PU [0..1]
+ kui : PU [0..1]
+ kul : PU [0..1]
+ kur : PU [0..1]
+ tu1 : Seconds [0..1]
+ tu2 : Seconds [0..1]
+ tu3 : Seconds [0..1]
+ tu4 : Seconds [0..1]
+ vucmax : PU [0..1]
+ vuimax : PU [0..1]
+ vuimin : PU [0..1]
+ vulmax : PU [0..1]
+ vulmin : PU [0..1]
+ vurmax : PU [0..1]
}

class UnderexcitationLimiterDynamics {

}

UnderexcitationLimiterDynamics <|-- UnderexcLimIEEE1 : inherits from
```

Type UEL1 model which has a circular limit boundary when plotted in terms of machine reactive power vs. real power output.

Reference: IEEE UEL1 421.5-2005, 10.1.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kuc [0..1] | [PU](#CIM17v40-PU) | UEL centre setting (<i>K</i><i><sub>UC</sub></i>). Typical value = 1,38. | |
| kuf [0..1] | [PU](#CIM17v40-PU) | UEL excitation system stabilizer gain (<i>K</i><i><sub>UF</sub></i>). Typical value = 3,3. | |
| kui [0..1] | [PU](#CIM17v40-PU) | UEL integral gain (<i>K</i><i><sub>UI</sub></i>). Typical value = 0. | |
| kul [0..1] | [PU](#CIM17v40-PU) | UEL proportional gain (<i>K</i><i><sub>UL</sub></i>). Typical value = 100. | |
| kur [0..1] | [PU](#CIM17v40-PU) | UEL radius setting (<i>K</i><i><sub>UR</sub></i>). Typical value = 1,95. | |
| tu1 [0..1] | [Seconds](#CIM17v40-Seconds) | UEL lead time constant (<i>T</i><i><sub>U1</sub></i>) (&gt;= 0). Typical value = 0. | |
| tu2 [0..1] | [Seconds](#CIM17v40-Seconds) | UEL lag time constant (<i>T</i><i><sub>U2</sub></i>) (&gt;= 0). Typical value = 0,05. | |
| tu3 [0..1] | [Seconds](#CIM17v40-Seconds) | UEL lead time constant (<i>T</i><i><sub>U3</sub></i>) (&gt;= 0). Typical value = 0. | |
| tu4 [0..1] | [Seconds](#CIM17v40-Seconds) | UEL lag time constant (<i>T</i><i><sub>U4</sub></i>) (&gt;= 0). Typical value = 0. | |
| vucmax [0..1] | [PU](#CIM17v40-PU) | UEL maximum limit for operating point phasor magnitude (<i>V</i><i><sub>UCMAX</sub></i>). Typical value = 5,8. | |
| vuimax [0..1] | [PU](#CIM17v40-PU) | UEL integrator output maximum limit (<i>V</i><i><sub>UIMAX</sub></i>) (&gt; UnderexcLimIEEE1.vuimin). | |
| vuimin [0..1] | [PU](#CIM17v40-PU) | UEL integrator output minimum limit (<i>V</i><i><sub>UIMIN</sub></i>) (&lt; UnderexcLimIEEE1.vuimax). | |
| vulmax [0..1] | [PU](#CIM17v40-PU) | UEL output maximum limit (<i>V</i><i><sub>ULMAX</sub></i>) (&gt; UnderexcLimIEEE1.vulmin). Typical value = 18. | |
| vulmin [0..1] | [PU](#CIM17v40-PU) | UEL output minimum limit (<i>V</i><i><sub>ULMIN</sub></i>) (&lt; UnderexcLimIEEE1.vulmax). Typical value = -18. | |
| vurmax [0..1] | [PU](#CIM17v40-PU) | UEL maximum limit for radius phasor magnitude (<i>V</i><i><sub>URMAX</sub></i>). Typical value = 5,8. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [UnderexcitationLimiterDynamics](CIM17v40-UnderexcitationLimiterDynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [UnderexcitationLimiterDynamics](CIM17v40-UnderexcitationLimiterDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-UnderexcLimIEEE2}
### UnderexcLimIEEE2

Inheritance path = [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class UnderexcLimIEEE2 {

+ k1 : Float [0..1]
+ k2 : Float [0..1]
+ kfb : PU [0..1]
+ kuf : PU [0..1]
+ kui : PU [0..1]
+ kul : PU [0..1]
+ p0 : PU [0..1]
+ p1 : PU [0..1]
+ p10 : PU [0..1]
+ p2 : PU [0..1]
+ p3 : PU [0..1]
+ p4 : PU [0..1]
+ p5 : PU [0..1]
+ p6 : PU [0..1]
+ p7 : PU [0..1]
+ p8 : PU [0..1]
+ p9 : PU [0..1]
+ q0 : PU [0..1]
+ q1 : PU [0..1]
+ q10 : PU [0..1]
+ q2 : PU [0..1]
+ q3 : PU [0..1]
+ q4 : PU [0..1]
+ q5 : PU [0..1]
+ q6 : PU [0..1]
+ q7 : PU [0..1]
+ q8 : PU [0..1]
+ q9 : PU [0..1]
+ tu1 : Seconds [0..1]
+ tu2 : Seconds [0..1]
+ tu3 : Seconds [0..1]
+ tu4 : Seconds [0..1]
+ tul : Seconds [0..1]
+ tup : Seconds [0..1]
+ tuq : Seconds [0..1]
+ tuv : Seconds [0..1]
+ vuimax : PU [0..1]
+ vuimin : PU [0..1]
+ vulmax : PU [0..1]
+ vulmin : PU [0..1]
}

class UnderexcitationLimiterDynamics {

}

UnderexcitationLimiterDynamics <|-- UnderexcLimIEEE2 : inherits from
```

Type UEL2 underexcitation limiter which has either a straight-line or multi-segment characteristic when plotted in terms of machine reactive power output vs. real power output.

Reference: IEEE UEL2 421.5-2005, 10.2 (limit characteristic lookup table shown in Figure 10.4 (p 32)).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| k1 [0..1] | [Float](#CIM17v40-Float) | UEL terminal voltage exponent applied to real power input to UEL limit look-up table (<i>k1</i>). Typical value = 2. | |
| k2 [0..1] | [Float](#CIM17v40-Float) | UEL terminal voltage exponent applied to reactive power output from UEL limit look-up table (<i>k2</i>). Typical value = 2. | |
| kfb [0..1] | [PU](#CIM17v40-PU) | Gain associated with optional integrator feedback input signal to UEL (<i>K</i><i><sub>FB</sub></i>). Typical value = 0. | |
| kuf [0..1] | [PU](#CIM17v40-PU) | UEL excitation system stabilizer gain (<i>K</i><i><sub>UF</sub></i>). Typical value = 0. | |
| kui [0..1] | [PU](#CIM17v40-PU) | UEL integral gain (<i>K</i><i><sub>UI</sub></i>). Typical value = 0,5. | |
| kul [0..1] | [PU](#CIM17v40-PU) | UEL proportional gain (<i>K</i><i><sub>UL</sub></i>). Typical value = 0,8. | |
| p0 [0..1] | [PU](#CIM17v40-PU) | Real power values for endpoints (<i>P</i><i><sub>0</sub></i>). Typical value = 0. | |
| p1 [0..1] | [PU](#CIM17v40-PU) | Real power values for endpoints (<i>P</i><i><sub>1</sub></i>). Typical value = 0,3. | |
| p10 [0..1] | [PU](#CIM17v40-PU) | Real power values for endpoints (<i>P</i><i><sub>10</sub></i>). | |
| p2 [0..1] | [PU](#CIM17v40-PU) | Real power values for endpoints (<i>P</i><i><sub>2</sub></i>). Typical value = 0,6. | |
| p3 [0..1] | [PU](#CIM17v40-PU) | Real power values for endpoints (<i>P</i><i><sub>3</sub></i>). Typical value = 0,9. | |
| p4 [0..1] | [PU](#CIM17v40-PU) | Real power values for endpoints (<i>P</i><i><sub>4</sub></i>). Typical value = 1,02. | |
| p5 [0..1] | [PU](#CIM17v40-PU) | Real power values for endpoints (<i>P</i><i><sub>5</sub></i>). | |
| p6 [0..1] | [PU](#CIM17v40-PU) | Real power values for endpoints (<i>P</i><i><sub>6</sub></i>). | |
| p7 [0..1] | [PU](#CIM17v40-PU) | Real power values for endpoints (<i>P</i><i><sub>7</sub></i>). | |
| p8 [0..1] | [PU](#CIM17v40-PU) | Real power values for endpoints (<i>P</i><i><sub>8</sub></i>). | |
| p9 [0..1] | [PU](#CIM17v40-PU) | Real power values for endpoints (<i>P</i><i><sub>9</sub></i>). | |
| q0 [0..1] | [PU](#CIM17v40-PU) | Reactive power values for endpoints (<i>Q</i><i><sub>0</sub></i>). Typical value = -0,31. | |
| q1 [0..1] | [PU](#CIM17v40-PU) | Reactive power values for endpoints (<i>Q</i><i><sub>1</sub></i>). Typical value = -0,31. | |
| q10 [0..1] | [PU](#CIM17v40-PU) | Reactive power values for endpoints (<i>Q</i><i><sub>10</sub></i>). | |
| q2 [0..1] | [PU](#CIM17v40-PU) | Reactive power values for endpoints (<i>Q</i><i><sub>2</sub></i>). Typical value = -0,28. | |
| q3 [0..1] | [PU](#CIM17v40-PU) | Reactive power values for endpoints (<i>Q</i><i><sub>3</sub></i>). Typical value = -0,21. | |
| q4 [0..1] | [PU](#CIM17v40-PU) | Reactive power values for endpoints (<i>Q</i><i><sub>4</sub></i>). Typical value = 0. | |
| q5 [0..1] | [PU](#CIM17v40-PU) | Reactive power values for endpoints (<i>Q</i><i><sub>5</sub></i>). | |
| q6 [0..1] | [PU](#CIM17v40-PU) | Reactive power values for endpoints (<i>Q</i><i><sub>6</sub></i>). | |
| q7 [0..1] | [PU](#CIM17v40-PU) | Reactive power values for endpoints (<i>Q</i><i><sub>7</sub></i>). | |
| q8 [0..1] | [PU](#CIM17v40-PU) | Reactive power values for endpoints (<i>Q</i><i><sub>8</sub></i>). | |
| q9 [0..1] | [PU](#CIM17v40-PU) | Reactive power values for endpoints (<i>Q</i><i><sub>9</sub></i>). | |
| tu1 [0..1] | [Seconds](#CIM17v40-Seconds) | UEL lead time constant (<i>T</i><i><sub>U1</sub></i>) (&gt;= 0). Typical value = 0. | |
| tu2 [0..1] | [Seconds](#CIM17v40-Seconds) | UEL lag time constant (<i>T</i><i><sub>U2</sub></i>) (&gt;= 0). Typical value = 0. | |
| tu3 [0..1] | [Seconds](#CIM17v40-Seconds) | UEL lead time constant (<i>T</i><i><sub>U3</sub></i>) (&gt;= 0). Typical value = 0. | |
| tu4 [0..1] | [Seconds](#CIM17v40-Seconds) | UEL lag time constant (<i>T</i><i><sub>U4</sub></i>) (&gt;= 0). Typical value = 0. | |
| tul [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant associated with optional integrator feedback input signal to UEL (<i>T</i><i><sub>UL</sub></i>) (&gt;= 0). Typical value = 0. | |
| tup [0..1] | [Seconds](#CIM17v40-Seconds) | Real power filter time constant (<i>T</i><i><sub>UP</sub></i>) (&gt;= 0). Typical value = 5. | |
| tuq [0..1] | [Seconds](#CIM17v40-Seconds) | Reactive power filter time constant (<i>T</i><i><sub>UQ</sub></i>) (&gt;= 0). Typical value = 0. | |
| tuv [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage filter time constant (<i>T</i><i><sub>UV</sub></i>) (&gt;= 0). Typical value = 5. | |
| vuimax [0..1] | [PU](#CIM17v40-PU) | UEL integrator output maximum limit (<i>V</i><i><sub>UIMAX</sub></i>) (&gt; UnderexcLimIEEE2.vuimin). Typical value = 0,25. | |
| vuimin [0..1] | [PU](#CIM17v40-PU) | UEL integrator output minimum limit (<i>V</i><i><sub>UIMIN</sub></i>) (&lt; UnderexcLimIEEE2.vuimax). Typical value = 0. | |
| vulmax [0..1] | [PU](#CIM17v40-PU) | UEL output maximum limit (<i>V</i><i><sub>ULMAX</sub></i>) (&gt; UnderexcLimIEEE2.vulmin). Typical value = 0,25. | |
| vulmin [0..1] | [PU](#CIM17v40-PU) | UEL output minimum limit (<i>V</i><i><sub>ULMIN</sub></i>) (&lt; UnderexcLimIEEE2.vulmax). Typical value = 0. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [UnderexcitationLimiterDynamics](CIM17v40-UnderexcitationLimiterDynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [UnderexcitationLimiterDynamics](CIM17v40-UnderexcitationLimiterDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-UnderexcLimX1}
### UnderexcLimX1

Inheritance path = [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class UnderexcLimX1 {

+ k : PU [0..1]
+ kf2 : PU [0..1]
+ km : PU [0..1]
+ melmax : PU [0..1]
+ tf2 : Seconds [0..1]
+ tm : Seconds [0..1]
}

class UnderexcitationLimiterDynamics {

}

UnderexcitationLimiterDynamics <|-- UnderexcLimX1 : inherits from
```

<font color="#0f0f0f">Allis-Chalmers minimum excitation limiter.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| k [0..1] | [PU](#CIM17v40-PU) | Minimum excitation limit slope (<i>K</i>) (&gt; 0). | |
| kf2 [0..1] | [PU](#CIM17v40-PU) | Differential gain (<i>K</i><i><sub>F2</sub></i>). | |
| km [0..1] | [PU](#CIM17v40-PU) | Minimum excitation limit gain (<i>K</i><i><sub>M</sub></i>). | |
| melmax [0..1] | [PU](#CIM17v40-PU) | Minimum excitation limit value (<i>MELMAX</i>). | |
| tf2 [0..1] | [Seconds](#CIM17v40-Seconds) | Differential time constant (<i>T</i><i><sub>F2</sub></i>) (&gt;= 0). | |
| tm [0..1] | [Seconds](#CIM17v40-Seconds) | Minimum excitation limit time constant (<i>T</i><i><sub>M</sub></i>) (&gt;= 0). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [UnderexcitationLimiterDynamics](CIM17v40-UnderexcitationLimiterDynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [UnderexcitationLimiterDynamics](CIM17v40-UnderexcitationLimiterDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-UnderexcLimX2}
### UnderexcLimX2

Inheritance path = [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class UnderexcLimX2 {

+ kf2 : PU [0..1]
+ km : PU [0..1]
+ melmax : PU [0..1]
+ qo : PU [0..1]
+ r : PU [0..1]
+ tf2 : Seconds [0..1]
+ tm : Seconds [0..1]
}

class UnderexcitationLimiterDynamics {

}

UnderexcitationLimiterDynamics <|-- UnderexcLimX2 : inherits from
```

<font color="#0f0f0f">Westinghouse minimum excitation limiter.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kf2 [0..1] | [PU](#CIM17v40-PU) | Differential gain (<i>K</i><i><sub>F2</sub></i>). | |
| km [0..1] | [PU](#CIM17v40-PU) | Minimum excitation limit gain (<i>K</i><i><sub>M</sub></i>). | |
| melmax [0..1] | [PU](#CIM17v40-PU) | Minimum excitation limit value (<i>MELMAX</i>). | |
| qo [0..1] | [PU](#CIM17v40-PU) | Excitation centre setting (<i>Q</i><i><sub>O</sub></i>). | |
| r [0..1] | [PU](#CIM17v40-PU) | Excitation radius (<i>R</i>). | |
| tf2 [0..1] | [Seconds](#CIM17v40-Seconds) | Differential time constant (<i>T</i><i><sub>F2</sub></i>) (&gt;= 0). | |
| tm [0..1] | [Seconds](#CIM17v40-Seconds) | Minimum excitation limit time constant (<i>T</i><i><sub>M</sub></i>) (&gt;= 0). | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [UnderexcitationLimiterDynamics](CIM17v40-UnderexcitationLimiterDynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [UnderexcitationLimiterDynamics](CIM17v40-UnderexcitationLimiterDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-UnderexcitationLimiterDynamics}
### UnderexcitationLimiterDynamics

Inheritance path = [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class UnderexcitationLimiterDynamics {

}

class DynamicsFunctionBlock {

}

DynamicsFunctionBlock <|-- UnderexcitationLimiterDynamics : inherits from
class ExcitationSystemDynamics {

}

UnderexcitationLimiterDynamics --> "1" ExcitationSystemDynamics : ExcitationSystemDynamics
class RemoteInputSignal {

}

UnderexcitationLimiterDynamics --> "0..1" RemoteInputSignal : RemoteInputSignal
```

Underexcitation limiter function block whose behaviour is described by reference to a standard model <font color="#0f0f0f">or by definition of a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | Excitation system model with which this underexcitation limiter model is associated. | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | Remote input signal used by this underexcitation limiter model. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-UnderexcitationLimiterUserDefined}
### UnderexcitationLimiterUserDefined

Inheritance path = [UnderexcitationLimiterDynamics](#CIM17v40-UnderexcitationLimiterDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class UnderexcitationLimiterUserDefined {

+ proprietary : Boolean [0..1]
}

class UnderexcitationLimiterDynamics {

}

UnderexcitationLimiterDynamics <|-- UnderexcitationLimiterUserDefined : inherits from
```

Underexcitation limiter function block whose dynamic behaviour is described by <font color="#0f0f0f">a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| proprietary [0..1] | [Boolean](#CIM17v40-Boolean) | Behaviour is based on a proprietary model as opposed to a detailed model.true = user-defined model is proprietary with behaviour mutually understood by sending and receiving applications and parameters passed as general attributesfalse = user-defined model is explicitly defined in terms of control blocks and their input and output signals. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [UnderexcitationLimiterDynamics](CIM17v40-UnderexcitationLimiterDynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [UnderexcitationLimiterDynamics](CIM17v40-UnderexcitationLimiterDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-UndergroundStructure}
### UndergroundStructure

Inheritance path = [Structure](#CIM17v40-Structure) => [AssetContainer](#CIM17v40-AssetContainer) => [Asset](#CIM17v40-Asset) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class UndergroundStructure {

+ hasVentilation : Boolean [0..1]
+ kind : enum:UndergroundStructureKind [0..1]
+ material : String [0..1]
+ sealingWarrantyExpiresDate : Date [0..1]
}

class Structure {

}

Structure <|-- UndergroundStructure : inherits from
```

Underground structure.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| hasVentilation [0..1] | [Boolean](#CIM17v40-Boolean) | True if vault is ventilating. | |
| kind [0..1] | [UndergroundStructureKind](#CIM17v40-UndergroundStructureKind) | True if vault is ventilating. | |
| material [0..1] | [String](#CIM17v40-String) | Primary material of underground structure. | |
| sealingWarrantyExpiresDate [0..1] | [Date](#CIM17v40-Date) | Date sealing warranty expires. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| fumigantAppliedDate [0..1] | [Date](#CIM17v40-Date) | see [Structure](#CIM17v40-Structure) | |
| fumigantName [0..1] | [String](#CIM17v40-String) | see [Structure](#CIM17v40-Structure) | |
| height [0..1] | [Length](#CIM17v40-Length) | see [Structure](CIM17v40-Structure) | |
| materialKind [0..1] | [StructureMaterialKind](#CIM17v40-StructureMaterialKind) | see [Structure](CIM17v40-Structure) | |
| ratedVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | see [Structure](CIM17v40-Structure) | |
| removeWeed [0..1] | [Boolean](#CIM17v40-Boolean) | see [Structure](#CIM17v40-Structure) | |
| weedRemovedDate [0..1] | [Date](#CIM17v40-Date) | see [Structure](#CIM17v40-Structure) | |
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | see [Asset](#CIM17v40-Asset) | |
| initialCondition [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | see [Asset](CIM17v40-Asset) | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | see [Asset](CIM17v40-Asset) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [Asset](CIM17v40-Asset) | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | see [Asset](CIM17v40-Asset) | |
| lotNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| position [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | see [Asset](CIM17v40-Asset) | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | see [Asset](CIM17v40-Asset) | |
| serialNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| type [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| utcNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | see [Asset](CIM17v40-Asset) | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | see [Asset](CIM17v40-Asset) | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | see [Asset](CIM17v40-Asset) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [Asset](CIM17v40-Asset) | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | see [Asset](CIM17v40-Asset) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Asset](CIM17v40-Asset) | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | see [Asset](CIM17v40-Asset) | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | see [Asset](CIM17v40-Asset) | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | see [Asset](CIM17v40-Asset) | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | see [Asset](CIM17v40-Asset) | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | see [Asset](CIM17v40-Asset) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Asset](CIM17v40-Asset) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [Asset](CIM17v40-Asset) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [Asset](CIM17v40-Asset) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Asset](CIM17v40-Asset) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Unit}
### Unit


```mermaid
classDiagram
direction TB

class Unit {

+ name : String [0..1]
}

```

The identification of the unit name for the time series quantities.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| name [0..1] | [String](#CIM17v40-String) | The coded representation of the unit. | |

{#CIM17v40-UnitInitialConditions}
### UnitInitialConditions

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class UnitInitialConditions {

+ cumEnergy : RealEnergy [0..1]
+ cumStatusChanges : Integer [0..1]
+ numberOfStartups : Integer [0..1]
+ onlineStatus : Boolean [0..1]
+ resourceMW : ActivePower [0..1]
+ resourceStatus : Integer [0..1]
+ statusDate : DateTime [0..1]
+ timeInStatus : Float [0..1]
+ timeInterval : DateTime [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- UnitInitialConditions : inherits from
class RegisteredGenerator {

}

UnitInitialConditions --> "0..1" RegisteredGenerator : GeneratingUnit
```

Resource status at the end of a given clearing period.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| cumEnergy [0..1] | [RealEnergy](#CIM17v40-RealEnergy) | Cumulative energy production over trading period. | |
| cumStatusChanges [0..1] | [Integer](#CIM17v40-Integer) | Cumulative number of status changes of the resource. | |
| numberOfStartups [0..1] | [Integer](#CIM17v40-Integer) | Number of start ups in the Operating Day until the end of previous hour. | |
| onlineStatus [0..1] | [Boolean](#CIM17v40-Boolean) | 'true' if the GeneratingUnit is currently On-Line | |
| resourceMW [0..1] | [ActivePower](#CIM17v40-ActivePower) | Resource MW output at the end of previous clearing period. | |
| resourceStatus [0..1] | [Integer](#CIM17v40-Integer) | Resource status at the end of previous clearing period:0 - off-line1 - on-line production2 - in shutdown process3 - in startup process | |
| statusDate [0..1] | [DateTime](#CIM17v40-DateTime) | Time and date for resourceStatus | |
| timeInStatus [0..1] | [Float](#CIM17v40-Float) | Time in market trading intervals the resource is in the state as of the end of the previous clearing period. | |
| timeInterval [0..1] | [DateTime](#CIM17v40-DateTime) | Time interval | |
| GeneratingUnit [0..1] | [RegisteredGenerator](#CIM17v40-RegisteredGenerator) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-UnplannedOutage}
### UnplannedOutage

Inheritance path = [Outage](#CIM17v40-Outage) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class UnplannedOutage {

+ cause : String [0..1]
+ causeKind : enum:OutageCauseKind [0..1]
+ reportedStartTime : DateTime [0..1]
}

class Outage {

}

Outage <|-- UnplannedOutage : inherits from
class FieldDispatchHistory {

}

UnplannedOutage --> "0..1" FieldDispatchHistory : FieldDispatchHistory
```

Document describing the consequence of an unplanned outage in a part of the electrical network. For the purposes of this model, an unplanned outage refers to a state where energy is not delivered; such as, customers out of service, a street light is not served, etc.

A unplanned outage may be created upon:

- impacts the SAIDI calculation

- a breaker trip,

- a fault indicator status change,

- a meter event indicating customer outage,

- a reception of one or more customer trouble calls, or

- an operator command, reflecting information obtained from the field crew.

Outage restoration may be performed using a switching plan which complements the outage information with detailed switching activities, including the relationship to the crew and work.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| cause [0..1] | [String](#CIM17v40-String) | The cause of this outage. This is the cause that is used to present to external entities. That is, the cause is weather, equipment failure, etc.Note: At present, this is a free string text; it could be replaced with an enumeration in the future. | |
| causeKind [0..1] | [OutageCauseKind](#CIM17v40-OutageCauseKind) | The possible cause that could be associated with this unplanned outage. | |
| reportedStartTime [0..1] | [DateTime](#CIM17v40-DateTime) | The earliest start time of the Outage - as reported by some system or individual | |
| FieldDispatchHistory [0..1] | [FieldDispatchHistory](#CIM17v40-FieldDispatchHistory) | The dispatch history associated with the unplanned outage | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| communityDescriptor [0..1] | [String](#CIM17v40-String) | see [Outage](#CIM17v40-Outage) | |
| customersRestored [0..1] | [Integer](#CIM17v40-Integer) | see [Outage](#CIM17v40-Outage) | |
| metersAffected [0..1] | [Integer](#CIM17v40-Integer) | see [Outage](#CIM17v40-Outage) | |
| originalCustomersServed [0..1] | [Integer](#CIM17v40-Integer) | see [Outage](#CIM17v40-Outage) | |
| originalMetersAffected [0..1] | [Integer](#CIM17v40-Integer) | see [Outage](#CIM17v40-Outage) | |
| outageKind [0..1] | [OutageStatusKind](#CIM17v40-OutageStatusKind) | see [Outage](CIM17v40-Outage) | |
| statusKind [0..1] | [CrewStatusKind](#CIM17v40-CrewStatusKind) | see [Outage](CIM17v40-Outage) | |
| utilityDisclaimer [0..1] | [String](#CIM17v40-String) | see [Outage](#CIM17v40-Outage) | |
| actualPeriod [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [Outage](CIM17v40-Outage) | |
| estimatedPeriod [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [Outage](CIM17v40-Outage) | |
| EstimatedRestorationTime [0..1] | [EstimatedRestorationTime](#CIM17v40-EstimatedRestorationTime) | see [Outage](CIM17v40-Outage) | |
| summary [0..1] | [ServicePointOutageSummary](#CIM17v40-ServicePointOutageSummary) | see [Outage](CIM17v40-Outage) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Usage}
### Usage

Inheritance path = [WorkIdentifiedObject](#CIM17v40-WorkIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Usage {

+ status : Status [0..1]
}

class WorkIdentifiedObject {

}

WorkIdentifiedObject <|-- Usage : inherits from
class OldWorkTask {

}

Usage --> "0..1" OldWorkTask : WorkTask
```

The way material and assets are used to perform a certain type of work task. The way is described in text in the inheritied description attribute.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| status [0..1] | [Status](#CIM17v40-Status) | | |
| `WorkTask [0..1]` (informative) | [OldWorkTask](#CIM17v40-OldWorkTask) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-UsagePoint}
### UsagePoint

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class UsagePoint {

+ amiBillingReady : enum:AmiBillingReadyKind [0..1]
+ checkBilling : Boolean [0..1]
+ connectionCategory : String [0..1]
+ connectionState : enum:UsagePointConnectedKind [0..1]
+ disconnectionMethod : String [0..1]
+ estimatedLoad : CurrentFlow [0..1]
+ grounded : Boolean [0..1]
+ isSdp : Boolean [0..1]
+ isVirtual : Boolean [0..1]
+ minimalUsageExpected : Boolean [0..1]
+ nominalServiceVoltage : Voltage [0..1]
+ outageRegion : String [0..1]
+ phaseCode : enum:PhaseCode [0..1]
+ phaseCount : Integer [0..1]
+ ratedCurrent : CurrentFlow [0..1]
+ ratedPower : ActivePower [0..1]
+ readCycle : String [0..1]
+ readRoute : String [0..1]
+ serviceDeliveryRemark : String [0..1]
+ servicePriority : String [0..1]
+ physicalConnectionCapacity : DecimalQuantity [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- UsagePoint : inherits from
class CustomerAgreement {

}

UsagePoint --> "0..1" CustomerAgreement : CustomerAgreement
class EnvironmentalMonitoringStation {

}

UsagePoint --> "0..1" EnvironmentalMonitoringStation : EnvironmentalMonitoringStation
class MeterReadSchedule {

}

UsagePoint --> "0..1" MeterReadSchedule : MeterReadSchedule
class ServiceCategory {

}

UsagePoint --> "0..1" ServiceCategory : ServiceCategory
class ServiceLocation {

}

UsagePoint --> "0..1" ServiceLocation : ServiceLocation
class ServiceSupplier {

}

UsagePoint --> "0..1" ServiceSupplier : ServiceSupplier
class UsagePointLocation {

}

UsagePoint --> "0..1" UsagePointLocation : UsagePointLocation
```

Logical or physical point in the network to which readings or events may be attributed. Used at the place where a physical or virtual meter may be located; however, it is not required that a meter be present.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| amiBillingReady [0..1] | [AmiBillingReadyKind](#CIM17v40-AmiBillingReadyKind) | Tracks the lifecycle of the metering installation at a usage point with respect to readiness for billing via advanced metering infrastructure reads. | |
| checkBilling [0..1] | [Boolean](#CIM17v40-Boolean) | True if as a result of an inspection or otherwise, there is a reason to suspect that a previous billing may have been performed with erroneous data. Value should be reset once this potential discrepancy has been resolved. | |
| connectionCategory [0..1] | [String](#CIM17v40-String) | A code used to specify the connection category, e.g., low voltage or low pressure, where the usage point is defined. | |
| connectionState [0..1] | [UsagePointConnectedKind](#CIM17v40-UsagePointConnectedKind) | State of the usage point with respect to connection to the network. | |
| disconnectionMethod [0..1] | [String](#CIM17v40-String) | Is an indication of how the usage point is physically connected or disconnected. | |
| estimatedLoad [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Estimated load. | |
| grounded [0..1] | [Boolean](#CIM17v40-Boolean) | True if grounded. | |
| isSdp [0..1] | [Boolean](#CIM17v40-Boolean) | If true, this usage point is a service delivery point, i.e., a usage point where the ownership of the service changes hands. | |
| isVirtual [0..1] | [Boolean](#CIM17v40-Boolean) | If true, this usage point is virtual, i.e., no physical location exists in the network where a meter could be located to collect the meter readings. For example, one may define a virtual usage point to serve as an aggregation of usage for all of a company's premises distributed widely across the distribution territory. Otherwise, the usage point is physical, i.e., there is a logical point in the network where a meter could be located to collect meter readings. | |
| minimalUsageExpected [0..1] | [Boolean](#CIM17v40-Boolean) | If true, minimal or zero usage is expected at this usage point for situations such as premises vacancy, logical or physical disconnect. It is used for readings validation and estimation. | |
| nominalServiceVoltage [0..1] | [Voltage](#CIM17v40-Voltage) | Nominal service voltage. | |
| outageRegion [0..1] | [String](#CIM17v40-String) | Outage region in which this usage point is located. | |
| phaseCode [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | Phase code. Number of wires and specific nominal phases can be deduced from enumeration literal values. For example, ABCN is three-phase, four-wire, s12n (splitSecondary12N) is single-phase, three-wire, and s1n and s2n are single-phase, two-wire. | |
| phaseCount [0..1] | [Integer](#CIM17v40-Integer) | Number of potential phases the Usage Point supports, typically 0, 1 or 3. | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Current flow that this usage point is configured to deliver. | |
| ratedPower [0..1] | [ActivePower](#CIM17v40-ActivePower) | Active power that this usage point is configured to deliver. | |
| readCycle [0..1] | [String](#CIM17v40-String) | Cycle day on which the meter for this usage point will normally be read. Usually correlated with the billing cycle. | |
| readRoute [0..1] | [String](#CIM17v40-String) | Identifier of the route to which this usage point is assigned for purposes of meter reading. Typically used to configure hand held meter reading systems prior to collection of reads. | |
| serviceDeliveryRemark [0..1] | [String](#CIM17v40-String) | Remarks about this usage point, for example the reason for it being rated with a non-nominal priority. | |
| servicePriority [0..1] | [String](#CIM17v40-String) | Priority of service for this usage point. Note that usage points at the same service location can have different priorities. | |
| CustomerAgreement [0..1] | [CustomerAgreement](#CIM17v40-CustomerAgreement) | Customer agreement regulating this service delivery point. | |
| EnvironmentalMonitoringStation [0..1] | [EnvironmentalMonitoringStation](#CIM17v40-EnvironmentalMonitoringStation) | | |
| MeterReadSchedule [0..1] | [MeterReadSchedule](#CIM17v40-MeterReadSchedule) | Meter read schedule that applies to the usage point | |
| physicalConnectionCapacity [0..1] | [DecimalQuantity](#CIM17v40-DecimalQuantity) | Quantitative information about the maximum physical capacity of the connection for the usage point. | |
| ServiceCategory [0..1] | [ServiceCategory](#CIM17v40-ServiceCategory) | Service category delivered by this usage point. | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | Service location where the service delivered by this usage point is consumed. | |
| ServiceSupplier [0..1] | [ServiceSupplier](#CIM17v40-ServiceSupplier) | ServiceSupplier (utility) utilising this usage point to deliver a service. | |
| UsagePointLocation [0..1] | [UsagePointLocation](#CIM17v40-UsagePointLocation) | Location of this usage point. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-UsagePointGroup}
### UsagePointGroup

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class UsagePointGroup {

+ type : String [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- UsagePointGroup : inherits from
class MeterReadSchedule {

}

UsagePointGroup --> "0..1" MeterReadSchedule : MeterReadSchedule
```

Abstraction for management of group communications within a two-way AMR system or the data for a group of related usage points. Commands can be issued to all of the usage points that belong to a usage point group using a defined group address and the underlying AMR communication infrastructure.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| type [0..1] | [String](#CIM17v40-String) | Type of this group. | |
| MeterReadSchedule [0..1] | [MeterReadSchedule](#CIM17v40-MeterReadSchedule) | Meter read schedule that applies to the usage point group | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-UsagePointLocation}
### UsagePointLocation

Inheritance path = [Location](#CIM17v40-Location) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class UsagePointLocation {

+ accessMethod : String [0..1]
+ remark : String [0..1]
+ siteAccessProblem : String [0..1]
}

class Location {

}

Location <|-- UsagePointLocation : inherits from
```

Location of an individual usage point.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| accessMethod [0..1] | [String](#CIM17v40-String) | Method for the service person to access this usage point location. For example, a description of where to obtain a key if the facility is unmanned and secured. | |
| remark [0..1] | [String](#CIM17v40-String) | Remarks about this location. | |
| siteAccessProblem [0..1] | [String](#CIM17v40-String) | Problems previously encountered when visiting or performing work at this location. Examples include: bad dog, violent customer, verbally abusive occupant, obstructions, safety hazards, etc. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| direction [0..1] | [String](#CIM17v40-String) | see [Location](#CIM17v40-Location) | |
| geoInfoReference [0..1] | [String](#CIM17v40-String) | see [Location](#CIM17v40-Location) | |
| type [0..1] | [String](#CIM17v40-String) | see [Location](#CIM17v40-Location) | |
| CoordinateSystem [0..1] | [CoordinateSystem](#CIM17v40-CoordinateSystem) | see [Location](CIM17v40-Location) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Location](CIM17v40-Location) | |
| Incident [0..1] | [Incident](#CIM17v40-Incident) | see [Location](CIM17v40-Location) | |
| mainAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Location](CIM17v40-Location) | |
| OutageOrder [0..1] | [OutageOrder](#CIM17v40-OutageOrder) | see [Location](CIM17v40-Location) | |
| phone1 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Location](CIM17v40-Location) | |
| phone2 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Location](CIM17v40-Location) | |
| secondaryAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Location](CIM17v40-Location) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Location](CIM17v40-Location) | |
| SwitchingOrder [0..1] | [SwitchingOrder](#CIM17v40-SwitchingOrder) | see [Location](CIM17v40-Location) | |
| TroubleOrder [0..1] | [TroubleOrder](#CIM17v40-TroubleOrder) | see [Location](CIM17v40-Location) | |
| TroubleTicket [0..1] | [TroubleTicket](#CIM17v40-TroubleTicket) | see [Location](CIM17v40-Location) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-UserAttribute}
### UserAttribute


```mermaid
classDiagram
direction TB

class UserAttribute {

+ name : String [0..1]
+ sequenceNumber : Integer [0..1]
+ value : StringQuantity [0..1]
}

class Specification {

}

UserAttribute --> "0..1" Specification : PropertySpecification
class Specification {

}

UserAttribute --> "0..1" Specification : RatingSpecification
class Transaction {

}

UserAttribute --> "0..1" Transaction : Transaction
```

Generic name-value pair class, with optional sequence number and units for value; can be used to model parts of information exchange when concrete types are not known in advance.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| name [0..1] | [String](#CIM17v40-String) | Name of an attribute. | |
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | Sequence number for this attribute in a list of attributes. | |
| `PropertySpecification [0..1]` (informative) | [Specification](#CIM17v40-Specification) | | |
| `RatingSpecification [0..1]` (informative) | [Specification](#CIM17v40-Specification) | | |
| Transaction [0..1] | [Transaction](#CIM17v40-Transaction) | Transaction for which this snapshot has been recorded. | |
| value [0..1] | [StringQuantity](#CIM17v40-StringQuantity) | Value of an attribute, including unit information. | |

{#CIM17v40-VAdjIEEE}
### VAdjIEEE

Inheritance path = [VoltageAdjusterDynamics](#CIM17v40-VoltageAdjusterDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class VAdjIEEE {

+ adjslew : Float [0..1]
+ taoff : Seconds [0..1]
+ taon : Seconds [0..1]
+ vadjf : Float [0..1]
+ vadjmax : PU [0..1]
+ vadjmin : PU [0..1]
}

class VoltageAdjusterDynamics {

}

VoltageAdjusterDynamics <|-- VAdjIEEE : inherits from
```

IEEE voltage adjuster which is used to represent the voltage adjuster in either a power factor or VAr control system.

Reference: IEEE 421.5-2005, 11.1.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| adjslew [0..1] | [Float](#CIM17v40-Float) | Rate at which output of adjuster changes (<i>ADJ_SLEW</i>). Unit = s / PU. Typical value = 300. | |
| taoff [0..1] | [Seconds](#CIM17v40-Seconds) | Time that adjuster pulses are off (<i>T</i><i><sub>AOFF</sub></i>) (&gt;= 0). Typical value = 0,5. | |
| taon [0..1] | [Seconds](#CIM17v40-Seconds) | Time that adjuster pulses are on (<i>T</i><i><sub>AON</sub></i>) (&gt;= 0). Typical value = 0,1. | |
| vadjf [0..1] | [Float](#CIM17v40-Float) | Set high to provide a continuous raise or lower (<i>V</i><i><sub>ADJF</sub></i>). | |
| vadjmax [0..1] | [PU](#CIM17v40-PU) | Maximum output of the adjuster (<i>V</i><i><sub>ADJMAX</sub></i>) (&gt; VAdjIEEE.vadjmin). Typical value = 1,1. | |
| vadjmin [0..1] | [PU](#CIM17v40-PU) | Minimum output of the adjuster (<i>V</i><i><sub>ADJMIN</sub></i>) (&lt; VAdjIEEE.vadjmax). Typical value = 0,9. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| PFVArControllerType1Dynamics [1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [VoltageAdjusterDynamics](CIM17v40-VoltageAdjusterDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-VCompIEEEType1}
### VCompIEEEType1

Inheritance path = [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class VCompIEEEType1 {

+ rc : PU [0..1]
+ tr : Seconds [0..1]
+ xc : PU [0..1]
}

class VoltageCompensatorDynamics {

}

VoltageCompensatorDynamics <|-- VCompIEEEType1 : inherits from
```

<font color="#0f0f0f">Terminal voltage transducer and load compensator as defined in IEEE 421.5-2005, 4. This model is common to all excitation system models described in the IEEE Standard. </font>

<font color="#0f0f0f">Parameter details:</font>

<ol>

<li><font color="#0f0f0f">If <i>Rc</i> and <i>Xc</i> are set to zero, the l</font>oad compensation is not employed and the behaviour is as a simple sensing circuit.</li>

</ol>

<ol>

<li>If all parameters (<i>Rc</i>, <i>Xc</i> and <i>Tr</i>) are set to zero, the standard model VCompIEEEType1 is bypassed.</li>

</ol>

Reference: IEEE 421.5-2005 4.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| rc [0..1] | [PU](#CIM17v40-PU) | <font color="#0f0f0f">Resistive component of compensation of a generator (<i>Rc</i>) (&gt;= 0).</font> | |
| tr [0..1] | [Seconds](#CIM17v40-Seconds) | <font color="#0f0f0f">Time constant which is used for the combined voltage sensing and compensation signal (<i>Tr</i>) (&gt;= 0).</font> | |
| xc [0..1] | [PU](#CIM17v40-PU) | <font color="#0f0f0f">Reactive component of compensation of a generator (<i>Xc</i>) (&gt;= 0).</font> | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [VoltageCompensatorDynamics](CIM17v40-VoltageCompensatorDynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [VoltageCompensatorDynamics](CIM17v40-VoltageCompensatorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-VCompIEEEType2}
### VCompIEEEType2

Inheritance path = [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class VCompIEEEType2 {

+ tr : Seconds [0..1]
}

class VoltageCompensatorDynamics {

}

VoltageCompensatorDynamics <|-- VCompIEEEType2 : inherits from
```

<font color="#0f0f0f">Terminal voltage transducer and load compensator as defined in IEEE 421.5-2005, 4. This model is designed to cover the following types of compensation: </font>

<ul>

<li><font color="#0f0f0f">reactive droop;</font></li>

<li><font color="#0f0f0f">transformer-drop or line-drop compensation;</font></li>

<li><font color="#0f0f0f">reactive differential compensation known also as cross-current compensation.</font></li>

</ul>

<font color="#0f0f0f">Reference: IEEE 421.5-2005, 4.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| tr [0..1] | [Seconds](#CIM17v40-Seconds) | <font color="#0f0f0f">Time constant which is used for the combined voltage sensing and compensation signal (<i>Tr</i>) (&gt;= 0).</font> | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [VoltageCompensatorDynamics](CIM17v40-VoltageCompensatorDynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [VoltageCompensatorDynamics](CIM17v40-VoltageCompensatorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-VDCOL}
### VDCOL


```mermaid
classDiagram
direction TB

class VDCOL {

}

```


{#CIM17v40-VSCDynamics}
### VSCDynamics

Inheritance path = [HVDCDynamics](#CIM17v40-HVDCDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class VSCDynamics {

}

class HVDCDynamics {

}

HVDCDynamics <|-- VSCDynamics : inherits from
class VsConverter {

}

VSCDynamics --> "1" VsConverter : VsConverter
```

VSC function block whose behaviour is described by reference to a standard model <font color="#0f0f0f">or by definition of a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| VsConverter [1] | [VsConverter](#CIM17v40-VsConverter) | Voltage source converter to which voltage source converter dynamics model applies. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-VSCUserDefined}
### VSCUserDefined

Inheritance path = [VSCDynamics](#CIM17v40-VSCDynamics) => [HVDCDynamics](#CIM17v40-HVDCDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class VSCUserDefined {

+ proprietary : Boolean [0..1]
}

class VSCDynamics {

}

VSCDynamics <|-- VSCUserDefined : inherits from
```

Voltage source converter (VSC) function block whose dynamic behaviour is described by <font color="#0f0f0f">a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| proprietary [0..1] | [Boolean](#CIM17v40-Boolean) | Behaviour is based on a proprietary model as opposed to a detailed model.true = user-defined model is proprietary with behaviour mutually understood by sending and receiving applications and parameters passed as general attributesfalse = user-defined model is explicitly defined in terms of control blocks and their input and output signals. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| VsConverter [1] | [VsConverter](#CIM17v40-VsConverter) | see [VSCDynamics](CIM17v40-VSCDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-VSCtype1}
### (informative) VSCtype1

Inheritance path = [VSCDynamics](#CIM17v40-VSCDynamics) => [HVDCDynamics](#CIM17v40-HVDCDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class VSCtype1 {

}

class VSCDynamics {

}

VSCDynamics <|-- VSCtype1 : inherits from
class BlockingFunction {

}

VSCtype1 --> "1" BlockingFunction : BlockingFunction
class DCvoltageControl {

}

VSCtype1 --> "1" DCvoltageControl : DCvoltageControl
class Pcontrol {

}

VSCtype1 --> "1" Pcontrol : Pcontrol
class PFmode {

}

VSCtype1 --> "1" PFmode : PFmodel
class Qlimiter {

}

VSCtype1 --> "1" Qlimiter : Qlimiter
class Qmode {

}

VSCtype1 --> "1" Qmode : Qmode
class Qregulator {

}

VSCtype1 --> "1" Qregulator : Qregulator
class Umode {

}

VSCtype1 --> "1" Umode : Umode
```


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `BlockingFunction [1]` (informative) | [BlockingFunction](#CIM17v40-BlockingFunction) | | |
| `DCvoltageControl [1]` (informative) | [DCvoltageControl](#CIM17v40-DCvoltageControl) | | |
| `Pcontrol [1]` (informative) | [Pcontrol](#CIM17v40-Pcontrol) | | |
| `PFmodel [1]` (informative) | [PFmode](#CIM17v40-PFmode) | | |
| `Qlimiter [1]` (informative) | [Qlimiter](#CIM17v40-Qlimiter) | | |
| `Qmode [1]` (informative) | [Qmode](#CIM17v40-Qmode) | | |
| `Qregulator [1]` (informative) | [Qregulator](#CIM17v40-Qregulator) | | |
| `Umode [1]` (informative) | [Umode](#CIM17v40-Umode) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| VsConverter [1] | [VsConverter](#CIM17v40-VsConverter) | see [VSCDynamics](CIM17v40-VSCDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ValueAliasSet}
### ValueAliasSet

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ValueAliasSet {

}

class IdentifiedObject {

}

IdentifiedObject <|-- ValueAliasSet : inherits from
```

Describes the translation of a set of values into a name and is intendend to facilitate custom translations. Each ValueAliasSet has a name, description etc. A specific Measurement may represent a discrete state like Open, Closed, Intermediate etc. This requires a translation from the MeasurementValue.value number to a string, e.g. 0-&gt;"Invalid", 1-&gt;"Open", 2-&gt;"Closed", 3-&gt;"Intermediate". Each ValueToAlias member in ValueAliasSet.Value describe a mapping for one particular value to a name.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ValueToAlias}
### ValueToAlias

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ValueToAlias {

+ value : Integer [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- ValueToAlias : inherits from
class ValueAliasSet {

}

ValueToAlias --> "1" ValueAliasSet : ValueAliasSet
```

Describes the translation of one particular value into a name, e.g. 1 as "Open".


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| value [0..1] | [Integer](#CIM17v40-Integer) | The value that is mapped. | |
| `ValueAliasSet [1]` (OfAggregate) | [ValueAliasSet](#CIM17v40-ValueAliasSet) | The ValueAliasSet having the ValueToAlias mappings. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Vehicle}
### Vehicle

Inheritance path = [WorkAsset](#CIM17v40-WorkAsset) => [Asset](#CIM17v40-Asset) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Vehicle {

+ odometerReadDateTime : DateTime [0..1]
+ odometerReading : Length [0..1]
+ usageKind : enum:VehicleUsageKind [0..1]
}

class WorkAsset {

}

WorkAsset <|-- Vehicle : inherits from
```

Vehicle asset.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| odometerReadDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time the last odometer reading was recorded. | |
| odometerReading [0..1] | [Length](#CIM17v40-Length) | Odometer reading of this vehicle as of the 'odometerReadingDateTime'. Refer to associated ActivityRecords for earlier readings. | |
| usageKind [0..1] | [VehicleUsageKind](#CIM17v40-VehicleUsageKind) | Kind of usage of the vehicle. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Crew [0..1] | [Crew](#CIM17v40-Crew) | see [WorkAsset](CIM17v40-WorkAsset) | |
| `CUWorkEquipmentAsset [0..1]` (informative) | [CUWorkEquipmentItem](#CIM17v40-CUWorkEquipmentItem) | see [WorkAsset](CIM17v40-WorkAsset) | |
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | see [Asset](#CIM17v40-Asset) | |
| initialCondition [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | see [Asset](CIM17v40-Asset) | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | see [Asset](CIM17v40-Asset) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [Asset](CIM17v40-Asset) | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | see [Asset](CIM17v40-Asset) | |
| lotNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| position [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | see [Asset](CIM17v40-Asset) | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | see [Asset](CIM17v40-Asset) | |
| serialNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| type [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| utcNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | see [Asset](CIM17v40-Asset) | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | see [Asset](CIM17v40-Asset) | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | see [Asset](CIM17v40-Asset) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [Asset](CIM17v40-Asset) | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | see [Asset](CIM17v40-Asset) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Asset](CIM17v40-Asset) | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | see [Asset](CIM17v40-Asset) | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | see [Asset](CIM17v40-Asset) | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | see [Asset](CIM17v40-Asset) | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | see [Asset](CIM17v40-Asset) | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | see [Asset](CIM17v40-Asset) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Asset](CIM17v40-Asset) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [Asset](CIM17v40-Asset) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [Asset](CIM17v40-Asset) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Asset](CIM17v40-Asset) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Vendor}
### Vendor

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Vendor {

}

class IdentifiedObject {

}

IdentifiedObject <|-- Vendor : inherits from
```

The entity that owns the point of sale and contracts with the cashier to receipt payments and vend tokens using the payment system. The vendor has a private contract with and is managed by the merchant which is a type of organisation. The vendor is accountable to the merchant for revenue collected, and the merchant is in turn accountable to the supplier.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-VendorShift}
### VendorShift

Inheritance path = [Shift](#CIM17v40-Shift) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class VendorShift {

+ merchantDebitAmount : Money [0..1]
+ posted : Boolean [0..1]
}

class Shift {

}

Shift <|-- VendorShift : inherits from
class MerchantAccount {

}

VendorShift --> "0..1" MerchantAccount : MerchantAccount
class Vendor {

}

VendorShift --> "0..1" Vendor : Vendor
```

The operating shift for a vendor during which the vendor may transact against the merchant's account. It aggregates transactions and receipts during the shift and periodically debits a merchant account. The totals in vendor shift should always be the sum of totals aggregated in all cashier shifts that were open under the particular vendor shift.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| merchantDebitAmount [0..1] | [Money](#CIM17v40-Money) | The amount that is to be debited from the merchant account for this vendor shift. This amount reflects the sum(PaymentTransaction.transactionAmount). | |
| posted [0..1] | [Boolean](#CIM17v40-Boolean) | If true, merchantDebitAmount has been debited from MerchantAccount; typically happens at the end of VendorShift when it closes. | |
| MerchantAccount [0..1] | [MerchantAccount](#CIM17v40-MerchantAccount) | Merchant account this vendor shift periodically debits (based on aggregated transactions). | |
| Vendor [0..1] | [Vendor](#CIM17v40-Vendor) | Vendor that opens and owns this vendor shift. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| receiptsGrandTotalBankable [0..1] | [Money](#CIM17v40-Money) | see [Shift](CIM17v40-Shift) | |
| receiptsGrandTotalNonBankable [0..1] | [Money](#CIM17v40-Money) | see [Shift](CIM17v40-Shift) | |
| receiptsGrandTotalRounding [0..1] | [Money](#CIM17v40-Money) | see [Shift](CIM17v40-Shift) | |
| transactionsGrandTotal [0..1] | [Money](#CIM17v40-Money) | see [Shift](CIM17v40-Shift) | |
| transactionsGrandTotalRounding [0..1] | [Money](#CIM17v40-Money) | see [Shift](CIM17v40-Shift) | |
| activityInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [Shift](CIM17v40-Shift) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-VerificationAction}
### VerificationAction

Inheritance path = [SwitchingAction](#CIM17v40-SwitchingAction) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class VerificationAction {

+ verificationCondition : String [0..1]
}

class SwitchingAction {

}

SwitchingAction <|-- VerificationAction : inherits from
class PowerSystemResource {

}

VerificationAction --> "0..1" PowerSystemResource : PowerSystemResource
```

Verification of a switch position or other condition as a switching step


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| verificationCondition [0..1] | [String](#CIM17v40-String) | freeform description of the condition to be verified | |
| PowerSystemResource [0..1] | [PowerSystemResource](#CIM17v40-PowerSystemResource) | The power system resource that the verification action is performed on | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| executedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| issuedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| phases [0..1] | [PhaseCode](#CIM17v40-PhaseCode) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| plannedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [SwitchingAction](#CIM17v40-SwitchingAction) | |
| Operator [0..1] | [Operator](#CIM17v40-Operator) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingEvent [0..1] | [SwitchingEvent](#CIM17v40-SwitchingEvent) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| SwitchingStep [0..1] | [SwitchingStep](#CIM17v40-SwitchingStep) | see [SwitchingAction](CIM17v40-SwitchingAction) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-ViolationLimit}
### ViolationLimit

Inheritance path = [Limit](#CIM17v40-Limit) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class ViolationLimit {

+ enforced : Boolean [0..1]
}

class Limit {

}

Limit <|-- ViolationLimit : inherits from
class Flowgate {

}

ViolationLimit --> "0..1" Flowgate : Flowgate
class MktMeasurement {

}

ViolationLimit --> "0..1" MktMeasurement : MktMeasurement
```

A type of limit that indicates if it is enforced and, through association, the organisation responsible for setting the limit.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enforced [0..1] | [Boolean](#CIM17v40-Boolean) | True if limit is enforced. | |
| `Flowgate [0..1]` (informative) | [Flowgate](#CIM17v40-Flowgate) | | |
| `MktMeasurement [0..1]` (informative) | [MktMeasurement](#CIM17v40-MktMeasurement) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-VisibilityLayer}
### VisibilityLayer

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class VisibilityLayer {

+ drawingOrder : Integer [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- VisibilityLayer : inherits from
```

Layers are typically used for grouping diagram objects according to themes and scales. Themes are used to display or hide certain information (e.g., lakes, borders), while scales are used for hiding or displaying information depending on the current zoom level (hide text when it is too small to be read, or when it exceeds the screen size). This is also called de-cluttering.

CIM based graphics exchange supports an m:n relationship between diagram objects and layers. The importing system shall convert an m:n case into an appropriate 1:n representation if the importing system does not support m:n.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| drawingOrder [0..1] | [Integer](#CIM17v40-Integer) | The drawing order for this layer. The higher the number, the later the layer and the objects within it are rendered. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-VolcanicAshCloud}
### VolcanicAshCloud

Inheritance path = [AtmosphericPhenomenon](#CIM17v40-AtmosphericPhenomenon) => [EnvironmentalPhenomenon](#CIM17v40-EnvironmentalPhenomenon)

```mermaid
classDiagram
direction TB

class VolcanicAshCloud {

+ density : ParticulateDensity [0..1]
+ particleSize : Length [0..1]
}

class AtmosphericPhenomenon {

}

AtmosphericPhenomenon <|-- VolcanicAshCloud : inherits from
```

An ash cloud formed as a result of a volcanic eruption.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| density [0..1] | [ParticulateDensity](#CIM17v40-ParticulateDensity) | Particulate density of the ash cloud during the time interval. | |
| particleSize [0..1] | [Length](#CIM17v40-Length) | The diameter of the particles during the time interval. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| direction [0..1] | [Bearing](#CIM17v40-Bearing) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| maxCoverage [0..1] | [PerCent](#CIM17v40-PerCent) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| minCoverage [0..1] | [PerCent](#CIM17v40-PerCent) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| speed [0..1] | [Speed](#CIM17v40-Speed) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| altitude [0..1] | [RelativeDisplacement](#CIM17v40-RelativeDisplacement) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| base [0..1] | [RelativeDisplacement](#CIM17v40-RelativeDisplacement) | see [AtmosphericPhenomenon](CIM17v40-AtmosphericPhenomenon) | |
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| PhenomenonClassification [0..1] | [PhenomenonClassification](#CIM17v40-PhenomenonClassification) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| timeInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |

{#CIM17v40-VoltageAdjusterDynamics}
### VoltageAdjusterDynamics

Inheritance path = [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class VoltageAdjusterDynamics {

}

class DynamicsFunctionBlock {

}

DynamicsFunctionBlock <|-- VoltageAdjusterDynamics : inherits from
class PFVArControllerType1Dynamics {

}

VoltageAdjusterDynamics --> "1" PFVArControllerType1Dynamics : PFVArControllerType1Dynamics
```

Voltage adjuster function block whose behaviour is described by reference to a standard model <font color="#0f0f0f">or by definition of a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| PFVArControllerType1Dynamics [1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | Power factor or VAr controller type 1 model with which this voltage adjuster is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-VoltageAdjusterUserDefined}
### VoltageAdjusterUserDefined

Inheritance path = [VoltageAdjusterDynamics](#CIM17v40-VoltageAdjusterDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class VoltageAdjusterUserDefined {

+ proprietary : Boolean [0..1]
}

class VoltageAdjusterDynamics {

}

VoltageAdjusterDynamics <|-- VoltageAdjusterUserDefined : inherits from
```

<font color="#0f0f0f">Voltage adjuster</font> function block whose dynamic behaviour is described by <font color="#0f0f0f">a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| proprietary [0..1] | [Boolean](#CIM17v40-Boolean) | Behaviour is based on a proprietary model as opposed to a detailed model.true = user-defined model is proprietary with behaviour mutually understood by sending and receiving applications and parameters passed as general attributesfalse = user-defined model is explicitly defined in terms of control blocks and their input and output signals. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| PFVArControllerType1Dynamics [1] | [PFVArControllerType1Dynamics](#CIM17v40-PFVArControllerType1Dynamics) | see [VoltageAdjusterDynamics](CIM17v40-VoltageAdjusterDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-VoltageCompensatorDynamics}
### VoltageCompensatorDynamics

Inheritance path = [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class VoltageCompensatorDynamics {

}

class DynamicsFunctionBlock {

}

DynamicsFunctionBlock <|-- VoltageCompensatorDynamics : inherits from
class ExcitationSystemDynamics {

}

VoltageCompensatorDynamics --> "1" ExcitationSystemDynamics : ExcitationSystemDynamics
class RemoteInputSignal {

}

VoltageCompensatorDynamics --> "0..1" RemoteInputSignal : RemoteInputSignal
```

Voltage compensator function block whose behaviour is described by reference to a standard model <font color="#0f0f0f">or by definition of a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | Excitation system model with which this voltage compensator is associated. | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | Remote input signal used by this voltage compensator model. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-VoltageCompensatorUserDefined}
### VoltageCompensatorUserDefined

Inheritance path = [VoltageCompensatorDynamics](#CIM17v40-VoltageCompensatorDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class VoltageCompensatorUserDefined {

+ proprietary : Boolean [0..1]
}

class VoltageCompensatorDynamics {

}

VoltageCompensatorDynamics <|-- VoltageCompensatorUserDefined : inherits from
```

Voltage compensator function block whose dynamic behaviour is described by <font color="#0f0f0f">a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| proprietary [0..1] | [Boolean](#CIM17v40-Boolean) | Behaviour is based on a proprietary model as opposed to a detailed model.true = user-defined model is proprietary with behaviour mutually understood by sending and receiving applications and parameters passed as general attributesfalse = user-defined model is explicitly defined in terms of control blocks and their input and output signals. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ExcitationSystemDynamics [1] | [ExcitationSystemDynamics](#CIM17v40-ExcitationSystemDynamics) | see [VoltageCompensatorDynamics](CIM17v40-VoltageCompensatorDynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [VoltageCompensatorDynamics](CIM17v40-VoltageCompensatorDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-VoltageControlZone}
### VoltageControlZone

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class VoltageControlZone {

}

class PowerSystemResource {

}

PowerSystemResource <|-- VoltageControlZone : inherits from
class BusbarSection {

}

VoltageControlZone --> "1" BusbarSection : BusbarSection
class RegulationSchedule {

}

VoltageControlZone --> "0..1" RegulationSchedule : RegulationSchedule
```

An area of the power system network which is defined for secondary voltage control purposes. A voltage control zone consists of a collection of substations with a designated bus bar section whose voltage will be controlled.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| BusbarSection [1] | [BusbarSection](#CIM17v40-BusbarSection) | A VoltageControlZone is controlled by a designated BusbarSection. | |
| RegulationSchedule [0..1] | [RegulationSchedule](#CIM17v40-RegulationSchedule) | A VoltageControlZone may have a voltage regulation schedule. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-VoltageLevel}
### VoltageLevel

Inheritance path = [EquipmentContainer](#CIM17v40-EquipmentContainer) => [ConnectivityNodeContainer](#CIM17v40-ConnectivityNodeContainer) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class VoltageLevel {

+ highVoltageLimit : Voltage [0..1]
+ lowVoltageLimit : Voltage [0..1]
}

class EquipmentContainer {

}

EquipmentContainer <|-- VoltageLevel : inherits from
class BaseVoltage {

}

VoltageLevel --> "1" BaseVoltage : BaseVoltage
class Substation {

}

VoltageLevel --> "1" Substation : Substation
```

A collection of equipment at one common system voltage forming a switchgear. The equipment typically consists of breakers, busbars, instrumentation, control, regulation and protection devices as well as assemblies of all these.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| highVoltageLimit [0..1] | [Voltage](#CIM17v40-Voltage) | The bus bar's high voltage limit.The limit applies to all equipment and nodes contained in a given VoltageLevel. It is not required that it is exchanged in pair with lowVoltageLimit. It is preferable to use operational VoltageLimit, which prevails, if present. | |
| lowVoltageLimit [0..1] | [Voltage](#CIM17v40-Voltage) | The bus bar's low voltage limit.The limit applies to all equipment and nodes contained in a given VoltageLevel. It is not required that it is exchanged in pair with highVoltageLimit. It is preferable to use operational VoltageLimit, which prevails, if present. | |
| BaseVoltage [1] | [BaseVoltage](#CIM17v40-BaseVoltage) | The base voltage used for all equipment within the voltage level. | |
| `Substation [1]` (OfAggregate) | [Substation](#CIM17v40-Substation) | The substation of the voltage level. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-VoltageLimit}
### VoltageLimit

Inheritance path = [OperationalLimit](#CIM17v40-OperationalLimit) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class VoltageLimit {

+ normalValue : Voltage [0..1]
+ value : Voltage [0..1]
}

class OperationalLimit {

}

OperationalLimit <|-- VoltageLimit : inherits from
```

Operational limit applied to voltage.

The use of operational VoltageLimit is preferred instead of limits defined at VoltageLevel. The operational VoltageLimits are used, if present.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| normalValue [0..1] | [Voltage](#CIM17v40-Voltage) | The normal limit on voltage. High or low limit nature of the limit depends upon the properties of the operational limit type. The attribute shall be a positive value or zero. | |
| value [0..1] | [Voltage](#CIM17v40-Voltage) | Limit on voltage. High or low limit nature of the limit depends upon the properties of the operational limit type. The attribute shall be a positive value or zero. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `OperationalLimitSet [1]` (OfAggregate) | [OperationalLimitSet](#CIM17v40-OperationalLimitSet) | see [OperationalLimit](CIM17v40-OperationalLimit) | |
| OperationalLimitType [0..1] | [OperationalLimitType](#CIM17v40-OperationalLimitType) | see [OperationalLimit](CIM17v40-OperationalLimit) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-VsCapabilityCurve}
### VsCapabilityCurve

Inheritance path = [Curve](#CIM17v40-Curve) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class VsCapabilityCurve {

}

class Curve {

}

Curve <|-- VsCapabilityCurve : inherits from
```

The P-Q capability curve for a voltage source converter, with P on X-axis and Qmin and Qmax on Y1-axis and Y2-axis.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| curveStyle [0..1] | [CurveStyle](#CIM17v40-CurveStyle) | see [Curve](CIM17v40-Curve) | |
| xMultiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| xUnit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| y3Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [Curve](CIM17v40-Curve) | |
| y3Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [Curve](CIM17v40-Curve) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-VsConverter}
### VsConverter

Inheritance path = [ACDCConverter](#CIM17v40-ACDCConverter) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class VsConverter {

+ delta : AngleDegrees [0..1]
+ droop : PU [0..1]
+ droopCompensation : Resistance [0..1]
+ maxModulationIndex : Float [0..1]
+ maxValveCurrent : CurrentFlow [0..1]
+ pPccControl : enum:VsPpccControlKind [0..1]
+ qPccControl : enum:VsQpccControlKind [0..1]
+ qShare : PerCent [0..1]
+ targetPhasePcc : AngleDegrees [0..1]
+ targetPowerFactorPcc : Float [0..1]
+ targetPWMfactor : Float [0..1]
+ targetQpcc : ReactivePower [0..1]
+ targetUpcc : Voltage [0..1]
+ uv : Voltage [0..1]
}

class ACDCConverter {

}

ACDCConverter <|-- VsConverter : inherits from
class VsCapabilityCurve {

}

VsConverter --> "0..1" VsCapabilityCurve : CapabilityCurve
class VSCDynamics {

}

VsConverter --> "0..1" VSCDynamics : VSCDynamics
```

DC side of the voltage source converter (VSC).


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| delta [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Angle between VsConverter.uv and ACDCConverter.uc. It is converter�s state variable used in power flow. The attribute shall be a positive value or zero. | |
| droop [0..1] | [PU](#CIM17v40-PU) | Droop constant. The pu value is obtained as D [kV/MW] x Sb / Ubdc. The attribute shall be a positive value. | |
| droopCompensation [0..1] | [Resistance](#CIM17v40-Resistance) | Compensation constant. Used to compensate for voltage drop when controlling voltage at a distant bus. The attribute shall be a positive value. | |
| maxModulationIndex [0..1] | [Float](#CIM17v40-Float) | The maximum quotient between the AC converter voltage (Uc) and DC voltage (Ud). A factor typically less than 1. It is converter�s configuration data used in power flow. | |
| maxValveCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | The maximum current through a valve. It is converter�s configuration data. | |
| pPccControl [0..1] | [VsPpccControlKind](#CIM17v40-VsPpccControlKind) | Kind of control of real power and/or DC voltage. | |
| qPccControl [0..1] | [VsQpccControlKind](#CIM17v40-VsQpccControlKind) | Kind of reactive power control. | |
| qShare [0..1] | [PerCent](#CIM17v40-PerCent) | Reactive power sharing factor among parallel converters on Uac control. The attribute shall be a positive value or zero. | |
| targetPhasePcc [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Phase target at AC side, at point of common coupling. The attribute shall be a positive value. | |
| targetPowerFactorPcc [0..1] | [Float](#CIM17v40-Float) | Power factor target at the AC side, at point of common coupling. The attribute shall be a positive value. | |
| targetPWMfactor [0..1] | [Float](#CIM17v40-Float) | Magnitude of pulse-modulation factor. The attribute shall be a positive value. | |
| targetQpcc [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | Reactive power injection target in AC grid, at point of common coupling. Load sign convention is used, i.e. positive sign means flow out from a node. | |
| targetUpcc [0..1] | [Voltage](#CIM17v40-Voltage) | Voltage target in AC grid, at point of common coupling. The attribute shall be a positive value. | |
| uv [0..1] | [Voltage](#CIM17v40-Voltage) | Line-to-line voltage on the valve side of the converter transformer. It is converter�s state variable, result from power flow. The attribute shall be a positive value. | |
| CapabilityCurve [0..1] | [VsCapabilityCurve](#CIM17v40-VsCapabilityCurve) | Capability curve of this converter. | |
| VSCDynamics [0..1] | [VSCDynamics](#CIM17v40-VSCDynamics) | Voltage source converter dynamics model used to describe dynamic behaviour of this converter. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| baseS [0..1] | [ApparentPower](#CIM17v40-ApparentPower) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| idc [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| idleLoss [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| maxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| maxUdc [0..1] | [Voltage](#CIM17v40-Voltage) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| minP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| minUdc [0..1] | [Voltage](#CIM17v40-Voltage) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| numberOfValves [0..1] | [Integer](#CIM17v40-Integer) | see [ACDCConverter](#CIM17v40-ACDCConverter) | |
| p [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| poleLossP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| q [0..1] | [ReactivePower](#CIM17v40-ReactivePower) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| ratedUdc [0..1] | [Voltage](#CIM17v40-Voltage) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| resistiveLoss [0..1] | [Resistance](#CIM17v40-Resistance) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| switchingLoss [0..1] | [ActivePowerPerCurrentFlow](#CIM17v40-ActivePowerPerCurrentFlow) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| targetPpcc [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| targetUdc [0..1] | [Voltage](#CIM17v40-Voltage) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| uc [0..1] | [Voltage](#CIM17v40-Voltage) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| udc [0..1] | [Voltage](#CIM17v40-Voltage) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| valveU0 [0..1] | [Voltage](#CIM17v40-Voltage) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| PccTerminal [0..1] | [Terminal](#CIM17v40-Terminal) | see [ACDCConverter](CIM17v40-ACDCConverter) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WaveTrap}
### WaveTrap

Inheritance path = [AuxiliaryEquipment](#CIM17v40-AuxiliaryEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WaveTrap {

}

class AuxiliaryEquipment {

}

AuxiliaryEquipment <|-- WaveTrap : inherits from
```

Line traps are devices that impede high frequency power line carrier signals yet present a negligible impedance at the main power frequency.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Terminal [1] | [Terminal](#CIM17v40-Terminal) | see [AuxiliaryEquipment](CIM17v40-AuxiliaryEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WeatherStation}
### WeatherStation

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WeatherStation {

}

class PowerSystemResource {

}

PowerSystemResource <|-- WeatherStation : inherits from
```

This represents a source of ambient temperature.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WheelingCounterParty}
### WheelingCounterParty

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WheelingCounterParty {

}

class IdentifiedObject {

}

IdentifiedObject <|-- WheelingCounterParty : inherits from
```

Counter party in a wheeling transaction.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WheelingReferenceSchedule}
### WheelingReferenceSchedule

Inheritance path = [BidHourlySchedule](#CIM17v40-BidHourlySchedule) => [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) => [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WheelingReferenceSchedule {

+ value : String [0..1]
}

class BidHourlySchedule {

}

BidHourlySchedule <|-- WheelingReferenceSchedule : inherits from
```

A unique identifier of a wheeling transaction. A wheeling transaction is a balanced Energy exchange among Supply and Demand Resources.

This schedule is assocated with the hourly parameters in a resource bid.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| value [0..1] | [String](#CIM17v40-String) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Bid [1] | [Bid](#CIM17v40-Bid) | see [BidHourlySchedule](CIM17v40-BidHourlySchedule) | |
| endTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [RegularIntervalSchedule](#CIM17v40-RegularIntervalSchedule) | |
| timeStep [0..1] | [Seconds](#CIM17v40-Seconds) | see [RegularIntervalSchedule](CIM17v40-RegularIntervalSchedule) | |
| startTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [BasicIntervalSchedule](#CIM17v40-BasicIntervalSchedule) | |
| value1Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value1Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| value2Unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | see [BasicIntervalSchedule](CIM17v40-BasicIntervalSchedule) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Whirlpool}
### Whirlpool

Inheritance path = [HydrosphericPhenomenon](#CIM17v40-HydrosphericPhenomenon) => [EnvironmentalPhenomenon](#CIM17v40-EnvironmentalPhenomenon)

```mermaid
classDiagram
direction TB

class Whirlpool {

}

class HydrosphericPhenomenon {

}

HydrosphericPhenomenon <|-- Whirlpool : inherits from
```

A whirlpool, a rapidly rotating mass of water in a river or sea into which objects may be drawn, typically caused by the meeting of conflicting currents.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| EnvironmentalInformation [0..1] | [EnvironmentalInformation](#CIM17v40-EnvironmentalInformation) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| PhenomenonClassification [0..1] | [PhenomenonClassification](#CIM17v40-PhenomenonClassification) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |
| timeInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [EnvironmentalPhenomenon](CIM17v40-EnvironmentalPhenomenon) | |

{#CIM17v40-WindAeroConstIEC}
### WindAeroConstIEC

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindAeroConstIEC {

}

class IdentifiedObject {

}

IdentifiedObject <|-- WindAeroConstIEC : inherits from
class WindGenTurbineType1aIEC {

}

WindAeroConstIEC --> "1" WindGenTurbineType1aIEC : WindGenTurbineType1aIEC
```

Constant aerodynamic torque model which assumes that the aerodynamic torque is constant.

Reference: IEC 61400-27-1:2015, 5.6.1.1.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WindGenTurbineType1aIEC [1] | [WindGenTurbineType1aIEC](#CIM17v40-WindGenTurbineType1aIEC) | Wind turbine type 1A model with which this wind aerodynamic model is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindAeroOneDimIEC}
### WindAeroOneDimIEC

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindAeroOneDimIEC {

+ ka : Float [0..1]
+ thetaomega : AngleDegrees [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- WindAeroOneDimIEC : inherits from
class WindTurbineType3IEC {

}

WindAeroOneDimIEC --> "1" WindTurbineType3IEC : WindTurbineType3IEC
```

One-dimensional aerodynamic model.

Reference: IEC 61400-27-1:2015, 5.6.1.2.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| ka [0..1] | [Float](#CIM17v40-Float) | Aerodynamic gain (<i>k</i><i><sub>a</sub></i>). It is a type-dependent parameter. | |
| thetaomega [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Initial pitch angle (<i>theta</i><i><sub>omega0</sub></i>). It is a case-dependent parameter. | |
| WindTurbineType3IEC [1] | [WindTurbineType3IEC](#CIM17v40-WindTurbineType3IEC) | Wind turbine type 3 model with which this wind aerodynamic model is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindAeroTwoDimIEC}
### WindAeroTwoDimIEC

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindAeroTwoDimIEC {

+ dpomega : PU [0..1]
+ dptheta : PU [0..1]
+ dpv1 : PU [0..1]
+ omegazero : PU [0..1]
+ pavail : PU [0..1]
+ thetav2 : AngleDegrees [0..1]
+ thetazero : AngleDegrees [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- WindAeroTwoDimIEC : inherits from
class WindTurbineType3IEC {

}

WindAeroTwoDimIEC --> "1" WindTurbineType3IEC : WindTurbineType3IEC
```

Two-dimensional aerodynamic model.

Reference: IEC 61400-27-1:2015, 5.6.1.3.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dpomega [0..1] | [PU](#CIM17v40-PU) | Partial derivative of aerodynamic power with respect to changes in WTR speed (<i>dp</i><i><sub>omega</sub></i>). It is a type-dependent parameter. | |
| dptheta [0..1] | [PU](#CIM17v40-PU) | Partial derivative of aerodynamic power with respect to changes in pitch angle (<i>dp</i><i><sub>theta</sub></i>). It is a type-dependent parameter. | |
| dpv1 [0..1] | [PU](#CIM17v40-PU) | Partial derivative (<i>dp</i><i><sub>v1</sub></i>). It is a type-dependent parameter. | |
| omegazero [0..1] | [PU](#CIM17v40-PU) | Rotor speed if the wind turbine is not derated (<i>omega</i><i><sub>0</sub></i>). It is a type-dependent parameter. | |
| pavail [0..1] | [PU](#CIM17v40-PU) | Available aerodynamic power (<i>p</i><i><sub>avail</sub></i><i>)</i>. It is a case-dependent parameter. | |
| thetav2 [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Blade angle at twice rated wind speed (<i>theta</i><i><sub>v2</sub></i>). It is a type-dependent parameter. | |
| thetazero [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Pitch angle if the wind turbine is not derated (<i>theta</i><i><sub>0</sub></i>). It is a case-dependent parameter. | |
| WindTurbineType3IEC [1] | [WindTurbineType3IEC](#CIM17v40-WindTurbineType3IEC) | Wind turbine type 3 model with which this wind aerodynamic model is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindContCurrLimIEC}
### WindContCurrLimIEC

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindContCurrLimIEC {

+ imax : PU [0..1]
+ imaxdip : PU [0..1]
+ kpqu : PU [0..1]
+ mdfslim : Boolean [0..1]
+ mqpri : Boolean [0..1]
+ tufiltcl : Seconds [0..1]
+ upqumax : PU [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- WindContCurrLimIEC : inherits from
class WindTurbineType3or4IEC {

}

WindContCurrLimIEC --> "1" WindTurbineType3or4IEC : WindTurbineType3or4IEC
```

Current limitation model. The current limitation model combines the physical limits and the control limits.

Reference: IEC 61400-27-1:2015, 5.6.5.8.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| imax [0..1] | [PU](#CIM17v40-PU) | Maximum continuous current at the wind turbine terminals (<i>i</i><i><sub>max</sub></i>). It is a type-dependent parameter. | |
| imaxdip [0..1] | [PU](#CIM17v40-PU) | Maximum current during voltage dip at the wind turbine terminals (<i>i</i><i><sub>maxdip</sub></i>). It is a project-dependent parameter. | |
| kpqu [0..1] | [PU](#CIM17v40-PU) | Partial derivative of reactive current limit (<i>K</i><i><sub>pqu</sub></i>) versus voltage. It is a type-dependent parameter. | |
| mdfslim [0..1] | [Boolean](#CIM17v40-Boolean) | Limitation of type 3 stator current (<i>M</i><i><sub>DFSLim</sub></i>). <i>M</i><i><sub>DFSLim</sub></i><sub> </sub>= 1 for wind turbines type 4. It is a type-dependent parameter.false= total current limitation (0 in the IEC model)true=stator current limitation (1 in the IEC model). | |
| mqpri [0..1] | [Boolean](#CIM17v40-Boolean) | Prioritisation of Q control during UVRT (<i>M</i><i><sub>qpri</sub></i>). It is a project-dependent parameter.true = reactive power priority (1 in the IEC model)false = active power priority (0 in the IEC model). | |
| tufiltcl [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage measurement filter time constant (<i>T</i><i><sub>ufiltcl</sub></i>) (&gt;= 0). It is a type-dependent parameter. | |
| upqumax [0..1] | [PU](#CIM17v40-PU) | Wind turbine voltage in the operation point where zero reactive current can be delivered (<i>u</i><i><sub>pqumax</sub></i>). It is a type-dependent parameter. | |
| WindTurbineType3or4IEC [1] | [WindTurbineType3or4IEC](#CIM17v40-WindTurbineType3or4IEC) | Wind turbine type 3 or type 4 model with which this wind control current limitation model is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindContPType3IEC}
### WindContPType3IEC

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindContPType3IEC {

+ dpmax : PU [0..1]
+ dprefmax : PU [0..1]
+ dprefmin : PU [0..1]
+ dthetamax : PU [0..1]
+ dthetamaxuvrt : PU [0..1]
+ kdtd : PU [0..1]
+ kip : PU [0..1]
+ kpp : PU [0..1]
+ mpuvrt : Boolean [0..1]
+ omegadtd : PU [0..1]
+ omegaoffset : PU [0..1]
+ pdtdmax : PU [0..1]
+ tdvs : Seconds [0..1]
+ thetaemin : PU [0..1]
+ thetauscale : PU [0..1]
+ tomegafiltp3 : Seconds [0..1]
+ tomegaref : Seconds [0..1]
+ tpfiltp3 : Seconds [0..1]
+ tpord : PU [0..1]
+ tufiltp3 : Seconds [0..1]
+ udvs : PU [0..1]
+ updip : PU [0..1]
+ zeta : Float [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- WindContPType3IEC : inherits from
class WindTurbineType3IEC {

}

WindContPType3IEC --> "1" WindTurbineType3IEC : WindTurbineType3IEC
```

P control model type 3.

Reference: IEC 61400-27-1:2015, 5.6.5.4.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dpmax [0..1] | [PU](#CIM17v40-PU) | Maximum wind turbine power ramp rate (<i>dp</i><i><sub>max</sub></i>). It is a type-dependent parameter. | |
| dprefmax [0..1] | [PU](#CIM17v40-PU) | Maximum ramp rate of wind turbine reference power (<i>dp</i><i><sub>refmax</sub></i>). It is a project-dependent parameter. | |
| dprefmin [0..1] | [PU](#CIM17v40-PU) | Minimum ramp rate of wind turbine reference power (<i>dp</i><i><sub>refmin</sub></i>). It is a project-dependent parameter. | |
| dthetamax [0..1] | [PU](#CIM17v40-PU) | Ramp limitation of torque, required in some grid codes (<i>dt</i><i><sub>max</sub></i>). It is a project-dependent parameter. | |
| dthetamaxuvrt [0..1] | [PU](#CIM17v40-PU) | Limitation of torque rise rate during UVRT (<i>dtheta</i><i><sub>maxUVRT</sub></i>). It is a project-dependent parameter. | |
| kdtd [0..1] | [PU](#CIM17v40-PU) | Gain for active drive train damping (<i>K</i><i><sub>DTD</sub></i>). It is a type-dependent parameter. | |
| kip [0..1] | [PU](#CIM17v40-PU) | PI controller integration parameter (<i>K</i><sub>Ip</sub>). It is a type-dependent parameter. | |
| kpp [0..1] | [PU](#CIM17v40-PU) | PI controller proportional gain (<i>K</i><sub>Pp</sub>). It is a type-dependent parameter. | |
| mpuvrt [0..1] | [Boolean](#CIM17v40-Boolean) | Enable UVRT power control mode (<i>M</i><i><sub>pUVRT</sub></i><sub>)</sub>. It is a project-dependent parameter.true = voltage control (1 in the IEC model)false = reactive power control (0 in the IEC model). | |
| omegadtd [0..1] | [PU](#CIM17v40-PU) | Active drive train damping frequency (<i>omega</i><i><sub>DTD</sub></i>). It can be calculated from two mass model parameters. It is a type-dependent parameter. | |
| omegaoffset [0..1] | [PU](#CIM17v40-PU) | Offset to reference value that limits controller action during rotor speed changes (<i>omega</i><i><sub>offset</sub></i>). It is a case-dependent parameter. | |
| pdtdmax [0..1] | [PU](#CIM17v40-PU) | Maximum active drive train damping power (<i>p</i><sub>DTDmax</sub>). It is a type-dependent parameter. | |
| tdvs [0..1] | [Seconds](#CIM17v40-Seconds) | Time<sub> </sub>delay after deep voltage sags (<i>T</i><i><sub>DVS</sub></i>) (&gt;= 0). It is a project-dependent parameter. | |
| thetaemin [0..1] | [PU](#CIM17v40-PU) | Minimum electrical generator torque (<i>t</i><sub>emin</sub>). It is a type-dependent parameter. | |
| thetauscale [0..1] | [PU](#CIM17v40-PU) | Voltage scaling factor of reset-torque (<i>t</i><sub>uscale</sub>). It is a project-dependent parameter. | |
| tomegafiltp3 [0..1] | [Seconds](#CIM17v40-Seconds) | Filter time constant for generator speed measurement (<i>T</i><sub>omegafiltp3</sub>) (&gt;= 0). It is a type-dependent parameter. | |
| tomegaref [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant in speed reference filter (<i>T</i><sub>omega,ref</sub>) (&gt;= 0). It is a type-dependent parameter. | |
| tpfiltp3 [0..1] | [Seconds](#CIM17v40-Seconds) | Filter time constant for power measurement (<i>T</i><sub>pfiltp3</sub>) (&gt;= 0). It is a type-dependent parameter. | |
| tpord [0..1] | [PU](#CIM17v40-PU) | Time constant in power order lag (<i>T</i><sub>pord</sub>). It is a type-dependent parameter. | |
| tufiltp3 [0..1] | [Seconds](#CIM17v40-Seconds) | Filter time constant for voltage measurement (<i>T</i><sub>ufiltp3</sub>) (&gt;= 0). It is a type-dependent parameter. | |
| udvs [0..1] | [PU](#CIM17v40-PU) | Voltage limit for hold UVRT status after deep voltage sags (<i>u</i><i><sub>DVS</sub></i>). It is a project-dependent parameter. | |
| updip [0..1] | [PU](#CIM17v40-PU) | Voltage dip threshold for P-control (<i>u</i><sub>Pdip</sub>). Part of turbine control, often different (e.g 0.8) from converter thresholds. It is a project-dependent parameter. | |
| zeta [0..1] | [Float](#CIM17v40-Float) | Coefficient for active drive train damping (<i>zeta</i>). It is a type-dependent parameter. | |
| WindTurbineType3IEC [1] | [WindTurbineType3IEC](#CIM17v40-WindTurbineType3IEC) | Wind turbine type 3 model with which this wind control P type 3 model is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindContPType4aIEC}
### WindContPType4aIEC

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindContPType4aIEC {

+ dpmaxp4a : PU [0..1]
+ tpordp4a : Seconds [0..1]
+ tufiltp4a : Seconds [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- WindContPType4aIEC : inherits from
class WindTurbineType4aIEC {

}

WindContPType4aIEC --> "1" WindTurbineType4aIEC : WindTurbineType4aIEC
```

P control model type 4A.

Reference: IEC 61400-27-1:2015, 5.6.5.5.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dpmaxp4a [0..1] | [PU](#CIM17v40-PU) | Maximum wind turbine power ramp rate (<i>dp</i><i><sub>maxp4A</sub></i>). It is a project-dependent parameter. | |
| tpordp4a [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant in power order lag (<i>T</i><i><sub>pordp4A</sub></i>) (&gt;= 0). It is a type-dependent parameter. | |
| tufiltp4a [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage measurement filter time constant (<i>T</i><i><sub>ufiltp4A</sub></i>) (&gt;= 0). It is a type-dependent parameter. | |
| WindTurbineType4aIEC [1] | [WindTurbineType4aIEC](#CIM17v40-WindTurbineType4aIEC) | Wind turbine type 4A model with which this wind control P type 4A model is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindContPType4bIEC}
### WindContPType4bIEC

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindContPType4bIEC {

+ dpmaxp4b : PU [0..1]
+ tpaero : Seconds [0..1]
+ tpordp4b : Seconds [0..1]
+ tufiltp4b : Seconds [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- WindContPType4bIEC : inherits from
class WindTurbineType4bIEC {

}

WindContPType4bIEC --> "1" WindTurbineType4bIEC : WindTurbineType4bIEC
```

P control model type 4B.

Reference: IEC 61400-27-1:2015, 5.6.5.6.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dpmaxp4b [0..1] | [PU](#CIM17v40-PU) | Maximum wind turbine power ramp rate (<i>dp</i><i><sub>maxp4B</sub></i>). It is a project-dependent parameter. | |
| tpaero [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant in aerodynamic power response (<i>T</i><i><sub>paero</sub></i>) (&gt;= 0). It is a type-dependent parameter. | |
| tpordp4b [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant in power order lag (<i>T</i><i><sub>pordp4B</sub></i>) (&gt;= 0). It is a type-dependent parameter. | |
| tufiltp4b [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage measurement filter time constant (<i>T</i><i><sub>ufiltp4B</sub></i>) (&gt;= 0). It is a type-dependent parameter. | |
| WindTurbineType4bIEC [1] | [WindTurbineType4bIEC](#CIM17v40-WindTurbineType4bIEC) | Wind turbine type 4B model with which this wind control P type 4B model is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindContPitchAngleIEC}
### WindContPitchAngleIEC

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindContPitchAngleIEC {

+ dthetamax : Float [0..1]
+ dthetamin : Float [0..1]
+ kic : PU [0..1]
+ kiomega : PU [0..1]
+ kpc : PU [0..1]
+ kpomega : PU [0..1]
+ kpx : PU [0..1]
+ thetamax : AngleDegrees [0..1]
+ thetamin : AngleDegrees [0..1]
+ ttheta : Seconds [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- WindContPitchAngleIEC : inherits from
class WindTurbineType3IEC {

}

WindContPitchAngleIEC --> "1" WindTurbineType3IEC : WindTurbineType3IEC
```

Pitch angle control model.

Reference: IEC 61400-27-1:2015, 5.6.5.2.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dthetamax [0..1] | [Float](#CIM17v40-Float) | Maximum pitch positive ramp rate (<i>dtheta</i><i><sub>max</sub></i>) (&gt; WindContPitchAngleIEC.dthetamin). It is a type-dependent parameter. Unit = degrees / s. | |
| dthetamin [0..1] | [Float](#CIM17v40-Float) | Maximum pitch negative ramp rate (<i>dtheta</i><i><sub>min</sub></i><i>)</i> (&lt; WindContPitchAngleIEC.dthetamax). It is a type-dependent parameter. Unit = degrees / s. | |
| kic [0..1] | [PU](#CIM17v40-PU) | Power PI controller integration gain (<i>K</i><i><sub>Ic</sub></i>). It is a type-dependent parameter. | |
| kiomega [0..1] | [PU](#CIM17v40-PU) | Speed PI controller integration gain (<i>K</i><i><sub>Iomega</sub></i>). It is a type-dependent parameter. | |
| kpc [0..1] | [PU](#CIM17v40-PU) | Power PI controller proportional gain (<i>K</i><i><sub>Pc</sub></i>). It is a type-dependent parameter. | |
| kpomega [0..1] | [PU](#CIM17v40-PU) | Speed PI controller proportional gain (<i>K</i><i><sub>Pomega</sub></i>). It is a type-dependent parameter. | |
| kpx [0..1] | [PU](#CIM17v40-PU) | Pitch cross coupling gain (<i>K</i><i><sub>PX</sub></i>). It is a type-dependent parameter. | |
| thetamax [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Maximum pitch angle (<i>theta</i><i><sub>max</sub></i>) (&gt; WindContPitchAngleIEC.thetamin). It is a type-dependent parameter. | |
| thetamin [0..1] | [AngleDegrees](#CIM17v40-AngleDegrees) | Minimum pitch angle (<i>theta</i><i><sub>min</sub></i>) (&lt; WindContPitchAngleIEC.thetamax). It is a type-dependent parameter. | |
| ttheta [0..1] | [Seconds](#CIM17v40-Seconds) | Pitch time constant (<i>ttheta</i>) (&gt;= 0). It is a type-dependent parameter. | |
| WindTurbineType3IEC [1] | [WindTurbineType3IEC](#CIM17v40-WindTurbineType3IEC) | Wind turbine type 3 model with which this pitch control model is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindContQIEC}
### WindContQIEC

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindContQIEC {

+ iqh1 : PU [0..1]
+ iqmax : PU [0..1]
+ iqmin : PU [0..1]
+ iqpost : PU [0..1]
+ kiq : PU [0..1]
+ kiu : PU [0..1]
+ kpq : PU [0..1]
+ kpu : PU [0..1]
+ kqv : PU [0..1]
+ rdroop : PU [0..1]
+ tpfiltq : Seconds [0..1]
+ tpost : Seconds [0..1]
+ tqord : Seconds [0..1]
+ tufiltq : Seconds [0..1]
+ udb1 : PU [0..1]
+ udb2 : PU [0..1]
+ umax : PU [0..1]
+ umin : PU [0..1]
+ uqdip : PU [0..1]
+ uref0 : PU [0..1]
+ windQcontrolModesType : enum:WindQcontrolModeKind [0..1]
+ windUVRTQcontrolModesType : enum:WindUVRTQcontrolModeKind [0..1]
+ xdroop : PU [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- WindContQIEC : inherits from
class WindTurbineType3or4IEC {

}

WindContQIEC --> "1" WindTurbineType3or4IEC : WindTurbineType3or4IEC
```

Q control model.

Reference: IEC 61400-27-1:2015, 5.6.5.7.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| iqh1 [0..1] | [PU](#CIM17v40-PU) | Maximum reactive current injection during dip (<i>i</i><i><sub>qh1</sub></i>). It is a type-dependent parameter. | |
| iqmax [0..1] | [PU](#CIM17v40-PU) | Maximum reactive current injection (<i>i</i><i><sub>qmax</sub></i>) (&gt; WindContQIEC.iqmin). It is a type-dependent parameter. | |
| iqmin [0..1] | [PU](#CIM17v40-PU) | Minimum reactive current injection (<i>i</i><i><sub>qmin</sub></i>) (&lt; WindContQIEC.iqmax). It is a type-dependent parameter. | |
| iqpost [0..1] | [PU](#CIM17v40-PU) | Post fault reactive current injection (<i>i</i><i><sub>qpost</sub></i>). It is a project-dependent parameter. | |
| kiq [0..1] | [PU](#CIM17v40-PU) | Reactive power PI controller integration gain (<i>K</i><i><sub>I,q</sub></i>). It is a type-dependent parameter. | |
| kiu [0..1] | [PU](#CIM17v40-PU) | Voltage PI controller integration gain (<i>K</i><i><sub>I,u</sub></i>). It is a type-dependent parameter. | |
| kpq [0..1] | [PU](#CIM17v40-PU) | Reactive power PI controller proportional gain (<i>K</i><i><sub>P,q</sub></i>). It is a type-dependent parameter. | |
| kpu [0..1] | [PU](#CIM17v40-PU) | Voltage PI controller proportional gain (<i>K</i><i><sub>P,u</sub></i>). It is a type-dependent parameter. | |
| kqv [0..1] | [PU](#CIM17v40-PU) | Voltage scaling factor for UVRT current (<i>K</i><i><sub>qv</sub></i>). It is a project-dependent parameter. | |
| rdroop [0..1] | [PU](#CIM17v40-PU) | Resistive component of voltage drop impedance (<i>r</i><i><sub>droop</sub></i>) (&gt;= 0). It is a project-dependent parameter. | |
| tpfiltq [0..1] | [Seconds](#CIM17v40-Seconds) | Power measurement filter time constant (<i>T</i><i><sub>pfiltq</sub></i>) (&gt;= 0). It is a type-dependent parameter. | |
| tpost [0..1] | [Seconds](#CIM17v40-Seconds) | Length of time period where post fault reactive power is injected (<i>T</i><i><sub>post</sub></i>) (&gt;= 0). It is a project-dependent parameter. | |
| tqord [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant in reactive power order lag (<i>T</i><i><sub>qord</sub></i>) (&gt;= 0). It is a type-dependent parameter. | |
| tufiltq [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage measurement filter time constant (<i>T</i><i><sub>ufiltq</sub></i>) (&gt;= 0). It is a type-dependent parameter. | |
| udb1 [0..1] | [PU](#CIM17v40-PU) | Voltage deadband lower limit (<i>u</i><i><sub>db1</sub></i>). It is a type-dependent parameter. | |
| udb2 [0..1] | [PU](#CIM17v40-PU) | Voltage deadband upper limit (<i>u</i><i><sub>db2</sub></i>). It is a type-dependent parameter. | |
| umax [0..1] | [PU](#CIM17v40-PU) | Maximum voltage in voltage PI controller integral term (<i>u</i><i><sub>max</sub></i>) (&gt; WindContQIEC.umin). It is a type-dependent parameter. | |
| umin [0..1] | [PU](#CIM17v40-PU) | Minimum voltage in voltage PI controller integral term (<i>u</i><i><sub>min</sub></i>) (&lt; WindContQIEC.umax). It is a type-dependent parameter. | |
| uqdip [0..1] | [PU](#CIM17v40-PU) | Voltage threshold for UVRT detection in Q control (<i>u</i><i><sub>qdip</sub></i>). It is a type-dependent parameter. | |
| uref0 [0..1] | [PU](#CIM17v40-PU) | User-defined bias in voltage reference (<i>u</i><i><sub>ref0</sub></i>). It is a case-dependent parameter. | |
| windQcontrolModesType [0..1] | [WindQcontrolModeKind](#CIM17v40-WindQcontrolModeKind) | Types of general wind turbine Q control modes (<i>M</i><i><sub>qG</sub></i>). It is a project-dependent parameter. | |
| windUVRTQcontrolModesType [0..1] | [WindUVRTQcontrolModeKind](#CIM17v40-WindUVRTQcontrolModeKind) | Types of UVRT Q control modes (<i>M</i><i><sub>qUVRT</sub></i>). It is a project-dependent parameter. | |
| xdroop [0..1] | [PU](#CIM17v40-PU) | Inductive component of voltage drop impedance (<i>x</i><i><sub>droop</sub></i>) (&gt;= 0). It is a project-dependent parameter. | |
| WindTurbineType3or4IEC [1] | [WindTurbineType3or4IEC](#CIM17v40-WindTurbineType3or4IEC) | Wind turbine type 3 or type 4 model with which this reactive control model is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindContQLimIEC}
### WindContQLimIEC

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindContQLimIEC {

+ qmax : PU [0..1]
+ qmin : PU [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- WindContQLimIEC : inherits from
class WindTurbineType3or4IEC {

}

WindContQLimIEC --> "0..1" WindTurbineType3or4IEC : WindTurbineType3or4IEC
```

Constant Q limitation model.

Reference: IEC 61400-27-1:2015, 5.6.5.9.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| qmax [0..1] | [PU](#CIM17v40-PU) | Maximum reactive power (<i>q</i><i><sub>max</sub></i>) (&gt; WindContQLimIEC.qmin). It is a type-dependent parameter. | |
| qmin [0..1] | [PU](#CIM17v40-PU) | Minimum reactive power (<i>q</i><i><sub>min</sub></i>) (&lt; WindContQLimIEC.qmax). It is a type-dependent parameter. | |
| WindTurbineType3or4IEC [0..1] | [WindTurbineType3or4IEC](#CIM17v40-WindTurbineType3or4IEC) | Wind generator type 3 or type 4 model with which this constant Q limitation model is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindContQPQULimIEC}
### WindContQPQULimIEC

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindContQPQULimIEC {

+ tpfiltql : Seconds [0..1]
+ tufiltql : Seconds [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- WindContQPQULimIEC : inherits from
class WindTurbineType3or4IEC {

}

WindContQPQULimIEC --> "0..1" WindTurbineType3or4IEC : WindTurbineType3or4IEC
```

QP and QU limitation model.

Reference: IEC 61400-27-1:2015, 5.6.5.10.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| tpfiltql [0..1] | [Seconds](#CIM17v40-Seconds) | Power measurement filter time constant for Q capacity (<i>T</i><i><sub>pfiltql</sub></i>) (&gt;= 0). It is a type-dependent parameter. | |
| tufiltql [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage measurement filter time constant for Q capacity (<i>T</i><i><sub>ufiltql</sub></i>) (&gt;= 0). It is a type-dependent parameter. | |
| WindTurbineType3or4IEC [0..1] | [WindTurbineType3or4IEC](#CIM17v40-WindTurbineType3or4IEC) | Wind generator type 3 or type 4 model with which this QP and QU limitation model is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindContRotorRIEC}
### WindContRotorRIEC

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindContRotorRIEC {

+ kirr : PU [0..1]
+ komegafilt : Float [0..1]
+ kpfilt : Float [0..1]
+ kprr : PU [0..1]
+ rmax : PU [0..1]
+ rmin : PU [0..1]
+ tomegafiltrr : Seconds [0..1]
+ tpfiltrr : Seconds [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- WindContRotorRIEC : inherits from
class WindGenTurbineType2IEC {

}

WindContRotorRIEC --> "1" WindGenTurbineType2IEC : WindGenTurbineType2IEC
```

Rotor resistance control model.

Reference: IEC 61400-27-1:2015, 5.6.5.3.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kirr [0..1] | [PU](#CIM17v40-PU) | Integral gain in rotor resistance PI controller (<i>K</i><i><sub>Irr</sub></i>). It is a type-dependent parameter. | |
| komegafilt [0..1] | [Float](#CIM17v40-Float) | Filter gain for generator speed measurement (<i>K</i><i><sub>omegafilt</sub></i>). It is a type-dependent parameter. | |
| kpfilt [0..1] | [Float](#CIM17v40-Float) | Filter gain for power measurement (<i>K</i><i><sub>pfilt</sub></i>). It is a type-dependent parameter. | |
| kprr [0..1] | [PU](#CIM17v40-PU) | Proportional gain in rotor resistance PI controller (<i>K</i><i><sub>Prr</sub></i>). It is a type-dependent parameter. | |
| rmax [0..1] | [PU](#CIM17v40-PU) | Maximum rotor resistance (<i>r</i><i><sub>max</sub></i>) (&gt; WindContRotorRIEC.rmin). It is a type-dependent parameter. | |
| rmin [0..1] | [PU](#CIM17v40-PU) | Minimum rotor resistance (<i>r</i><i><sub>min</sub></i>) (&lt; WindContRotorRIEC.rmax). It is a type-dependent parameter. | |
| tomegafiltrr [0..1] | [Seconds](#CIM17v40-Seconds) | Filter time constant for generator speed measurement (<i>T</i><i><sub>omegafiltrr</sub></i>) (&gt;= 0). It is a type-dependent parameter. | |
| tpfiltrr [0..1] | [Seconds](#CIM17v40-Seconds) | Filter time constant for power measurement (<i>T</i><i><sub>pfiltrr</sub></i>) (&gt;= 0). It is a type-dependent parameter. | |
| WindGenTurbineType2IEC [1] | [WindGenTurbineType2IEC](#CIM17v40-WindGenTurbineType2IEC) | Wind turbine type 2 model with whitch this wind control rotor resistance model is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindDynamicsLookupTable}
### WindDynamicsLookupTable

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindDynamicsLookupTable {

+ input : Float [0..1]
+ lookupTableFunctionType : enum:WindLookupTableFunctionKind [0..1]
+ output : Float [0..1]
+ sequence : Integer [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- WindDynamicsLookupTable : inherits from
class WindContCurrLimIEC {

}

WindDynamicsLookupTable --> "0..1" WindContCurrLimIEC : WindContCurrLimIEC
class WindContPType3IEC {

}

WindDynamicsLookupTable --> "0..1" WindContPType3IEC : WindContPType3IEC
class WindContQPQULimIEC {

}

WindDynamicsLookupTable --> "0..1" WindContQPQULimIEC : WindContQPQULimIEC
class WindContRotorRIEC {

}

WindDynamicsLookupTable --> "0..1" WindContRotorRIEC : WindContRotorRIEC
class WindGenType3bIEC {

}

WindDynamicsLookupTable --> "0..1" WindGenType3bIEC : WindGenType3bIEC
class WindPitchContPowerIEC {

}

WindDynamicsLookupTable --> "0..1" WindPitchContPowerIEC : WindPitchContPowerIEC
class WindPlantFreqPcontrolIEC {

}

WindDynamicsLookupTable --> "0..1" WindPlantFreqPcontrolIEC : WindPlantFreqPcontrolIEC
class WindPlantReactiveControlIEC {

}

WindDynamicsLookupTable --> "0..1" WindPlantReactiveControlIEC : WindPlantReactiveControlIEC
class WindProtectionIEC {

}

WindDynamicsLookupTable --> "0..1" WindProtectionIEC : WindProtectionIEC
```

Look up table for the purpose of wind standard models.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| input [0..1] | [Float](#CIM17v40-Float) | Input value (<i>x</i>) for the lookup table function. | |
| lookupTableFunctionType [0..1] | [WindLookupTableFunctionKind](#CIM17v40-WindLookupTableFunctionKind) | Type of the lookup table function. | |
| output [0..1] | [Float](#CIM17v40-Float) | Output value (<i>y</i>) for the lookup table function. | |
| sequence [0..1] | [Integer](#CIM17v40-Integer) | Sequence numbers of the pairs of the input (<i>x</i>) and the output (<i>y</i>) of the lookup table function. | |
| WindContCurrLimIEC [0..1] | [WindContCurrLimIEC](#CIM17v40-WindContCurrLimIEC) | The current control limitation model with which this wind dynamics lookup table is associated. | |
| WindContPType3IEC [0..1] | [WindContPType3IEC](#CIM17v40-WindContPType3IEC) | The P control type 3 model with which this wind dynamics lookup table is associated. | |
| WindContQPQULimIEC [0..1] | [WindContQPQULimIEC](#CIM17v40-WindContQPQULimIEC) | The QP and QU limitation model with which this wind dynamics lookup table is associated. | |
| WindContRotorRIEC [0..1] | [WindContRotorRIEC](#CIM17v40-WindContRotorRIEC) | The rotor resistance control model with which this wind dynamics lookup table is associated. | |
| WindGenType3bIEC [0..1] | [WindGenType3bIEC](#CIM17v40-WindGenType3bIEC) | The generator type 3B model with which this wind dynamics lookup table is associated. | |
| WindPitchContPowerIEC [0..1] | [WindPitchContPowerIEC](#CIM17v40-WindPitchContPowerIEC) | The pitch control power model with which this wind dynamics lookup table is associated. | |
| WindPlantFreqPcontrolIEC [0..1] | [WindPlantFreqPcontrolIEC](#CIM17v40-WindPlantFreqPcontrolIEC) | The frequency and active power wind plant control model with which this wind dynamics lookup table is associated. | |
| WindPlantReactiveControlIEC [0..1] | [WindPlantReactiveControlIEC](#CIM17v40-WindPlantReactiveControlIEC) | The voltage and reactive power wind plant control model with which this wind dynamics lookup table is associated. | |
| WindProtectionIEC [0..1] | [WindProtectionIEC](#CIM17v40-WindProtectionIEC) | The grid protection model with which this wind dynamics lookup table is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindGenTurbineType1aIEC}
### WindGenTurbineType1aIEC

Inheritance path = [WindTurbineType1or2IEC](#CIM17v40-WindTurbineType1or2IEC) => [WindTurbineType1or2Dynamics](#CIM17v40-WindTurbineType1or2Dynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindGenTurbineType1aIEC {

}

class WindTurbineType1or2IEC {

}

WindTurbineType1or2IEC <|-- WindGenTurbineType1aIEC : inherits from
class WindAeroConstIEC {

}

WindGenTurbineType1aIEC --> "1" WindAeroConstIEC : WindAeroConstIEC
```

Wind turbine IEC type 1A.

Reference: IEC 61400-27-1:2015, 5.5.2.2.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WindAeroConstIEC [1] | [WindAeroConstIEC](#CIM17v40-WindAeroConstIEC) | Wind aerodynamic model associated with this wind turbine type 1A model. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WindMechIEC [1] | [WindMechIEC](#CIM17v40-WindMechIEC) | see [WindTurbineType1or2IEC](CIM17v40-WindTurbineType1or2IEC) | |
| WindProtectionIEC [1] | [WindProtectionIEC](#CIM17v40-WindProtectionIEC) | see [WindTurbineType1or2IEC](CIM17v40-WindTurbineType1or2IEC) | |
| AsynchronousMachineDynamics [1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [WindTurbineType1or2Dynamics](CIM17v40-WindTurbineType1or2Dynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [WindTurbineType1or2Dynamics](CIM17v40-WindTurbineType1or2Dynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindGenTurbineType1bIEC}
### WindGenTurbineType1bIEC

Inheritance path = [WindTurbineType1or2IEC](#CIM17v40-WindTurbineType1or2IEC) => [WindTurbineType1or2Dynamics](#CIM17v40-WindTurbineType1or2Dynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindGenTurbineType1bIEC {

}

class WindTurbineType1or2IEC {

}

WindTurbineType1or2IEC <|-- WindGenTurbineType1bIEC : inherits from
class WindPitchContPowerIEC {

}

WindGenTurbineType1bIEC --> "1" WindPitchContPowerIEC : WindPitchContPowerIEC
```

Wind turbine IEC type 1B.

Reference: IEC 61400-27-1:2015, 5.5.2.3.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WindPitchContPowerIEC [1] | [WindPitchContPowerIEC](#CIM17v40-WindPitchContPowerIEC) | Pitch control power model associated with this wind turbine type 1B model. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WindMechIEC [1] | [WindMechIEC](#CIM17v40-WindMechIEC) | see [WindTurbineType1or2IEC](CIM17v40-WindTurbineType1or2IEC) | |
| WindProtectionIEC [1] | [WindProtectionIEC](#CIM17v40-WindProtectionIEC) | see [WindTurbineType1or2IEC](CIM17v40-WindTurbineType1or2IEC) | |
| AsynchronousMachineDynamics [1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [WindTurbineType1or2Dynamics](CIM17v40-WindTurbineType1or2Dynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [WindTurbineType1or2Dynamics](CIM17v40-WindTurbineType1or2Dynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindGenTurbineType2IEC}
### WindGenTurbineType2IEC

Inheritance path = [WindTurbineType1or2IEC](#CIM17v40-WindTurbineType1or2IEC) => [WindTurbineType1or2Dynamics](#CIM17v40-WindTurbineType1or2Dynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindGenTurbineType2IEC {

}

class WindTurbineType1or2IEC {

}

WindTurbineType1or2IEC <|-- WindGenTurbineType2IEC : inherits from
class WindContRotorRIEC {

}

WindGenTurbineType2IEC --> "1" WindContRotorRIEC : WindContRotorRIEC
class WindPitchContPowerIEC {

}

WindGenTurbineType2IEC --> "1" WindPitchContPowerIEC : WindPitchContPowerIEC
```

Wind turbine IEC type 2.

Reference: IEC 61400-27-1:2015, 5.5.3.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WindContRotorRIEC [1] | [WindContRotorRIEC](#CIM17v40-WindContRotorRIEC) | Wind control rotor resistance model associated with wind turbine type 2 model. | |
| WindPitchContPowerIEC [1] | [WindPitchContPowerIEC](#CIM17v40-WindPitchContPowerIEC) | Pitch control power model associated with this wind turbine type 2 model. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WindMechIEC [1] | [WindMechIEC](#CIM17v40-WindMechIEC) | see [WindTurbineType1or2IEC](CIM17v40-WindTurbineType1or2IEC) | |
| WindProtectionIEC [1] | [WindProtectionIEC](#CIM17v40-WindProtectionIEC) | see [WindTurbineType1or2IEC](CIM17v40-WindTurbineType1or2IEC) | |
| AsynchronousMachineDynamics [1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [WindTurbineType1or2Dynamics](CIM17v40-WindTurbineType1or2Dynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [WindTurbineType1or2Dynamics](CIM17v40-WindTurbineType1or2Dynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindGenType3IEC}
### WindGenType3IEC

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindGenType3IEC {

+ dipmax : PU [0..1]
+ diqmax : PU [0..1]
+ xs : PU [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- WindGenType3IEC : inherits from
class WindTurbineType3IEC {

}

WindGenType3IEC --> "0..1" WindTurbineType3IEC : WindTurbineType3IEC
```

Parent class supporting relationships to IEC wind turbines type 3 generator models of IEC type 3A and 3B.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dipmax [0..1] | [PU](#CIM17v40-PU) | Maximum active current ramp rate (<i>di</i><i><sub>pmax</sub></i>). It is a project-dependent parameter. | |
| diqmax [0..1] | [PU](#CIM17v40-PU) | Maximum reactive current ramp rate (<i>di</i><i><sub>qmax</sub></i>). It is a project-dependent parameter. | |
| xs [0..1] | [PU](#CIM17v40-PU) | Electromagnetic transient reactance (<i>x</i><i><sub>S</sub></i>). It is a type-dependent parameter. | |
| WindTurbineType3IEC [0..1] | [WindTurbineType3IEC](#CIM17v40-WindTurbineType3IEC) | Wind turbine type 3 model with which this wind generator type 3 is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindGenType3aIEC}
### WindGenType3aIEC

Inheritance path = [WindGenType3IEC](#CIM17v40-WindGenType3IEC) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindGenType3aIEC {

+ kpc : Float [0..1]
+ tic : Seconds [0..1]
}

class WindGenType3IEC {

}

WindGenType3IEC <|-- WindGenType3aIEC : inherits from
class WindTurbineType4IEC {

}

WindGenType3aIEC --> "0..1" WindTurbineType4IEC : WindTurbineType4IEC
```

IEC type 3A generator set model.

Reference: IEC 61400-27-1:2015, 5.6.3.2.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kpc [0..1] | [Float](#CIM17v40-Float) | Current PI controller proportional gain (<i>K</i><i><sub>Pc</sub></i>). It is a type-dependent parameter. | |
| tic [0..1] | [Seconds](#CIM17v40-Seconds) | Current PI controller integration time constant (<i>T</i><i><sub>Ic</sub></i>) (&gt;= 0). It is a type-dependent parameter. | |
| WindTurbineType4IEC [0..1] | [WindTurbineType4IEC](#CIM17v40-WindTurbineType4IEC) | Wind turbine type 4 model with which this wind generator type 3A model is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dipmax [0..1] | [PU](#CIM17v40-PU) | see [WindGenType3IEC](CIM17v40-WindGenType3IEC) | |
| diqmax [0..1] | [PU](#CIM17v40-PU) | see [WindGenType3IEC](CIM17v40-WindGenType3IEC) | |
| xs [0..1] | [PU](#CIM17v40-PU) | see [WindGenType3IEC](CIM17v40-WindGenType3IEC) | |
| WindTurbineType3IEC [0..1] | [WindTurbineType3IEC](#CIM17v40-WindTurbineType3IEC) | see [WindGenType3IEC](CIM17v40-WindGenType3IEC) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindGenType3bIEC}
### WindGenType3bIEC

Inheritance path = [WindGenType3IEC](#CIM17v40-WindGenType3IEC) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindGenType3bIEC {

+ mwtcwp : Boolean [0..1]
+ tg : Seconds [0..1]
+ two : Seconds [0..1]
}

class WindGenType3IEC {

}

WindGenType3IEC <|-- WindGenType3bIEC : inherits from
```

IEC type 3B generator set model.

Reference: IEC 61400-27-1:2015, 5.6.3.3.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mwtcwp [0..1] | [Boolean](#CIM17v40-Boolean) | Crowbar control mode (<i>M</i><i><sub>WTcwp</sub></i>). It is a case-dependent parameter.true = 1 in the IEC modelfalse = 0 in the IEC model. | |
| tg [0..1] | [Seconds](#CIM17v40-Seconds) | Current generation time constant (<i>T</i><i><sub>g</sub></i>) (&gt;= 0). It is a type-dependent parameter. | |
| two [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant for crowbar washout filter (<i>T</i><i><sub>wo</sub></i>) (&gt;= 0). It is a case-dependent parameter. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dipmax [0..1] | [PU](#CIM17v40-PU) | see [WindGenType3IEC](CIM17v40-WindGenType3IEC) | |
| diqmax [0..1] | [PU](#CIM17v40-PU) | see [WindGenType3IEC](CIM17v40-WindGenType3IEC) | |
| xs [0..1] | [PU](#CIM17v40-PU) | see [WindGenType3IEC](CIM17v40-WindGenType3IEC) | |
| WindTurbineType3IEC [0..1] | [WindTurbineType3IEC](#CIM17v40-WindTurbineType3IEC) | see [WindGenType3IEC](CIM17v40-WindGenType3IEC) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindGenType4IEC}
### WindGenType4IEC

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindGenType4IEC {

+ dipmax : PU [0..1]
+ diqmax : PU [0..1]
+ diqmin : PU [0..1]
+ tg : Seconds [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- WindGenType4IEC : inherits from
class WindTurbineType4aIEC {

}

WindGenType4IEC --> "0..1" WindTurbineType4aIEC : WindTurbineType4aIEC
class WindTurbineType4bIEC {

}

WindGenType4IEC --> "0..1" WindTurbineType4bIEC : WindTurbineType4bIEC
```

IEC type 4 generator set model.

Reference: IEC 61400-27-1:2015, 5.6.3.4.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dipmax [0..1] | [PU](#CIM17v40-PU) | Maximum active current ramp rate (<i>di</i><i><sub>pmax</sub></i>). It is a project-dependent parameter. | |
| diqmax [0..1] | [PU](#CIM17v40-PU) | Maximum reactive current ramp rate (<i>di</i><i><sub>qmax</sub></i>). It is a project-dependent parameter. | |
| diqmin [0..1] | [PU](#CIM17v40-PU) | Minimum reactive current ramp rate (<i>di</i><i><sub>qmin</sub></i>). It is a project-dependent parameter. | |
| tg [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant (<i>T</i><i><sub>g</sub></i>) (&gt;= 0). It is a type-dependent parameter. | |
| WindTurbineType4aIEC [0..1] | [WindTurbineType4aIEC](#CIM17v40-WindTurbineType4aIEC) | Wind turbine type 4A model with which this wind generator type 4 model is associated. | |
| WindTurbineType4bIEC [0..1] | [WindTurbineType4bIEC](#CIM17v40-WindTurbineType4bIEC) | Wind turbine type 4B model with which this wind generator type 4 model is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindGeneratingUnit}
### WindGeneratingUnit

Inheritance path = [GeneratingUnit](#CIM17v40-GeneratingUnit) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindGeneratingUnit {

+ windGenUnitType : enum:WindGenUnitKind [0..1]
}

class GeneratingUnit {

}

GeneratingUnit <|-- WindGeneratingUnit : inherits from
```

A wind driven generating unit, connected to the grid by means of a rotating machine. May be used to represent a single turbine or an aggregation.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| windGenUnitType [0..1] | [WindGenUnitKind](#CIM17v40-WindGenUnitKind) | The kind of wind generating unit. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| allocSpinResP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| autoCntrlMarginP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| baseP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlDeadband [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlPulseHigh [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlPulseLow [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| controlResponseRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| efficiency [0..1] | [PerCent](#CIM17v40-PerCent) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| genControlMode [0..1] | [GeneratorControlMode](#CIM17v40-GeneratorControlMode) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| genControlSource [0..1] | [GeneratorControlSource](#CIM17v40-GeneratorControlSource) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| governorMPL [0..1] | [PU](#CIM17v40-PU) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| governorSCD [0..1] | [PerCent](#CIM17v40-PerCent) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| highControlLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| initialP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| longPF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| lowControlLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| lowerRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| maxEconomicP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| maximumAllowableSpinningReserve [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| maxOperatingP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| minEconomicP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| minimumOffTime [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| minOperatingP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| modelDetail [0..1] | [Classification](#CIM17v40-Classification) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| nominalP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| normalPF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| penaltyFactor [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| raiseRampRate [0..1] | [ActivePowerChangeRate](#CIM17v40-ActivePowerChangeRate) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| ratedGrossMaxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| ratedGrossMinP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| ratedNetMaxP [0..1] | [ActivePower](#CIM17v40-ActivePower) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| shortPF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| startupCost [0..1] | [Money](#CIM17v40-Money) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| startupTime [0..1] | [Seconds](#CIM17v40-Seconds) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| tieLinePF [0..1] | [Float](#CIM17v40-Float) | see [GeneratingUnit](#CIM17v40-GeneratingUnit) | |
| totalEfficiency [0..1] | [PerCent](#CIM17v40-PerCent) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| variableCost [0..1] | [Money](#CIM17v40-Money) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| `GenUnitOpSchedule [0..1]` (AggregateOf) | [GenUnitOpSchedule](#CIM17v40-GenUnitOpSchedule) | see [GeneratingUnit](CIM17v40-GeneratingUnit) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindMechIEC}
### WindMechIEC

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindMechIEC {

+ cdrt : PU [0..1]
+ hgen : Seconds [0..1]
+ hwtr : Seconds [0..1]
+ kdrt : PU [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- WindMechIEC : inherits from
class WindTurbineType1or2IEC {

}

WindMechIEC --> "0..1" WindTurbineType1or2IEC : WindTurbineType1or2IEC
class WindTurbineType3IEC {

}

WindMechIEC --> "0..1" WindTurbineType3IEC : WindTurbineType3IEC
class WindTurbineType4bIEC {

}

WindMechIEC --> "0..1" WindTurbineType4bIEC : WindTurbineType4bIEC
```

Two mass model.

Reference: IEC 61400-27-1:2015, 5.6.2.1.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| cdrt [0..1] | [PU](#CIM17v40-PU) | Drive train damping (<i>c</i><i><sub>drt</sub></i><i>)</i>. It is a type-dependent parameter. | |
| hgen [0..1] | [Seconds](#CIM17v40-Seconds) | Inertia constant of generator (<i>H</i><i><sub>gen</sub></i>) (&gt;= 0). It is a type-dependent parameter. | |
| hwtr [0..1] | [Seconds](#CIM17v40-Seconds) | Inertia constant of wind turbine rotor (<i>H</i><i><sub>WTR</sub></i>) (&gt;= 0). It is a type-dependent parameter. | |
| kdrt [0..1] | [PU](#CIM17v40-PU) | Drive train stiffness (<i>k</i><i><sub>drt</sub></i>). It is a type-dependent parameter. | |
| WindTurbineType1or2IEC [0..1] | [WindTurbineType1or2IEC](#CIM17v40-WindTurbineType1or2IEC) | Wind generator type 1 or type 2 model with which this wind mechanical model is associated. | |
| WindTurbineType3IEC [0..1] | [WindTurbineType3IEC](#CIM17v40-WindTurbineType3IEC) | Wind turbine type 3 model with which this wind mechanical model is associated. | |
| WindTurbineType4bIEC [0..1] | [WindTurbineType4bIEC](#CIM17v40-WindTurbineType4bIEC) | Wind turbine type 4B model with which this wind mechanical model is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindPitchContPowerIEC}
### WindPitchContPowerIEC

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindPitchContPowerIEC {

+ dpmax : PU [0..1]
+ dpmin : PU [0..1]
+ pmin : PU [0..1]
+ pset : PU [0..1]
+ t1 : Seconds [0..1]
+ tr : Seconds [0..1]
+ uuvrt : PU [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- WindPitchContPowerIEC : inherits from
class WindGenTurbineType1bIEC {

}

WindPitchContPowerIEC --> "0..1" WindGenTurbineType1bIEC : WindGenTurbineType1bIEC
class WindGenTurbineType2IEC {

}

WindPitchContPowerIEC --> "0..1" WindGenTurbineType2IEC : WindGenTurbineType2IEC
```

Pitch control power model.

Reference: IEC 61400-27-1:2015, 5.6.5.1.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dpmax [0..1] | [PU](#CIM17v40-PU) | Rate limit for increasing power (<i>dp</i><i><sub>max</sub></i>) (&gt; WindPitchContPowerIEC.dpmin). It is a type-dependent parameter. | |
| dpmin [0..1] | [PU](#CIM17v40-PU) | Rate limit for decreasing power (<i>dp</i><i><sub>min</sub></i>) (&lt; WindPitchContPowerIEC.dpmax). It is a type-dependent parameter. | |
| pmin [0..1] | [PU](#CIM17v40-PU) | Minimum power setting (<i>p</i><i><sub>min</sub></i>). It is a type-dependent parameter. | |
| pset [0..1] | [PU](#CIM17v40-PU) | If <i>p</i><i><sub>init</sub></i><sub> </sub>&lt; <i>p</i><i><sub>set</sub></i><sub> </sub>then power will be ramped down to <i>p</i><i><sub>min</sub></i>. It is (<i>p</i><i><sub>set</sub></i>) in the IEC 61400-27-1:2015. It is a type-dependent parameter. | |
| t1 [0..1] | [Seconds](#CIM17v40-Seconds) | Lag time constant (<i>T</i><i><sub>1</sub></i>) (&gt;= 0). It is a type-dependent parameter. | |
| tr [0..1] | [Seconds](#CIM17v40-Seconds) | Voltage measurement time constant (<i>T</i><i><sub>r</sub></i>) (&gt;= 0). It is a type-dependent parameter. | |
| uuvrt [0..1] | [PU](#CIM17v40-PU) | Dip detection threshold (<i>u</i><i><sub>UVRT</sub></i>). It is a type-dependent parameter. | |
| WindGenTurbineType1bIEC [0..1] | [WindGenTurbineType1bIEC](#CIM17v40-WindGenTurbineType1bIEC) | Wind turbine type 1B model with which this pitch control power model is associated. | |
| WindGenTurbineType2IEC [0..1] | [WindGenTurbineType2IEC](#CIM17v40-WindGenTurbineType2IEC) | Wind turbine type 2 model with which this pitch control power model is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindPlantDynamics}
### WindPlantDynamics

Inheritance path = [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindPlantDynamics {

}

class DynamicsFunctionBlock {

}

DynamicsFunctionBlock <|-- WindPlantDynamics : inherits from
class RemoteInputSignal {

}

WindPlantDynamics --> "0..1" RemoteInputSignal : RemoteInputSignal
```

Parent class supporting relationships to wind turbines type 3 and type 4 and wind plant IEC and user-defined wind plants including their control models.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | The remote signal with which this power plant is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindPlantFreqPcontrolIEC}
### WindPlantFreqPcontrolIEC

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindPlantFreqPcontrolIEC {

+ dprefmax : PU [0..1]
+ dprefmin : PU [0..1]
+ dpwprefmax : PU [0..1]
+ dpwprefmin : PU [0..1]
+ kiwpp : Float [0..1]
+ kiwppmax : PU [0..1]
+ kiwppmin : PU [0..1]
+ kpwpp : Float [0..1]
+ kwppref : PU [0..1]
+ prefmax : PU [0..1]
+ prefmin : PU [0..1]
+ tpft : Seconds [0..1]
+ tpfv : Seconds [0..1]
+ twpffiltp : Seconds [0..1]
+ twppfiltp : Seconds [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- WindPlantFreqPcontrolIEC : inherits from
class WindPlantIEC {

}

WindPlantFreqPcontrolIEC --> "1" WindPlantIEC : WindPlantIEC
```

Frequency and active power controller model.

Reference: IEC 61400-27-1:2015, Annex D.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dprefmax [0..1] | [PU](#CIM17v40-PU) | Maximum ramp rate of <i>p</i><i><sub>WTref</sub></i> request from the plant controller to the wind turbines (<i>dp</i><i><sub>refmax</sub></i>) (&gt; WindPlantFreqPcontrolIEC.dprefmin). It is a case-dependent parameter. | |
| dprefmin [0..1] | [PU](#CIM17v40-PU) | Minimum (negative) ramp rate of <i>p</i><i><sub>WTref</sub></i> request from the plant controller to the wind turbines (<i>dp</i><i><sub>refmin</sub></i>) (&lt; WindPlantFreqPcontrolIEC.dprefmax). It is a project-dependent parameter. | |
| dpwprefmax [0..1] | [PU](#CIM17v40-PU) | Maximum positive ramp rate for wind plant power reference (<i>dp</i><i><sub>WPrefmax</sub></i>) (&gt; WindPlantFreqPcontrolIEC.dpwprefmin). It is a project-dependent parameter. | |
| dpwprefmin [0..1] | [PU](#CIM17v40-PU) | Maximum negative ramp rate for wind plant power reference (<i>dp</i><i><sub>WPrefmin</sub></i>) (&lt; WindPlantFreqPcontrolIEC.dpwprefmax). It is a project-dependent parameter. | |
| kiwpp [0..1] | [Float](#CIM17v40-Float) | Plant P controller integral gain (<i>K</i><i><sub>IWPp</sub></i>). It is a project-dependent parameter. | |
| kiwppmax [0..1] | [PU](#CIM17v40-PU) | Maximum PI integrator term (<i>K</i><i><sub>IWPpmax</sub></i>) (&gt; WindPlantFreqPcontrolIEC.kiwppmin). It is a project-dependent parameter. | |
| kiwppmin [0..1] | [PU](#CIM17v40-PU) | Minimum PI integrator term (<i>K</i><i><sub>IWPpmin</sub></i>) (&lt; WindPlantFreqPcontrolIEC.kiwppmax). It is a project-dependent parameter. | |
| kpwpp [0..1] | [Float](#CIM17v40-Float) | Plant P controller proportional gain (<i>K</i><i><sub>PWPp</sub></i>). It is a project-dependent parameter. | |
| kwppref [0..1] | [PU](#CIM17v40-PU) | Power reference gain (<i>K</i><i><sub>WPpref</sub></i>). It is a project-dependent parameter. | |
| prefmax [0..1] | [PU](#CIM17v40-PU) | Maximum <i>p</i><i><sub>WTref</sub></i> request from the plant controller to the wind turbines (<i>p</i><i><sub>refmax</sub></i>) (&gt; WindPlantFreqPcontrolIEC.prefmin). It is a project-dependent parameter. | |
| prefmin [0..1] | [PU](#CIM17v40-PU) | Minimum <i>p</i><i><sub>WTref</sub></i> request from the plant controller to the wind turbines (<i>p</i><i><sub>refmin</sub></i>) (&lt; WindPlantFreqPcontrolIEC.prefmax). It is a project-dependent parameter. | |
| tpft [0..1] | [Seconds](#CIM17v40-Seconds) | Lead time constant in reference value transfer function (<i>T</i><i><sub>pft</sub></i>) (&gt;= 0). It is a project-dependent parameter. | |
| tpfv [0..1] | [Seconds](#CIM17v40-Seconds) | Lag time constant in reference value transfer function (<i>T</i><i><sub>pfv</sub></i>) (&gt;= 0). It is a project-dependent parameter. | |
| twpffiltp [0..1] | [Seconds](#CIM17v40-Seconds) | Filter time constant for frequency measurement (<i>T</i><i><sub>WPffiltp</sub></i>) (&gt;= 0). It is a project-dependent parameter. | |
| twppfiltp [0..1] | [Seconds](#CIM17v40-Seconds) | Filter time constant for active power measurement (<i>T</i><i><sub>WPpfiltp</sub></i>) (&gt;= 0). It is a project-dependent parameter. | |
| WindPlantIEC [1] | [WindPlantIEC](#CIM17v40-WindPlantIEC) | Wind plant model with which this wind plant frequency and active power control is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindPlantIEC}
### WindPlantIEC

Inheritance path = [WindPlantDynamics](#CIM17v40-WindPlantDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindPlantIEC {

}

class WindPlantDynamics {

}

WindPlantDynamics <|-- WindPlantIEC : inherits from
class WindPlantFreqPcontrolIEC {

}

WindPlantIEC --> "1" WindPlantFreqPcontrolIEC : WindPlantFreqPcontrolIEC
class WindPlantReactiveControlIEC {

}

WindPlantIEC --> "1" WindPlantReactiveControlIEC : WindPlantReactiveControlIEC
```

Simplified IEC type plant level model.

Reference: IEC 61400-27-1:2015, Annex D.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WindPlantFreqPcontrolIEC [1] | [WindPlantFreqPcontrolIEC](#CIM17v40-WindPlantFreqPcontrolIEC) | Wind plant frequency and active power control model associated with this wind plant. | |
| WindPlantReactiveControlIEC [1] | [WindPlantReactiveControlIEC](#CIM17v40-WindPlantReactiveControlIEC) | Wind plant model with which this wind reactive control is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [WindPlantDynamics](CIM17v40-WindPlantDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindPlantReactiveControlIEC}
### WindPlantReactiveControlIEC

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindPlantReactiveControlIEC {

+ dxrefmax : PU [0..1]
+ dxrefmin : PU [0..1]
+ kiwpx : Float [0..1]
+ kiwpxmax : PU [0..1]
+ kiwpxmin : PU [0..1]
+ kpwpx : Float [0..1]
+ kwpqref : PU [0..1]
+ kwpqu : PU [0..1]
+ tuqfilt : Seconds [0..1]
+ twppfiltq : Seconds [0..1]
+ twpqfiltq : Seconds [0..1]
+ twpufiltq : Seconds [0..1]
+ txft : Seconds [0..1]
+ txfv : Seconds [0..1]
+ uwpqdip : PU [0..1]
+ windPlantQcontrolModesType : enum:WindPlantQcontrolModeKind [0..1]
+ xrefmax : PU [0..1]
+ xrefmin : PU [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- WindPlantReactiveControlIEC : inherits from
class WindPlantIEC {

}

WindPlantReactiveControlIEC --> "1" WindPlantIEC : WindPlantIEC
```

Simplified plant voltage and reactive power control model for use with type 3 and type 4 wind turbine models.

Reference: IEC 61400-27-1:2015, Annex D.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dxrefmax [0..1] | [PU](#CIM17v40-PU) | Maximum positive ramp rate for wind turbine reactive power/voltage reference (<i>dx</i><i><sub>refmax</sub></i>) (&gt; WindPlantReactiveControlIEC.dxrefmin). It is a project-dependent parameter. | |
| dxrefmin [0..1] | [PU](#CIM17v40-PU) | Maximum negative ramp rate for wind turbine reactive power/voltage reference (<i>dx</i><i><sub>refmin</sub></i>) (&lt; WindPlantReactiveControlIEC.dxrefmax). It is a project-dependent parameter. | |
| kiwpx [0..1] | [Float](#CIM17v40-Float) | Plant Q controller integral gain (<i>K</i><i><sub>IWPx</sub></i>). It is a project-dependent parameter. | |
| kiwpxmax [0..1] | [PU](#CIM17v40-PU) | Maximum reactive power/voltage reference from integration (<i>K</i><i><sub>IWPxmax</sub></i>) (&gt; WindPlantReactiveControlIEC.kiwpxmin). It is a project-dependent parameter. | |
| kiwpxmin [0..1] | [PU](#CIM17v40-PU) | Minimum reactive power/voltage reference from integration (<i>K</i><i><sub>IWPxmin</sub></i>) (&lt; WindPlantReactiveControlIEC.kiwpxmax). It is a project-dependent parameter. | |
| kpwpx [0..1] | [Float](#CIM17v40-Float) | Plant Q controller proportional gain (<i>K</i><i><sub>PWPx</sub></i>). It is a project-dependent parameter. | |
| kwpqref [0..1] | [PU](#CIM17v40-PU) | Reactive power reference gain (<i>K</i><i><sub>WPqref</sub></i>). It is a project-dependent parameter. | |
| kwpqu [0..1] | [PU](#CIM17v40-PU) | Plant voltage control droop (<i>K</i><i><sub>WPqu</sub></i>). It is a project-dependent parameter. | |
| tuqfilt [0..1] | [Seconds](#CIM17v40-Seconds) | Filter time constant for voltage-dependent reactive power (<i>T</i><i><sub>uqfilt</sub></i>) (&gt;= 0). It is a project-dependent parameter. | |
| twppfiltq [0..1] | [Seconds](#CIM17v40-Seconds) | Filter time constant for active power measurement (<i>T</i><i><sub>WPpfiltq</sub></i>) (&gt;= 0). It is a project-dependent parameter. | |
| twpqfiltq [0..1] | [Seconds](#CIM17v40-Seconds) | Filter time constant for reactive power measurement (<i>T</i><i><sub>WPqfiltq</sub></i>) (&gt;= 0). It is a project-dependent parameter. | |
| twpufiltq [0..1] | [Seconds](#CIM17v40-Seconds) | Filter time constant for voltage measurement (<i>T</i><i><sub>WPufiltq</sub></i>) (&gt;= 0). It is a project-dependent parameter. | |
| txft [0..1] | [Seconds](#CIM17v40-Seconds) | Lead time constant in reference value transfer function (<i>T</i><i><sub>xft</sub></i>) (&gt;= 0). It is a project-dependent parameter. | |
| txfv [0..1] | [Seconds](#CIM17v40-Seconds) | Lag time constant in reference value transfer function (<i>T</i><i><sub>xfv</sub></i>) (&gt;= 0). It is a project-dependent parameter. | |
| uwpqdip [0..1] | [PU](#CIM17v40-PU) | Voltage threshold for UVRT detection in Q control (<i>u</i><i><sub>WPqdip</sub></i>). It is a project-dependent parameter. | |
| windPlantQcontrolModesType [0..1] | [WindPlantQcontrolModeKind](#CIM17v40-WindPlantQcontrolModeKind) | Reactive power/voltage controller mode (<i>M</i><i><sub>WPqmode</sub></i>). It is a case-dependent parameter. | |
| xrefmax [0..1] | [PU](#CIM17v40-PU) | Maximum <i>x</i><sub>WTref</sub> (<i>q</i><i><sub>WTref</sub></i> or delta<i> u</i><i><sub>WTref</sub></i>) request from the plant controller (<i>x</i><i><sub>refmax</sub></i>) (&gt; WindPlantReactiveControlIEC.xrefmin). It is a case-dependent parameter. | |
| xrefmin [0..1] | [PU](#CIM17v40-PU) | Minimum <i>x</i><i><sub>WTref</sub></i> (<i>q</i><i><sub>WTref</sub></i> or delta <i>u</i><i><sub>WTref</sub></i>) request from the plant controller (<i>x</i><i><sub>refmin</sub></i>) (&lt; WindPlantReactiveControlIEC.xrefmax). It is a project-dependent parameter. | |
| WindPlantIEC [1] | [WindPlantIEC](#CIM17v40-WindPlantIEC) | Wind plant reactive control model associated with this wind plant. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindPlantUserDefined}
### WindPlantUserDefined

Inheritance path = [WindPlantDynamics](#CIM17v40-WindPlantDynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindPlantUserDefined {

+ proprietary : Boolean [0..1]
}

class WindPlantDynamics {

}

WindPlantDynamics <|-- WindPlantUserDefined : inherits from
```

Wind plant function block whose dynamic behaviour is described by <font color="#0f0f0f">a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| proprietary [0..1] | [Boolean](#CIM17v40-Boolean) | Behaviour is based on a proprietary model as opposed to a detailed model.true = user-defined model is proprietary with behaviour mutually understood by sending and receiving applications and parameters passed as general attributesfalse = user-defined model is explicitly defined in terms of control blocks and their input and output signals. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [WindPlantDynamics](CIM17v40-WindPlantDynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindProtectionIEC}
### WindProtectionIEC

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindProtectionIEC {

+ dfimax : PU [0..1]
+ fover : PU [0..1]
+ funder : PU [0..1]
+ mzc : Boolean [0..1]
+ tfma : Seconds [0..1]
+ uover : PU [0..1]
+ uunder : PU [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- WindProtectionIEC : inherits from
class WindTurbineType1or2IEC {

}

WindProtectionIEC --> "0..1" WindTurbineType1or2IEC : WindTurbineType1or2IEC
class WindTurbineType3or4IEC {

}

WindProtectionIEC --> "0..1" WindTurbineType3or4IEC : WindTurbineType3or4IEC
```

The grid protection model includes protection against over- and under-voltage, and against over- and under-frequency.

Reference: IEC 61400-27-1:2015, 5.6.6.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dfimax [0..1] | [PU](#CIM17v40-PU) | Maximum rate of change of frequency (<i>dF</i><i><sub>max</sub></i>). It is a type-dependent parameter. | |
| fover [0..1] | [PU](#CIM17v40-PU) | Wind turbine over frequency protection activation threshold (<i>f</i><i><sub>over</sub></i>). It is a project-dependent parameter. | |
| funder [0..1] | [PU](#CIM17v40-PU) | Wind turbine under frequency protection activation threshold (<i>f</i><i><sub>under</sub></i>). It is a project-dependent parameter. | |
| mzc [0..1] | [Boolean](#CIM17v40-Boolean) | Zero crossing measurement mode (<i>Mzc</i>). It is a type-dependent parameter.true = WT protection system uses zero crossings to detect frequency (1 in the IEC model)false = WT protection system does not use zero crossings to detect frequency (0 in the IEC model). | |
| tfma [0..1] | [Seconds](#CIM17v40-Seconds) | Time interval of moving average window (<i>TfMA</i>) (&gt;= 0). It is a type-dependent parameter. | |
| uover [0..1] | [PU](#CIM17v40-PU) | Wind turbine over voltage protection activation threshold (<i>u</i><i><sub>over</sub></i>). It is a project-dependent parameter. | |
| uunder [0..1] | [PU](#CIM17v40-PU) | Wind turbine under voltage protection activation threshold (<i>u</i><i><sub>under</sub></i>). It is a project-dependent parameter. | |
| WindTurbineType1or2IEC [0..1] | [WindTurbineType1or2IEC](#CIM17v40-WindTurbineType1or2IEC) | Wind generator type 1 or type 2 model with which this wind turbine protection model is associated. | |
| WindTurbineType3or4IEC [0..1] | [WindTurbineType3or4IEC](#CIM17v40-WindTurbineType3or4IEC) | Wind generator type 3 or type 4 model with which this wind turbine protection model is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindRefFrameRotIEC}
### WindRefFrameRotIEC

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindRefFrameRotIEC {

+ tpll : Seconds [0..1]
+ upll1 : PU [0..1]
+ upll2 : PU [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- WindRefFrameRotIEC : inherits from
class WindTurbineType3or4IEC {

}

WindRefFrameRotIEC --> "1" WindTurbineType3or4IEC : WindTurbineType3or4IEC
```

Reference frame rotation model.

Reference: IEC 61400-27-1:2015, 5.6.3.5.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| tpll [0..1] | [Seconds](#CIM17v40-Seconds) | Time constant for PLL first order filter model (<i>T</i><i><sub>PLL</sub></i>) (&gt;= 0). It is a type-dependent parameter. | |
| upll1 [0..1] | [PU](#CIM17v40-PU) | Voltage below which the angle of the voltage is filtered and possibly also frozen (<i>u</i><i><sub>PLL1</sub></i>). It is a type-dependent parameter. | |
| upll2 [0..1] | [PU](#CIM17v40-PU) | Voltage (<i>u</i><i><sub>PLL2</sub></i>) below which the angle of the voltage is frozen if <i>u</i><i><sub>PLL2</sub></i><sub> </sub>is smaller or equal to <i>u</i><i><sub>PLL1</sub></i> . It is a type-dependent parameter. | |
| WindTurbineType3or4IEC [1] | [WindTurbineType3or4IEC](#CIM17v40-WindTurbineType3or4IEC) | Wind turbine type 3 or type 4 model with which this reference frame rotation model is associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindTurbineType1or2Dynamics}
### WindTurbineType1or2Dynamics

Inheritance path = [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindTurbineType1or2Dynamics {

}

class DynamicsFunctionBlock {

}

DynamicsFunctionBlock <|-- WindTurbineType1or2Dynamics : inherits from
class AsynchronousMachineDynamics {

}

WindTurbineType1or2Dynamics --> "1" AsynchronousMachineDynamics : AsynchronousMachineDynamics
class RemoteInputSignal {

}

WindTurbineType1or2Dynamics --> "0..1" RemoteInputSignal : RemoteInputSignal
```

Parent class supporting relationships to wind turbines type 1 and type 2 and their control models. Generator model for wind turbine of type 1 or type 2 is a standard asynchronous generator model.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | Asynchronous machine model with which this wind generator type 1 or type 2 model is associated. | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | Remote input signal used by this wind generator type 1 or type 2 model. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindTurbineType1or2IEC}
### WindTurbineType1or2IEC

Inheritance path = [WindTurbineType1or2Dynamics](#CIM17v40-WindTurbineType1or2Dynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindTurbineType1or2IEC {

}

class WindTurbineType1or2Dynamics {

}

WindTurbineType1or2Dynamics <|-- WindTurbineType1or2IEC : inherits from
class WindMechIEC {

}

WindTurbineType1or2IEC --> "1" WindMechIEC : WindMechIEC
class WindProtectionIEC {

}

WindTurbineType1or2IEC --> "1" WindProtectionIEC : WindProtectionIEC
```

Parent class supporting relationships to IEC wind turbines type 1 and type 2 including their control models.

Generator model for wind turbine of IEC type 1 or type 2 is a standard asynchronous generator model.

Reference: IEC 61400-27-1:2015, 5.5.2 and 5.5.3.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WindMechIEC [1] | [WindMechIEC](#CIM17v40-WindMechIEC) | Wind mechanical model associated with this wind generator type 1 or type 2 model. | |
| WindProtectionIEC [1] | [WindProtectionIEC](#CIM17v40-WindProtectionIEC) | Wind turbune protection model associated with this wind generator type 1 or type 2 model. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [WindTurbineType1or2Dynamics](CIM17v40-WindTurbineType1or2Dynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [WindTurbineType1or2Dynamics](CIM17v40-WindTurbineType1or2Dynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindTurbineType3IEC}
### WindTurbineType3IEC

Inheritance path = [WindTurbineType3or4IEC](#CIM17v40-WindTurbineType3or4IEC) => [WindTurbineType3or4Dynamics](#CIM17v40-WindTurbineType3or4Dynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindTurbineType3IEC {

}

class WindTurbineType3or4IEC {

}

WindTurbineType3or4IEC <|-- WindTurbineType3IEC : inherits from
class WindAeroOneDimIEC {

}

WindTurbineType3IEC --> "0..1" WindAeroOneDimIEC : WindAeroOneDimIEC
class WindAeroTwoDimIEC {

}

WindTurbineType3IEC --> "0..1" WindAeroTwoDimIEC : WindAeroTwoDimIEC
class WindContPitchAngleIEC {

}

WindTurbineType3IEC --> "1" WindContPitchAngleIEC : WindContPitchAngleIEC
class WindContPType3IEC {

}

WindTurbineType3IEC --> "1" WindContPType3IEC : WindContPType3IEC
class WindGenType3IEC {

}

WindTurbineType3IEC --> "0..1" WindGenType3IEC : WindGenType3IEC
class WindMechIEC {

}

WindTurbineType3IEC --> "1" WindMechIEC : WindMechIEC
```

Parent class supporting relationships to IEC wind turbines type 3 including their control models.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WindAeroOneDimIEC [0..1] | [WindAeroOneDimIEC](#CIM17v40-WindAeroOneDimIEC) | Wind aerodynamic model associated with this wind generator type 3 model. | |
| WindAeroTwoDimIEC [0..1] | [WindAeroTwoDimIEC](#CIM17v40-WindAeroTwoDimIEC) | Wind aerodynamic model associated with this wind turbine type 3 model. | |
| WindContPitchAngleIEC [1] | [WindContPitchAngleIEC](#CIM17v40-WindContPitchAngleIEC) | Wind control pitch angle model associated with this wind turbine type 3. | |
| WindContPType3IEC [1] | [WindContPType3IEC](#CIM17v40-WindContPType3IEC) | Wind control P type 3 model associated with this wind turbine type 3 model. | |
| WindGenType3IEC [0..1] | [WindGenType3IEC](#CIM17v40-WindGenType3IEC) | Wind generator type 3 model associated with this wind turbine type 3 model. | |
| WindMechIEC [1] | [WindMechIEC](#CIM17v40-WindMechIEC) | Wind mechanical model associated with this wind turbine type 3 model. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WindContCurrLimIEC [1] | [WindContCurrLimIEC](#CIM17v40-WindContCurrLimIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| WIndContQIEC [1] | [WindContQIEC](#CIM17v40-WindContQIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| WindContQLimIEC [0..1] | [WindContQLimIEC](#CIM17v40-WindContQLimIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| WindContQPQULimIEC [0..1] | [WindContQPQULimIEC](#CIM17v40-WindContQPQULimIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| WindProtectionIEC [1] | [WindProtectionIEC](#CIM17v40-WindProtectionIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| WindRefFrameRotIEC [1] | [WindRefFrameRotIEC](#CIM17v40-WindRefFrameRotIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| PowerElectronicsConnection [1] | [PowerElectronicsConnection](#CIM17v40-PowerElectronicsConnection) | see [WindTurbineType3or4Dynamics](CIM17v40-WindTurbineType3or4Dynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [WindTurbineType3or4Dynamics](CIM17v40-WindTurbineType3or4Dynamics) | |
| `WindPlantDynamics [0..1]` (OfAggregate) | [WindPlantDynamics](#CIM17v40-WindPlantDynamics) | see [WindTurbineType3or4Dynamics](CIM17v40-WindTurbineType3or4Dynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindTurbineType3or4Dynamics}
### WindTurbineType3or4Dynamics

Inheritance path = [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindTurbineType3or4Dynamics {

}

class DynamicsFunctionBlock {

}

DynamicsFunctionBlock <|-- WindTurbineType3or4Dynamics : inherits from
class PowerElectronicsConnection {

}

WindTurbineType3or4Dynamics --> "1" PowerElectronicsConnection : PowerElectronicsConnection
class RemoteInputSignal {

}

WindTurbineType3or4Dynamics --> "0..1" RemoteInputSignal : RemoteInputSignal
class WindPlantDynamics {

}

WindTurbineType3or4Dynamics --> "0..1" WindPlantDynamics : WindPlantDynamics
```

Parent class supporting relationships to wind turbines type 3 and type 4 and wind plant including their control models.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| PowerElectronicsConnection [1] | [PowerElectronicsConnection](#CIM17v40-PowerElectronicsConnection) | The power electronics connection associated with this wind turbine type 3 or type 4 dynamics model. | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | Remote input signal used by these wind turbine type 3 or type 4 models. | |
| `WindPlantDynamics [0..1]` (OfAggregate) | [WindPlantDynamics](#CIM17v40-WindPlantDynamics) | The wind plant with which the wind turbines type 3 or type 4 are associated. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindTurbineType3or4IEC}
### WindTurbineType3or4IEC

Inheritance path = [WindTurbineType3or4Dynamics](#CIM17v40-WindTurbineType3or4Dynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindTurbineType3or4IEC {

}

class WindTurbineType3or4Dynamics {

}

WindTurbineType3or4Dynamics <|-- WindTurbineType3or4IEC : inherits from
class WindContCurrLimIEC {

}

WindTurbineType3or4IEC --> "1" WindContCurrLimIEC : WindContCurrLimIEC
class WindContQIEC {

}

WindTurbineType3or4IEC --> "1" WindContQIEC : WIndContQIEC
class WindContQLimIEC {

}

WindTurbineType3or4IEC --> "0..1" WindContQLimIEC : WindContQLimIEC
class WindContQPQULimIEC {

}

WindTurbineType3or4IEC --> "0..1" WindContQPQULimIEC : WindContQPQULimIEC
class WindProtectionIEC {

}

WindTurbineType3or4IEC --> "1" WindProtectionIEC : WindProtectionIEC
class WindRefFrameRotIEC {

}

WindTurbineType3or4IEC --> "1" WindRefFrameRotIEC : WindRefFrameRotIEC
```

Parent class supporting relationships to IEC wind turbines type 3 and type 4 including their control models.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WindContCurrLimIEC [1] | [WindContCurrLimIEC](#CIM17v40-WindContCurrLimIEC) | Wind control current limitation model associated with this wind turbine type 3 or type 4 model. | |
| WIndContQIEC [1] | [WindContQIEC](#CIM17v40-WindContQIEC) | Wind control Q model associated with this wind turbine type 3 or type 4 model. | |
| WindContQLimIEC [0..1] | [WindContQLimIEC](#CIM17v40-WindContQLimIEC) | Constant Q limitation model associated with this wind generator type 3 or type 4 model. | |
| WindContQPQULimIEC [0..1] | [WindContQPQULimIEC](#CIM17v40-WindContQPQULimIEC) | QP and QU limitation model associated with this wind generator type 3 or type 4 model. | |
| WindProtectionIEC [1] | [WindProtectionIEC](#CIM17v40-WindProtectionIEC) | Wind turbune protection model associated with this wind generator type 3 or type 4 model. | |
| WindRefFrameRotIEC [1] | [WindRefFrameRotIEC](#CIM17v40-WindRefFrameRotIEC) | Reference frame rotation model associated with this wind turbine type 3 or type 4 model. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| PowerElectronicsConnection [1] | [PowerElectronicsConnection](#CIM17v40-PowerElectronicsConnection) | see [WindTurbineType3or4Dynamics](CIM17v40-WindTurbineType3or4Dynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [WindTurbineType3or4Dynamics](CIM17v40-WindTurbineType3or4Dynamics) | |
| `WindPlantDynamics [0..1]` (OfAggregate) | [WindPlantDynamics](#CIM17v40-WindPlantDynamics) | see [WindTurbineType3or4Dynamics](CIM17v40-WindTurbineType3or4Dynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindTurbineType4IEC}
### WindTurbineType4IEC

Inheritance path = [WindTurbineType3or4IEC](#CIM17v40-WindTurbineType3or4IEC) => [WindTurbineType3or4Dynamics](#CIM17v40-WindTurbineType3or4Dynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindTurbineType4IEC {

}

class WindTurbineType3or4IEC {

}

WindTurbineType3or4IEC <|-- WindTurbineType4IEC : inherits from
class WindGenType3aIEC {

}

WindTurbineType4IEC --> "0..1" WindGenType3aIEC : WindGenType3aIEC
```

Parent class supporting relationships to IEC wind turbines type 4 including their control models.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WindGenType3aIEC [0..1] | [WindGenType3aIEC](#CIM17v40-WindGenType3aIEC) | Wind generator type 3A model associated with this wind turbine type 4 model. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WindContCurrLimIEC [1] | [WindContCurrLimIEC](#CIM17v40-WindContCurrLimIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| WIndContQIEC [1] | [WindContQIEC](#CIM17v40-WindContQIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| WindContQLimIEC [0..1] | [WindContQLimIEC](#CIM17v40-WindContQLimIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| WindContQPQULimIEC [0..1] | [WindContQPQULimIEC](#CIM17v40-WindContQPQULimIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| WindProtectionIEC [1] | [WindProtectionIEC](#CIM17v40-WindProtectionIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| WindRefFrameRotIEC [1] | [WindRefFrameRotIEC](#CIM17v40-WindRefFrameRotIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| PowerElectronicsConnection [1] | [PowerElectronicsConnection](#CIM17v40-PowerElectronicsConnection) | see [WindTurbineType3or4Dynamics](CIM17v40-WindTurbineType3or4Dynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [WindTurbineType3or4Dynamics](CIM17v40-WindTurbineType3or4Dynamics) | |
| `WindPlantDynamics [0..1]` (OfAggregate) | [WindPlantDynamics](#CIM17v40-WindPlantDynamics) | see [WindTurbineType3or4Dynamics](CIM17v40-WindTurbineType3or4Dynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindTurbineType4aIEC}
### WindTurbineType4aIEC

Inheritance path = [WindTurbineType4IEC](#CIM17v40-WindTurbineType4IEC) => [WindTurbineType3or4IEC](#CIM17v40-WindTurbineType3or4IEC) => [WindTurbineType3or4Dynamics](#CIM17v40-WindTurbineType3or4Dynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindTurbineType4aIEC {

}

class WindTurbineType4IEC {

}

WindTurbineType4IEC <|-- WindTurbineType4aIEC : inherits from
class WindContPType4aIEC {

}

WindTurbineType4aIEC --> "1" WindContPType4aIEC : WindContPType4aIEC
class WindGenType4IEC {

}

WindTurbineType4aIEC --> "0..1" WindGenType4IEC : WindGenType4IEC
```

Wind turbine IEC type 4A.

Reference: IEC 61400-27-1:2015, 5.5.5.2.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WindContPType4aIEC [1] | [WindContPType4aIEC](#CIM17v40-WindContPType4aIEC) | Wind control P type 4A model associated with this wind turbine type 4A model. | |
| WindGenType4IEC [0..1] | [WindGenType4IEC](#CIM17v40-WindGenType4IEC) | Wind generator type 4 model associated with this wind turbine type 4A model. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WindGenType3aIEC [0..1] | [WindGenType3aIEC](#CIM17v40-WindGenType3aIEC) | see [WindTurbineType4IEC](CIM17v40-WindTurbineType4IEC) | |
| WindContCurrLimIEC [1] | [WindContCurrLimIEC](#CIM17v40-WindContCurrLimIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| WIndContQIEC [1] | [WindContQIEC](#CIM17v40-WindContQIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| WindContQLimIEC [0..1] | [WindContQLimIEC](#CIM17v40-WindContQLimIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| WindContQPQULimIEC [0..1] | [WindContQPQULimIEC](#CIM17v40-WindContQPQULimIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| WindProtectionIEC [1] | [WindProtectionIEC](#CIM17v40-WindProtectionIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| WindRefFrameRotIEC [1] | [WindRefFrameRotIEC](#CIM17v40-WindRefFrameRotIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| PowerElectronicsConnection [1] | [PowerElectronicsConnection](#CIM17v40-PowerElectronicsConnection) | see [WindTurbineType3or4Dynamics](CIM17v40-WindTurbineType3or4Dynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [WindTurbineType3or4Dynamics](CIM17v40-WindTurbineType3or4Dynamics) | |
| `WindPlantDynamics [0..1]` (OfAggregate) | [WindPlantDynamics](#CIM17v40-WindPlantDynamics) | see [WindTurbineType3or4Dynamics](CIM17v40-WindTurbineType3or4Dynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindTurbineType4bIEC}
### WindTurbineType4bIEC

Inheritance path = [WindTurbineType4IEC](#CIM17v40-WindTurbineType4IEC) => [WindTurbineType3or4IEC](#CIM17v40-WindTurbineType3or4IEC) => [WindTurbineType3or4Dynamics](#CIM17v40-WindTurbineType3or4Dynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindTurbineType4bIEC {

}

class WindTurbineType4IEC {

}

WindTurbineType4IEC <|-- WindTurbineType4bIEC : inherits from
class WindContPType4bIEC {

}

WindTurbineType4bIEC --> "1" WindContPType4bIEC : WindContPType4bIEC
class WindGenType4IEC {

}

WindTurbineType4bIEC --> "0..1" WindGenType4IEC : WindGenType4IEC
class WindMechIEC {

}

WindTurbineType4bIEC --> "1" WindMechIEC : WindMechIEC
```

Wind turbine IEC type 4B.

Reference: IEC 61400-27-1:2015, 5.5.5.3.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WindContPType4bIEC [1] | [WindContPType4bIEC](#CIM17v40-WindContPType4bIEC) | Wind control P type 4B model associated with this wind turbine type 4B model. | |
| WindGenType4IEC [0..1] | [WindGenType4IEC](#CIM17v40-WindGenType4IEC) | Wind generator type 4 model associated with this wind turbine type 4B model. | |
| WindMechIEC [1] | [WindMechIEC](#CIM17v40-WindMechIEC) | Wind mechanical model associated with this wind turbine type 4B model. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| WindGenType3aIEC [0..1] | [WindGenType3aIEC](#CIM17v40-WindGenType3aIEC) | see [WindTurbineType4IEC](CIM17v40-WindTurbineType4IEC) | |
| WindContCurrLimIEC [1] | [WindContCurrLimIEC](#CIM17v40-WindContCurrLimIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| WIndContQIEC [1] | [WindContQIEC](#CIM17v40-WindContQIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| WindContQLimIEC [0..1] | [WindContQLimIEC](#CIM17v40-WindContQLimIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| WindContQPQULimIEC [0..1] | [WindContQPQULimIEC](#CIM17v40-WindContQPQULimIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| WindProtectionIEC [1] | [WindProtectionIEC](#CIM17v40-WindProtectionIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| WindRefFrameRotIEC [1] | [WindRefFrameRotIEC](#CIM17v40-WindRefFrameRotIEC) | see [WindTurbineType3or4IEC](CIM17v40-WindTurbineType3or4IEC) | |
| PowerElectronicsConnection [1] | [PowerElectronicsConnection](#CIM17v40-PowerElectronicsConnection) | see [WindTurbineType3or4Dynamics](CIM17v40-WindTurbineType3or4Dynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [WindTurbineType3or4Dynamics](CIM17v40-WindTurbineType3or4Dynamics) | |
| `WindPlantDynamics [0..1]` (OfAggregate) | [WindPlantDynamics](#CIM17v40-WindPlantDynamics) | see [WindTurbineType3or4Dynamics](CIM17v40-WindTurbineType3or4Dynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindType1or2UserDefined}
### WindType1or2UserDefined

Inheritance path = [WindTurbineType1or2Dynamics](#CIM17v40-WindTurbineType1or2Dynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindType1or2UserDefined {

+ proprietary : Boolean [0..1]
}

class WindTurbineType1or2Dynamics {

}

WindTurbineType1or2Dynamics <|-- WindType1or2UserDefined : inherits from
```

Wind type 1 or type 2 function block whose dynamic behaviour is described by <font color="#0f0f0f">a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| proprietary [0..1] | [Boolean](#CIM17v40-Boolean) | Behaviour is based on a proprietary model as opposed to a detailed model.true = user-defined model is proprietary with behaviour mutually understood by sending and receiving applications and parameters passed as general attributesfalse = user-defined model is explicitly defined in terms of control blocks and their input and output signals. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AsynchronousMachineDynamics [1] | [AsynchronousMachineDynamics](#CIM17v40-AsynchronousMachineDynamics) | see [WindTurbineType1or2Dynamics](CIM17v40-WindTurbineType1or2Dynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [WindTurbineType1or2Dynamics](CIM17v40-WindTurbineType1or2Dynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindType3or4UserDefined}
### WindType3or4UserDefined

Inheritance path = [WindTurbineType3or4Dynamics](#CIM17v40-WindTurbineType3or4Dynamics) => [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindType3or4UserDefined {

+ proprietary : Boolean [0..1]
}

class WindTurbineType3or4Dynamics {

}

WindTurbineType3or4Dynamics <|-- WindType3or4UserDefined : inherits from
```

Wind type 3 or type 4 function block whose dynamic behaviour is described by <font color="#0f0f0f">a user-defined model.</font>


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| proprietary [0..1] | [Boolean](#CIM17v40-Boolean) | Behaviour is based on a proprietary model as opposed to a detailed model.true = user-defined model is proprietary with behaviour mutually understood by sending and receiving applications and parameters passed as general attributesfalse = user-defined model is explicitly defined in terms of control blocks and their input and output signals. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| PowerElectronicsConnection [1] | [PowerElectronicsConnection](#CIM17v40-PowerElectronicsConnection) | see [WindTurbineType3or4Dynamics](CIM17v40-WindTurbineType3or4Dynamics) | |
| RemoteInputSignal [0..1] | [RemoteInputSignal](#CIM17v40-RemoteInputSignal) | see [WindTurbineType3or4Dynamics](CIM17v40-WindTurbineType3or4Dynamics) | |
| `WindPlantDynamics [0..1]` (OfAggregate) | [WindPlantDynamics](#CIM17v40-WindPlantDynamics) | see [WindTurbineType3or4Dynamics](CIM17v40-WindTurbineType3or4Dynamics) | |
| enabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [DynamicsFunctionBlock](#CIM17v40-DynamicsFunctionBlock) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WindingInsulation}
### WindingInsulation

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WindingInsulation {

+ insulationPFStatus : String [0..1]
+ insulationResistance : String [0..1]
+ leakageReactance : Reactance [0..1]
+ status : Status [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- WindingInsulation : inherits from
class TransformerEnd {

}

WindingInsulation --> "1" TransformerEnd : FromWinding
class TransformerEnd {

}

WindingInsulation --> "1" TransformerEnd : ToWinding
class TransformerObservation {

}

WindingInsulation --> "0..1" TransformerObservation : TransformerObservation
```

Winding insulation condition as a result of a test.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| insulationPFStatus [0..1] | [String](#CIM17v40-String) | Status of Winding Insulation Power Factor as of statusDate: Acceptable, Minor Deterioration or Moisture Absorption, Major Deterioration or Moisture Absorption, Failed. | |
| insulationResistance [0..1] | [String](#CIM17v40-String) | For testType, status of Winding Insulation Resistance as of statusDate. Typical values are: Acceptable, Questionable, Failed. | |
| leakageReactance [0..1] | [Reactance](#CIM17v40-Reactance) | As of statusDate, the leakage reactance measured at the "from" winding with the "to" winding short-circuited and all other windings open-circuited. | |
| `FromWinding [1]` (informative) | [TransformerEnd](#CIM17v40-TransformerEnd) | | |
| status [0..1] | [Status](#CIM17v40-Status) | | |
| `ToWinding [1]` (informative) | [TransformerEnd](#CIM17v40-TransformerEnd) | | |
| `TransformerObservation [0..1]` (informative) | [TransformerObservation](#CIM17v40-TransformerObservation) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WireAssemblyInfo}
### WireAssemblyInfo

Inheritance path = [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WireAssemblyInfo {

}

class AssetInfo {

}

AssetInfo <|-- WireAssemblyInfo : inherits from
```

Describes the construction of a multi-conductor wire.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WireInfo}
### WireInfo

Inheritance path = [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WireInfo {

+ coreRadius : Length [0..1]
+ coreStrandCount : Integer [0..1]
+ gmr : Length [0..1]
+ insulated : Boolean [0..1]
+ insulationMaterial : enum:WireInsulationKind [0..1]
+ insulationThickness : Length [0..1]
+ material : enum:WireMaterialKind [0..1]
+ rAC25 : ResistancePerLength [0..1]
+ rAC50 : ResistancePerLength [0..1]
+ rAC75 : ResistancePerLength [0..1]
+ radius : Length [0..1]
+ ratedCurrent : CurrentFlow [0..1]
+ rDC20 : ResistancePerLength [0..1]
+ sizeDescription : String [0..1]
+ strandCount : Integer [0..1]
}

class AssetInfo {

}

AssetInfo <|-- WireInfo : inherits from
```

Wire data that can be specified per line segment phase, or for the line segment as a whole in case its phases all have the same wire characteristics.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| coreRadius [0..1] | [Length](#CIM17v40-Length) | (if there is a different core material) Radius of the central core. | |
| coreStrandCount [0..1] | [Integer](#CIM17v40-Integer) | (if used) Number of strands in the steel core. | |
| gmr [0..1] | [Length](#CIM17v40-Length) | Geometric mean radius. If we replace the conductor by a thin walled tube of radius GMR, then its reactance is identical to the reactance of the actual conductor. | |
| insulated [0..1] | [Boolean](#CIM17v40-Boolean) | True if conductor is insulated. | |
| insulationMaterial [0..1] | [WireInsulationKind](#CIM17v40-WireInsulationKind) | (if insulated conductor) Material used for insulation. | |
| insulationThickness [0..1] | [Length](#CIM17v40-Length) | (if insulated conductor) Thickness of the insulation. | |
| material [0..1] | [WireMaterialKind](#CIM17v40-WireMaterialKind) | Conductor material. | |
| rAC25 [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | AC resistance per unit length of the conductor at 25 �C. | |
| rAC50 [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | AC resistance per unit length of the conductor at 50 �C. | |
| rAC75 [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | AC resistance per unit length of the conductor at 75 �C. | |
| radius [0..1] | [Length](#CIM17v40-Length) | Outside radius of the wire. | |
| ratedCurrent [0..1] | [CurrentFlow](#CIM17v40-CurrentFlow) | Current carrying capacity of the wire under stated thermal conditions. | |
| rDC20 [0..1] | [ResistancePerLength](#CIM17v40-ResistancePerLength) | DC resistance per unit length of the conductor at 20 �C. | |
| sizeDescription [0..1] | [String](#CIM17v40-String) | Describes the wire gauge or cross section (e.g., 4/0, #2, 336.5). | |
| strandCount [0..1] | [Integer](#CIM17v40-Integer) | Number of strands in the conductor. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WirePhaseInfo}
### WirePhaseInfo


```mermaid
classDiagram
direction TB

class WirePhaseInfo {

+ phaseInfo : enum:SinglePhaseKind [0..1]
}

class WireAssemblyInfo {

}

WirePhaseInfo --> "1" WireAssemblyInfo : WireAssemblyInfo
class WireInfo {

}

WirePhaseInfo --> "0..1" WireInfo : WireInfo
class WirePosition {

}

WirePhaseInfo --> "0..1" WirePosition : WirePosition
```

Information on a wire carrying a single phase.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| phaseInfo [0..1] | [SinglePhaseKind](#CIM17v40-SinglePhaseKind) | Phase information. | |
| WireAssemblyInfo [1] | [WireAssemblyInfo](#CIM17v40-WireAssemblyInfo) | Wire assembly information using this wire phase information. | |
| WireInfo [0..1] | [WireInfo](#CIM17v40-WireInfo) | Wire information contributing to this wire phase information. | |
| WirePosition [0..1] | [WirePosition](#CIM17v40-WirePosition) | Wire position with this wire phase information. | |

{#CIM17v40-WirePosition}
### WirePosition

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WirePosition {

+ sequenceNumber : Integer [0..1]
+ xCoord : Displacement [0..1]
+ yCoord : Displacement [0..1]
}

class IdentifiedObject {

}

IdentifiedObject <|-- WirePosition : inherits from
class WireSpacingInfo {

}

WirePosition --> "0..1" WireSpacingInfo : WireSpacingInfo
```

Identification, spacing and configuration of the wires of a conductor with respect to a structure.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | Numbering for wires on a WireSpacingInfo. Neutrals should be numbered last. | |
| xCoord [0..1] | [Displacement](#CIM17v40-Displacement) | Signed horizontal distance from the wire at this position to a common reference point. | |
| yCoord [0..1] | [Displacement](#CIM17v40-Displacement) | Signed vertical distance from the wire at this position: above ground (positive value) or burial depth below ground (negative value). | |
| WireSpacingInfo [0..1] | [WireSpacingInfo](#CIM17v40-WireSpacingInfo) | Wire spacing data this wire position belongs to. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WireSegment}
### WireSegment

Inheritance path = [Conductor](#CIM17v40-Conductor) => [ConductingEquipment](#CIM17v40-ConductingEquipment) => [Equipment](#CIM17v40-Equipment) => [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WireSegment {

}

class Conductor {

}

Conductor <|-- WireSegment : inherits from
```

A two terminal and power conducting device of negligible impedance and length represented as zero impedance device that can be used to connect auxiliary equipment to its terminals.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| length [0..1] | [Length](#CIM17v40-Length) | see [Conductor](CIM17v40-Conductor) | |
| BaseVoltage [0..1] | [BaseVoltage](#CIM17v40-BaseVoltage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| GroundingAction [0..1] | [GroundAction](#CIM17v40-GroundAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| JumpingAction [0..1] | [JumperAction](#CIM17v40-JumperAction) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| Outage [0..1] | [Outage](#CIM17v40-Outage) | see [ConductingEquipment](CIM17v40-ConductingEquipment) | |
| aggregate [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| inService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| networkAnalysisEnabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| normallyInService [0..1] | [Boolean](#CIM17v40-Boolean) | see [Equipment](#CIM17v40-Equipment) | |
| AdditionalEquipmentContainer [0..*] | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| `EquipmentContainer [0..1]` (OfAggregate) | [EquipmentContainer](#CIM17v40-EquipmentContainer) | see [Equipment](CIM17v40-Equipment) | |
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WireSegmentPhase}
### WireSegmentPhase

Inheritance path = [PowerSystemResource](#CIM17v40-PowerSystemResource) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WireSegmentPhase {

+ phase : enum:SinglePhaseKind [0..1]
+ sequenceNumber : Integer [0..1]
}

class PowerSystemResource {

}

PowerSystemResource <|-- WireSegmentPhase : inherits from
class WireSegment {

}

WireSegmentPhase --> "1" WireSegment : WireSegment
```

Represents a single wire of an alternating current wire segment.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| phase [0..1] | [SinglePhaseKind](#CIM17v40-SinglePhaseKind) | The phase connection of the wire at both ends. | |
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | Number designation for this wire segment phase. Each wire segment phase within a wire segment should have a unique sequence number. | |
| WireSegment [1] | [WireSegment](#CIM17v40-WireSegment) | The wire segment to which the phase belongs. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| AssetDatasheet [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| PSRType [0..1] | [PSRType](#CIM17v40-PSRType) | see [PowerSystemResource](CIM17v40-PowerSystemResource) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WireSpacingInfo}
### WireSpacingInfo

Inheritance path = [AssetInfo](#CIM17v40-AssetInfo) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WireSpacingInfo {

+ isCable : Boolean [0..1]
+ phaseWireCount : Integer [0..1]
+ phaseWireSpacing : Length [0..1]
+ usage : enum:WireUsageKind [0..1]
}

class AssetInfo {

}

AssetInfo <|-- WireSpacingInfo : inherits from
class DuctBank {

}

WireSpacingInfo --> "0..1" DuctBank : DuctBank
```

Wire spacing data that associates multiple wire positions with the line segment, and allows to calculate line segment impedances. Number of phases can be derived from the number of associated wire positions whose phase is not neutral.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| isCable [0..1] | [Boolean](#CIM17v40-Boolean) | If true, this spacing data describes a cable. | |
| phaseWireCount [0..1] | [Integer](#CIM17v40-Integer) | Number of wire sub-conductors in the symmetrical bundle (typically between 1 and 4). | |
| phaseWireSpacing [0..1] | [Length](#CIM17v40-Length) | Distance between wire sub-conductors in a symmetrical bundle. | |
| usage [0..1] | [WireUsageKind](#CIM17v40-WireUsageKind) | Usage of the associated wires. | |
| `DuctBank [0..1]` (informative) | [DuctBank](#CIM17v40-DuctBank) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| CatalogAssetType [0..1] | [CatalogAssetType](#CIM17v40-CatalogAssetType) | see [AssetInfo](CIM17v40-AssetInfo) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [AssetInfo](CIM17v40-AssetInfo) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Work}
### (informative) Work

Inheritance path = [BaseWork](#CIM17v40-BaseWork) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Work {

+ requestDateTime : DateTime [0..1]
+ workOrderNumber : String [0..1]
}

class BaseWork {

}

BaseWork <|-- Work : inherits from
class BusinessCase {

}

Work --> "0..1" BusinessCase : BusinessCase
class ErpProjectAccounting {

}

Work --> "0..1" ErpProjectAccounting : ErpProjectAccounting
class Project {

}

Work --> "0..1" Project : Project
class WorkBillingInfo {

}

Work --> "0..1" WorkBillingInfo : WorkBillingInfo
```

Document used to request, initiate, track and record work.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| requestDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time work was requested. | |
| workOrderNumber [0..1] | [String](#CIM17v40-String) | Work order number (or other unique identifying information) for this work. | |
| `BusinessCase [0..1]` (informative) | [BusinessCase](#CIM17v40-BusinessCase) | | |
| `ErpProjectAccounting [0..1]` (informative) | [ErpProjectAccounting](#CIM17v40-ErpProjectAccounting) | | |
| `Project [0..1]` (informative) | [Project](#CIM17v40-Project) | | |
| `WorkBillingInfo [0..1]` (informative) | [WorkBillingInfo](#CIM17v40-WorkBillingInfo) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [ServiceRequestKind](#CIM17v40-ServiceRequestKind) | see [BaseWork](CIM17v40-BaseWork) | |
| statusKind [0..1] | [WorkStatusKind](#CIM17v40-WorkStatusKind) | see [BaseWork](CIM17v40-BaseWork) | |
| priority [0..1] | [Priority](#CIM17v40-Priority) | see [BaseWork](CIM17v40-BaseWork) | |
| WorkLocation [0..1] | [WorkLocation](#CIM17v40-WorkLocation) | see [BaseWork](CIM17v40-BaseWork) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WorkActivityRecord}
### WorkActivityRecord

Inheritance path = [ActivityRecord](#CIM17v40-ActivityRecord) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WorkActivityRecord {

+ percentComplete : PerCent [0..1]
}

class ActivityRecord {

}

ActivityRecord <|-- WorkActivityRecord : inherits from
class BaseWork {

}

WorkActivityRecord --> "0..1" BaseWork : BaseWork
```

Records information about the status of work or work task at a point in time.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| percentComplete [0..1] | [PerCent](#CIM17v40-PerCent) | Estimated percentage of completion of this individual work task or overall work order. | |
| BaseWork [0..1] | [BaseWork](#CIM17v40-BaseWork) | Base work that this activity record tracks. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| reason [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| severity [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| type [0..1] | [String](#CIM17v40-String) | see [ActivityRecord](#CIM17v40-ActivityRecord) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| Document [0..1] | [Document](#CIM17v40-Document) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [ActivityRecord](CIM17v40-ActivityRecord) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WorkAsset}
### (informative) WorkAsset

Inheritance path = [Asset](#CIM17v40-Asset) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WorkAsset {

}

class Asset {

}

Asset <|-- WorkAsset : inherits from
class Crew {

}

WorkAsset --> "0..1" Crew : Crew
class CUWorkEquipmentItem {

}

WorkAsset --> "0..1" CUWorkEquipmentItem : CUWorkEquipmentAsset
```

Asset used to perform work.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| Crew [0..1] | [Crew](#CIM17v40-Crew) | Crew using this work asset. | |
| `CUWorkEquipmentAsset [0..1]` (informative) | [CUWorkEquipmentItem](#CIM17v40-CUWorkEquipmentItem) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| critical [0..1] | [Boolean](#CIM17v40-Boolean) | see [Asset](#CIM17v40-Asset) | |
| initialCondition [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| initialLossOfLife [0..1] | [PerCent](#CIM17v40-PerCent) | see [Asset](CIM17v40-Asset) | |
| inUseState [0..1] | [InUseStateKind](#CIM17v40-InUseStateKind) | see [Asset](CIM17v40-Asset) | |
| kind [0..1] | [AssetKind](#CIM17v40-AssetKind) | see [Asset](CIM17v40-Asset) | |
| lifecycleState [0..1] | [AssetLifecycleStateKind](#CIM17v40-AssetLifecycleStateKind) | see [Asset](CIM17v40-Asset) | |
| lotNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| position [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| purchasePrice [0..1] | [Money](#CIM17v40-Money) | see [Asset](CIM17v40-Asset) | |
| retiredReason [0..1] | [RetiredReasonKind](#CIM17v40-RetiredReasonKind) | see [Asset](CIM17v40-Asset) | |
| serialNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| type [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| utcNumber [0..1] | [String](#CIM17v40-String) | see [Asset](#CIM17v40-Asset) | |
| acceptanceTest [0..1] | [AcceptanceTest](#CIM17v40-AcceptanceTest) | see [Asset](CIM17v40-Asset) | |
| AssetContainer [0..1] | [AssetContainer](#CIM17v40-AssetContainer) | see [Asset](CIM17v40-Asset) | |
| AssetDeployment [0..1] | [AssetDeployment](#CIM17v40-AssetDeployment) | see [Asset](CIM17v40-Asset) | |
| AssetInfo [0..1] | [AssetInfo](#CIM17v40-AssetInfo) | see [Asset](CIM17v40-Asset) | |
| BreakerOperation [0..1] | [SwitchOperationSummary](#CIM17v40-SwitchOperationSummary) | see [Asset](CIM17v40-Asset) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Asset](CIM17v40-Asset) | |
| `ErpInventory [0..1]` (informative) | [ErpInventory](#CIM17v40-ErpInventory) | see [Asset](CIM17v40-Asset) | |
| `ErpItemMaster [0..1]` (informative) | [ErpItemMaster](#CIM17v40-ErpItemMaster) | see [Asset](CIM17v40-Asset) | |
| FinancialInfo [0..1] | [FinancialInfo](#CIM17v40-FinancialInfo) | see [Asset](CIM17v40-Asset) | |
| inUseDate [0..1] | [InUseDate](#CIM17v40-InUseDate) | see [Asset](CIM17v40-Asset) | |
| lifecycleDate [0..1] | [LifecycleDate](#CIM17v40-LifecycleDate) | see [Asset](CIM17v40-Asset) | |
| Location [0..1] | [Location](#CIM17v40-Location) | see [Asset](CIM17v40-Asset) | |
| ProductAssetModel [0..1] | [ProductAssetModel](#CIM17v40-ProductAssetModel) | see [Asset](CIM17v40-Asset) | |
| ServiceLocation [0..1] | [ServiceLocation](#CIM17v40-ServiceLocation) | see [Asset](CIM17v40-Asset) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Asset](CIM17v40-Asset) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WorkBillingInfo}
### (informative) WorkBillingInfo

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WorkBillingInfo {

+ costEstimate : Money [0..1]
+ deposit : Money [0..1]
+ discount : Float [0..1]
+ dueDateTime : DateTime [0..1]
+ issueDateTime : DateTime [0..1]
+ receivedDateTime : DateTime [0..1]
+ workPrice : Money [0..1]
}

class Document {

}

Document <|-- WorkBillingInfo : inherits from
class CustomerAccount {

}

WorkBillingInfo --> "0..1" CustomerAccount : CustomerAccount
```

Billing information for work performed for the customer. The history of Work Billing Info, Invoices, and Payments is to be maintained in associated ActivityRecords.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| costEstimate [0..1] | [Money](#CIM17v40-Money) | Estimated cost for work. | |
| deposit [0..1] | [Money](#CIM17v40-Money) | Amount of price on deposit. | |
| discount [0..1] | [Float](#CIM17v40-Float) | Discount from standard price. | |
| dueDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time by which payment for bill is expected from client. | |
| issueDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time bill was issued to client. | |
| receivedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date payment was received from client. | |
| workPrice [0..1] | [Money](#CIM17v40-Money) | Amount of bill. | |
| `CustomerAccount [0..1]` (informative) | [CustomerAccount](#CIM17v40-CustomerAccount) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WorkCostDetail}
### (informative) WorkCostDetail

Inheritance path = [WorkDocument](#CIM17v40-WorkDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WorkCostDetail {

+ amount : Money [0..1]
+ isDebit : Boolean [0..1]
+ transactionDateTime : DateTime [0..1]
}

class WorkDocument {

}

WorkDocument <|-- WorkCostDetail : inherits from
class CostType {

}

WorkCostDetail --> "1" CostType : CostType
class Design {

}

WorkCostDetail --> "0..1" Design : Design
class ErpProjectAccounting {

}

WorkCostDetail --> "1" ErpProjectAccounting : ErpProjectAccounting
class OverheadCost {

}

WorkCostDetail --> "0..1" OverheadCost : OverheadCost
class WorkCostSummary {

}

WorkCostDetail --> "0..1" WorkCostSummary : WorkCostSummary
class OldWorkTask {

}

WorkCostDetail --> "0..1" OldWorkTask : WorkTask
```

A collection of all of the individual cost items collected from multiple sources.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| amount [0..1] | [Money](#CIM17v40-Money) | Amount in designated currency for work, either a total or an individual element. As defined in the attribute "type," multiple instances are applicable to each work for: planned cost, actual cost, authorized cost, budgeted cost, forecasted cost, other. | |
| isDebit [0..1] | [Boolean](#CIM17v40-Boolean) | True if 'amount' is a debit, false if it is a credit. | |
| transactionDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time that 'amount' is posted to the work. | |
| `CostType [1]` (informative) | [CostType](#CIM17v40-CostType) | | |
| `Design [0..1]` (informative) | [Design](#CIM17v40-Design) | | |
| `ErpProjectAccounting [1]` (informative) | [ErpProjectAccounting](#CIM17v40-ErpProjectAccounting) | | |
| `OverheadCost [0..1]` (informative) | [OverheadCost](#CIM17v40-OverheadCost) | | |
| `WorkCostSummary [0..1]` (informative) | [WorkCostSummary](#CIM17v40-WorkCostSummary) | | |
| `WorkTask [0..1]` (informative) | [OldWorkTask](#CIM17v40-OldWorkTask) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WorkCostSummary}
### (informative) WorkCostSummary

Inheritance path = [WorkDocument](#CIM17v40-WorkDocument) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WorkCostSummary {

}

class WorkDocument {

}

WorkDocument <|-- WorkCostSummary : inherits from
class WorkCostDetail {

}

WorkCostSummary --> "0..1" WorkCostDetail : WorkCostDetail
```

A roll up by cost type for the entire cost of a work order. For example, total labor.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `WorkCostDetail [0..1]` (informative) | [WorkCostDetail](#CIM17v40-WorkCostDetail) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WorkDocument}
### WorkDocument

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WorkDocument {

}

class Document {

}

Document <|-- WorkDocument : inherits from
```

Shadow class for Document, to isolate subclassing from this package. If any subclass gets normative and needs inheritance, it will inherit directly from Document.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WorkFlowStep}
### (informative) WorkFlowStep

Inheritance path = [WorkIdentifiedObject](#CIM17v40-WorkIdentifiedObject) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WorkFlowStep {

+ sequenceNumber : Integer [0..1]
+ status : Status [0..1]
}

class WorkIdentifiedObject {

}

WorkIdentifiedObject <|-- WorkFlowStep : inherits from
class Work {

}

WorkFlowStep --> "0..1" Work : Work
```

A pre-defined set of work steps for a given type of work.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| sequenceNumber [0..1] | [Integer](#CIM17v40-Integer) | Used to define dependencies of each work flow step, which is for the instance of WorkTask associated with a given instance of WorkFlow. | |
| status [0..1] | [Status](#CIM17v40-Status) | | |
| `Work [0..1]` (informative) | [Work](#CIM17v40-Work) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WorkIdentifiedObject}
### WorkIdentifiedObject

Inheritance path = [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WorkIdentifiedObject {

}

class IdentifiedObject {

}

IdentifiedObject <|-- WorkIdentifiedObject : inherits from
```

Shadow class for IdentifiedObject, to isolate subclassing from this package. If any subclass gets normative and needs inheritance, it will inherit directly from IdentifiedObject.


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WorkLocation}
### WorkLocation

Inheritance path = [Location](#CIM17v40-Location) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WorkLocation {

}

class Location {

}

Location <|-- WorkLocation : inherits from
class OneCallRequest {

}

WorkLocation --> "0..1" OneCallRequest : OneCallRequest
```

Information about a particular location for various forms of work.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| `OneCallRequest [0..1]` (informative) | [OneCallRequest](#CIM17v40-OneCallRequest) | | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| direction [0..1] | [String](#CIM17v40-String) | see [Location](#CIM17v40-Location) | |
| geoInfoReference [0..1] | [String](#CIM17v40-String) | see [Location](#CIM17v40-Location) | |
| type [0..1] | [String](#CIM17v40-String) | see [Location](#CIM17v40-Location) | |
| CoordinateSystem [0..1] | [CoordinateSystem](#CIM17v40-CoordinateSystem) | see [Location](CIM17v40-Location) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Location](CIM17v40-Location) | |
| Incident [0..1] | [Incident](#CIM17v40-Incident) | see [Location](CIM17v40-Location) | |
| mainAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Location](CIM17v40-Location) | |
| OutageOrder [0..1] | [OutageOrder](#CIM17v40-OutageOrder) | see [Location](CIM17v40-Location) | |
| phone1 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Location](CIM17v40-Location) | |
| phone2 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Location](CIM17v40-Location) | |
| secondaryAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Location](CIM17v40-Location) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Location](CIM17v40-Location) | |
| SwitchingOrder [0..1] | [SwitchingOrder](#CIM17v40-SwitchingOrder) | see [Location](CIM17v40-Location) | |
| TroubleOrder [0..1] | [TroubleOrder](#CIM17v40-TroubleOrder) | see [Location](CIM17v40-Location) | |
| TroubleTicket [0..1] | [TroubleTicket](#CIM17v40-TroubleTicket) | see [Location](CIM17v40-Location) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WorkOrder}
### WorkOrder

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WorkOrder {

}

class Document {

}

Document <|-- WorkOrder : inherits from
```


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WorkRequest}
### WorkRequest

Inheritance path = [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WorkRequest {

}

class Document {

}

Document <|-- WorkRequest : inherits from
```

Document used to plan or initiate work


#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WorkTask}
### WorkTask

Inheritance path = [BaseWork](#CIM17v40-BaseWork) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WorkTask {

+ completedDateTime : DateTime [0..1]
+ contractorCost : Money [0..1]
+ crewETA : DateTime [0..1]
+ estimatedCompletionTime : DateTime [0..1]
+ instruction : String [0..1]
+ laborCost : Money [0..1]
+ laborHours : Hours [0..1]
+ materiallCost : Money [0..1]
+ schedOverride : String [0..1]
+ startedDateTime : DateTime [0..1]
+ taskKind : enum:WorkTaskKind [0..1]
+ toolCost : Money [0..1]
}

class BaseWork {

}

BaseWork <|-- WorkTask : inherits from
class SwitchingPlan {

}

WorkTask --> "0..1" SwitchingPlan : SwitchingPlan
class TroubleOrder {

}

WorkTask --> "0..1" TroubleOrder : TroubleOrder
class Work {

}

WorkTask --> "1" Work : Work
```

A task within a set of work.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| completedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time work task was completed. | |
| contractorCost [0..1] | [Money](#CIM17v40-Money) | Total contractor costs associated with the work task. | |
| crewETA [0..1] | [DateTime](#CIM17v40-DateTime) | Estimated time of arrival, so that customer or police/fire department can be informed when the crew will arrive. | |
| estimatedCompletionTime [0..1] | [DateTime](#CIM17v40-DateTime) | Time and Date when the work task will be completed. | |
| instruction [0..1] | [String](#CIM17v40-String) | Instructions for performing this task. | |
| laborCost [0..1] | [Money](#CIM17v40-Money) | Total labor costs associated with the work task. | |
| laborHours [0..1] | [Hours](#CIM17v40-Hours) | Hours of labor expended under work task. | |
| materiallCost [0..1] | [Money](#CIM17v40-Money) | Total material costs associated with the work task. | |
| schedOverride [0..1] | [String](#CIM17v40-String) | If specified, override schedule and perform this task in accordance with instructions specified here. | |
| startedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time work task was started. | |
| taskKind [0..1] | [WorkTaskKind](#CIM17v40-WorkTaskKind) | Kind of work. | |
| toolCost [0..1] | [Money](#CIM17v40-Money) | Total tool costs associated with the work task. | |
| SwitchingPlan [0..1] | [SwitchingPlan](#CIM17v40-SwitchingPlan) | Switching plan executed by this work task. | |
| TroubleOrder [0..1] | [TroubleOrder](#CIM17v40-TroubleOrder) | The trouble order that contains the work tasks. | |
| Work [1] | [Work](#CIM17v40-Work) | Work this task belongs to. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [ServiceRequestKind](#CIM17v40-ServiceRequestKind) | see [BaseWork](CIM17v40-BaseWork) | |
| statusKind [0..1] | [WorkStatusKind](#CIM17v40-WorkStatusKind) | see [BaseWork](CIM17v40-BaseWork) | |
| priority [0..1] | [Priority](#CIM17v40-Priority) | see [BaseWork](CIM17v40-BaseWork) | |
| WorkLocation [0..1] | [WorkLocation](#CIM17v40-WorkLocation) | see [BaseWork](CIM17v40-BaseWork) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-WorkTimeSchedule}
### WorkTimeSchedule

Inheritance path = [TimeSchedule](#CIM17v40-TimeSchedule) => [Document](#CIM17v40-Document) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class WorkTimeSchedule {

+ kind : enum:WorkTimeScheduleKind [0..1]
}

class TimeSchedule {

}

TimeSchedule <|-- WorkTimeSchedule : inherits from
class BaseWork {

}

WorkTimeSchedule --> "0..1" BaseWork : BaseWork
class ServiceRequest {

}

WorkTimeSchedule --> "0..1" ServiceRequest : ServiceRequest
```

Time schedule specific to work.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [WorkTimeScheduleKind](#CIM17v40-WorkTimeScheduleKind) | Kind of this work schedule. | |
| BaseWork [0..1] | [BaseWork](#CIM17v40-BaseWork) | Time schedule for this work or work task. | |
| ServiceRequest [0..1] | [ServiceRequest](#CIM17v40-ServiceRequest) | The service request for which the work time schedule exists | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| disabled [0..1] | [Boolean](#CIM17v40-Boolean) | see [TimeSchedule](#CIM17v40-TimeSchedule) | |
| offset [0..1] | [Seconds](#CIM17v40-Seconds) | see [TimeSchedule](CIM17v40-TimeSchedule) | |
| recurrencePattern [0..1] | [String](#CIM17v40-String) | see [TimeSchedule](#CIM17v40-TimeSchedule) | |
| recurrencePeriod [0..1] | [Seconds](#CIM17v40-Seconds) | see [TimeSchedule](CIM17v40-TimeSchedule) | |
| MeterReadSchedule [0..1] | [MeterReadSchedule](#CIM17v40-MeterReadSchedule) | see [TimeSchedule](CIM17v40-TimeSchedule) | |
| scheduleInterval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | see [TimeSchedule](CIM17v40-TimeSchedule) | |
| authorName [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| comment [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| createdDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| lastModifiedDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | see [Document](#CIM17v40-Document) | |
| revisionNumber [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| subject [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| title [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| type [0..1] | [String](#CIM17v40-String) | see [Document](#CIM17v40-Document) | |
| Approver [0..1] | [Approver](#CIM17v40-Approver) | see [Document](CIM17v40-Document) | |
| Author [0..1] | [Author](#CIM17v40-Author) | see [Document](CIM17v40-Document) | |
| docStatus [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| Editor [0..1] | [Editor](#CIM17v40-Editor) | see [Document](CIM17v40-Document) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Document](CIM17v40-Document) | |
| Issuer [0..1] | [Issuer](#CIM17v40-Issuer) | see [Document](CIM17v40-Document) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Document](CIM17v40-Document) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |

{#CIM17v40-Zone}
### Zone

Inheritance path = [Location](#CIM17v40-Location) => [IdentifiedObject](#CIM17v40-IdentifiedObject)

```mermaid
classDiagram
direction TB

class Zone {

+ kind : enum:ZoneKind [0..1]
}

class Location {

}

Location <|-- Zone : inherits from
```

Area divided off from other areas. It may be part of the electrical network, a land area where special restrictions apply, weather areas, etc. For weather, it is an area where a set of relatively homogenous weather measurements apply.


#### Native Members

| name | type | description | mapping |
|------|------|-------------|---------|
| kind [0..1] | [ZoneKind](#CIM17v40-ZoneKind) | Kind of this zone. | |

#### Inherited Members

| name | type | description | mapping |
|------|------|-------------|---------|
| direction [0..1] | [String](#CIM17v40-String) | see [Location](#CIM17v40-Location) | |
| geoInfoReference [0..1] | [String](#CIM17v40-String) | see [Location](#CIM17v40-Location) | |
| type [0..1] | [String](#CIM17v40-String) | see [Location](#CIM17v40-Location) | |
| CoordinateSystem [0..1] | [CoordinateSystem](#CIM17v40-CoordinateSystem) | see [Location](CIM17v40-Location) | |
| electronicAddress [0..1] | [ElectronicAddress](#CIM17v40-ElectronicAddress) | see [Location](CIM17v40-Location) | |
| Incident [0..1] | [Incident](#CIM17v40-Incident) | see [Location](CIM17v40-Location) | |
| mainAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Location](CIM17v40-Location) | |
| OutageOrder [0..1] | [OutageOrder](#CIM17v40-OutageOrder) | see [Location](CIM17v40-Location) | |
| phone1 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Location](CIM17v40-Location) | |
| phone2 [0..1] | [TelephoneNumber](#CIM17v40-TelephoneNumber) | see [Location](CIM17v40-Location) | |
| secondaryAddress [0..1] | [StreetAddress](#CIM17v40-StreetAddress) | see [Location](CIM17v40-Location) | |
| status [0..1] | [Status](#CIM17v40-Status) | see [Location](CIM17v40-Location) | |
| SwitchingOrder [0..1] | [SwitchingOrder](#CIM17v40-SwitchingOrder) | see [Location](CIM17v40-Location) | |
| TroubleOrder [0..1] | [TroubleOrder](#CIM17v40-TroubleOrder) | see [Location](CIM17v40-Location) | |
| TroubleTicket [0..1] | [TroubleTicket](#CIM17v40-TroubleTicket) | see [Location](CIM17v40-Location) | |
| mRID [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| aliasName [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| description [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| name [0..1] | [String](#CIM17v40-String) | see [IdentifiedObject](#CIM17v40-IdentifiedObject) | |
| InstanceSet [1] | [InstanceSet](#CIM17v40-InstanceSet) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |
| PropertiesCIMDataObject [0..1] | [ChangeSetMember](#CIM17v40-ChangeSetMember) | see [IdentifiedObject](CIM17v40-IdentifiedObject) | |


## Compound Types

## CIM17v40-ASTMStandard
### (Attribute) ASTMStandard

Standard published by ASTM (ASTM International).

```mermaid
classDiagram
direction TB

Standard published by ASTM (ASTM International).http://langdale.com.au/2005/UML#attributeEdition of ASTM standard.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeASTM standard number.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| standardEdition [0..1] | [ASTMStandardEditionKind](#CIM17v40-ASTMStandardEditionKind) | Edition of ASTM standard. | |
| standardNumber [0..1] | [ASTMStandardKind](#CIM17v40-ASTMStandardKind) | ASTM standard number. | |

## CIM17v40-AcceptanceTest
### (Attribute) AcceptanceTest

Acceptance test for assets.

```mermaid
classDiagram
direction TB

Acceptance test for assets.http://langdale.com.au/2005/UML#attributeDate and time the asset was last tested using the 'type' of test and yielding the current status in 'success' attribute.http://langdale.com.au/2005/UML#attributeTrue if asset has passed acceptance test and may be placed in or is in service. It is set to false if asset is removed from service and is required to be tested again before being placed back in service, possibly in a new location. Since asset may go through multiple tests during its lifecycle, the date of each acceptance test may be recorded in 'Asset.ActivityRecord.status.dateTime'.http://langdale.com.au/2005/UML#attributeType of test or group of tests that was conducted on 'dateTime'.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time the asset was last tested using the 'type' of test and yielding the current status in 'success' attribute. | |
| success [0..1] | [Boolean](#CIM17v40-Boolean) | True if asset has passed acceptance test and may be placed in or is in service. It is set to false if asset is removed from service and is required to be tested again before being placed back in service, possibly in a new location. Since asset may go through multiple tests during its lifecycle, the date of each acceptance test may be recorded in 'Asset.ActivityRecord.status.dateTime'. | |
| type [0..1] | [String](#CIM17v40-String) | Type of test or group of tests that was conducted on 'dateTime'. | |

## CIM17v40-AccountMovement
### (Attribute) AccountMovement

Credit/debit movements for an account.

```mermaid
classDiagram
direction TB

Credit/debit movements for an account.http://langdale.com.au/2005/UML#attributeAmount that was credited to/debited from an account. For example: payment received/interest charge on arrears.http://langdale.com.au/2005/UML#attributeDate and time when the credit/debit transaction was performed.http://langdale.com.au/2005/UML#attributeReason for credit/debit transaction on an account. Example: payment received/arrears interest levied.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| amount [0..1] | [Money](#CIM17v40-Money) | Amount that was credited to/debited from an account. For example: payment received/interest charge on arrears. | |
| dateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time when the credit/debit transaction was performed. | |
| reason [0..1] | [String](#CIM17v40-String) | Reason for credit/debit transaction on an account. Example: payment received/arrears interest levied. | |

## CIM17v40-AccountingUnit
### (Attribute) AccountingUnit

Unit for accounting; use either 'energyUnit' or 'currencyUnit' to specify the unit for 'value'.

```mermaid
classDiagram
direction TB

Unit for accounting; use either 'energyUnit' or 'currencyUnit' to specify the unit for 'value'.http://langdale.com.au/2005/UML#attributeUnit of service.http://langdale.com.au/2005/UML#attributeUnit of currency.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeMultiplier for the 'energyUnit' or 'monetaryUnit'.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeValue expressed in applicable units.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| energyUnit [0..1] | [RealEnergy](#CIM17v40-RealEnergy) | Unit of service. | |
| monetaryUnit [0..1] | [Currency](#CIM17v40-Currency) | Unit of currency. | |
| multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | Multiplier for the 'energyUnit' or 'monetaryUnit'. | |
| value [0..1] | [Float](#CIM17v40-Float) | Value expressed in applicable units. | |

## CIM17v40-BankAccountDetail
### (Attribute) BankAccountDetail

Details of a bank account.

```mermaid
classDiagram
direction TB

Details of a bank account.http://langdale.com.au/2005/UML#attributeOperational account reference number.http://langdale.com.au/2005/UML#attributeName of bank where account is held.http://langdale.com.au/2005/UML#attributeBranch of bank where account is held.http://langdale.com.au/2005/UML#attributeNational identity number (or equivalent) of account holder.http://langdale.com.au/2005/UML#attributeName of account holder.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| accountNumber [0..1] | [String](#CIM17v40-String) | Operational account reference number. | |
| bankName [0..1] | [String](#CIM17v40-String) | Name of bank where account is held. | |
| branchCode [0..1] | [String](#CIM17v40-String) | Branch of bank where account is held. | |
| holderID [0..1] | [String](#CIM17v40-String) | National identity number (or equivalent) of account holder. | |
| holderName [0..1] | [String](#CIM17v40-String) | Name of account holder. | |

## CIM17v40-CIGREStandard
### (Attribute) CIGREStandard

Standard published by CIGRE (Council on Large Electric Systems).

```mermaid
classDiagram
direction TB

Standard published by CIGRE (Council on Large Electric Systems).http://langdale.com.au/2005/UML#attributeEdition of CIGRE standard.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeCIGRE standard number.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| standardEdition [0..1] | [CIGREStandardEditionKind](#CIM17v40-CIGREStandardEditionKind) | Edition of CIGRE standard. | |
| standardNumber [0..1] | [CIGREStandardKind](#CIM17v40-CIGREStandardKind) | CIGRE standard number. | |

## CIM17v40-ControlledAppliance
### (Attribute) ControlledAppliance

Appliance controlled with a PAN device control.

```mermaid
classDiagram
direction TB

Appliance controlled with a PAN device control.http://langdale.com.au/2005/UML#attributeTrue if the appliance is an electric vehicle.http://langdale.com.au/2005/UML#attributeTrue if the appliance is exterior lighting.http://langdale.com.au/2005/UML#attributeTrue if the appliance is a generation system.http://langdale.com.au/2005/UML#attributeTrue if the appliance is HVAC compressor or furnace.http://langdale.com.au/2005/UML#attributeTrue if the appliance is interior lighting.http://langdale.com.au/2005/UML#attributeTrue if the appliance is an irrigation pump.http://langdale.com.au/2005/UML#attributeTrue if the appliance is managed commercial or industrial load.http://langdale.com.au/2005/UML#attributeTrue if the appliance is a pool, pump, spa or jacuzzi.http://langdale.com.au/2005/UML#attributeTrue if the appliance is a simple miscellaneous load.http://langdale.com.au/2005/UML#attributeTrue if the appliance is a smart appliance.http://langdale.com.au/2005/UML#attributeTrue if the appliance is a stip or baseboard heater.http://langdale.com.au/2005/UML#attributeTrue if the appliance is a water heater.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| isElectricVehicle [0..1] | [Boolean](#CIM17v40-Boolean) | True if the appliance is an electric vehicle. | |
| isExteriorLighting [0..1] | [Boolean](#CIM17v40-Boolean) | True if the appliance is exterior lighting. | |
| isGenerationSystem [0..1] | [Boolean](#CIM17v40-Boolean) | True if the appliance is a generation system. | |
| isHvacCompressorOrFurnace [0..1] | [Boolean](#CIM17v40-Boolean) | True if the appliance is HVAC compressor or furnace. | |
| isInteriorLighting [0..1] | [Boolean](#CIM17v40-Boolean) | True if the appliance is interior lighting. | |
| isIrrigationPump [0..1] | [Boolean](#CIM17v40-Boolean) | True if the appliance is an irrigation pump. | |
| isManagedCommercialIndustrialLoad [0..1] | [Boolean](#CIM17v40-Boolean) | True if the appliance is managed commercial or industrial load. | |
| isPoolPumpSpaJacuzzi [0..1] | [Boolean](#CIM17v40-Boolean) | True if the appliance is a pool, pump, spa or jacuzzi. | |
| isSimpleMiscLoad [0..1] | [Boolean](#CIM17v40-Boolean) | True if the appliance is a simple miscellaneous load. | |
| isSmartAppliance [0..1] | [Boolean](#CIM17v40-Boolean) | True if the appliance is a smart appliance. | |
| isStripAndBaseboardHeater [0..1] | [Boolean](#CIM17v40-Boolean) | True if the appliance is a stip or baseboard heater. | |
| isWaterHeater [0..1] | [Boolean](#CIM17v40-Boolean) | True if the appliance is a water heater. | |

## CIM17v40-DINStandard
### (Attribute) DINStandard

Standard published by DIN (German Institute of Standards).

```mermaid
classDiagram
direction TB

Standard published by DIN (German Institute of Standards).http://langdale.com.au/2005/UML#attributeEdition of DIN standard.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeDIN standard number.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| standardEdition [0..1] | [DINStandardEditionKind](#CIM17v40-DINStandardEditionKind) | Edition of DIN standard. | |
| standardNumber [0..1] | [DINStandardKind](#CIM17v40-DINStandardKind) | DIN standard number. | |

## CIM17v40-DateInterval
### DateInterval

Interval between two dates.

```mermaid
classDiagram
direction TB

Interval between two dates.End date of this interval.http://langdale.com.au/2005/UML#attributeStart date of this interval.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| end [0..1] | [Date](#CIM17v40-Date) | End date of this interval. | |
| start [0..1] | [Date](#CIM17v40-Date) | Start date of this interval. | |

## CIM17v40-DateTimeInterval
### (Attribute) DateTimeInterval

Interval between two date and time points, where the interval includes the start time but excludes end time.

```mermaid
classDiagram
direction TB

Interval between two date and time points, where the interval includes the start time but excludes end time.http://langdale.com.au/2005/UML#compoundhttp://langdale.com.au/2005/UML#attributeEnd date and time of this interval. The end date and time where the interval is defined up to, but excluded.http://langdale.com.au/2005/UML#attributeStart date and time of this interval. The start date and time is included in the defined interval.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| end [0..1] | [DateTime](#CIM17v40-DateTime) | End date and time of this interval. The end date and time where the interval is defined up to, but excluded. | |
| start [0..1] | [DateTime](#CIM17v40-DateTime) | Start date and time of this interval. The start date and time is included in the defined interval. | |

## CIM17v40-DecimalQuantity
### (Attribute) DecimalQuantity

Quantity with decimal value and associated unit or currency information.

```mermaid
classDiagram
direction TB

Quantity with decimal value and associated unit or currency information.http://langdale.com.au/2005/UML#attributehttp://langdale.com.au/2005/UML#compoundCurrency of this quantity.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeUnit multiplier of this quantity.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeUnit of this quantity.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeValue of this quantity.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| currency [0..1] | [Currency](#CIM17v40-Currency) | Currency of this quantity. | |
| multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | Unit multiplier of this quantity. | |
| unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | Unit of this quantity. | |
| value [0..1] | [Decimal](#CIM17v40-Decimal) | Value of this quantity. | |

## CIM17v40-DeploymentDate
### (Attribute) DeploymentDate

Dates for deployment events of an asset. May have multiple deployment type dates for this device and a compound type allows a query to return multiple dates.

```mermaid
classDiagram
direction TB

Dates for deployment events of an asset. May have multiple deployment type dates for this device and a compound type allows a query to return multiple dates.http://langdale.com.au/2005/UML#compoundhttp://langdale.com.au/2005/UML#attributeDate and time asset most recently put in service.http://langdale.com.au/2005/UML#attributeDate and time asset most recently installed.http://langdale.com.au/2005/UML#attributeDate and time of asset deployment transition to not yet installed.http://langdale.com.au/2005/UML#attributeDate and time asset most recently taken out of service.http://langdale.com.au/2005/UML#attributeDate and time asset most recently removed.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| inServiceDate [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time asset most recently put in service. | |
| installedDate [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time asset most recently installed. | |
| notYetInstalledDate [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time of asset deployment transition to not yet installed. | |
| outOfServiceDate [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time asset most recently taken out of service. | |
| removedDate [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time asset most recently removed. | |

## CIM17v40-DobleStandard
### (Attribute) DobleStandard

Standard published by Doble.

```mermaid
classDiagram
direction TB

Standard published by Doble.http://langdale.com.au/2005/UML#attributeEdition of Doble standard.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeDoble standard number.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| standardEdition [0..1] | [DobleStandardEditionKind](#CIM17v40-DobleStandardEditionKind) | Edition of Doble standard. | |
| standardNumber [0..1] | [DobleStandardKind](#CIM17v40-DobleStandardKind) | Doble standard number. | |

## CIM17v40-Due
### (Attribute) Due

Details on amounts due for an account.

```mermaid
classDiagram
direction TB

Details on amounts due for an account.http://langdale.com.au/2005/UML#attributehttp://langdale.com.au/2005/UML#compoundPart of 'current' that constitutes the arrears portion.http://langdale.com.au/2005/UML#attributePart of 'current' that constitutes the charge portion: 'charges' = 'Charge.fixedPortion' + 'Charge.variablePortion'.http://langdale.com.au/2005/UML#attributeCurrent total amount now due: current = principle + arrears + interest + charges. Typically the rule for settlement priority is: interest dues, then arrears dues, then current dues, then charge dues.http://langdale.com.au/2005/UML#attributePart of 'current' that constitutes the interest portion.http://langdale.com.au/2005/UML#attributePart of 'current' that constitutes the portion of the principle amount currently due.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| arrears [0..1] | [Money](#CIM17v40-Money) | Part of 'current' that constitutes the arrears portion. | |
| charges [0..1] | [Money](#CIM17v40-Money) | Part of 'current' that constitutes the charge portion: 'charges' = 'Charge.fixedPortion' + 'Charge.variablePortion'. | |
| current [0..1] | [Money](#CIM17v40-Money) | Current total amount now due: current = principle + arrears + interest + charges. Typically the rule for settlement priority is: interest dues, then arrears dues, then current dues, then charge dues. | |
| interest [0..1] | [Money](#CIM17v40-Money) | Part of 'current' that constitutes the interest portion. | |
| principle [0..1] | [Money](#CIM17v40-Money) | Part of 'current' that constitutes the portion of the principle amount currently due. | |

## CIM17v40-EPAStandard
### (Attribute) EPAStandard

Standard published by EPA (United States Environmental Protection Agency).

```mermaid
classDiagram
direction TB

Standard published by EPA (United States Environmental Protection Agency).http://langdale.com.au/2005/UML#attributeEdition of EPA standard.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeEPA standard number.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| standardEdition [0..1] | [EPAStandardEditionKind](#CIM17v40-EPAStandardEditionKind) | Edition of EPA standard. | |
| standardNumber [0..1] | [EPAStandardKind](#CIM17v40-EPAStandardKind) | EPA standard number. | |

## CIM17v40-ElectronicAddress
### (Attribute) ElectronicAddress

Electronic address information.

```mermaid
classDiagram
direction TB

Electronic address information.http://langdale.com.au/2005/UML#compoundhttp://langdale.com.au/2005/UML#attributePrimary email address.http://langdale.com.au/2005/UML#attributeAlternate email address.http://langdale.com.au/2005/UML#attributeAddress on local area network.http://langdale.com.au/2005/UML#attributeMAC (Media Access Control) address.http://langdale.com.au/2005/UML#attributePassword needed to log in.http://langdale.com.au/2005/UML#attributeRadio address.http://langdale.com.au/2005/UML#attributeUser ID needed to log in, which can be for an individual person, an organisation, a location, etc.http://langdale.com.au/2005/UML#attributeWorld wide web address.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| email1 [0..1] | [String](#CIM17v40-String) | Primary email address. | |
| email2 [0..1] | [String](#CIM17v40-String) | Alternate email address. | |
| lan [0..1] | [String](#CIM17v40-String) | Address on local area network. | |
| mac [0..1] | [String](#CIM17v40-String) | MAC (Media Access Control) address. | |
| password [0..1] | [String](#CIM17v40-String) | Password needed to log in. | |
| radio [0..1] | [String](#CIM17v40-String) | Radio address. | |
| userID [0..1] | [String](#CIM17v40-String) | User ID needed to log in, which can be for an individual person, an organisation, a location, etc. | |
| web [0..1] | [String](#CIM17v40-String) | World wide web address. | |

## CIM17v40-EndDeviceCapability
### (Attribute) EndDeviceCapability

Inherent capabilities of an end device (i.e., the functions it supports).

```mermaid
classDiagram
direction TB

Inherent capabilities of an end device (i.e., the functions it supports).http://langdale.com.au/2005/UML#attributeTrue if autonomous DST (daylight saving time) function is supported.http://langdale.com.au/2005/UML#attributeTrue if communication function is supported.http://langdale.com.au/2005/UML#attributeTrue if connect and disconnect function is supported.http://langdale.com.au/2005/UML#attributeTrue if demand response function is supported.http://langdale.com.au/2005/UML#attributeTrue if electric metering function is supported.http://langdale.com.au/2005/UML#attributeTrue if gas metering function is supported.http://langdale.com.au/2005/UML#attributeTrue if metrology function is supported.http://langdale.com.au/2005/UML#attributeTrue if on request read function is supported.http://langdale.com.au/2005/UML#attributeTrue if outage history function is supported.http://langdale.com.au/2005/UML#attributeTrue if device performs pressure compensation for metered quantities.http://langdale.com.au/2005/UML#attributeTrue if pricing information is supported.http://langdale.com.au/2005/UML#attributeTrue if device produces pulse outputs.http://langdale.com.au/2005/UML#attributeTrue if relays programming function is supported.http://langdale.com.au/2005/UML#attributeTrue if reverse flow function is supported.http://langdale.com.au/2005/UML#attributeTrue if device performs super compressibility compensation for metered quantities.http://langdale.com.au/2005/UML#attributeTrue if device performs temperature compensation for metered quantities.http://langdale.com.au/2005/UML#attributeTrue if the displaying of text messages is supported.http://langdale.com.au/2005/UML#attributeTrue if water metering function is supported.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| autonomousDst [0..1] | [Boolean](#CIM17v40-Boolean) | True if autonomous DST (daylight saving time) function is supported. | |
| communication [0..1] | [Boolean](#CIM17v40-Boolean) | True if communication function is supported. | |
| connectDisconnect [0..1] | [Boolean](#CIM17v40-Boolean) | True if connect and disconnect function is supported. | |
| demandResponse [0..1] | [Boolean](#CIM17v40-Boolean) | True if demand response function is supported. | |
| electricMetering [0..1] | [Boolean](#CIM17v40-Boolean) | True if electric metering function is supported. | |
| gasMetering [0..1] | [Boolean](#CIM17v40-Boolean) | True if gas metering function is supported. | |
| metrology [0..1] | [Boolean](#CIM17v40-Boolean) | True if metrology function is supported. | |
| onRequestRead [0..1] | [Boolean](#CIM17v40-Boolean) | True if on request read function is supported. | |
| outageHistory [0..1] | [Boolean](#CIM17v40-Boolean) | True if outage history function is supported. | |
| pressureCompensation [0..1] | [Boolean](#CIM17v40-Boolean) | True if device performs pressure compensation for metered quantities. | |
| pricingInfo [0..1] | [Boolean](#CIM17v40-Boolean) | True if pricing information is supported. | |
| pulseOutput [0..1] | [Boolean](#CIM17v40-Boolean) | True if device produces pulse outputs. | |
| relaysProgramming [0..1] | [Boolean](#CIM17v40-Boolean) | True if relays programming function is supported. | |
| reverseFlow [0..1] | [Boolean](#CIM17v40-Boolean) | True if reverse flow function is supported. | |
| superCompressibilityCompensation [0..1] | [Boolean](#CIM17v40-Boolean) | True if device performs super compressibility compensation for metered quantities. | |
| temperatureCompensation [0..1] | [Boolean](#CIM17v40-Boolean) | True if device performs temperature compensation for metered quantities. | |
| textMessage [0..1] | [Boolean](#CIM17v40-Boolean) | True if the displaying of text messages is supported. | |
| waterMetering [0..1] | [Boolean](#CIM17v40-Boolean) | True if water metering function is supported. | |

## CIM17v40-EndDeviceTiming
### (Attribute) EndDeviceTiming

Timing for the control actions of end devices.

```mermaid
classDiagram
direction TB

Timing for the control actions of end devices.http://langdale.com.au/2005/UML#attributehttp://langdale.com.au/2005/UML#compoundDuration of the end device control action or the business event that is the subject of the end device control.http://langdale.com.au/2005/UML#attributeTrue if 'duration' is indefinite.http://langdale.com.au/2005/UML#attributeKind of randomisation to be applied to the end device control actions to be executed.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeStart and end time of an interval during which end device control actions are to be executed.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| duration [0..1] | [Minutes](#CIM17v40-Minutes) | Duration of the end device control action or the business event that is the subject of the end device control. | |
| durationIndefinite [0..1] | [Boolean](#CIM17v40-Boolean) | True if 'duration' is indefinite. | |
| randomisation [0..1] | [RandomisationKind](#CIM17v40-RandomisationKind) | Kind of randomisation to be applied to the end device control actions to be executed. | |
| interval [0..1] | [DateTimeInterval](#CIM17v40-DateTimeInterval) | Start and end time of an interval during which end device control actions are to be executed. | |

## CIM17v40-ExtensionItem
### (Attribute) ExtensionItem

Specifies the extensions list items

```mermaid
classDiagram
direction TB

Specifies the extensions list itemshttp://langdale.com.au/2005/UML#attributethe name of the extensionhttp://langdale.com.au/2005/UML#attributeThe type of the extensionhttp://langdale.com.au/2005/UML#attributethe value of the extensionhttp://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| extName [0..1] | [String](#CIM17v40-String) | the name of the extension | |
| extType [0..1] | [String](#CIM17v40-String) | The type of the extension | |
| extValue [0..1] | [String](#CIM17v40-String) | the value of the extension | |

## CIM17v40-ExtensionsList
### ExtensionsList

Specifies the enumeration of the extension item

```mermaid
classDiagram
direction TB

Specifies the enumeration of the extension itema compound type that defines the extension name, type and valuehttp://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| extensionsItem [0..1] | [ExtensionItem](#CIM17v40-ExtensionItem) | a compound type that defines the extension name, type and value | |

## CIM17v40-FaultImpedance
### (Attribute) FaultImpedance

Impedance description for the fault.

```mermaid
classDiagram
direction TB

Impedance description for the fault.http://langdale.com.au/2005/UML#compoundhttp://langdale.com.au/2005/UML#attributeThe resistance of the fault between phases and ground.http://langdale.com.au/2005/UML#attributeThe resistance of the fault between phases.http://langdale.com.au/2005/UML#attributeThe reactance of the fault between phases and ground.http://langdale.com.au/2005/UML#attributeThe reactance of the fault between phases.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| rGround [0..1] | [Resistance](#CIM17v40-Resistance) | The resistance of the fault between phases and ground. | |
| rLineToLine [0..1] | [Resistance](#CIM17v40-Resistance) | The resistance of the fault between phases. | |
| xGround [0..1] | [Reactance](#CIM17v40-Reactance) | The reactance of the fault between phases and ground. | |
| xLineToLine [0..1] | [Reactance](#CIM17v40-Reactance) | The reactance of the fault between phases. | |

## CIM17v40-FloatQuantity
### (Attribute) FloatQuantity

Quantity with float value and associated unit information.

```mermaid
classDiagram
direction TB

Quantity with float value and associated unit information.http://langdale.com.au/2005/UML#attributehttp://langdale.com.au/2005/UML#compoundUnit multiplier of this quantity.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeUnit of this quantity.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeValue of this quantity.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | Unit multiplier of this quantity. | |
| unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | Unit of this quantity. | |
| value [0..1] | [Float](#CIM17v40-Float) | Value of this quantity. | |

## CIM17v40-IECStandard
### (Attribute) IECStandard

Standard published by IEC (International Electrotechnical Commission).

```mermaid
classDiagram
direction TB

Standard published by IEC (International Electrotechnical Commission).http://langdale.com.au/2005/UML#attributeEdition of IEC standard.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeIEC standard number.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| standardEdition [0..1] | [IECStandardEditionKind](#CIM17v40-IECStandardEditionKind) | Edition of IEC standard. | |
| standardNumber [0..1] | [IECStandardKind](#CIM17v40-IECStandardKind) | IEC standard number. | |

## CIM17v40-IEEEStandard
### (Attribute) IEEEStandard

Standard published by IEEE (Institute of Electrical and Electronics Engineers).

```mermaid
classDiagram
direction TB

Standard published by IEEE (Institute of Electrical and Electronics Engineers).http://langdale.com.au/2005/UML#attributeEdition of IEEE standard.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeIEEE standard number.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| standardEdition [0..1] | [IEEEStandardEditionKind](#CIM17v40-IEEEStandardEditionKind) | Edition of IEEE standard. | |
| standardNumber [0..1] | [IEEEStandardKind](#CIM17v40-IEEEStandardKind) | IEEE standard number. | |

## CIM17v40-ISOStandard
### (Attribute) ISOStandard

Standard published by ISO (International Organization for Standardization).

```mermaid
classDiagram
direction TB

Standard published by ISO (International Organization for Standardization).http://langdale.com.au/2005/UML#attributeEdition of ISO standard.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeISO standard number.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| standardEdition [0..1] | [ISOStandardEditionKind](#CIM17v40-ISOStandardEditionKind) | Edition of ISO standard. | |
| standardNumber [0..1] | [ISOStandardKind](#CIM17v40-ISOStandardKind) | ISO standard number. | |

## CIM17v40-InUseDate
### (Attribute) InUseDate

Dates associated with asset 'in use' status. May have multiple in use dates for this device and a compound type allows a query to return multiple dates.

```mermaid
classDiagram
direction TB

Dates associated with asset 'in use' status. May have multiple in use dates for this device and a compound type allows a query to return multiple dates.http://langdale.com.au/2005/UML#compoundhttp://langdale.com.au/2005/UML#attributeDate asset was most recently put in use.http://langdale.com.au/2005/UML#attributeDate of most recent asset transition to not ready for use state.http://langdale.com.au/2005/UML#attributeDate of most recent asset transition to ready for use state.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| inUseDate [0..1] | [Date](#CIM17v40-Date) | Date asset was most recently put in use. | |
| notReadyForUseDate [0..1] | [Date](#CIM17v40-Date) | Date of most recent asset transition to not ready for use state. | |
| readyForUseDate [0..1] | [Date](#CIM17v40-Date) | Date of most recent asset transition to ready for use state. | |

## CIM17v40-IntegerQuantity
### (Attribute) IntegerQuantity

Quantity with integer value and associated unit information.

```mermaid
classDiagram
direction TB

Quantity with integer value and associated unit information.http://langdale.com.au/2005/UML#attributehttp://langdale.com.au/2005/UML#compoundUnit multiplier of this quantity.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeUnit of this quantity.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeValue of this quantity.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | Unit multiplier of this quantity. | |
| unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | Unit of this quantity. | |
| value [0..1] | [Integer](#CIM17v40-Integer) | Value of this quantity. | |

## CIM17v40-LaborelecStandard
### (Attribute) LaborelecStandard

Standard published by Laborelec.

```mermaid
classDiagram
direction TB

Standard published by Laborelec.http://langdale.com.au/2005/UML#attributeEdition of Laborelec standard.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeLaborelec standard number.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| standardEdition [0..1] | [LaborelecStandardEditionKind](#CIM17v40-LaborelecStandardEditionKind) | Edition of Laborelec standard. | |
| standardNumber [0..1] | [LaborelecStandardKind](#CIM17v40-LaborelecStandardKind) | Laborelec standard number. | |

## CIM17v40-LifecycleDate
### (Attribute) LifecycleDate

Dates for asset lifecycle state changes. May have multiple lifecycle dates for this device and a compound type allows a query to return multiple dates.

```mermaid
classDiagram
direction TB

Dates for asset lifecycle state changes. May have multiple lifecycle dates for this device and a compound type allows a query to return multiple dates.http://langdale.com.au/2005/UML#compoundhttp://langdale.com.au/2005/UML#attributeDate current installation was completed, which may not be the same as the in-service date. Asset may have been installed at other locations previously. Ignored if asset is (1) not currently installed (e.g., stored in a depot) or (2) not intended to be installed (e.g., vehicle, tool).http://langdale.com.au/2005/UML#attributeDate the asset was manufactured.http://langdale.com.au/2005/UML#attributeDate the asset was purchased. Note that even though an asset may have been purchased, it may not have been received into inventory at the time of purchase.http://langdale.com.au/2005/UML#attributeDate the asset was received and first placed into inventory.http://langdale.com.au/2005/UML#attributeDate when the asset was last removed from service. Ignored if (1) not intended to be in service, or (2) currently in service.http://langdale.com.au/2005/UML#attributeDate the asset is permanently retired from service and may be scheduled for disposal. Ignored if asset is (1) currently in service, or (2) permanently removed from service.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| installationDate [0..1] | [Date](#CIM17v40-Date) | Date current installation was completed, which may not be the same as the in-service date. Asset may have been installed at other locations previously. Ignored if asset is (1) not currently installed (e.g., stored in a depot) or (2) not intended to be installed (e.g., vehicle, tool). | |
| manufacturedDate [0..1] | [Date](#CIM17v40-Date) | Date the asset was manufactured. | |
| purchaseDate [0..1] | [Date](#CIM17v40-Date) | Date the asset was purchased. Note that even though an asset may have been purchased, it may not have been received into inventory at the time of purchase. | |
| receivedDate [0..1] | [Date](#CIM17v40-Date) | Date the asset was received and first placed into inventory. | |
| removalDate [0..1] | [Date](#CIM17v40-Date) | Date when the asset was last removed from service. Ignored if (1) not intended to be in service, or (2) currently in service. | |
| retiredDate [0..1] | [Date](#CIM17v40-Date) | Date the asset is permanently retired from service and may be scheduled for disposal. Ignored if asset is (1) currently in service, or (2) permanently removed from service. | |

## CIM17v40-LineDetail
### (Attribute) LineDetail

Details on an amount line, with rounding, date and note.

```mermaid
classDiagram
direction TB

Details on an amount line, with rounding, date and note.http://langdale.com.au/2005/UML#attributeAmount for this line item.http://langdale.com.au/2005/UML#attributeDate and time when this line was created in the application process.http://langdale.com.au/2005/UML#attributeFree format note relevant to this line.http://langdale.com.au/2005/UML#attributeTotalised monetary value of all errors due to process rounding or truncating that is not reflected in 'amount'.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| amount [0..1] | [Money](#CIM17v40-Money) | Amount for this line item. | |
| dateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time when this line was created in the application process. | |
| note [0..1] | [String](#CIM17v40-String) | Free format note relevant to this line. | |
| rounding [0..1] | [Money](#CIM17v40-Money) | Totalised monetary value of all errors due to process rounding or truncating that is not reflected in 'amount'. | |

## CIM17v40-MonthDayInterval
### MonthDayInterval

Interval between two times specified as month and day.

```mermaid
classDiagram
direction TB

Interval between two times specified as month and day.End time of this interval.http://langdale.com.au/2005/UML#attributeStart time of this interval.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| end [0..1] | [MonthDay](#CIM17v40-MonthDay) | End time of this interval. | |
| start [0..1] | [MonthDay](#CIM17v40-MonthDay) | Start time of this interval. | |

## CIM17v40-PowerSystemProjectLifecycleToBeDeleted
### PowerSystemProjectLifecycleToBeDeleted

Represent the base lifecycle of a functional model change that could be a construction of new elements.

```mermaid
classDiagram
direction TB

Represent the base lifecycle of a functional model change that could be a construction of new elements.The date the Power System Project is in cancelled stage.http://langdale.com.au/2005/UML#attributeThe date Power System Project is in committed stage.http://langdale.com.au/2005/UML#attributeThe date Power System Project is in build stage.http://langdale.com.au/2005/UML#attributeThe date Power System Project is in planning stage.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| cancelled [0..1] | [Date](#CIM17v40-Date) | The date the Power System Project is in cancelled stage. | |
| committed [0..1] | [Date](#CIM17v40-Date) | The date Power System Project is in committed stage. | |
| inBuild [0..1] | [Date](#CIM17v40-Date) | The date Power System Project is in build stage. | |
| inPlan [0..1] | [Date](#CIM17v40-Date) | The date Power System Project is in planning stage. | |

## CIM17v40-Priority
### (Attribute) Priority

Priority definition.

```mermaid
classDiagram
direction TB

Priority definition.http://langdale.com.au/2005/UML#attributeJustification for 'rank'.http://langdale.com.au/2005/UML#attributePriority level; lower number means high priority inside the same 'type'.http://langdale.com.au/2005/UML#attributeType describing 'rank'; e.g., high, emergency, etc.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| justification [0..1] | [String](#CIM17v40-String) | Justification for 'rank'. | |
| rank [0..1] | [Integer](#CIM17v40-Integer) | Priority level; lower number means high priority inside the same 'type'. | |
| type [0..1] | [String](#CIM17v40-String) | Type describing 'rank'; e.g., high, emergency, etc. | |

## CIM17v40-Ratio
### (Attribute) Ratio

Fraction specified explicitly with a numerator and denominator, which can be used to calculate the quotient.

```mermaid
classDiagram
direction TB

Fraction specified explicitly with a numerator and denominator, which can be used to calculate the quotient.http://langdale.com.au/2005/UML#compoundhttp://langdale.com.au/2005/UML#attributeThe part of a fraction that is below the line and that functions as the divisor of the numerator.http://langdale.com.au/2005/UML#attributeThe part of a fraction that is above the line and signifies the number to be divided by the denominator.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| denominator [0..1] | [Float](#CIM17v40-Float) | The part of a fraction that is below the line and that functions as the divisor of the numerator. | |
| numerator [0..1] | [Float](#CIM17v40-Float) | The part of a fraction that is above the line and signifies the number to be divided by the denominator. | |

## CIM17v40-RationalNumber
### (Attribute) RationalNumber

Rational number = 'numerator' / 'denominator'.

```mermaid
classDiagram
direction TB

Rational number = 'numerator' / 'denominator'.http://langdale.com.au/2005/UML#attributeDenominator. Value 1 indicates the number is a simple integer.http://langdale.com.au/2005/UML#attributeNumerator.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| denominator [0..1] | [Integer](#CIM17v40-Integer) | Denominator. Value 1 indicates the number is a simple integer. | |
| numerator [0..1] | [Integer](#CIM17v40-Integer) | Numerator. | |

## CIM17v40-ReadingInterharmonic
### (Attribute) ReadingInterharmonic

Interharmonics are represented as a rational number 'numerator' / 'denominator', and harmonics are represented using the same mechanism and identified by 'denominator'=1.

```mermaid
classDiagram
direction TB

Interharmonics are represented as a rational number 'numerator' / 'denominator', and harmonics are represented using the same mechanism and identified by 'denominator'=1.http://langdale.com.au/2005/UML#attributeInterharmonic denominator. Value 0 means not applicable. Value 2 is used in combination with 'numerator'=1 to represent interharmonic 1/2. Finally, value 1 indicates the harmonic of the order specified with 'numerator'.http://langdale.com.au/2005/UML#attributeInterharmonic numerator. Value 0 means not applicable. Value 1 is used in combination with 'denominator'=2 to represent interharmonic 1/2, and with 'denominator'=1 it represents fundamental frequency. Finally, values greater than 1 indicate the harmonic of that order (e.g., 'numerator'=5 is the fifth harmonic).http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| denominator [0..1] | [Integer](#CIM17v40-Integer) | Interharmonic denominator. Value 0 means not applicable. Value 2 is used in combination with 'numerator'=1 to represent interharmonic 1/2. Finally, value 1 indicates the harmonic of the order specified with 'numerator'. | |
| numerator [0..1] | [Integer](#CIM17v40-Integer) | Interharmonic numerator. Value 0 means not applicable. Value 1 is used in combination with 'denominator'=2 to represent interharmonic 1/2, and with 'denominator'=1 it represents fundamental frequency. Finally, values greater than 1 indicate the harmonic of that order (e.g., 'numerator'=5 is the fifth harmonic). | |

## CIM17v40-RelativeDisplacement
### (Attribute) RelativeDisplacement

Vertical displacement relative to either sealevel, ground or the center of the earth.

```mermaid
classDiagram
direction TB

Vertical displacement relative to either sealevel, ground or the center of the earth.http://langdale.com.au/2005/UML#attributehttp://langdale.com.au/2005/UML#attributehttp://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| displacement [0..1] | [Displacement](#CIM17v40-Displacement) | | |
| kind [0..1] | [RelativeDisplacementKind](#CIM17v40-RelativeDisplacementKind) | | |

## CIM17v40-RemoteConnectDisconnectInfo
### (Attribute) RemoteConnectDisconnectInfo

Details of remote connect and disconnect function.

```mermaid
classDiagram
direction TB

Details of remote connect and disconnect function.http://langdale.com.au/2005/UML#attributehttp://langdale.com.au/2005/UML#compoundSetting of the timeout elapsed time.http://langdale.com.au/2005/UML#attributeVoltage limit on customer side of RCD switch above which the connect should not be made.http://langdale.com.au/2005/UML#attributeLimit of energy before disconnect.http://langdale.com.au/2005/UML#attributeStart date and time to accumulate energy for energy usage limiting.http://langdale.com.au/2005/UML#attributeWarning energy limit, used to trigger event code that energy usage is nearing limit.http://langdale.com.au/2005/UML#attributeTrue if the RCD switch has to be armed before a connect action can be initiated.http://langdale.com.au/2005/UML#attributeTrue if the RCD switch has to be armed before a disconnect action can be initiated.http://langdale.com.au/2005/UML#attributeTrue if the energy usage is limited and the customer will be disconnected if they go over the limit.http://langdale.com.au/2005/UML#attributeTrue if load limit has to be checked to issue an immediate disconnect (after a connect) if load is over the limit.http://langdale.com.au/2005/UML#attributeTrue if voltage limit has to be checked to prevent connect if voltage is over the limit.http://langdale.com.au/2005/UML#attributeLoad limit above which the connect should either not take place or should cause an immediate disconnect.http://langdale.com.au/2005/UML#attributeTrue if pushbutton has to be used for connect.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| armedTimeout [0..1] | [Seconds](#CIM17v40-Seconds) | Setting of the timeout elapsed time. | |
| customerVoltageLimit [0..1] | [Voltage](#CIM17v40-Voltage) | Voltage limit on customer side of RCD switch above which the connect should not be made. | |
| energyLimit [0..1] | [RealEnergy](#CIM17v40-RealEnergy) | Limit of energy before disconnect. | |
| energyUsageStartDateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Start date and time to accumulate energy for energy usage limiting. | |
| energyUsageWarning [0..1] | [RealEnergy](#CIM17v40-RealEnergy) | Warning energy limit, used to trigger event code that energy usage is nearing limit. | |
| isArmConnect [0..1] | [Boolean](#CIM17v40-Boolean) | True if the RCD switch has to be armed before a connect action can be initiated. | |
| isArmDisconnect [0..1] | [Boolean](#CIM17v40-Boolean) | True if the RCD switch has to be armed before a disconnect action can be initiated. | |
| isEnergyLimiting [0..1] | [Boolean](#CIM17v40-Boolean) | True if the energy usage is limited and the customer will be disconnected if they go over the limit. | |
| needsPowerLimitCheck [0..1] | [Boolean](#CIM17v40-Boolean) | True if load limit has to be checked to issue an immediate disconnect (after a connect) if load is over the limit. | |
| needsVoltageLimitCheck [0..1] | [Boolean](#CIM17v40-Boolean) | True if voltage limit has to be checked to prevent connect if voltage is over the limit. | |
| powerLimit [0..1] | [ActivePower](#CIM17v40-ActivePower) | Load limit above which the connect should either not take place or should cause an immediate disconnect. | |
| usePushbutton [0..1] | [Boolean](#CIM17v40-Boolean) | True if pushbutton has to be used for connect. | |

## CIM17v40-ServicePointOutageSummary
### (Attribute) ServicePointOutageSummary

Summary counts of service points affected by an outage. These counts are sometimes referred to as total and critical customer count.

```mermaid
classDiagram
direction TB

Summary counts of service points affected by an outage. These counts are sometimes referred to as total and critical customer count.http://langdale.com.au/2005/UML#compoundhttp://langdale.com.au/2005/UML#attributeNumber of critical service (delivery) points affected by an outage.http://langdale.com.au/2005/UML#attributeNumber of all service (delivery) points affected by an outage.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| criticalCount [0..1] | [Integer](#CIM17v40-Integer) | Number of critical service (delivery) points affected by an outage. | |
| totalCount [0..1] | [Integer](#CIM17v40-Integer) | Number of all service (delivery) points affected by an outage. | |

## CIM17v40-Status
### (Attribute) Status

Current status information relevant to an entity.

```mermaid
classDiagram
direction TB

Current status information relevant to an entity.http://langdale.com.au/2005/UML#compoundhttp://langdale.com.au/2005/UML#attributeDate and time for which status 'value' applies.http://langdale.com.au/2005/UML#attributeReason code or explanation for why an object went to the current status 'value'.http://langdale.com.au/2005/UML#attributePertinent information regarding the current 'value', as free form text.http://langdale.com.au/2005/UML#attributeStatus value at 'dateTime'; prior status changes may have been kept in instances of activity records associated with the object to which this status applies.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| dateTime [0..1] | [DateTime](#CIM17v40-DateTime) | Date and time for which status 'value' applies. | |
| reason [0..1] | [String](#CIM17v40-String) | Reason code or explanation for why an object went to the current status 'value'. | |
| remark [0..1] | [String](#CIM17v40-String) | Pertinent information regarding the current 'value', as free form text. | |
| value [0..1] | [String](#CIM17v40-String) | Status value at 'dateTime'; prior status changes may have been kept in instances of activity records associated with the object to which this status applies. | |

## CIM17v40-StreetAddress
### (Attribute) StreetAddress

General purpose street and postal address information.

```mermaid
classDiagram
direction TB

General purpose street and postal address information.http://langdale.com.au/2005/UML#attributehttp://langdale.com.au/2005/UML#compoundThe language in which the address is specified, using ISO 639-1 two digit language code.http://langdale.com.au/2005/UML#attributePost office box.http://langdale.com.au/2005/UML#attributePostal code for the address.http://langdale.com.au/2005/UML#attributeStatus of this address.http://langdale.com.au/2005/UML#attributeStreet detail.http://langdale.com.au/2005/UML#attributeTown detail.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| language [0..1] | [String](#CIM17v40-String) | The language in which the address is specified, using ISO 639-1 two digit language code. | |
| poBox [0..1] | [String](#CIM17v40-String) | Post office box. | |
| postalCode [0..1] | [String](#CIM17v40-String) | Postal code for the address. | |
| status [0..1] | [Status](#CIM17v40-Status) | Status of this address. | |
| streetDetail [0..1] | [StreetDetail](#CIM17v40-StreetDetail) | Street detail. | |
| townDetail [0..1] | [TownDetail](#CIM17v40-TownDetail) | Town detail. | |

## CIM17v40-StreetDetail
### (Attribute) StreetDetail

Street details, in the context of address.

```mermaid
classDiagram
direction TB

Street details, in the context of address.http://langdale.com.au/2005/UML#compoundhttp://langdale.com.au/2005/UML#attributeFirst line of a free form address or some additional address information (for example a mail stop).http://langdale.com.au/2005/UML#attribute(if applicable) Second line of a free form address.http://langdale.com.au/2005/UML#attribute(if applicable) Third line of a free form address.http://langdale.com.au/2005/UML#attribute(if applicable) In certain cases the physical location of the place of interest does not have a direct point of entry from the street, but may be located inside a larger structure such as a building, complex, office block, apartment, etc.http://langdale.com.au/2005/UML#attribute(if applicable) Utilities often make use of external reference systems, such as those of the town-planner's department or surveyor general's mapping system, that allocate global reference codes to streets.http://langdale.com.au/2005/UML#attributeThe identification by name or number, expressed as text, of the floor in the building as part of this address.http://langdale.com.au/2005/UML#attributeName of the street.http://langdale.com.au/2005/UML#attributeDesignator of the specific location on the street.http://langdale.com.au/2005/UML#attributePrefix to the street name. For example: North, South, East, West.http://langdale.com.au/2005/UML#attributeSuffix to the street name. For example: North, South, East, West.http://langdale.com.au/2005/UML#attributeNumber of the apartment or suite.http://langdale.com.au/2005/UML#attributeType of street. Examples include: street, circle, boulevard, avenue, road, drive, etc.http://langdale.com.au/2005/UML#attributeTrue if this street is within the legal geographical boundaries of the specified town (default).http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| addressGeneral [0..1] | [String](#CIM17v40-String) | First line of a free form address or some additional address information (for example a mail stop). | |
| addressGeneral2 [0..1] | [String](#CIM17v40-String) | (if applicable) Second line of a free form address. | |
| addressGeneral3 [0..1] | [String](#CIM17v40-String) | (if applicable) Third line of a free form address. | |
| buildingName [0..1] | [String](#CIM17v40-String) | (if applicable) In certain cases the physical location of the place of interest does not have a direct point of entry from the street, but may be located inside a larger structure such as a building, complex, office block, apartment, etc. | |
| code [0..1] | [String](#CIM17v40-String) | (if applicable) Utilities often make use of external reference systems, such as those of the town-planner's department or surveyor general's mapping system, that allocate global reference codes to streets. | |
| floorIdentification [0..1] | [String](#CIM17v40-String) | The identification by name or number, expressed as text, of the floor in the building as part of this address. | |
| name [0..1] | [String](#CIM17v40-String) | Name of the street. | |
| number [0..1] | [String](#CIM17v40-String) | Designator of the specific location on the street. | |
| prefix [0..1] | [String](#CIM17v40-String) | Prefix to the street name. For example: North, South, East, West. | |
| suffix [0..1] | [String](#CIM17v40-String) | Suffix to the street name. For example: North, South, East, West. | |
| suiteNumber [0..1] | [String](#CIM17v40-String) | Number of the apartment or suite. | |
| type [0..1] | [String](#CIM17v40-String) | Type of street. Examples include: street, circle, boulevard, avenue, road, drive, etc. | |
| withinTownLimits [0..1] | [Boolean](#CIM17v40-Boolean) | True if this street is within the legal geographical boundaries of the specified town (default). | |

## CIM17v40-StringQuantity
### (Attribute) StringQuantity

Quantity with string value (when it is not important whether it is an integral or a floating point number) and associated unit information.

```mermaid
classDiagram
direction TB

Quantity with string value (when it is not important whether it is an integral or a floating point number) and associated unit information.http://langdale.com.au/2005/UML#compoundhttp://langdale.com.au/2005/UML#attributeUnit multiplier of this quantity.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeUnit of this quantity.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeValue of this quantity.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| multiplier [0..1] | [UnitMultiplier](#CIM17v40-UnitMultiplier) | Unit multiplier of this quantity. | |
| unit [0..1] | [UnitSymbol](#CIM17v40-UnitSymbol) | Unit of this quantity. | |
| value [0..1] | [String](#CIM17v40-String) | Value of this quantity. | |

## CIM17v40-TAPPIStandard
### (Attribute) TAPPIStandard

Standard published by TAPPI.

```mermaid
classDiagram
direction TB

Standard published by TAPPI.http://langdale.com.au/2005/UML#attributeEdition of TAPPI standard.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeTAPPI standard number.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| standardEdition [0..1] | [TAPPIStandardEditionKind](#CIM17v40-TAPPIStandardEditionKind) | Edition of TAPPI standard. | |
| standardNumber [0..1] | [TAPPIStandardKind](#CIM17v40-TAPPIStandardKind) | TAPPI standard number. | |

## CIM17v40-TelephoneNumber
### (Attribute) TelephoneNumber

Telephone number.

```mermaid
classDiagram
direction TB

Telephone number.http://langdale.com.au/2005/UML#compoundhttp://langdale.com.au/2005/UML#attribute(if applicable) Area or region code.http://langdale.com.au/2005/UML#attributeCity code.http://langdale.com.au/2005/UML#attributeCountry code.http://langdale.com.au/2005/UML#attribute(if applicable) Dial out code, for instance to call outside an enterprise.http://langdale.com.au/2005/UML#attribute(if applicable) Extension for this telephone number.http://langdale.com.au/2005/UML#attribute(if applicable) Prefix used when calling an international number.http://langdale.com.au/2005/UML#attributePhone number according to International Telecommunication Union (ITU) E.164.http://langdale.com.au/2005/UML#attributeMain (local) part of this telephone number.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| areaCode [0..1] | [String](#CIM17v40-String) | (if applicable) Area or region code. | |
| cityCode [0..1] | [String](#CIM17v40-String) | City code. | |
| countryCode [0..1] | [String](#CIM17v40-String) | Country code. | |
| dialOut [0..1] | [String](#CIM17v40-String) | (if applicable) Dial out code, for instance to call outside an enterprise. | |
| extension [0..1] | [String](#CIM17v40-String) | (if applicable) Extension for this telephone number. | |
| internationalPrefix [0..1] | [String](#CIM17v40-String) | (if applicable) Prefix used when calling an international number. | |
| ituPhone [0..1] | [String](#CIM17v40-String) | Phone number according to International Telecommunication Union (ITU) E.164. | |
| localNumber [0..1] | [String](#CIM17v40-String) | Main (local) part of this telephone number. | |

## CIM17v40-TimeInterval
### (Attribute) TimeInterval

Interval between two times.

```mermaid
classDiagram
direction TB

Interval between two times.http://langdale.com.au/2005/UML#compoundhttp://langdale.com.au/2005/UML#attributeEnd time of this interval.http://langdale.com.au/2005/UML#attributeStart time of this interval.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| end [0..1] | [Time](#CIM17v40-Time) | End time of this interval. | |
| start [0..1] | [Time](#CIM17v40-Time) | Start time of this interval. | |

## CIM17v40-TownDetail
### (Attribute) TownDetail

Town details, in the context of address.

```mermaid
classDiagram
direction TB

Town details, in the context of address.http://langdale.com.au/2005/UML#compoundhttp://langdale.com.au/2005/UML#attributeTown code.http://langdale.com.au/2005/UML#attributeName of the country.http://langdale.com.au/2005/UML#attributeTown name.http://langdale.com.au/2005/UML#attributeTown section. For example, it is common for there to be 36 sections per township.http://langdale.com.au/2005/UML#attributeName of the state or province.http://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| code [0..1] | [String](#CIM17v40-String) | Town code. | |
| country [0..1] | [String](#CIM17v40-String) | Name of the country. | |
| name [0..1] | [String](#CIM17v40-String) | Town name. | |
| section [0..1] | [String](#CIM17v40-String) | Town section. For example, it is common for there to be 36 sections per township. | |
| stateOrProvince [0..1] | [String](#CIM17v40-String) | Name of the state or province. | |

## CIM17v40-UKMinistryOfDefenceStandard
### (Attribute) UKMinistryOfDefenceStandard

Standard published by United Kingdom Ministry of Defence.

```mermaid
classDiagram
direction TB

Standard published by United Kingdom Ministry of Defence.http://langdale.com.au/2005/UML#compoundhttp://langdale.com.au/2005/UML#attributeEdition of UK Ministry of Defence standard.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeUK Ministry of Defence standard number.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| standardEdition [0..1] | [UKMinistryOfDefenceStandardEditionKind](#CIM17v40-UKMinistryOfDefenceStandardEditionKind) | Edition of UK Ministry of Defence standard. | |
| standardNumber [0..1] | [UKMinistryofDefenceStandardKind](#CIM17v40-UKMinistryofDefenceStandardKind) | UK Ministry of Defence standard number. | |

## CIM17v40-Version
### (Attribute) Version

This is the version for a group of devices or objects. This could be used to track the version for any group of objects or devices over time. For example, for a DERGroup, the requesting system may want to get the details of a specific version of a DERGroup.

```mermaid
classDiagram
direction TB

This is the version for a group of devices or objects. This could be used to track the version for any group of objects or devices over time. For example, for a DERGroup, the requesting system may want to get the details of a specific version of a DERGroup.http://langdale.com.au/2005/UML#attributedate of this versionhttp://langdale.com.au/2005/UML#attributemajor release level for this versionhttp://langdale.com.au/2005/UML#attributeminor release level for this versionhttp://langdale.com.au/2005/UML#attributerevision level for this versionhttp://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| date [0..1] | [DateTime](#CIM17v40-DateTime) | date of this version | |
| major [0..1] | [Integer](#CIM17v40-Integer) | major release level for this version | |
| minor [0..1] | [Integer](#CIM17v40-Integer) | minor release level for this version | |
| revision [0..1] | [Integer](#CIM17v40-Integer) | revision level for this version | |

## CIM17v40-WEPStandard
### (Attribute) WEPStandard

Standard published by Westinghouse - a WEP (Westinghouse Engineering Procedure).

```mermaid
classDiagram
direction TB

Standard published by Westinghouse - a WEP (Westinghouse Engineering Procedure).http://langdale.com.au/2005/UML#compoundhttp://langdale.com.au/2005/UML#attributeEdition of WEP standard.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attributeWEP standard number.http://langdale.com.au/2005/UML#enumerationhttp://langdale.com.au/2005/UML#attribute
```


#### Members

| name | type | description | mapping |
|------|------|-------------|---------|
| standardEdition [0..1] | [WEPStandardEditionKind](#CIM17v40-WEPStandardEditionKind) | Edition of WEP standard. | |
| standardNumber [0..1] | [WEPStandardKind](#CIM17v40-WEPStandardKind) | WEP standard number. | |


## Enumerations

CIM17v40-ADSInstructionTypeCommitment
### ADSInstructionTypeCommitment


| name | description |
|------|-------------|
| SHUT_DOWN | |
| START_UP | |

CIM17v40-ADSInstructionTypeOOS
### ADSInstructionTypeOOS

MIN_CONSTRAINT

MAX_CONSTRAINT

FIXED_CONSTRAINT


| name | description |
|------|-------------|
| FIXED_CONSTRAINT | |
| MAX_CONSTRAINT | |
| MIN_CONSTRAINT | |

CIM17v40-ASTMStandardEditionKind
### (Attribute) ASTMStandardEditionKind

List of editions of ASTM standards.


| name | description |
|------|-------------|
| 00(2005) | 00(2005) standard edition. |
| 00(2005)e1 | 00(2005)e1 standard edition. |
| 00(2010) | 00(2010) standard edition. |
| 01 | 01 standard edition. |
| 01a(2007) | 01a(2007) standard edition. |
| 01e1 | 01e1 standard edition. |
| 02 | 02 standard edition. |
| 02(2007) | 02(2007) standard edition. |
| 02(2008) | 02(2008) standard edition. |
| 02(2009) | 02(2009) standard edition. |
| 02(2012) | 02(2012) standard edition. |
| 02(2014) | 02(2014) standard edition. |
| 02a | 02a standard edition. |
| 02b | 02b standard edition. |
| 02e1 | 02e1 standard edition. |
| 03 | 03 standard edition. |
| 03(2008) | 03(2008) standard edition. |
| 03(2014) | 03(2014) standard edition. |
| 03a | 03a standard edition. |
| 04 | 04 standard edition. |
| 04a | 04a standard edition. |
| 04ae1 | 04ae1 standard edition. |
| 04e1 | 04e1 standard edition. |
| 04e2 | 04e2 standard edition. |
| 05 | 05 standard edition. |
| 05(2010) | 05(2010) standard edition. |
| 05a | 05a standard edition. |
| 05a(2010) | 05a(2010) standard edition. |
| 06 | 06 standard edition. |
| 07 | 07 standard edition. |
| 07(2013) | 07(2013) standard edition. |
| 08 | 08 standard edition. |
| 08e1 | 08e1 standard edition. |
| 09 | 09 standard edition. |
| 09(2013) | 09(2013) standard edition. |
| 10 | 10 standard edition. |
| 10a | 10a standard edition. |
| 11 | 11 standard edition. |
| 11a | 11a standard edition. |
| 12 | 12 standard edition. |
| 12a | 12a standard edition. |
| 12b | 12b standard edition. |
| 13 | 13 standard edition. |
| 13e1 | 13e1 standard edition. |
| 14 | 14 standard edition. |
| 14a | 14a standard edition. |
| 14e1 | 14e1 standard edition. |
| 14e2 | 14e2 standard edition. |
| 15 | 15 standard edition. |
| 15a | 15a standard edition. |
| 65 | 65 standard edition. |
| 71 | 71 standard edition. |
| 74 | 74 standard edition. |
| 80e1 | 80e1 standard edition. |
| 82 | 82 standard edition. |
| 83(1996)e1 | 83(1996)e1 standard edition. |
| 85 | 85 standard edition. |
| 85(1990)e1 | 85(1990)e1 standard edition. |
| 87(1995) | 87(1995) standard edition. |
| 87e1 | 87e1 standard edition. |
| 88 | 88 standard edition. |
| 90e1 | 90e1 standard edition. |
| 91 | 91 standard edition. |
| 92 | 92 standard edition. |
| 94 | 94 standard edition. |
| 94(1999) | 94(1999) standard edition. |
| 94(2004) | 94(2004) standard edition. |
| 94(2010) | 94(2010) standard edition. |
| 94e1 | 94e1 standard edition. |
| 95 | 95 standard edition. |
| 95(2000)e1 | 95(2000)e1 standard edition. |
| 96 | 96 standard edition. |
| 96(2002)e1 | 96(2002)e1 standard edition. |
| 96a | 96a standard edition. |
| 96e1 | 96e1 standard edition. |
| 97 | 97 standard edition. |
| 97(2002) | 97(2002) standard edition. |
| 97(2003) | 97(2003) standard edition. |
| 97(2008) | 97(2008) standard edition. |
| 97a | 97a standard edition. |
| 97a(2004) | 97a(2004) standard edition. |
| 98 | 98 standard edition. |
| 98a | 98a standard edition. |
| 99 | 99 standard edition. |
| 99(2004)e1 | 99(2004)e1 standard edition. |
| 99(2005) | 99(2005) standard edition. |
| 99(2009) | 99(2009) standard edition. |
| 99a | 99a standard edition. |
| 99a(2004) | 99a(2004) standard edition. |
| 99e1 | 99e1 standard edition. |
| 99e2 | 99e2 standard edition. |
| none | No kind of standard. |
| unknown | Unknown kind of standard. |

CIM17v40-ASTMStandardKind
### (Attribute) ASTMStandardKind

List of ASTM standards.


| name | description |
|------|-------------|
| D1169 | Standard Test Method for Specific Resistance (Resistivity) of Electrical Insulating Liquids. |
| D1275 | Standard Test Method for Corrosive Sulfur in Electrical Insulating Oils. |
| D1298 | Standard Test Method for Density, Relative Density, or API Gravity of Crude Petroleum and Liquid Petroleum Products by Hydrometer Method -or-Standard Test Method for Density, Relative Density (Specific Gravity), or API Gravity of Crude Petroleum and Liquid Petroleum Products by Hydrometer Method. |
| D149 | Standard Test Method for Dielectric Breakdown Voltage and Dielectric Strength of Solid Electrical Insulating Materials at Commercial Power Frequencies. |
| D1500 | Standard Test Method for ASTM Color of Petroleum Products (ASTM Color Scale). |
| D1524 | Standard Test Method for Visual Examination of Used Electrical Insulating Oils of Petroleum Origin in the Field. |
| D1533 | Standard Test Method for Water in Insulating Liquids by Coulometric Karl Fischer Titration. |
| D1816 | Standard Test Method for Dielectric Breakdown Voltage of Insulating Liquids Using VDE Electrodes. |
| D2029 | Standard Test Methods for Water Vapor Content of Electrical Insulating Gases by Measurement of Dew Point. |
| D2112 | Standard Test Method for Oxidation Stability of Inhibited Mineral Insulating Oil by Pressure Vessel. |
| D2129 | Standard Test Method for Color of Clear Electrical Insulating Liquids (Platinum-Cobalt Scale). |
| D2140 | Standard Practice for Calculating Carbon-Type Composition of Insulating Oils of Petroleum Origin -or-Standard Test Method for Carbon-Type Composition of Insulating Oils of Petroleum Origin. |
| D2144 | Standard Practices for Examination of Electrical Insulating Oils by Infrared Absorption -or-Standard Test Methods for Examination of Electrical Insulating Oils by Infrared Absorption. |
| D2668 | Standard Test Method for 2,6-di-tert-Butyl- p-Cresol and 2,6-di-tert-Butyl Phenol in Electrical Insulating Oil by Infrared Absorption -or-Standard Test Method for 2,6-Ditertiary-Butyl Para Cresol and 2,6-Ditertiary-Butyl Phenol in Electrical Insulating Oil by Infrared Absorption. |
| D3612 | Standard Test Method for Analysis of Gases Dissolved in Electrical Insulating Oil by Gas Chromatography. |
| D4052 | Standard Test Method for Density, Relative Density, and API Gravity of Liquids by Digital Density Meter -or-Standard Test Method for Density and Relative Density of Liquids by Digital Density Meter. |
| D4059 | Standard Test Method for Analysis of Polychlorinated Biphenyls in Insulating Liquids by Gas Chromatography. |
| D4230 | Standard Test Method of Measuring Humidity with Cooled-Surface Condensation (Dew-Point) Hygrometer. |
| D4243 | Standard Test Method for Measurement of Average Viscometric Degree of Polymerization of New and Aged Electrical Papers and Boards. |
| D445 | Standard Test Method for Kinematic Viscosity of Transparent and Opaque Liquids (and Calculation of Dynamic Viscosity) -or-Standard Method Of Test For Viscosity Of Transparent And Opaque Liquids (Kinematic And Dynamic Viscosities). |
| D4768 | Standard Test Method for Analysis of 2,6-Ditertiary-Butyl Para-Cresol and 2,6-Ditertiary-Butyl Phenol in Insulating Liquids by Gas Chromatography. |
| D5837 | Standard Test Method for Furanic Compounds in Electrical Insulating Liquids by High-Performance Liquid Chromatography (HPLC). |
| D5853 | Standard Test Method for Pour Point of Crude Oils. |
| D5949 | Standard Test Method for Pour Point of Petroleum Products (Automatic Pressure Pulsing Method). |
| D5950 | Standard Test Method for Pour Point of Petroleum Products (Automatic Tilt Method). |
| D5985 | Standard Test Method for Pour Point of Petroleum Products (Rotational Method). |
| D6304 | Standard Test Method for Determination of Water in Petroleum Products, Lubricating Oils, and Additives by Coulometric Karl Fischer Titration. |
| D6749 | Standard Test Method for Pour Point of Petroleum Products (Automatic Air Pressure Method). |
| D6786 | Standard Test Method for Particle Count in Mineral Insulating Oil Using Automatic Optical Particle Counters. |
| D6892 | Standard Test Method for Pour Point of Petroleum Products (Robotic Tilt Method). |
| D7151 | Standard Test Method for Determination of Elements in Insulating Oils by Inductively Coupled Plasma Atomic Emission Spectrometry (ICP-AES). |
| D7346 | Standard Test Method for No Flow Point and Pour Point of Petroleum Products and Liquid Fuels -or-Standard Test Method for No Flow Point and Pour Point of Petroleum Products -or-Standard Test Method for No Flow Point of Petroleum Products. |
| D828 | Standard Test Method for Tensile Properties of Paper and Paperboard Using Constant-Rate-of-Elongation Apparatus (Withdrawn 2009). |
| D877 | Standard Test Method for Dielectric Breakdown Voltage of Insulating Liquids Using Disk Electrodes. |
| D877/D877M | Standard Test Method for Dielectric Breakdown Voltage of Insulating Liquids Using Disk Electrodes. |
| D92 | Standard Test Method for Flash and Fire Points by Cleveland Open Cup Tester -or-Standard Test Method for Flash and Fire Points by Cleveland Open Cup. |
| D924 | Standard Test Method for Dissipation Factor (or Power Factor) and Relative Permittivity (Dielectric Constant) of Electrical Insulating Liquids. |
| D93 | Standard Test Methods for Flash Point by Pensky-Martens Closed Cup Tester -or-Standard Test Method for Flash Point by Pensky-Martens Closed Tester -or-Standard Method Of Test For Flash Point by Pensky-Martens Closed Tester. |
| D97 | Standard Test Method for Pour Point of Petroleum Products -or-Standard Test Method for Pour Point of Petroleum Oils. |
| D974 | Standard Test Method for Acid and Base Number by Color-Indicator Titration. |

CIM17v40-AccumulationKind
### (Attribute) AccumulationKind

Kind of accumulation behaviour for read / measured values from individual end points.


| name | description |
|------|-------------|
| boundedQuantity | A time-independent cumulative quantity much like a 'bulkQuantity' or a 'latchingQuantity', except that the accumulation stops at the maximum or minimum values. When the maximum is reached, any additional positive accumulation is discarded, but negative accumulation may be accepted (thus lowering the counter.) Likewise, when the negative bound is reached, any additional negative accumulation is discarded, but positive accumulation is accepted (thus increasing the counter.) |
| bulkQuantity | A value from a register which represents the bulk quantity of a commodity. This quantity is computed as the integral of the commodity usage rate. This value is typically used as the basis for the dial reading at the meter, and as a result, will roll over upon reaching a maximum dial value.Note 1: With the metering system, the roll-over behaviour typically implies a roll-under behavior so that the value presented is always a positive value (e.g. unsigned integer or positive decimal.) However, when communicating data between enterprise applications a negative value might occur in a case such as net metering.Note 2: A 'bulkQuantity' refers primarily to the dial reading and not the consumption over a specific period of time. |
| continuousCumulative | The sum of the previous billing period values and the present period value.Note: 'continuousCumulative' is commonly used in conjunction with 'demand', and it would represent the cumulative sum of the previous billing period maximum demand values (as occurring with each demand reset) summed with the present period maximum demand value (which has yet to be reset.) |
| cumulative | The sum of the previous billing period values.Note: 'cumulative' is commonly used in conjunction with �demand.� Each demand reset causes the maximum demand value for the present billing period (since the last demand reset) to accumulate as an accumulative total of all maximum demands. So instead of 'zeroing' the demand register, a demand reset has the effect of adding the present maximum demand to this accumulating total. |
| deltaData | The difference between the value at the end of the prescribed interval and the beginning of the interval. This is used for incremental interval data.Note: One common application would be for load profile data, another use might be to report the number of events within an interval (such as the number of equipment energisations within the specified period of time.) |
| indicating | As if a needle is swung out on the meter face to a value to indicate the current value.Note: An 'indicating' value is typically measured over hundreds of milliseconds or greater, or may imply a �pusher� mechanism to capture a value. Compare this to 'instantaneous' which is measured over a shorter period of time. |
| instantaneous | Typically measured over the fastest period of time allowed by the definition of the metric (usually milliseconds or tens of milliseconds.)Note: 'instantaneous' was moved to attribute #3 in Ed.2 of IEC 61968-9, from attribute #1 in Ed.1 of IEC 61968-9. |
| latchingQuantity | When this description is applied to a metered value, it implies that the value is a time-independent cumulative quantity much like a 'bulkQuantity', except that it latches upon the maximum value upon reaching that value. Any additional accumulation (positive or negative) is discarded until a reset occurs.Note: A 'latchingQuantity' may also occur in the downward direction � upon reaching a minimum value. The terms 'maximum' or 'minimum' (for 'aggregate') will usually be included when this type of accumulation behaviour is present.When this description is applied to an encoded value (UOM= 'Code'), it implies that the value has one or more bits which are latching. The condition that caused the bit to be set may have long since evaporated.In either case, the timestamp that accompanies the value may not coincide with the moment the value was initially set.In both cases a system will need to perform an operation to clear the latched value. |
| none | Not applicable, or implied by the unit of measure. |
| summation | A form of accumulation which is selective with respect to time.Note : 'summation' could be considered a specialisation of 'bulkQuantity' as it selectively accumulates pulses over a timing pattern (while 'bulkQuantity' accumulates pulses all of the time). |
| timeDelay | A form of computation which introduces a time delay characteristic to the data value. |

CIM17v40-ActionType
### (Attribute) ActionType

Action type associated with an ActionRequest against a ParticipantInterfaces::Trade.


| name | description |
|------|-------------|
| CANCEL | Cancel a trade. |

CIM17v40-AdderType
### AdderType

BASELI NE

NEGOTIATED


| name | description |
|------|-------------|
| BASELINE | |
| NEGOTIATED | |

CIM17v40-AggregateKind
### (Attribute) AggregateKind

Kind of aggregation for read / measured values from multiple end points.


| name | description |
|------|-------------|
| average | The value represents average. |
| excess | The value represents an amount over which a threshold was exceeded. |
| fifthMaximum | The fifth highest value observed. |
| fourthMaximum | The fourth highest value observed. |
| highThreshold | The value represents a programmed high threshold. |
| lowThreshold | The value represents a programmed low threshold. |
| maximum | The highest value observed. |
| minimum | The smallest value observed. |
| nominal | The nominal value. |
| none | Not applicable. |
| normal | The normal value. |
| secondMaximum | The second highest value observed. |
| secondMinimum | The second smallest value observed. |
| sum | The accumulated sum. |
| thirdMaximum | The third highest value observed. |

CIM17v40-AlarmDisplayType
### AlarmDisplayType


| name | description |
|------|-------------|
| Appear | |
| Disappear | |
| Fleeting | |

CIM17v40-AllocationEnergyTypeCode
### AllocationEnergyTypeCode


| name | description |
|------|-------------|
| ACNG | |
| BS | |
| DAPE | |
| DASE | |
| ESRT | |
| ESYS | |
| ETC | |
| HASE | |
| LMPM | |
| MINL | |
| MLE | |
| MSSLFE | |
| OE | |
| OTHER | |
| OVGN | |
| PE | |
| RCNG | |
| RE | |
| RED | |
| RMRD | |
| RMRH | |
| RMRR | |
| RMRS | |
| RMRT | |
| RSYS | |
| RTSSE | |
| SDWN | |
| SE | |
| SLIC | |
| SRE | |
| STRT | |
| SUMR | |
| TCNG | |
| TEST | |
| TOR | |
| VS | |

CIM17v40-AmiBillingReadyKind
### (Attribute) AmiBillingReadyKind

Lifecycle states of the metering installation at a usage point with respect to readiness for billing via advanced metering infrastructure reads.


| name | description |
|------|-------------|
| amiCapable | Usage point is equipped with an AMI capable meter that is not yet currently equipped with a communications module. |
| amiDisabled | Usage point is equipped with an AMI capable meter; however, the AMI functionality has been disabled or is not being used. |
| billingApproved | Usage point is equipped with an operating AMI capable meter and accuracy has been certified for billing purposes. |
| enabled | Usage point is equipped with an AMI capable meter having communications capability. |
| nonAmi | Usage point is equipped with a non AMI capable meter. |
| nonMetered | Usage point is not currently equipped with a meter. |
| operable | Usage point is equipped with an AMI capable meter that is functioning and communicating with the AMI network. |

CIM17v40-AnalogLimitType
### (Attribute) AnalogLimitType

Limit type specified for AnalogLimits.


| name | description |
|------|-------------|
| BranchLongTerm | Branch Long Term Limit |
| BranchMediumTerm | Branch Medium Term Limit |
| BranchShortTerm | Branch Short Term Limit |
| VoltageHigh | Voltage High Limit |
| VoltageLow | Voltage Low Limit |

CIM17v40-AnalogToDigitalLogicKind
### (Attribute) AnalogToDigitalLogicKind

Categories of analog to digital (or logical result) comparison.


| name | description |
|------|-------------|
| eq | Equal (like) comparison operation. |
| ge | Greater or equal comparison operation. |
| gt | Greater than comparison operation. |
| le | Less or equal comparison operation. |
| lt | Less than comparison operation. |
| ne | Not equal (unlike) comparison operation. |

CIM17v40-AnalyticKind
### (Attribute) AnalyticKind

Possible kinds of analytics.


| name | description |
|------|-------------|
| agingAnalytic | Analytic evaluates aging. |
| faultAnalytic | Analytic evaluates fault. |
| healthAnalytic | Analytic evaluates asset health. |
| other | Analytic evaluates other factor. |
| replacementAnalytic | Analytic evaluates need for replacement. |
| riskAnalytic | Analytic evaluates risk. |

CIM17v40-AnchorKind
### (Attribute) AnchorKind

Kind of anchor.


| name | description |
|------|-------------|
| concrete | |
| helix | |
| multiHelix | |
| other | |
| rod | |
| screw | |
| unknown | |

CIM17v40-AncillaryCommodityType
### AncillaryCommodityType

ancillary serivce types


| name | description |
|------|-------------|
| NONSPIN | non spinning reserve |
| REGDN | regulation down |
| REGUP | regulation up |
| SPIN | spinning reserve |

CIM17v40-AnodeType
### (Attribute) AnodeType

Aggregated Nodes Types for example:

<ul>

<li>SYS - System Zone/Region; </li>

</ul>

<ul>

<li>RUC - RUC Zone; </li>

</ul>

<ul>

<li>LFZ - Load Forecast Zone; </li>

</ul>

<ul>

<li>REG - Market Energy/Ancillary Service Region; </li>

</ul>

<ul>

<li>AGR - Aggregate Generation Resource; </li>

</ul>

<ul>

<li>POD - Point of Delivery; </li>

</ul>

<ul>

<li>ALR - Aggregate Load Resource; </li>

</ul>

<ul>

<li>LTAC - Load TransmissionAccessCharge (TAC) Group; </li>

</ul>

<ul>

<li>ACA - Adjacent Control Area </li>

</ul>

<ul>

<li>ASR - Aggregated System Resource </li>

</ul>

<ul>

<li>ECA - Embedded Control Area </li>

</ul>


| name | description |
|------|-------------|
| ACA | Adjacent Control Area |
| AGR | Aggregate Generation Resource; |
| ALR | Aggregate Load Resource; |
| ASR | Aggregated System Resource |
| DER | Distributed Energy Resource. |
| ECA | Embedded Control Area |
| LFZ | Load Forecast Zone |
| LTAC | Load TransmissionAccessCharge (TAC) Group; |
| POD | Point of Delivery; |
| REG | Market Energy/Ancillary Service Region; |
| RUC | RUC Zone |
| SYS | System Zone/Region; |

CIM17v40-ApnodeType
### (Attribute) ApnodeType

Aggregate Node Types for example:

AG - Aggregated Generation

CPZ - Custom Price Zone

DPZ - Default Price Zone

LAP - Load Aggregation Point

TH - Trading Hub

SYS - System Zone

CA - Control Area

GA - generic aggregation

EHV - 500 kV

GH - generic hub

ZN - zone

INT - Interface

BUS - Bus


| name | description |
|------|-------------|
| AG | Aggregated Generation |
| BUS | Bus |
| CA | Control Area |
| CPZ | Custom Price Zone |
| DCA | Designated Congestion Area |
| DPZ | Default Price Zone |
| EHV | 500 kV - Extra High Voltage aggregate price nodes |
| GA | generic aggregation |
| GH | generic hub |
| INT | Interface |
| SYS | System Zone |
| TH | Trading Hub |
| ZN | Zone |

CIM17v40-ApplicationSecurityKind
### (Attribute) ApplicationSecurityKind

Specifies the expected security mechanism, per IEC 62351-4, to be utilized.


| name | description |
|------|-------------|
| endToEndSecure | Indicates that E2E-security shall be used in order to allow establishment of an MMS association. |
| nonSecure | Indicates that an application security shall not be used in order to allow establishment of an MSS association. |
| secure | Indicates that the A-security-profile as specified in Clause 11 (or IEC TS 62351-4:2007) shall be used in order to allow establishment of an MMS association. |

CIM17v40-AreaControlMode
### (Attribute) AreaControlMode

Area's present control mode.


| name | description |
|------|-------------|
| CF | CF = Constant Frequency |
| CTL | Constant Tie-Line |
| OFF | Off control |
| TLB | Tie-Line Bias |

CIM17v40-AreaKind
### (Attribute) AreaKind

Enumeration for the type of area defined; e.g., county, state, parish, zipcode, etc.


| name | description |
|------|-------------|
| borough | Enumeration for the type of area defined for the borough |
| county | Enumeration for the type of area defined for the county |
| parish | Enumeration for the type of area defined for the parish |
| serviceArea | Enumeration for the type of area defined for the service area |
| state | Enumeration for the type of area defined for the state |
| township | Enumeration for the type of area defined for the township |
| ward | Enumeration for the type of area defined for the ward |
| zipcode | Enumeration for the type of area defined for the zipcode |

CIM17v40-AssetFailureClassification
### (Attribute) AssetFailureClassification

Classifications of asset failures.


| name | description |
|------|-------------|
| defect | Failure due to defect. |
| major | Major failure. |
| majorNeedsReplacement | Major failure � asset needs to be replaced. |
| minor | Minor failure. |

CIM17v40-AssetFailureMode
### (Attribute) AssetFailureMode

What asset has failed to be able to do.

Reason for breaker failure.

Note: This enumeration provides essential information to asset health analytics. The existing list is a starting point and is anticipated to be fleshed out further as requirements are better understood (PAB 2016/01/09).


| name | description |
|------|-------------|
| failToCarryLoad | Failure to carry load. |
| failToClose | Failure to close. |
| failToInterrupt | Failure to interrupt. |
| failToOpen | Failure to open. |
| failToProvideInsulationLevel | Failure to provide insulation. |

CIM17v40-AssetGroupKind
### (Attribute) AssetGroupKind

Possible kinds of asset groups.


| name | description |
|------|-------------|
| analysisGroup | Group is used for analysis purposes. |
| complianceGroup | Group is used for compliance purposes. |
| functionalGroup | Group is used for functional purposes, for example assets which are grouped together because they are part of a for a particular function - such as a group of feeders. |
| inventoryGroup | Group is used for inventory purposes. |
| other | |

CIM17v40-AssetHazardKind
### (Attribute) AssetHazardKind

Type of hazard that is posed to asset in this location.

Note: This enumeration provides essential information to asset health analytics. The existing list is a starting point and is anticipated to be fleshed out further as requirements are better understood (PAB 2016/01/09).


| name | description |
|------|-------------|
| ambientTempAbove38 | Subject to ambient temperature above 38 �C. |
| ambientTempBelowMinus12 | Subject to ambient temperature of below -12 �C. |
| childrenAtPlay | Children play in area (stray kite/ball hazard). |
| fishingArea | Fishing in area (fishing pole/line hazard). |
| other | If other, look at type field for more information. |
| vegetation | Vegetation growing below asset that may cause problem. |

CIM17v40-AssetKind
### (Attribute) AssetKind

Kinds of assets or asset components.


| name | description |
|------|-------------|
| breakerAirBlastBreaker | Air blast circuit breaker. |
| breakerBulkOilBreaker | Bulk oil circuit breaker. |
| breakerInsulatingStackAssembly | Breaker insulating stack assembly (for live tank breaker). |
| breakerMinimumOilBreaker | Minimum oil circuit breaker. |
| breakerSF6DeadTankBreaker | SF6 dead tank breaker. |
| breakerSF6LiveTankBreaker | SF6 live tank breaker. |
| breakerTankAssembly | Breaker tank assembly. |
| other | Other type of Asset. The type attribute may provide more details in this case. |
| transformer | Transformer. |
| transformerTank | Transformer tank. |

CIM17v40-AssetLifecycleStateKind
### (Attribute) AssetLifecycleStateKind

Lifecycle states an asset can be in.

While the possible lifecycle states are standardized, the allowed transitions are not - they are intended to be defined by the business process requirements of local implementations.


| name | description |
|------|-------------|
| disposedOf | Asset disposed of. |
| manufactured | Asset manufactured. |
| purchased | Asset purchased. |
| received | Asset received. |
| retired | Asset retired. |

CIM17v40-AssetModelUsageKind
### (Attribute) AssetModelUsageKind

Usage for an asset model.


| name | description |
|------|-------------|
| customerSubstation | Asset model is intended for use in customer substation. |
| distributionOverhead | Asset model is intended for use in distribution overhead network. |
| distributionUnderground | Asset model is intended for use in underground distribution network. |
| other | Other kind of asset model usage. |
| streetlight | Asset model is intended for use as streetlight. |
| substation | Asset model is intended for use in substation. |
| transmission | Asset model is intended for use in transmission network. |
| unknown | Usage of the asset model is unknown. |

CIM17v40-AssetStringKind
### (Attribute) AssetStringKind

Definition of type of string useful in asset domain.


| name | description |
|------|-------------|
| visualExamRemarks | Remarks related to a visual exam.Could be used for remarks on oil appearance resulting from visual examination, including sediment, appearance, free water. |

CIM17v40-AssetTemperaturePressureAnalogKind
### (Attribute) AssetTemperaturePressureAnalogKind

Analogs representing temperatures or pressures related to assets.


| name | description |
|------|-------------|
| oilPressureAtValve | Oil pressure at valve (in KPa). |
| oilTemperatureAtValve | Oil temperature at valve (in �C). |

CIM17v40-AsynchronousMachineKind
### (Attribute) AsynchronousMachineKind

Kind of Asynchronous Machine.


| name | description |
|------|-------------|
| generator | The Asynchronous Machine is a generator. |
| motor | The Asynchronous Machine is a motor. |

CIM17v40-AtmosphericAnalogKind
### (Attribute) AtmosphericAnalogKind

Kinds of analogs (floats) measuring an atmospheric condition.


| name | description |
|------|-------------|
| albedo | |
| ambientTemperature | The temperature measured b<font color="#0f0f0f">y a thermometer exposed to the air in a place sheltered from direct solar radiation. </font>Also known as "dry bulb" because<font color="#0f0f0f"> the air temperature is indicated by a thermometer not affecte</font>d by the moisture of the air. |
| atmosphericPressure | |
| ceiling | |
| dewPoint | The temperature to which air must be cooled at constant pressure and constant water-vapor content in order for saturation to occur. In other words, it is the temperature at which water vapor starts to condense out of the air. |
| heatIndex | The temperature of how hot it "feels like" for a given combination of warm air temperature and relative humidity. |
| horizontalVisibility | |
| humidity | |
| ice | |
| illuminanceDiffuseHorizontal | |
| illuminanceDirectNormal | |
| illuminanceGlobalHorizontal | |
| irradianceDiffuseHorizonal | |
| irradianceDirectNormal | |
| irradianceExtraTerrestrialHorizontal | |
| irradianceExtraTerrestrialVertical | |
| irradianceGlobalHorizontal | |
| luminanceZenith | |
| precipitation | |
| rain | |
| skyCoverageOpaque | |
| skyCoverageTotal | |
| snow | Snow amount over a specified period of time. |
| verticalVisibility | |
| windChill | The temperature of how cold it "feels like" based on the rate of heat loss from exposed skin caused by the effects of wind and cold temperatures. |
| windSpeedGust | Maximum instantaneous wind speed in the 10 minute period preceding a moment in time so long as more than 10 knots of difference has been exhibited between peaks and lulls during that 10 minute time period.0 value means no gusts during preceding 10 minute period. |
| windSpeedInstantaneous | Wind speed at a moment in time. |
| windSpeedPeak | Peak instantaneous wind speed in the 60 minutes preceding a moment in time as long as peak speed greater than 25 knots.0 value means speed did not exceed 25 knots during preceding 60 minutes. |
| windSpeedSustained | Average instantaneous wind speed over the 2-minute time period preceding a moment in time. |

CIM17v40-AutomaticDispInstTypeCommitment
### (Attribute) AutomaticDispInstTypeCommitment

Commitment instruction types.


| name | description |
|------|-------------|
| DR_ADJUSTMENT | Distributed Resource adjustment for a distributed resource that is already deployed (committed). |
| DR_DEPLOY | Distributed Resource Deployment |
| DR_RELEASE | Distributed Resource Release |
| SHUT_DOWN | Shut down instruction type |
| START_UP | Start up instruction type |

CIM17v40-AutomaticDispatchMode
### (Attribute) AutomaticDispatchMode

Automatic Dispatch mode.


| name | description |
|------|-------------|
| CONTINGENCY | Contingnency occurance, redispatch of contingency reserves |
| INTERVAL | |
| MANUAL | Operator override |

CIM17v40-BatteryStateKind
### (Attribute) BatteryStateKind

The state of the battery unit.


| name | description |
|------|-------------|
| charging | Stored energy is increasing. |
| discharging | Stored energy is decreasing. |
| empty | Unable to discharge, and not charging. |
| full | Unable to charge, and not discharging. |
| waiting | Neither charging nor discharging, but able to do so. |

CIM17v40-BidCalculationBasis
### (Attribute) BidCalculationBasis

The basis used to calculate the bid price curve for an energy default bid.


| name | description |
|------|-------------|
| COST_BASED | Based on unit generation characteristics and a cost of fuel. |
| LMP_BASED | Based on prices paid at particular pricing location. |
| NEGOTIATED | An amount negotiated with the designated Independent Entity. |

CIM17v40-BidMitigationStatus
### (Attribute) BidMitigationStatus

For example:

'S' - Mitigated by SMPM because of "misconduct"

'L; - Mitigated by LMPM because of "misconduct"

'R' - Modified by LMPM because of RMR rules

'M' - Mitigated because of "misconduct" both by SMPM and LMPM

'B' - Mitigated because of "misconduct" both by SMPM and modified by LMLM because of RMR rules

'O' - original


| name | description |
|------|-------------|
| B | |
| L | |
| M | |
| O | |
| R | |
| S | |

CIM17v40-BidMitigationType
### (Attribute) BidMitigationType

For example:

Initial

Final


| name | description |
|------|-------------|
| F | |
| I | |

CIM17v40-BidPriceCapType
### BidPriceCapType


| name | description |
|------|-------------|
| AS | |
| ENERGY | |
| RUC | |

CIM17v40-BidStatusType
### BidStatusType

Status indication for bids

CV - Conditionally Valid Bid

CM - Conditionally Modified Bid

V - Valid Bid

M - Modified Bid

RJ - Rejected Bid

I - Invalid Bid

CX - Cancelled Bid

O - Obsolete Bid

CL - Clean Bid

RP - Replicated Bid


| name | description |
|------|-------------|
| CL | Clean |
| CM | |
| CV | |
| CX | |
| I | |
| M | |
| O | |
| RJ | |
| RP | Replicated |
| V | |

CIM17v40-BidType
### (Attribute) BidType

For example:

DEFAULT_ENERGY_BID

DEFAULT_STARTUP_BID

DEFAULT_MINIMUM_LOAD_BID


| name | description |
|------|-------------|
| DEFAULT_ENERGY_BID | |
| DEFAULT_MINIMUM_LOAD_BID | |
| DEFAULT_STARTUP_BID | |

CIM17v40-BidTypeRMR
### (Attribute) BidTypeRMR

Bid self schedule type has two types as the required output of requirements and qualified pre-dispatch.


| name | description |
|------|-------------|
| QUALIFIED_PREDISPATCH | Output of requirements bid self schedule type. |
| REQUIREMENTS | Qualified pre-dispatch bid self schedule type. |

CIM17v40-BillMediaKind
### (Attribute) BillMediaKind

Kind of bill media.


| name | description |
|------|-------------|
| electronic | |
| other | |
| paper | |

CIM17v40-BoilerControlMode
### (Attribute) BoilerControlMode

Boiler control mode.


| name | description |
|------|-------------|
| coordinated | Coordinated. |
| following | Following. |

CIM17v40-BreakerApplicationKind
### (Attribute) BreakerApplicationKind

Classifications of network roles in which breakers can be deployed. The classifications are intended to reflect both criticality of breaker in network operations and typical usage experienced by breaker.

Note: This enumeration provides essential information to asset health analytics. The existing list is a starting point and is anticipated to be fleshed out further as requirements are better understood (PAB 2016/01/09).


| name | description |
|------|-------------|
| busBreaker | Bus breaker. |
| busTieBreaker | Bus tie breaker. |
| capacitorOrReactorBankBreaker | Capacitor or reactor breaker. |
| feederBreaker | Feeder breaker. |
| other | Other type of breaker application. |
| spare | Spare breaker. |
| stepUpTransformerBreakerFossil | Step-up transformer breaker for fossil generator. |
| stepUpTransformerBreakerHydro | Step-up transformer breaker for hydro generator. |
| stepUpTransformerBreakerNuclear | Step-up transformer breaker for nuclear generator. |
| stepUpTransformerBreakerPumpedStorage | Step-up transformer breaker for pumped storage. |
| substationTransformerBreaker | Substation transformer breaker. |
| transmissionFlowGateLineBreaker | Transmission flow gate line breaker. |
| transmissionLineBreaker | Transmission line breaker. |
| transmissionTieLineBreaker | Transmission tie line breaker. |

CIM17v40-BreakerConfiguration
### (Attribute) BreakerConfiguration

Switching arrangement for bay.


| name | description |
|------|-------------|
| breakerAndAHalf | Breaker and a half. |
| doubleBreaker | Double breaker. |
| noBreaker | No breaker. |
| singleBreaker | Single breaker. |

CIM17v40-BreakerFailureReasonKind
### (Attribute) BreakerFailureReasonKind

Reason for breaker failure.

Note: This enumeration provides essential information to asset health analytics. The existing list is a starting point and is anticipated to be fleshed out further as requirements are better understood (PAB 2016/01/09).


| name | description |
|------|-------------|
| SF6BlastValveFailure | SF6 blast valve failure. |
| SF6PufferFailure | SF6 puffer valve failure. |
| blastValveFailure | Blast valve failure. |
| bushingFailure | Bushing failure. |
| closeCoilOpenShortedFailed | Close coil open shorted failure. |
| contaminatedAir | Contaminated air. |
| contaminatedArcChutes | Contaminated arc chutes. |
| contaminatedGas | Contaminated gas. |
| contaminatedGasAir | Contaminated gas or air. |
| controlCircuitFailure | Control circuit failure. |
| degradedLubrication | Degraded lubrication. |
| externalOrInternalContamination | External or internal contamination. |
| highPressureAirPlant | High pressure air plant. |
| highResistanceLoadPath | High resistance load path. |
| highResistancePath | High resistance path. |
| interrupterContactFailure | Interrupter contact failure. |
| interrupterFailure | Interrupter failure. |
| linkageFailure | Linkage failure. |
| lossOfOil | Loss of oil. |
| lossOfVacuum | Loss of vacuum. |
| lowGasPressure | Low gas pressure. |
| mechanismFailure | Blast valve failure. |
| mechanismOrLinkageFailure | Mechanism or linkage failure. |
| oilRelatedFailure | Oil-related failure. |
| poorOilQuality | Poor oil quality. |
| rackingMechanismFailure | Racking mechanism failure. |
| resistorFailure | Resistor failure. |
| resistorGradingCapacitorFailure | Resistor grading capacitor failure. |
| solidDielectricFailure | Solid dielectric failure. |
| storedEnergyFailure | Stored energy failure. |
| tripCoilOpenShortedFailed | Trip coil open shorted failure. |

CIM17v40-BreakerMaintenanceKind
### (Attribute) BreakerMaintenanceKind

Possible types of breaker maintenance work.


| name | description |
|------|-------------|
| externalOutOfService | External out-of-service inspection and maintenance. |
| internalOutOfService | Internal (interrupter) inspection and maintenance (breaker out of service). |
| interrupterOverhaul | Overhaul of breaker interrupter unit. |

CIM17v40-BreakerRepairItemKind
### (Attribute) BreakerRepairItemKind

Breaker components and problem areas which can be the focus of a repair work task.


| name | description |
|------|-------------|
| SF6GasLeak | SF6 gas leak repair. |
| airCompressor | Air compressor repair. |
| auxiliarySwitchAndLinkage | Auxiliary switch and linkage repair. |
| busConnection | Bus connection repair. |
| checkValve | Check valve repair. |
| closeCoil | Close coil repair. |
| contactor | Contactor repair. |
| controlCircuit | Control circuit repair. |
| corrosion | Corrosion repair. |
| gasDensitySupervision | Gas density supervision repair. |
| heaterOrThermostat | Heater or thermostat repair. |
| hydraulicFluidLeak | Hydraulic fluid leak repair. |
| interrupterAssembly | Interrupter assembly repair. |
| other | Other type of repair. |
| positionIndicator | Position indicator repair. |
| pressureSwitch | Pressure switch repair. |
| pumpOrMotor | Pump or motor repair. |
| relay | Relay repair. |
| storedEnergySystem | Stored energy system repair. |
| tripCoil | Trip coil repair. |
| tripControlValve | Trip control valve repair. |
| wiring | Wiring repair. |

CIM17v40-BusbarConfiguration
### (Attribute) BusbarConfiguration

Busbar layout for bay.


| name | description |
|------|-------------|
| doubleBus | Double bus. |
| mainWithTransfer | Main bus with transfer bus. |
| ringBus | Ring bus. |
| singleBus | Single bus. |

CIM17v40-BushingInsulationKind
### (Attribute) BushingInsulationKind

Insulation kind for bushings.


| name | description |
|------|-------------|
| compound | Compound. |
| oilImpregnatedPaper | Oil impregnated paper. |
| other | Other. |
| resinBondedPaper | Resin bonded paper. |
| resinImpregnatedPaper | Resin impregnated paper. |
| solidPorcelain | Solid porcelain. |

CIM17v40-BushingInsulationPfTestKind
### (Attribute) BushingInsulationPfTestKind

Kind of PF test for bushing insulation.


| name | description |
|------|-------------|
| c1 | Power factor tap-to-ground. |
| c2 | Power factor tap-to-conductor. |

CIM17v40-CIGREStandardEditionKind
### (Attribute) CIGREStandardEditionKind

List of editions for CIGRE standards.


| name | description |
|------|-------------|
| 2000 | 2000 standard edition. |
| none | No standard edition. |
| unknown | Unknown standard edition. |

CIM17v40-CIGREStandardKind
### (Attribute) CIGREStandardKind

List of CIGRE standards.


| name | description |
|------|-------------|
| TB 170 | CIGRE Technical Brochure 170 Static Electrification in Power Transformers. |

CIM17v40-CRRCategoryType
### (Attribute) CRRCategoryType

Congestion Revenue Rights category types.


| name | description |
|------|-------------|
| NSR | Network Service |
| PTP | Point to Point |

CIM17v40-CRRHedgeType
### (Attribute) CRRHedgeType

Congestion Revenue Right hedge type.


| name | description |
|------|-------------|
| OBLIGATION | |
| OPTION | |

CIM17v40-CRRRoleType
### (Attribute) CRRRoleType

Role types an organisation can play with respect to a congestion revenue right.


| name | description |
|------|-------------|
| BUYER | |
| OWNER | |
| SELLER | |

CIM17v40-CRRSegmentType
### (Attribute) CRRSegmentType

Type of the CRR, from the possible type definitions in the CRR System (e.g. 'LSE', 'ETC').


| name | description |
|------|-------------|
| AUC | |
| CAP | |
| CF | |
| CVR | Converted rights. |
| ETC | Existing Transmission Contract. |
| LSE | Load Serving Entity. |
| MT | Merchant transmission. |
| TOR | Transmission Ownership Rights. |

CIM17v40-CableConstructionKind
### (Attribute) CableConstructionKind

Kind of cable construction.


| name | description |
|------|-------------|
| compacted | Compacted cable. |
| compressed | Compressed cable. |
| other | Other kind of cable construction. |
| sector | Sector cable. |
| segmental | Segmental cable. |
| solid | Solid cable. |
| stranded | Stranded cable. |

CIM17v40-CableOuterJacketKind
### (Attribute) CableOuterJacketKind

Kind of cable outer jacket.


| name | description |
|------|-------------|
| insulating | Insulating cable outer jacket. |
| linearLowDensityPolyethylene | Linear low density polyethylene cable outer jacket. |
| none | Cable has no outer jacket. |
| other | Pther kind of cable outer jacket. |
| polyethylene | Polyethylene cable outer jacket. |
| pvc | PVC cable outer jacket. |
| semiconducting | Semiconducting cable outer jacket. |

CIM17v40-CableShieldMaterialKind
### (Attribute) CableShieldMaterialKind

Kind of cable shield material.


| name | description |
|------|-------------|
| aluminum | Aluminum cable shield. |
| copper | Copper cable shield. |
| lead | Lead cable shield. |
| other | Other kind of cable shield material. |
| steel | Steel cable shield. |

CIM17v40-CalculationIntervalUnitKind
### (Attribute) CalculationIntervalUnitKind

Units in which calculation interval period is defined.


| name | description |
|------|-------------|
| cycle | Period expressed in cycles. |
| day | Period expressed in days. |
| hour | Period expressed in hours. |
| milliSecond | Period expressed in milli-seconds. |
| minute | Period expressed in minutes. |
| month | Period expressed in months. |
| perCycle | Period expressed in per-cycle. |
| season | Period expressed in seasons. |
| second | Period expressed in seconds. |
| week | Period expressed in weeks. |
| year | Period expressed in years. |

CIM17v40-CalculationKind
### (Attribute) CalculationKind

Categorisation of calculation operation that can be done to Measurement.


| name | description |
|------|-------------|
| div | Division operation the input values (operands). |
| mul | Multiplication operation the input values (operands). |
| sqrt | Square root operator - only one input value (operands). |
| sum | Summation operation over the input values (operands). |

CIM17v40-CalculationModeKind
### (Attribute) CalculationModeKind

The mode of the calculation (total, periodic, sliding).

.


| name | description |
|------|-------------|
| period | Calcuation is for fixed period. |
| sliding | Calculation is for sliding period. |
| total | Calculation is for total period. |

CIM17v40-CalculationTechniqueKind
### (Attribute) CalculationTechniqueKind

Possible calculation techniques.


| name | description |
|------|-------------|
| average | Result is average value for period. |
| maximum | Result is maximum value for period. |
| minimum | Result is minimum value for period. |
| trueRMS | Result is RMS value for period. |

CIM17v40-ChargeKind
### (Attribute) ChargeKind

Kind of charge.


| name | description |
|------|-------------|
| auxiliaryCharge | Any other charge which is not a consumptionCharge or demandCharge. For example: debt recovery, arrears, standing charge or charge for another service such as street lighting. |
| consumptionCharge | The charge levied for the actual usage of the service, normally expressed in terms of a tariff. For example: usage x price per kWh = total charge for consumption. |
| demandCharge | The charge related to the usage within a defined time interval, normally expressed in terms of a tariff. For example: a maximum-demand tariff will levy an additional charge on top of the consumption charge if the usage exceeds a defined limit per hour. |
| other | Other kind of charge. |
| taxCharge | Any charge that is classified as a tax of a kind. For example: VAT, GST, TV tax, etc. |

CIM17v40-CheckOutType
### (Attribute) CheckOutType

To indicate a check out type such as adjusted capacity or dispatch capacity.


| name | description |
|------|-------------|
| AFTER_THE_FACT | |
| PRE_HOUR | |
| PRE_SCHEDULE | |

CIM17v40-ChequeKind
### (Attribute) ChequeKind

Kind of cheque.


| name | description |
|------|-------------|
| bankOrder | Payment order used by a bank. |
| other | Other kind of cheque. |
| postalOrder | Payment order used by institutions other than banks. |

CIM17v40-CleanTradeProductType
### CleanTradeProductType


| name | description |
|------|-------------|
| APN | Energy Trades at Aggregated Pricing Nodes |
| CPT | Converted Physical Energy Trade |
| NRT | Non-Spinning Reserve Trade |
| PHY | Physical Energy Tra |
| RDT | Regulation Down Trade |
| RUT | Regulation Up Trade |
| SRT | Spinning Reserve Trade |

CIM17v40-ClearanceActionKind
### (Attribute) ClearanceActionKind

Type of clearance action.


| name | description |
|------|-------------|
| issue | Issue clearance. |
| release | Release clearance. |
| update | Update clearance. |

CIM17v40-CloudKind
### (Attribute) CloudKind

Kind of cloud.


| name | description |
|------|-------------|
| altoCumulus | |
| altoStratus | |
| cirroCumulus | |
| cirroStratus | |
| cirrus | |
| cumuloNimbus | |
| cumulus | |
| nimboStratus | |
| other | |
| stratoCumulus | |
| stratus | |
| toweringCumulus | |

CIM17v40-ComDirectionKind
### (Attribute) ComDirectionKind

Kind of communication direction.


| name | description |
|------|-------------|
| biDirectional | Communication with the device is bi-directional. |
| fromDevice | Communication is from device. |
| toDevice | Communication is to device. |

CIM17v40-ComTechnologyKind
### (Attribute) ComTechnologyKind

Kind of communication technology.


| name | description |
|------|-------------|
| cellular | Communicates using a public cellular radio network. A specific variant of 'rf'. |
| ethernet | Communicates using one or more of a family of frame-based computer networking technologies conforming to the IEEE 802.3 standard. |
| homePlug | Communicates using power line communication technologies conforming to the standards established by the HomePlug Powerline Alliance. A specific variant of 'plc'. |
| pager | Communicates using a public one-way or two-way radio-based paging network. A specific variant of 'rf'. |
| phone | Communicates using a basic, wireline telephone system. |
| plc | Communicates using power line communication technologies. |
| rf | Communicates using private or public radio-based technology. |
| rfMesh | Communicates using a mesh radio technology. A specific variant of 'rf'. |
| zigbee | Communicates using radio communication technologies conforming to the standards established by the ZigBee. A specific variant of 'rf'. |

CIM17v40-CommitmentType
### (Attribute) CommitmentType

For example:

SELF - Self commitment

ISO - New commitment for this market period

UC - Existing commitment that was a hold over from a previous market


| name | description |
|------|-------------|
| ISO | |
| SELF | |
| UC | |

CIM17v40-CommodityKind
### (Attribute) CommodityKind

Kind of commodity being measured.


| name | description |
|------|-------------|
| air | Atmospheric air |
| carbon | The element has an atomic number of 6. |
| ch4 | Methane CH4 |
| co2 | Carbon Dioxide CO2 |
| communication | A measurement of the communication infrastructure itself. |
| coolingFluid | The cool fluid returns warmer than when it was sent. The heat conveyed may be metered. |
| electricityPrimaryMetered | It is possible for a meter to be outfitted with an external VT and/or CT. The meter might not be aware of these devices, and the display not compensate for their presence. Ultimately, when these scalars are applied, the value that represents the service value is called the �primary metered� value. The �index� in sub-category 3 mirrors those of sub-category 0. |
| electricitySecondaryMetered | All types of metered quantities. This type of reading comes from the meter and represents a �secondary� metered value. |
| hch | Hexachlorocyclohexane HCH |
| heatingFluid | This fluid is likely in liquid form. It is not necessarily water or water based. The warm fluid returns cooler than when it was sent. The heat conveyed may be metered. |
| insulativeGas | (SF6 is found separately below.) |
| insulativeOil | Oil that is used in transformers to provide insulation and heat conduction. |
| internet | Internet service |
| naturalGas | A naturally occurring hydrocarbon gas mixture. |
| none | Not Applicable |
| nonpotableWater | Reclaimed water � possibly used for irrigation but not sufficiently treated to be considered safe for drinking. |
| nox | Nitrous Oxides NOX |
| pfc | Perfluorocarbons PFC |
| potableWater | Drinkable water |
| propane | The formula is C3H8 |
| refuse | trash |
| sf6 | Sulfurhexafluoride SF6 |
| so2 | Sulfur Dioxide SO2 |
| steam | Water in steam form, usually used for heating. |
| tvLicence | Television |
| wasteWater | (Sewerage) |

CIM17v40-CompositeSwitchKind
### (Attribute) CompositeSwitchKind

Kind of composite switch.


| name | description |
|------|-------------|
| escoThrowOver | |
| gral | |
| other | |
| ral | |
| regulatorBypass | |
| throwOver | |
| ugMultiSwitch | |

CIM17v40-ConditionFactorKind
### (Attribute) ConditionFactorKind

Kind of condition factor.


| name | description |
|------|-------------|
| accountAllocation | |
| labor | |
| material | |
| other | |
| travel | |

CIM17v40-ConstraintLimitType
### (Attribute) ConstraintLimitType

Binding constraint results limit type, For example:

MAXIMUM

MINIMUM


| name | description |
|------|-------------|
| MAXIMUM | |
| MINIMUM | |

CIM17v40-ConstraintRampType
### (Attribute) ConstraintRampType

Constraint Ramp type.


| name | description |
|------|-------------|
| FAST | |
| SLOW | |

CIM17v40-ContingencyEquipmentStatusKind
### (Attribute) ContingencyEquipmentStatusKind

Indicates the state which the contingency equipment is to be in when the contingency is applied.


| name | description |
|------|-------------|
| inService | The equipment is to be put into service. |
| outOfService | The equipment is to be taken out of service. |

CIM17v40-ContractType
### (Attribute) ContractType

Transmission Contract Type, For example:

O - Other

TE - Transmission Export

TI - Transmission Import

ETC - Existing Transmission Contract

RMT - RMT Contract

TOR - Transmission Ownership Right

RMR - Reliability Must Run Contract

CVR - Converted contract


| name | description |
|------|-------------|
| CVR | CVR - Converted contract. |
| ETC | ETC - Existing Transmission Contract |
| O | O - Other |
| RMR | RMR - Reliability Must Run Contract |
| RMT | RMT - RMT Contract |
| TE | TE - Transmission Export |
| TI | TI - Transmission Import |
| TOR | TOR - Transmission Ownership Right |

CIM17v40-ControlAreaTypeKind
### (Attribute) ControlAreaTypeKind

The type of control area.


| name | description |
|------|-------------|
| AGC | Used for automatic generation control. |
| Forecast | Used for load forecast. |
| Interchange | Used for interchange specification or control. |

CIM17v40-CoolantType
### (Attribute) CoolantType

Method of cooling a machine.


| name | description |
|------|-------------|
| air | Air. |
| hydrogenGas | Hydrogen gas. |
| water | Water. |

CIM17v40-CoolingKind
### (Attribute) CoolingKind

Kind of cooling.


| name | description |
|------|-------------|
| forcedAir | |
| forcedOilAndAir | |
| other | |
| selfCooling | |

CIM17v40-CorporateStandardKind
### (Attribute) CorporateStandardKind

Kind of corporate standard.


| name | description |
|------|-------------|
| experimental | Asset model is used experimentally. |
| other | Other kind of corporate standard for the asset model. |
| standard | Asset model is used as corporate standard. |
| underEvaluation | Asset model usage is under evaluation. |

CIM17v40-CostBasis
### (Attribute) CostBasis

For example:

Bid Cost

Proxy Cost

Registered Cost


| name | description |
|------|-------------|
| BIDC | |
| PRXC | |
| REGC | |

CIM17v40-CoverageCodeKind
### (Attribute) CoverageCodeKind

Kinds of weather condition coverage.


| name | description |
|------|-------------|
| brief | |
| frequent | |
| intermittant | |
| isolated | |
| numerous | |
| occasional | |
| partly | |
| patchy | |
| periodsOf | |
| scattered | |
| widespread | |

CIM17v40-CrewStatusKind
### (Attribute) CrewStatusKind

Defines the current status of the Crew - assigned, arrived, etc.


| name | description |
|------|-------------|
| arrived | the crew is on site at the outage location |
| assigned | the crew has been assigned to work on a task |
| awaitingCrewAssignment | Indicates that the work is awaiting one or more crews to be assigned |
| enroute | the crew has been dispatched to work on an outage |
| fieldComplete | the crew has corrected the outage in the field. The equipment or other devices may not be energized at this time. |

CIM17v40-CsOperatingModeKind
### (Attribute) CsOperatingModeKind

Operating mode for HVDC line operating as Current Source Converter.


| name | description |
|------|-------------|
| inverter | Operating as inverter, which is the power receiving end. |
| rectifier | Operating as rectifier, which is the power sending end. |

CIM17v40-CsPpccControlKind
### (Attribute) CsPpccControlKind

Active power control modes for HVDC line operating as Current Source Converter.


| name | description |
|------|-------------|
| activePower | Control is active power control at AC side, at point of common coupling. Target is provided by ACDCConverter.targetPpcc. |
| dcCurrent | Control is DC current with target value provided by CsConverter.targetIdc. |
| dcVoltage | Control is DC voltage with target value provided by ACDCConverter.targetUdc. |

CIM17v40-Currency
### (Attribute) Currency

Monetary currencies. ISO 4217 standard including 3-character currency code.


| name | description |
|------|-------------|
| AED | United Arab Emirates dirham. |
| AFN | Afghan afghani. |
| ALL | Albanian lek. |
| AMD | Armenian dram. |
| ANG | Netherlands Antillean guilder. |
| AOA | Angolan kwanza. |
| ARS | Argentine peso. |
| AUD | Australian dollar. |
| AWG | Aruban florin. |
| AZN | Azerbaijani manat. |
| BAM | Bosnia and Herzegovina convertible mark. |
| BBD | Barbados dollar. |
| BDT | Bangladeshi taka. |
| BGN | Bulgarian lev. |
| BHD | Bahraini dinar. |
| BIF | Burundian franc. |
| BMD | Bermudian dollar (customarily known as Bermuda dollar). |
| BND | Brunei dollar. |
| BOB | Boliviano. |
| BOV | Bolivian Mvdol (funds code). |
| BRL | Brazilian real. |
| BSD | Bahamian dollar. |
| BTN | Bhutanese ngultrum. |
| BWP | Botswana pula. |
| BYR | Belarusian ruble. |
| BZD | Belize dollar. |
| CAD | Canadian dollar. |
| CDF | Congolese franc. |
| CHF | Swiss franc. |
| CLF | Unidad de Fomento (funds code), Chile. |
| CLP | Chilean peso. |
| CNY | Chinese yuan. |
| COP | Colombian peso. |
| COU | Unidad de Valor Real. |
| CRC | Costa Rican colon. |
| CUC | Cuban convertible peso. |
| CUP | Cuban peso. |
| CVE | Cape Verde escudo. |
| CZK | Czech koruna. |
| DJF | Djiboutian franc. |
| DKK | Danish krone. |
| DOP | Dominican peso. |
| DZD | Algerian dinar. |
| EEK | Estonian kroon. |
| EGP | Egyptian pound. |
| ERN | Eritrean nakfa. |
| ETB | Ethiopian birr. |
| EUR | Euro. |
| FJD | Fiji dollar. |
| FKP | Falkland Islands pound. |
| GBP | Pound sterling. |
| GEL | Georgian lari. |
| GHS | Ghanaian cedi. |
| GIP | Gibraltar pound. |
| GMD | Gambian dalasi. |
| GNF | Guinean franc. |
| GTQ | Guatemalan quetzal. |
| GYD | Guyanese dollar. |
| HKD | Hong Kong dollar. |
| HNL | Honduran lempira. |
| HRK | Croatian kuna. |
| HTG | Haitian gourde. |
| HUF | Hungarian forint. |
| IDR | Indonesian rupiah. |
| ILS | Israeli new sheqel. |
| INR | Indian rupee. |
| IQD | Iraqi dinar. |
| IRR | Iranian rial. |
| ISK | Icelandic kr�na. |
| JMD | Jamaican dollar. |
| JOD | Jordanian dinar. |
| JPY | Japanese yen. |
| KES | Kenyan shilling. |
| KGS | Kyrgyzstani som. |
| KHR | Cambodian riel. |
| KMF | Comoro franc. |
| KPW | North Korean won. |
| KRW | South Korean won. |
| KWD | Kuwaiti dinar. |
| KYD | Cayman Islands dollar. |
| KZT | Kazakhstani tenge. |
| LAK | Lao kip. |
| LBP | Lebanese pound. |
| LKR | Sri Lanka rupee. |
| LRD | Liberian dollar. |
| LSL | Lesotho loti. |
| LTL | Lithuanian litas. |
| LVL | Latvian lats. |
| LYD | Libyan dinar. |
| MAD | Moroccan dirham. |
| MDL | Moldovan leu. |
| MGA | Malagasy ariary. |
| MKD | Macedonian denar. |
| MMK | Myanma kyat. |
| MNT | Mongolian tugrik. |
| MOP | Macanese pataca. |
| MRO | Mauritanian ouguiya. |
| MUR | Mauritian rupee. |
| MVR | Maldivian rufiyaa. |
| MWK | Malawian kwacha. |
| MXN | Mexican peso. |
| MYR | Malaysian ringgit. |
| MZN | Mozambican metical. |
| NAD | Namibian dollar. |
| NGN | Nigerian naira. |
| NIO | Cordoba oro. |
| NOK | Norwegian krone. |
| NPR | Nepalese rupee. |
| NZD | New Zealand dollar. |
| OMR | Omani rial. |
| PAB | Panamanian balboa. |
| PEN | Peruvian nuevo sol. |
| PGK | Papua New Guinean kina. |
| PHP | Philippine peso. |
| PKR | Pakistani rupee. |
| PLN | Polish zloty. |
| PYG | Paraguayan guaran�. |
| QAR | Qatari rial. |
| RON | Romanian new leu. |
| RSD | Serbian dinar. |
| RUB | Russian rouble. |
| RWF | Rwandan franc. |
| SAR | Saudi riyal. |
| SBD | Solomon Islands dollar. |
| SCR | Seychelles rupee. |
| SDG | Sudanese pound. |
| SEK | Swedish krona/kronor. |
| SGD | Singapore dollar. |
| SHP | Saint Helena pound. |
| SLL | Sierra Leonean leone. |
| SOS | Somali shilling. |
| SRD | Surinamese dollar. |
| STD | S�o Tom� and Pr�ncipe dobra. |
| SYP | Syrian pound. |
| SZL | Lilangeni. |
| THB | Thai baht. |
| TJS | Tajikistani somoni. |
| TMT | Turkmenistani manat. |
| TND | Tunisian dinar. |
| TOP | Tongan pa'anga. |
| TRY | Turkish lira. |
| TTD | Trinidad and Tobago dollar. |
| TWD | New Taiwan dollar. |
| TZS | Tanzanian shilling. |
| UAH | Ukrainian hryvnia. |
| UGX | Ugandan shilling. |
| USD | United States dollar. |
| UYU | Uruguayan peso. |
| UZS | Uzbekistan som. |
| VEF | Venezuelan bol�var fuerte. |
| VND | Vietnamese Dong. |
| VUV | Vanuatu vatu. |
| WST | Samoan tala. |
| XAF | CFA franc BEAC. |
| XCD | East Caribbean dollar. |
| XOF | CFA Franc BCEAO. |
| XPF | CFP franc. |
| YER | Yemeni rial. |
| ZAR | South African rand. |
| ZMK | Zambian kwacha. |
| ZWL | Zimbabwe dollar. |

CIM17v40-CurrentStatusSC
### CurrentStatusSC

ACTIVE

INACTIVE


| name | description |
|------|-------------|
| ACTIVE | |
| INACTIVE | |

CIM17v40-CurveStyle
### (Attribute) CurveStyle

Style or shape of curve.


| name | description |
|------|-------------|
| constantYValue | The Y-axis values are assumed constant until the next curve point and prior to the first curve point. |
| straightLineYValues | The Y-axis values are assumed to be a straight line between values. Also known as linear interpolation. |

CIM17v40-CustomerBillingKind
### (Attribute) CustomerBillingKind

Kind of customer billing.


| name | description |
|------|-------------|
| consolidatedEss | Consolidated bill from energy service supplier (ESS). |
| consolidatedUdc | Consolidated bill from utility distribution company (UDC). |
| other | |
| separateEssUdc | Separate bills from ESS and UDC. |

CIM17v40-CustomerKind
### (Attribute) CustomerKind

Kind of customer.


| name | description |
|------|-------------|
| commercialIndustrial | Commercial industrial customer. |
| energyServiceScheduler | Customer as energy service scheduler. |
| energyServiceSupplier | Customer as energy service supplier. |
| enterprise | Enterprise customer |
| internalUse | Internal use customer. |
| other | Other kind of customer. |
| pumpingLoad | Pumping load customer. |
| regionalOperator | Regional Operator customer |
| residential | Residential customer. |
| residentialAndCommercial | Residential and commercial customer. |
| residentialAndStreetlight | Residential and streetlight customer. |
| residentialFarmService | Residential farm service customer. |
| residentialStreetlightOthers | Residential streetlight or other related customer. |
| subsidiary | Subsidiary customer |
| windMachine | Wind machine customer. |

CIM17v40-DAMMarketType
### DAMMarketType


| name | description |
|------|-------------|
| DAM | |

CIM17v40-DCConverterOperatingModeKind
### (Attribute) DCConverterOperatingModeKind

The operating mode of an HVDC bipole.


| name | description |
|------|-------------|
| bipolar | Bipolar operation. |
| monopolarGroundReturn | Monopolar operation with ground return. |
| monopolarMetallicReturn | Monopolar operation with metallic return. |

CIM17v40-DCPolarityKind
### (Attribute) DCPolarityKind

Polarity for DC circuits.


| name | description |
|------|-------------|
| middle | Middle pole. The converter terminal is the midpoint in a bipolar or symmetric monopole configuration. The midpoint can be grounded and/or have a metallic return. |
| negative | Negative pole. The converter terminal is intended to operate at a negative voltage relative the midpoint or positive terminal. |
| positive | Positive pole. The converter terminal is intended to operate at a positive voltage relative the midpoint or negative terminal. |

CIM17v40-DERParameterKind
### (Attribute) DERParameterKind

Specifies the DER parameters related to the unit of power, ramp rate and regulation flows.


| name | description |
|------|-------------|
| activePower | The amount of power being used, measured in Watts. |
| apparentPower | The combination of reactive power and active power, and is the product of voltage and current without reference to the phase angle. |
| decreasingRampRate | An indication of whether the ramp rate associated with a curve is negative. |
| highFilterBiDirectionalRegulation | AC voltage regulation of high frequency |
| highFilterDownRegulation | High Pass Frequency Regulation downwards. |
| highFilterUpRegulation | High Pass Frequency Regulation upwards. |
| increasingRampRate | An indication of whether the ramp rate associated with a curve is positive. |
| lowFilterBiDirectionalRegulation | Used to filter out the sinosuidal disturbances to the grid. |
| lowFilterDownRegulation | Low Pass Frequency Regulation downwards. |
| lowFilterUpRegulation | Low Pass Frequency Regulation upwards. |
| reactivePower | The measure of reactance, measured in Vars. |
| voltage | The measure of difference in potential between two points, measured in Volts. |

CIM17v40-DERUnitSymbol
### (Attribute) DERUnitSymbol

The units defined for usage in DER related contexts. This class is a subset plus possible additions of the UnitSymbol Class in the CIM Domain Package.


| name | description |
|------|-------------|
| A | Current in Ampere. |
| Ah | Ampere-hours, Ampere-hours. |
| As | Ampere seconds (A�s). |
| Btu | Energy, British Thermal Unit. |
| Hz | Frequency in Hertz (1/s). |
| Q | Quantity power, Q. |
| Qh | Quantity energy, Qh. |
| V | Electric potential in Volt (W/A). |
| VA | Apparent power in Volt Ampere (See also real power and reactive power.) |
| VAh | Apparent energy in Volt Ampere hours. |
| VAr | Reactive power in Volt Ampere reactive. The �reactive� or �imaginary� component of electrical power (VIsin(phi)). (See also real power and apparent power).Note: Different meter designs use different methods to arrive at their results. Some meters may compute reactive power as an arithmetic value, while others compute the value vectorially. The data consumer should determine the method in use and the suitability of the measurement for the intended purpose. |
| VArh | Reactive energy in Volt Ampere reactive hours. |
| VPerVA | Power factor, PF, the ratio of the active power to the apparent power. Note: The sign convention used for power factor will differ between IEC meters and EEI (ANSI) meters. It is assumed that the data consumers understand the type of meter being used and agree on the sign convention in use at any given utility. |
| VPerVAr | Power factor, PF, the ratio of the active power to the apparent power. Note: The sign convention used for power factor will differ between IEC meters and EEI (ANSI) meters. It is assumed that the data consumers understand the type of meter being used and agree on the sign convention in use at any given utility. |
| Vh | Volt-hour, Volt hours. |
| Vs | Volt second (Ws/A). |
| W | Real power in Watt (J/s). Electrical power may have real and reactive components. The real portion of electrical power (I�R or VIcos(phi)), is expressed in Watts. (See also apparent power and reactive power.) |
| WPerA | Active power per current flow, watt per Ampere. |
| WPers | Ramp rate in Watt per second. |
| Wh | Real energy in Watt hours. |
| deg | Plane angle in degrees. |
| degC | Relative temperature in degrees Celsius.In the SI unit system the symbol is �C. Electric charge is measured in coulomb that has the unit symbol C. To distinguish degree Celsius form coulomb the symbol used in the UML is degC. Reason for not using �C is the special character � is difficult to manage in software. |
| h | Time, hour = 60 min = 3600 s. |
| min | Time, minute = 60 s. |
| ohm | Electric resistance in ohm (V/A). |
| ohmPerm | Electric resistance per length in ohm per metre ((V/A)/m). |
| ohmm | resistivity, Ohm metre, (rho). |
| onePerHz | Reciprocal of frequency (1/Hz). |
| s | Time in seconds. |
| therm | Energy, Therm. |

CIM17v40-DINStandardEditionKind
### (Attribute) DINStandardEditionKind

List of editions for DIN standards.


| name | description |
|------|-------------|
| 1985 | 1985 standard edition. |
| none | No standard edition. |
| unknown | Unknown standard edition. |

CIM17v40-DINStandardKind
### (Attribute) DINStandardKind

List of DIN standards.


| name | description |
|------|-------------|
| 51353 | Testing of insulating oils; detection of corrosive sulfur; silver strip test. |

CIM17v40-DemographicKind
### (Attribute) DemographicKind

Demographic kind of a land property.


| name | description |
|------|-------------|
| other | |
| rural | |
| urban | |

CIM17v40-DependencyKind
### (Attribute) DependencyKind


| name | description |
|------|-------------|
| mutuallyExclusive | |
| required | |

CIM17v40-DeploymentStateKind
### (Attribute) DeploymentStateKind

Possible states of asset deployment.


| name | description |
|------|-------------|
| inService | Asset in service in deployment location. |
| installed | Asset installed in deployment location. |
| notYetInstalled | Asset not yet installed in deployment location. |
| outOfService | Asset out of service, but in deployment location. |
| removed | Asset removed from deployment location. |

CIM17v40-DesignKind
### (Attribute) DesignKind

Kind of design.


| name | description |
|------|-------------|
| asBuilt | |
| estimated | |
| other | |

CIM17v40-DispatchAcceptStatus
### DispatchAcceptStatus


| name | description |
|------|-------------|
| ACCEPT | |
| CANNOT | |
| DECLINE | |
| NON_RESPONSE | |
| OK | |
| PARTIAL | |

CIM17v40-DispatchResponseType
### (Attribute) DispatchResponseType

For example:

NON_RESPONSE

ACCEPT

DECLINE

PARTIAL


| name | description |
|------|-------------|
| ACCEPT | |
| DECLINE | |
| NON_RESPONSE | |
| PARTIAL | |

CIM17v40-DispatchTransactionType
### DispatchTransactionType


| name | description |
|------|-------------|
| Purchase | |
| Sale | |

CIM17v40-DobleStandardEditionKind
### (Attribute) DobleStandardEditionKind

List of editions for Doble standards.


| name | description |
|------|-------------|
| none | No edition. |
| unknown | Unknown edition. |

CIM17v40-DobleStandardKind
### (Attribute) DobleStandardKind

List of Doble standards.


| name | description |
|------|-------------|
| methanol | Doble test for methanol. |

CIM17v40-DroopSignalFeedbackKind
### (Attribute) DroopSignalFeedbackKind

Governor droop signal feedback source.


| name | description |
|------|-------------|
| electricalPower | Electrical power feedback (connection indicated as 1 in the block diagrams of models, e.g. GovCT1, GovCT2). |
| fuelValveStroke | Fuel valve stroke feedback (true stroke) (connection indicated as 2 in the block diagrams of model, e.g. GovCT1, GovCT2). |
| governorOutput | Governor output feedback (requested stroke) (connection indicated as 3 in the block diagrams of models, e.g. GovCT1, GovCT2). |
| none | No droop signal feedback, is isochronous governor. |

CIM17v40-EPAStandardEditionKind
### (Attribute) EPAStandardEditionKind

List of editions for EPA standards.


| name | description |
|------|-------------|
| A | Standard edition A. |
| none | No standard edition. |
| unknown | Unknown standard edition. |

CIM17v40-EPAStandardKind
### (Attribute) EPAStandardKind

List of EPA standards.


| name | description |
|------|-------------|
| 8082 | Polychlorinated Biphenyls (PCBs) by Gas Chromatography. |

CIM17v40-ERTConfidenceKind
### (Attribute) ERTConfidenceKind

The estimated restoration time (ERT) is the amount of time estimated to correct the outage and can have a confidence factor applied such as high or low confidence that the ERT will be accomplished. This confidence factor may be updated as needed during the outage period - just as the actual ERT can be updated.


| name | description |
|------|-------------|
| high | there is a high confidence that the ERT will be accomplished |
| low | there is a low confidence that the ERT will be accomplished. |

CIM17v40-EmissionType
### (Attribute) EmissionType

The type of emission.


| name | description |
|------|-------------|
| carbonDioxide | Carbon dioxide. |
| carbonDisulfide | Carbon disulfide. |
| chlorine | Chlorine. |
| hydrogenSulfide | Hydrogen sulfide. |
| nitrogenOxide | Nitrogen oxide. |
| sulfurDioxide | Sulfur dioxide. |

CIM17v40-EmissionValueSource
### (Attribute) EmissionValueSource

The source of the emission value.


| name | description |
|------|-------------|
| calculated | Calculated. |
| measured | Measured. |

CIM17v40-EndDeviceFunctionKind
### (Attribute) EndDeviceFunctionKind

Kind of end device function.


| name | description |
|------|-------------|
| autonomousDst | Autonomous application of daylight saving time (DST). |
| demandResponse | Demand response functions. |
| electricMetering | Electricity metering. |
| gasMetering | Gas metering. |
| metrology | Presentation of metered values to a user or another system (always a function of a meter, but might not be supported by a load control unit). |
| onRequestRead | On-request reads. |
| outageHistory | Reporting historical power interruption data. |
| relaysProgramming | Support for one or more relays that may be programmable in the meter (and tied to TOU, time pulse, load control or other functions). |
| reverseFlow | Detection and monitoring of reverse flow. |
| waterMetering | Water metering. |

CIM17v40-EnergyPriceIndexType
### (Attribute) EnergyPriceIndexType

For example:

WHOLESALE

RETAIL

BOTH


| name | description |
|------|-------------|
| BOTH | |
| RETAIL | |
| WHOLESALE | |

CIM17v40-EnergyProductType
### (Attribute) EnergyProductType

Energy product type.


| name | description |
|------|-------------|
| DYN | Dynamic |
| FIRM | Firm |
| NFRM | Non Firm |
| WHL | Wheeling |

CIM17v40-EnergyTransactionType
### (Attribute) EnergyTransactionType

Defines the state of a transaction.


| name | description |
|------|-------------|
| approve | Approve |
| deny | Deny |
| study | Study |

CIM17v40-EnergyTypeCode
### EnergyTypeCode

Valid Enumerations:

1) DASE Day Ahead Scheduled Energy;

2) DSSE Day Ahead Incremental Self Schedule Energy;

3) DABE Day Ahead Incremental Energy Bid Awarded Energy;

4) OE Optimal Energy;

5) HASE Hour ahead pre-dispatched schedule energy;

6) SRE Standard Ramping Energy;

7) RED Ramping Energy Deviation;

8) EDE Exceptional Dispatch energy;

9) RMRE RMR Energy;

10) MSSLFE MSSLF Energy;

11) RE Residual Energy;

12) MLE Minimum Load Energy;

13) SE SLIC Energy;

14) RTSSE Real time self scheduled energy;

15) DMLE Day ahead minimum load energy;

16) PE Pumping Energy;

17) TEE Total Expected Energy;

18) DAPE - Day-Ahead Pumping Energy;


| name | description |
|------|-------------|
| DABE | |
| DAPE | |
| DASE | |
| DMLE | |
| DSSE | |
| EDE | |
| HASE | |
| MLE | |
| MSSLFE | |
| OE | |
| PE | |
| RE | |
| RED | |
| RMRE | |
| RTSSE | |
| SE | |
| SRE | |
| TEE | |

CIM17v40-EnergyTypeKind
### (Attribute) EnergyTypeKind


| name | description |
|------|-------------|
| ConsumerLoad | |
| IndustrialLoad | |
| Other | |
| PVpark | |
| WindPark | |

CIM17v40-EnvironmentalDiscreteKind
### (Attribute) EnvironmentalDiscreteKind

Discrete (integer) measuring an environmental condition.


| name | description |
|------|-------------|
| cloudCover | Cloud cover in octa. |

CIM17v40-EquipmentStatusType
### (Attribute) EquipmentStatusType

Status of equipment.


| name | description |
|------|-------------|
| In | Equipment is in. |
| Out | Equipment is out. |

CIM17v40-ErpAccountKind
### (Attribute) ErpAccountKind

Kind of ERP account.


| name | description |
|------|-------------|
| estimate | |
| normal | |
| reversal | |
| statistical | |

CIM17v40-ErpInvoiceKind
### (Attribute) ErpInvoiceKind

Kind of ERP invoice.


| name | description |
|------|-------------|
| purchase | |
| sale | |

CIM17v40-ErpInvoiceLineItemKind
### (Attribute) ErpInvoiceLineItemKind

Kind of invoice line item.


| name | description |
|------|-------------|
| initial | |
| other | |
| recalculation | |

CIM17v40-ExcIEEEST1AUELselectorKind
### (Attribute) ExcIEEEST1AUELselectorKind

Types of connections for the UEL input used in ExcIEEEST1A.


| name | description |
|------|-------------|
| ignoreUELsignal | Ignore UEL signal. |
| inputAddedToErrorSignal | UEL input added to error signal. |
| inputHVgateErrorSignal | UEL input HV gate with error signal. |
| inputHVgateVoltageOutput | UEL input HV gate with voltage regulator output. |

CIM17v40-ExcREXSFeedbackSignalKind
### (Attribute) ExcREXSFeedbackSignalKind

Types of rate feedback signals.


| name | description |
|------|-------------|
| fieldCurrent | The exciter field current is used. |
| fieldVoltage | The voltage regulator output voltage is used. It is the same as exciter field voltage. |
| outputVoltage | The output voltage of the exciter is used. |

CIM17v40-ExcST6BOELselectorKind
### (Attribute) ExcST6BOELselectorKind

Types of connections for the OEL input used for static excitation systems type 6B.


| name | description |
|------|-------------|
| afterUEL | The connection is after UEL. Corresponds to <i>OELin</i> = 2 on the ExcST6B diagram. |
| beforeUEL | The connection is before UEL. Corresponds to <i>OELin</i> = 1 on the ExcST6B diagram. |
| noOELinput | No OEL input is used. Corresponds to <i>OELin</i> not = 1 and not = 2 on the ExcST6B diagram. Original ExcST6B model would have called this <i>OELin</i> = 0. |

CIM17v40-ExcST7BOELselectorKind
### (Attribute) ExcST7BOELselectorKind

Types of connections for the OEL input used for static excitation systems type 7B.


| name | description |
|------|-------------|
| addVref | The signal is added to <i>Vref</i>. Corresponds to <i>OELin</i> = 1 on the ExcST7B diagram. |
| inputLVgate | The signal is connected into the input <i>LVGate</i>. Corresponds to <i>OELin</i> = 2 on the ExcST7B diagram. |
| noOELinput | No OEL input is used. Corresponds to <i>OELin</i> not = 1 and not = 2 and not = 3 on the ExcST7B diagram. Original ExcST7B model would have called this <i>OELin</i> = 0. |
| outputLVgate | The signal is connected into the output <i>LVGate</i>. Corresponds to <i>OELin</i> = 3 on the ExcST7B diagram. |

CIM17v40-ExcST7BUELselectorKind
### (Attribute) ExcST7BUELselectorKind

Types of connections for the UEL input used for static excitation systems type 7B.


| name | description |
|------|-------------|
| addVref | The signal is added to <i>Vref</i>. Corresponds to <i>UELin</i> = 1 on the ExcST7B diagram. |
| inputHVgate | The signal is connected into the input <i>HVGate</i>. Corresponds to <i>UELin</i> = 2 on the ExcST7B diagram. |
| noUELinput | No UEL input is used. Corresponds to <i>UELin</i> not = 1 and not = 2 and not = 3 on the ExcST7B diagram. Original ExcST7B model would have called this <i>UELin</i> = 0. |
| outputHVgate | The signal is connected into the output <i>HVGate</i>. Corresponds to <i>UELin</i> = 3 on the ExcST7B diagram. |

CIM17v40-ExecutionType
### (Attribute) ExecutionType

Execution types of Market Runs.


| name | description |
|------|-------------|
| DA | Day Ahead |
| HASP | Real TIme Hour Ahead Execution |
| RTD | Real Time Dispatch |
| RTPD | Real Time Pre-dispatch |

CIM17v40-FACTSDeviceKind
### (Attribute) FACTSDeviceKind

Kind of FACTS device.


| name | description |
|------|-------------|
| statcom | Static synchronous compensator. |
| svc | Static VAr compensator. |
| tcpar | Thyristor-controlled phase-angle regulator. |
| tcsc | Thyristor-controlled series capacitor. |
| tcvl | Thyristor-controlled voltage limiter. |
| tsbr | Thyristor-switched braking resistor. |
| tssc | Thyristor-switched series capacitor. |
| upfc | Unified power flow controller. |

CIM17v40-FScale
### (Attribute) FScale

Fujita scale (referred to as EF-scale starting in 2007) for tornado damage. A set of wind estimates (not measurements) based on damage. It uses three-second gusts estimated at the point of damage based on a judgment of 8 levels of damage to 28 indicators. These estimates vary with height and exposure.

The 3 second gust is not the same wind as in standard surface observations.

Enumerations based on NOAA conventions.


| name | description |
|------|-------------|
| five | Over 200 mph 3-second gust. |
| four | 166-200 mph 3-second gust. |
| minusNine | Unknown. |
| one | 86-110 mph 3-second gust. |
| three | 136-165 mph 3-second gust. |
| two | 111-135 mph 3-second gust. |
| zero | 65-85 mph 3-second gust. |

CIM17v40-FacilityKind
### (Attribute) FacilityKind

Types of facilities at which an asset can be deployed.


| name | description |
|------|-------------|
| distributionPoleTop | Distribution pole top. |
| substationDistribution | Distribution substation. |
| substationFossilPlant | Fossil plant substation. |
| substationHydroPlant | Hydro plant substation. |
| substationNuclearPlant | Nuclear plant substation. |
| substationSubTransmission | Subtransmission substation. |
| substationTransmission | Transmission substation. |

CIM17v40-FailureIsolationMethodKind
### (Attribute) FailureIsolationMethodKind

How the failure has been isolated.


| name | description |
|------|-------------|
| breakerOperation | Isolated via breaker operation. |
| burnedInTheClear | Isolated by equipment burning in the clear. |
| fuse | Isolated by fuse. |
| manuallyIsolated | Isolated by manual operation. |
| other | Isolated by other action. |

CIM17v40-FaultIndicatorResetKind
### (Attribute) FaultIndicatorResetKind

Kind of resetting the fault indicators.


| name | description |
|------|-------------|
| automatic | |
| manual | |
| other | |
| remote | |

CIM17v40-FlagTypeRMR
### (Attribute) FlagTypeRMR

Indicates whether the unit is RMR and it's condition type, for example:

N' - not an RMR unit

'1' - RMR Condition 1 unit

'2' - RMR Condition 2 unit


| name | description |
|------|-------------|
| 1 | '1' - RMR Condition 1 unit |
| 2 | '2' - RMR Condition 2 unit |
| N | 'N' - not an RMR unit |

CIM17v40-FlowDirectionKind
### (Attribute) FlowDirectionKind

Kind of flow direction for reading/measured values proper to some commodities such as, for example, energy, power, demand.


| name | description |
|------|-------------|
| forward | "Delivered," or "Imported" as defined 61968-2.Forward Active Energy is a positive kWh value as one would naturally expect to find as energy is supplied by the utility and consumed at the service.Forward Reactive Energy is a positive VArh value as one would naturally expect to find in the presence of inductive loading.In polyphase metering, the forward energy register is incremented when the sum of the phase energies is greater than zero:<img src="HTS_1.PNG" width="209" height="16" border="0" alt="graphic"/> |
| lagging | Typically used to describe that a power factor is lagging the reference value.Note 1: When used to describe VA, �lagging� describes a form of measurement where reactive power is considered in all four quadrants, but real power is considered only in quadrants I and IV.Note 2: When used to describe power factor, the term �Lagging� implies that the PF is negative. The term �lagging� in this case takes the place of the negative sign. If a signed PF value is to be passed by the data producer, then the direction of flow enumeration zero (none) should be used in order to avoid the possibility of creating an expression that employs a double negative. The data consumer should be able to tell from the sign of the data if the PF is leading or lagging. This principle is analogous to the concept that �Reverse� energy is an implied negative value, and to publish a negative reverse value would be ambiguous.Note 3: Lagging power factors typically indicate inductive loading. |
| leading | Typically used to describe that a power factor is leading the reference value.Note: Leading power factors typically indicate capacitive loading. |
| net | {vbar}Forward{vbar} - {vbar}Reverse{vbar}, See 61968-2.Note: In some systems, the value passed as a �net� value could become negative. In other systems the value passed as a �net� value is always a positive number, and rolls-over and rolls-under as needed. |
| none | Not Applicable (N/A) |
| q1minusQ4 | Q1 minus Q4 |
| q1plusQ2 | Reactive positive quadrants. (The term �lagging� is preferred.) |
| q1plusQ3 | Quadrants 1 and 3 |
| q1plusQ4 | Quadrants 1 and 4 usually represent forward active energy |
| q2minusQ3 | Q2 minus Q3 |
| q2plusQ3 | Quadrants 2 and 3 usually represent reverse active energy |
| q2plusQ4 | Quadrants 2 and 4 |
| q3minusQ2 | Q3 minus Q2 |
| q3plusQ4 | Reactive negative quadrants. (The term �leading� is preferred.) |
| quadrant1 | Q1 only |
| quadrant2 | Q2 only |
| quadrant3 | Q3 only |
| quadrant4 | Q4 only |
| reverse | Reverse Active Energy is equivalent to "Received," or "Exported" as defined in 61968-2.Reverse Active Energy is a positive kWh value as one would expect to find when energy is backfed by the service onto the utility network.Reverse Reactive Energy is a positive VArh value as one would expect to find in the presence of capacitive loading and a leading Power Factor.In polyphase metering, the reverse energy register is incremented when the sum of the phase energies is less than zero:<img src="HTS_1.PNG" width="209" height="16" border="0" alt="graphic"/>Note: The value passed as a reverse value is always a positive value. It is understood by the label �reverse� that it represents negative flow. |
| total | {vbar}Forward{vbar} + {vbar}Reverse{vbar}, See 61968-2.The sum of the commodity in all quadrants Q1+Q2+Q3+Q4.In polyphase metering, the total energy register is incremented when the absolute value of the sum of the phase energies is greater than zero:<img src="HTS_1.PNG" width="217" height="16" border="0" alt="graphic"/> |
| totalByPhase | In polyphase metering, the total by phase energy register is incremented when the sum of the absolute values of the phase energies is greater than zero:<img src="HTS_1.PNG" width="234" height="16" border="0" alt="graphic"/>In single phase metering, the formulas for �Total� and �Total by phase� collapse to the same expression. For communication purposes however, the �Total� enumeration should be used with single phase meter data. |

CIM17v40-FlowDirectionType
### (Attribute) FlowDirectionType

Specifies the direction of energy flow in the flowgate.


| name | description |
|------|-------------|
| Forward | Forward direction. |
| Reverse | Reverse direction. |

CIM17v40-FrancisGovernorControlKind
### (Attribute) FrancisGovernorControlKind

Governor control flag for Francis hydro model.


| name | description |
|------|-------------|
| electromechanicalElectrohydraulic | Electromechanical and electrohydraulic regulator (Cflag=3). |
| mechanicHydraulicTransientFeedback | Mechanic-hydraulic regulator with transient feedback (Cflag=2). |
| mechanicHydrolicTachoAccelerator | Mechanic-hydraulic regulator with tacho-accelerometer (Cflag = 1). |

CIM17v40-FuelSource
### (Attribute) FuelSource

For example:

Bio Gas (Landfill, Sewage, Digester, etc.)

Biomass

Coal

DIST

Natural Gas

Geothermal

HRCV

None

Nuclear

Oil

Other

Solar

Waste to Energy

Water

Wind


| name | description |
|------|-------------|
| BGAS | Bio Gas (Landfill, Sewage, Digester, etc.) |
| BIOM | Biomass |
| COAL | Coal |
| DIST | |
| GAS | |
| GEOT | GeoThermal |
| HRCV | |
| NG | Natural Gas |
| NNG | Non-Natural Gas |
| NONE | |
| NUCL | Nuclear |
| OIL | |
| OTHR | Other |
| SOLR | Solar |
| WAST | Waste to Energy |
| WATR | Water |
| WIND | Wind |

CIM17v40-FuelType
### (Attribute) FuelType

Type of fuel.


| name | description |
|------|-------------|
| brownCoalLignite | Brown coal lignite. |
| coal | Generic coal, not including lignite type. |
| coalDerivedGas | Coal derived gas. |
| gas | Natural gas. |
| hardCoal | Hard coal. |
| lignite | The fuel is lignite coal. Note that this is a special type of coal, so the other enum of coal is reserved for hard coal types or if the exact type of coal is not known. |
| oil | Oil. |
| oilShale | Oil Shale. |
| other | Any fuel type not included in the rest of the enumerated value. |
| peat | Peat. |

CIM17v40-GateLogicKind
### (Attribute) GateLogicKind

Define the different logical operations.


| name | description |
|------|-------------|
| and | A logical AND operation. True when all input are true. |
| nand | A logical NAND operation. False when all input are true. |
| nor | A logical NOR operation. False when one or more input are true. |
| not | A logical NOT operation. Only one input and true input will give false out and false in will give true out. An inverter. |
| or | A logical OR operation. True when one or more input are true. |
| xnor | A logical XNOR operation. The function is the inverse of the exclusive OR (XOR) gate. All input false or true will give true. Otherwise false. |
| xor | A logical XOR operation. All input false or true will give false. Otherwise true. |

CIM17v40-GeneratorControlMode
### (Attribute) GeneratorControlMode

Unit control modes.


| name | description |
|------|-------------|
| pulse | Pulse control mode. |
| setpoint | Setpoint control mode. |

CIM17v40-GeneratorControlSource
### (Attribute) GeneratorControlSource

The source of controls for a generating unit.


| name | description |
|------|-------------|
| offAGC | Off of automatic generation control (AGC). |
| onAGC | On automatic generation control (AGC). |
| plantControl | Plant is controlling. |
| unavailable | Not available. |

CIM17v40-GenericNonLinearLoadModelKind
### (Attribute) GenericNonLinearLoadModelKind

Type of generic non-linear load model.


| name | description |
|------|-------------|
| exponentialRecovery | Exponential recovery model. |
| loadAdaptive | Load adaptive model. |

CIM17v40-GeosphericAnalogKind
### (Attribute) GeosphericAnalogKind

Kinds of analogs (floats) measuring a geospheric condition.


| name | description |
|------|-------------|
| lightningDensity | Flash rate in strikes/hour/km<sup>2</sup>. |
| seismicEastWest | |
| seismicNorthSouth | |
| seismicVertical | |
| snowPackDepth | |
| temperature | |

CIM17v40-GovHydro4ModelKind
### (Attribute) GovHydro4ModelKind

Possible types of GovHydro4 models.


| name | description |
|------|-------------|
| francisPelton | Francis or Pelton model. |
| kaplan | Kaplan model. |
| simple | Simple model. |

CIM17v40-HydroEnergyConversionKind
### (Attribute) HydroEnergyConversionKind

Specifies the capability of the hydro generating unit to convert energy as a generator or pump.


| name | description |
|------|-------------|
| generator | Able to generate power, but not able to pump water for energy storage. |
| pumpAndGenerator | Able to both generate power and pump water for energy storage. |

CIM17v40-HydroPlantStorageKind
### (Attribute) HydroPlantStorageKind

The type of hydro power plant.


| name | description |
|------|-------------|
| pumpedStorage | Pumped storage. |
| runOfRiver | Run of river. |
| storage | Storage. |

CIM17v40-HydroTurbineKind
### (Attribute) HydroTurbineKind

Type of turbine.


| name | description |
|------|-------------|
| francis | Francis. |
| kaplan | Kaplan. |
| pelton | Pelton. |

CIM17v40-HydrosphericAnalogKind
### (Attribute) HydrosphericAnalogKind

Kinds of analogs (floats) measuring a hydrospheric condition.


| name | description |
|------|-------------|
| floodLevel | |
| stormSurgeHeight | |
| surfaceTemperature | |
| waterTemperature | |
| waveHeight | |

CIM17v40-ICCPAccessPrivilegeKind
### (Attribute) ICCPAccessPrivilegeKind

Provides access privilege information regarding an ICCP point.


| name | description |
|------|-------------|
| readOnly | Indicates that the remote is not allowed to change the value of the ICCPPoint. |
| readWrite | Indicates that the remote can not only get the value, but may also change the value of the ICCP Point. |

CIM17v40-ICCPPointKind
### (Attribute) ICCPPointKind

The kind of ICCP point that is to be conveyed.


| name | description |
|------|-------------|
| discrete | Indicates that an ICCP discrete type is to be conveyed. |
| packedProtectionEvent | Indicates that an ICCP packed Protection Event is to be conveyed. |
| real | Indicates that an ICCP real type is to be conveyed. |
| singleProtectionEvent | Indicates that an ICCP single Protection Event type is to be conveyed. |
| state | Indicates that an ICCP state type is to be conveyed. |
| stateSupplemental | Indicates that an ICCP state supplemental type is to be conveyed. |

CIM17v40-ICCPQualityKind
### (Attribute) ICCPQualityKind

Indicates the type of quality information that is to be exchanged. For protection events the value shall be "none".


| name | description |
|------|-------------|
| extended | Indicates that only extended information is to be provided. |
| extendedwithQualityTime | Provides quality, timestamp, and extended information. |
| none | Indicates that no quality is conveyed with the ICCP point. |
| qualityAndTime | Indicates that quality and a timestamp are to be provided. |
| qualityOnly | Indicates that only quality is to be provided. |

CIM17v40-ICCPScopeKind
### (Attribute) ICCPScopeKind

Specifies the control centre scope.


| name | description |
|------|-------------|
| iCC | Inter-Control Centre scope � available for exchange between the control centres in the bilateral table. |
| vCC | Virtual Control Centre Scope � globally available. |

CIM17v40-IECStandardEditionKind
### (Attribute) IECStandardEditionKind

List of editions for IEC standards.


| name | description |
|------|-------------|
| 1963 | 1963 edition. |
| 1967 | 1967 edition. |
| 1973 | 1973 edition. |
| 1974 | 1974 edition. |
| 1977 | 1977 edition. |
| 1978 | 1978 edition. |
| 1979 | 1979 edition. |
| 1985 | 1985 edition. |
| 1989 | 1989 edition. |
| 1992 | 1992 edition. |
| 1992/AMD1:2004 | 1992/AMD1:2004 edition. |
| 1992/COR1:1992 | 1992/COR1:1992 edition. |
| 1993 | 1993 edition. |
| 1995 | 1995 edition. |
| 1997 | 1997 edition. |
| 1998 | 1998 edition. |
| 2004 | 2004 edition. |
| 2004/AMD1:2007 | 2004/AMD1:2007 edition. |
| 2004/AMD1:2007CSV | 2004/AMD1:2007CSV edition. |
| 2005 | 2005 edition. |
| 2007 | 2007 edition. |
| 2008 | 2008 edition. |
| 2010 | 2010 edition. |
| 2011 | 2011 edition. |
| 2012 | 2012 edition. |
| 2013 | 2013 edition. |
| 2013/COR:2013 | 2013/COR:2013 edition. |
| none | No edition. |
| unknown | Unknown edition. |

CIM17v40-IECStandardKind
### (Attribute) IECStandardKind

List of IEC standards.


| name | description |
|------|-------------|
| 60156 | Insulating liquids - Determination of the breakdown voltage at power frequency - Test method. |
| 60243-1 | Electric strength of insulating materials - Test methods - Part 1: Tests at power frequencies. |
| 60243-2 | Electric strength of insulating materials - Test methods - Part 2: Additional requirements for tests using direct voltage. |
| 60243-3 | Electric strength of insulating materials - Test methods - Part 3: Additional requirements for 1,2/50 �s impulse tests. |
| 60247 | Insulating liquids - Measurement of relative permittivity, dielectric dissipation factor (tan d) and d.c. resistivity -or-Measurement of relative permittivity, dielectric dissipation factor and d.c. resistivity of insulating liquids -or-Recommended test cells for measuring the resistivity of insulating liquids and methods of cleaning the cells. |
| 60422 | Mineral insulating oils in electrical equipment - Supervision and maintenance guidance. |
| 60450 | Measurement of the average viscometric degree of polymerization of new and aged cellulosic electrically insulating materials. |
| 60567 | Oil-filled electrical equipment - Sampling of gases and analysis of free and dissolved gasses - Guidance -or-Oil-filled electrical equipment - Sampling of gases and of oil for analysis of free and dissolved gases - Guidance -or-Guide for the sampling of gases and of oil form oil-filled electrical equipment and for the analysis of free and dissolved gases. |
| 60666 | Detection and determination of specified additives in mineral insulating oils -or-Detection and determination of specified anti-oxidant additives in insulating oils. |
| 60814 | Insulating liquids - Oil-impregnated paper and pressboard - Determination of water by automatic coulometric Karl Fischer titration. |
| 60970 | Insulating liquids - Methods for counting and sizing particles -or-Methods for counting and sizing particles in insulating liquids. |
| 60997 | Determination of polychlorinated biphenyls (PCBs) in mineral insulating oils by packed column gas chromatography (GC).Withdrawn. |
| 61125 | Unused hydrocarbon based insulating liquids - Test methods for evaluating the oxidation stability. |
| 61198 | Mineral insulating oils - Methods for the determination of 2-furfural and related compounds. |
| 61619 | Insulating liquids - Contamination by polychlorinated biphenyls (PCBs) - Method of determination by capillary column gas chromatography. |
| 61868 | Mineral insulating oils � Determination of kinematic viscosity at very low temperatures. |
| 62535 | Insulating liquids � Test method for detection of potentially corrosive sulphur in used and unused insulating oil. |
| 62697-1 | Test methods for quantitative determination of corrosive sulfur compounds in unused and used insulating liquids - Part 1: Test method for quantitative determination of dibenzyldisulfide (DBDS). |
| 62770 | Fluids for electrotechnical applications � Unused natural esters for transformers and similar electrical equipment. |

CIM17v40-IEEEStandardEditionKind
### (Attribute) IEEEStandardEditionKind

List of editions for IEEE standards.


| name | description |
|------|-------------|
| 1978 | 1978 standard edition. |
| 1995 | 1995 standard edition. |
| none | No standard edition. |
| unknown | Unknown standard edition. |

CIM17v40-IEEEStandardKind
### (Attribute) IEEEStandardKind

List of IEEE standards.


| name | description |
|------|-------------|
| 62 | IEEE Guide for Diagnostic Field Testing of Electric Power Apparatus - Part 1: Oil Filled Power Transformers, Regulators, and Reactors -or-IEEE Guide for Field Testing Power Apparatus Insulation. |

CIM17v40-IPAddressKind
### (Attribute) IPAddressKind

Indicates if the addressing of the IPAccessPoint, gateway, and subnet are per IPv4 or IPv6.


| name | description |
|------|-------------|
| iPv4 | Indicates that IPv4 dotted decimal notation is in use. |
| iPv6 | Indicates that an IPv6 dotted decimal is in use. |

CIM17v40-ISOStandardEditionKind
### (Attribute) ISOStandardEditionKind

List of editions for ISO standards.


| name | description |
|------|-------------|
| 1973 | 1973 standard edition. |
| 1974 | 1974 standard edition. |
| 1976 | 1976 standard edition. |
| 1983 | 1983 standard edition. |
| 1985 | 1985 standard edition. |
| 1988 | 1988 standard edition. |
| 1992 | 1992 standard edition. |
| 1993 | 1993 standard edition. |
| 1994 | 1994 standard edition. |
| 1994/Cor1:1997 | 1994/Cor1:1997 standard edition. |
| 1998 | 1998 standard edition. |
| 2000 | 2000 standard edition. |
| 2002 | 2002 standard edition. |
| 2005 | 2005 standard edition. |
| 2008 | 2008 standard edition. |
| none | No standard edition. |
| unknown | Unknown standard edition. |

CIM17v40-ISOStandardKind
### (Attribute) ISOStandardKind

List of ISO standards.


| name | description |
|------|-------------|
| 1924 | Paper and board -- Determination of tensile strength. |
| 1924-1 | Paper and board -- Determination of tensile properties -- Part 1: Constant rate of loading method. |
| 1924-2 | Paper and board -- Determination of tensile properties -- Part 2: Constant rate of elongation method (20 mm/min) -or-Paper and board -- Determination of tensile properties -- Part 2: Constant rate of elongation method. |
| 1924-3 | Paper and board -- Determination of tensile properties -- Part 3: Constant rate of elongation method (100 mm/min). |
| 2592 | Determination of flash and fire points -- Cleveland open cup method (copied directly from ASTM D92). |
| 2719 | Determination of flash point -- Pensky-Martens closed cup method (copied directly from ASTM D93) -or-Petroleum products and lubricants -- Determination of flash point -- Pensky-Martens closed cup method (copied directly from ASTM D93) -or-Petroleum products -- Determination of flash point -- Pensky-Martens closed cup method (copied directly from ASTM D93). |
| 3016 | Petroleum products -- Determination of pour point -or-Petroleum oils -- Determination of pour point. |
| 3104 | Petroleum products -- Transparent and opaque liquids -- Determination of kinematic viscosity and calculation of dynamic viscosity. |
| 3675 | Crude petroleum and liquid petroleum products -- Laboratory determination of density -- Hydrometer method -or-Crude petroleum and liquid petroleum products -- Laboratory determination of density or relative density -- Hydrometer method. |

CIM17v40-IfdBaseKind
### (Attribute) IfdBaseKind

Excitation base system mode.


| name | description |
|------|-------------|
| ifag | Air gap line mode. |
| iffl | Full load system mode. |
| ifnl | No load system with saturation mode. |

CIM17v40-InUseStateKind
### (Attribute) InUseStateKind

Possible 'in use' states that an asset can be in.


| name | description |
|------|-------------|
| inUse | Asset is deployed (in use) or is being put into use. |
| notReadyForUse | Asset is not ready to be put into use. |
| readyForUse | Asset is ready to be put into use. |

CIM17v40-InputSignalKind
### (Attribute) InputSignalKind

Types of input signals. In dynamics modelling, commonly represented by the <i>j</i> parameter.


| name | description |
|------|-------------|
| branchCurrent | Input signal is amplitude of remote branch current. |
| busFrequency | Input signal is bus voltage fr<font color="#0f0f0f">equency. This could be a terminal frequency or remote frequency.</font> |
| busFrequencyDeviation | Input signal is deviation of bus voltage frequ<font color="#0f0f0f">ency. This could be a terminal frequency deviation or remote frequency deviation.</font> |
| busVoltage | Input signal <font color="#0f0f0f">is bus voltage. This could be a terminal voltage or remote voltage.</font> |
| busVoltageDerivative | Input signal is derivative of bus voltag<font color="#0f0f0f">e. This could be a terminal voltage derivative or remote voltage derivative.</font> |
| fieldCurrent | Input signal is generator field current. |
| generatorAcceleratingPower | Input signal is generator accelerating power. |
| generatorElectricalPower | Input signal is generator electrical power on rated <i>S</i>. |
| generatorMechanicalPower | Input signal is generator mechanical power. |
| rotorAngularFrequencyDeviation | Input signal is rotor or shaft angular frequency deviation. |
| rotorSpeed | Input signal is rotor or shaft speed (angular frequency). |

CIM17v40-InspectionAnalogKind
### (Attribute) InspectionAnalogKind

Analogs typically recorded during a field inspection.


| name | description |
|------|-------------|
| airPressureHPSystemReading | Analog value represents High Pressure system air pressure. |
| airPressureLPSystemReading | Analog value represents Low Pressure system air pressure. |
| airPressureReading | Analog value represents air pressure. |
| compressorHourMeterReading | Analog value represents reading from compressor hour meter. |
| sF6PressureReading | Analog value represents SF6 gas pressure. |

CIM17v40-InspectionDiscreteKind
### (Attribute) InspectionDiscreteKind

Discretes representing breaker inspection result.


| name | description |
|------|-------------|
| bushingOilLevelsOK | Are bushing oil levels OK? |
| checkOilLevelOK | Check oil level OK? |
| controlCabinetHeaterOn | Is the control cabinet heater on? |
| gasIndicatorNormal | Is the circuit switcher gas indicator normal? |
| hydraulicFluidLevelOK | Hydraulic fluid level OK? |
| hydraulicOilLevelOK | Is the hydraulic oil level OK? Can apply to any individual pole. |
| lowToHighPressureCount | Count of ??. |
| motorOperationsCount | Count of motor operations. |
| oilTankLevelsOK | Are the oil tank levels OK? |
| operationCount | Count of operations. |
| pumpMotorOperationCount | Count of pump motor operations. |
| springPressureReadingOK | Is the spring pressure reading OK? Can apply to whole breaker or any individual pole. |
| visibleDamageOrLeaks | Any visible damage and/or oil/air/SF6 leaks?. |

CIM17v40-IntensityCodeKind
### (Attribute) IntensityCodeKind

Kinds of weather condition intensity.


| name | description |
|------|-------------|
| heavy | |
| light | |
| veryHeavy | |
| veryLight | |

CIM17v40-InterTieDirection
### (Attribute) InterTieDirection

Direction of an intertie.


| name | description |
|------|-------------|
| E | Export. |
| I | Import. |

CIM17v40-InterruptingMediumKind
### (Attribute) InterruptingMediumKind

Kinds of interrupting mediums.


| name | description |
|------|-------------|
| airBlast | Air blast. |
| airMagnetic | Air magnetic. |
| bulkOil | Bulk oil. |
| gasSinglePressure | Gas single pressure. |
| gasTwoPressure | Gas two pressure. |
| minimumOil | Minimum oil. |
| vacuum | Vacuum. |

CIM17v40-JobFlagType
### JobFlagType


| name | description |
|------|-------------|
| CREATED | |
| DELETED | |
| MODIFIED | |

CIM17v40-JobScheduleType
### JobScheduleType


| name | description |
|------|-------------|
| CRITICAL | |
| NONCRITICAL | |

CIM17v40-JobStartEndType
### JobStartEndType


| name | description |
|------|-------------|
| END | |
| NA | |
| START | |

CIM17v40-JointConfigurationKind
### (Attribute) JointConfigurationKind

Kind of configuration for joints.


| name | description |
|------|-------------|
| other | |
| wires1to1 | |
| wires2to1 | |
| wires3to1 | |

CIM17v40-JointFillKind
### (Attribute) JointFillKind

Kind of fill for Joint.


| name | description |
|------|-------------|
| airNoFilling | |
| asphaltic | |
| bluefill254 | |
| epoxy | |
| insoluseal | |
| noFillPrefab | |
| noVoid | |
| oil | |
| other | |
| petrolatum | |

CIM17v40-LFCResourceType
### LFCResourceType


| name | description |
|------|-------------|
| GEN | |
| PUMP | |

CIM17v40-LaborelecStandardEditionKind
### (Attribute) LaborelecStandardEditionKind

List of editions for Laborelec standards.


| name | description |
|------|-------------|
| none | No standard edition. |
| unknown | Unknown standard edition. |

CIM17v40-LaborelecStandardKind
### (Attribute) LaborelecStandardKind

List of Laborelec standards.


| name | description |
|------|-------------|
| methanol | Laborelec test for methanol. |

CIM17v40-LandPropertyKind
### (Attribute) LandPropertyKind

Kind of (land) property.


| name | description |
|------|-------------|
| building | Site enclosed within a building. |
| customerPremise | Site with a customer. |
| depot | Storehouse for supplies that also serves as a station for supporting crews. |
| external | Property owned or used by an external party that is not a customer. |
| gridSupplyPoint | Substation where the distribution and transmission networks meet and hence have mixed ownership and mixed operational control. |
| store | Place of storage (e.g., a warehouse) to put aside, or accumulate, material and equipment for use when needed. |
| substation | Transmission network switchyard. |

CIM17v40-LoadFollowingCapacityType
### LoadFollowingCapacityType


| name | description |
|------|-------------|
| DOWN | |
| UP | |

CIM17v40-LoadForecastType
### (Attribute) LoadForecastType

Load forecast zone types.


| name | description |
|------|-------------|
| LFZ | Load forecast zone. |
| LZMS | Metered sub system zone. |

CIM17v40-LocationKind
### (Attribute) LocationKind

The nature of the location being defined for an environmental entity. Possible values are center, perimeter, primary, secondary.


| name | description |
|------|-------------|
| center | The center of a phenomenon. Will typically be used with a Location with a single PositionPoint instance. |
| extent | The area or line of a phenomenon, not the center. Will typically be used with a Location with multiple PositionPoint instances. |
| primary | Primary area to which an environmental alert applies. |
| secondary | Secondary area to which an environmental alert applies. |

CIM17v40-LookUpTableFunctionKind
### (Attribute) LookUpTableFunctionKind


| name | description |
|------|-------------|
| additionalQcurrent | |
| vdcol | |

CIM17v40-MPMTestIdentifierType
### (Attribute) MPMTestIdentifierType

Market power mitigation test identifier type, for example:

1 - Global Price Test

2 - Global Conduct Test

3 - Global Impact Test

4 - Local Price Test

5 - Local Conduct Test

6 - Local Impact Test


| name | description |
|------|-------------|
| 1 | 1 - Global Price Test. |
| 2 | 2 - Global Conduct Test. |
| 3 | 3 - Global Impact Test. |
| 4 | 4 - Local Price Test. |
| 5 | 5 - Local Conduct Test. |
| 6 | 6 - Local Impact Test. |

CIM17v40-MPMTestMethodType
### (Attribute) MPMTestMethodType

Market power mitigation test method type.

Tests with the normal (default) thresholds or tests with the alternate thresholds.


| name | description |
|------|-------------|
| ALTERNATE | Alternate. |
| NORMAL | Normal. |

CIM17v40-MPMTestOutcome
### (Attribute) MPMTestOutcome

For example:

Passed

Failed

Disabled

Skipped


| name | description |
|------|-------------|
| D | Disabled |
| F | Failed |
| P | Passed |
| S | Skipped |

CIM17v40-MQSCHGType
### (Attribute) MQSCHGType

For example:

ADD - add

CHG - change


| name | description |
|------|-------------|
| ADD | |
| CHG | |

CIM17v40-MQSDELType
### MQSDELType

ADD - add

DEL - delete

CHG - change


| name | description |
|------|-------------|
| ADD | |
| CHG | |
| DEL | |

CIM17v40-MQSInstructionSource
### (Attribute) MQSInstructionSource

Valid values, for example:

INS - Instruction from RTM

ACT - Actual instruction after the fact


| name | description |
|------|-------------|
| ACT | |
| INS | |

CIM17v40-MacroPeriodKind
### (Attribute) MacroPeriodKind

Kind of macro period for calculations on read / measured values.


| name | description |
|------|-------------|
| billingPeriod | Captured during the billing period starting at midnight of the first day of the billing period (as defined by the billing cycle day). If during the current billing period, it specifies a period from the start of the current billing period until "now". |
| daily | Daily period starting at midnight. If for the current day, this specifies the time from midnight to "now". |
| monthly | Monthly period starting at midnight on the first day of the month. If within the current month, this specifies the period from the start of the month until "now." |
| none | Not applicable. |
| seasonal | A season of time spanning multiple months. E.g. "Summer," "Spring," "Fall," and "Winter" based cycle. If within the current season, it specifies the period from the start of the current season until "now." |
| specifiedPeriod | For the period defined by the start and end of the TimePeriod element in the message. |
| weekly | Weekly period starting at midnight on the first day of the week and ending the instant before midnight the last day of the week. If within the current week, it specifies the period from the start of the week until "now." |

CIM17v40-MarketEventStatusKind
### (Attribute) MarketEventStatusKind

Market event status types.


| name | description |
|------|-------------|
| active | The status of the event is currently in a active state.Active (when sysdate is equal or greater than to planned start time) |
| cancelled | The status of the event is currently in a cancelled state.Cancelled (stopped before planned start time or planned end time) |
| completed | The status of the event is currently in a completed state.Complete (when sysdate is equal to the release time) |
| planned | The status of the event is currently in a planned state.Planned (sysdate is less than planned start time) |

CIM17v40-MarketProductSelfSchedType
### (Attribute) MarketProductSelfSchedType

Market product self schedule bid types.


| name | description |
|------|-------------|
| ETC | Existing Transmission Contract. |
| LPT | Low price taker. |
| PT | Price taker. |
| RA | Resource adequacy. |
| RGMR | Regulatory must run. |
| RMR | Reliability Must Run. |
| RMT | Reliability must take. |
| SP | Self provision. |
| TOR | Transmission Ownership Right. |

CIM17v40-MarketProductType
### (Attribute) MarketProductType

For example:

Energy, Reg Up, Reg Down, Spin Reserve, Nonspin Reserve, RUC, Load Folloing Up, and Load Following Down.


| name | description |
|------|-------------|
| EN | energy type |
| LFD | Load following down |
| LFU | Load following up |
| NR | non spinning reserve |
| RC | Residual Unit Commitment |
| RD | regulation down |
| REG | Regulation |
| RU | regulation up |
| SR | spinning reserve |

CIM17v40-MarketProductTypeAsReq
### MarketProductTypeAsReq

RU - Regulation Up

RD - Regulation Down

SR - Spin Reserve

NR - Nonspin Reserve

AS - Upward Ancillary Service


| name | description |
|------|-------------|
| AS | |
| NR | non spinning reserve |
| RD | regulation down |
| RU | regulation up |
| SR | spinning reserve |

CIM17v40-MarketRoleKind
### MarketRoleKind

Kind of market role an organisation can have. This list is not exhausted, as other roles may exist.


| name | description |
|------|-------------|
| BalanceResponsibleParty | A party that has a contract proving financial security and identifying balance responsibility with the Imbalance Settlement Responsible of the Market Balance Area entitling the party to operate in the market. This is the only role allowing a party to nominate energy on a wholesale level.<b><i>Additional information:</i></b>The meaning of the word "balance" in this context signifies that the quantity contracted to provide or to consume shall be equal to the quantity really provided or consumed. Equivalent to "Program responsible party" in the Netherlands. Equivalent to "Balance group manager" in Germany. Equivalent to "market agent" in Spain. |
| BalanceSupplier | A party that markets the difference between actual metered energy consumption and the energy bought with firm energy contracts by the Party Connected to the Grid. In addition the Balance Supplier markets any difference with the firm energy contract (of the Party Connected to the Grid) and the metered production.<b><i>Additional information:</i></b>There is only one Balance Supplier for each Accounting Point. |
| BillingAgent | The party responsible for invoicing a concerned party. |
| BlockEnergyTrader | A party that is selling or buying energy on a firm basis (a fixed volume per market time period). |
| CapacityCoordinator | A party, acting on behalf of the System Operators involved, responsible for establishing a coordinated Offered Capacity and/or Net Transfer Capacity (NTC) and/or Available Transfer Capacity (ATC) between several Market Balance Areas. |
| CapacityTrader | A party that has a contract to participate in the Capacity Market to acquire capacity through a Transmission Capacity Allocator.The capacity may be acquired on behalf of an Interconnection Trade Responsible or for sale on secondary capacity markets. |
| Consumer | A party that consumes electricity.<b><i>Additional information:</i></b>This is a Type of Party Connected to the Grid. |
| ConsumptionResponsibleParty | A party who can be brought to rights, legally and financially, for any imbalance between enegry nominated and consumed for all associated Accounting Points.<b><i>Additional information:</i></b>This is a type of Balance Responsible Party. |
| ControlAreaOperator | Responsible for :1. The coordination of exchange programs between its related Market Balance Areas and for the exchanges between its associated Control Areas.2. The load frequency control for its own area.3. The coordination of the correction of time deviations. |
| ControlBlockOperator | Responsible for :1. The coordination of exchanges between its associated Control Blocks and the organisation of the coordination of exchange programs between its related Control Areas.2. The load frequency control within its own block and ensuring that its Control Areas respect their obligations in respect to load frequency control and time deviation.3. The organisation of the settlement and/or compensation between its Control Areas. |
| CoordinationCenterOperator | Responsible for :1. The coordination of exchange programs between its related Control Blocks and for the exchanges between its associated Coordination Center Zones.2. Ensuring that its Control Blocks respect their obligations in respect to load frequency control.3. Calculating the time deviation in cooperation with the associated coordination centers.4. Carrying out the settlement and/or compensation between its Control Blocks and against the other Coordination Center Zones. |
| GridAccessProvider | A party responsible for providing access to the grid through an Accounting Point and its use for energy consumption or production to the Party Connected to the Grid. |
| GridOperator | A party that operates one or more grids. |
| ImbalanceSettlementResponsible | A party that is responsible for settlement of the difference between the contracted quantities and the realised quantities of energy products for the Balance Responsible Parties in a Market Balance Area.Note:The Imbalance Settlement Responsible has not the responsibility to invoice. The Imbalance Settlement Responsible may delegate the invoicing responsibility to a more generic role such as a Billing Agent. |
| InterconnectionTradeResponsible | Is a Balance Responsible Party or depends on one. They are recognized by the Nomination Validator for the nomination of already allocated capacity.<b><i>Additional information:</i></b>This is a type of Balance Responsible Party. |
| MOLResponsible | Responsible for the management of the available tenders for all Acquiring System Operators to establish the order of the reserve capacity that can be activated. |
| MarketInformationAggregator | Market Information Aggregator, A party that provides market related information that has been compiled from the figures supplied by different actors in the market. This information may also be published or distributed for general use.<b><i>Note:</i></b>The Market Information Aggregator may receive information from any market participant that is relevant for publication or distribution. |
| MarketOperator | The unique power exchange of trades for the actual delivery of energy that receives the bids from the Balance Responsible Parties that have a contract to bid. The Market Operator determines the market energy price for the Market Balance Area after applying technical constraints from the System Operator. It may also establish the price for the reconciliation within a Metering Grid Area. |
| MeterAdministrator | A party responsible for keeping a database of meters. |
| MeterOperator | A party responsible for installing, maintaining, testing, certifying and decommissioning physical meters. |
| MeteredDataAggregator | A party responsible for the establishment and qualification of metered data from the Metered Data Responsible. This data is aggregated according to a defined set of market rules. |
| MeteredDataCollector | A party responsible for meter reading and quality control of the reading. |
| MeteredDataResponsible | A party responsible for the establishment and validation of metered data based on the collected data received from the Metered Data Collector. The party is responsible for the history of metered data for a Metering Point. |
| MeteringPointAdministrator | A party responsible for registering the parties linked to the metering points in a Metering Grid Area. They are also responsible for maintaining the Metering Point technical specifications. They are responsible for creating and terminating metering points. |
| NominationValidator | Has the responsibility of ensuring that all capacity nominated is within the allowed limits and confirming all valid nominations to all involved parties. They inform the Interconnection Trade Responsible of the maximum nominated capacity allowed. Depending on market rules for a given interconnection the corresponding System Operators may appoint one Nomination Validator. |
| PartyConnectedToTheGrid | A party that contracts for the right to consume or produce electricity at an Accounting Point. |
| Producer | A party that produces electricity.<b><i>Additional information:</i></b>This is a type of Party Connected to the Grid. |
| ProductionResponsibleParty | A party who can be brought to rights, legally and financially, for any imbalance between energy nominated and produced for all associated Accounting Points.<b><i>Additional information:</i></b>This is a type of Balance Responsible Party. |
| ReconciliationAccountable | A party that is financially accountable for the reconciled volume of energy products for a profiled Accounting Point. |
| ReconciliationResponsible | A party that is responsible for reconciling, within a Metering Grid Area, the volumes used in the imbalance settlement process for profiled Accounting Points and the actual metered quantities.Note:The Reconciliation Responsible may delegate the invoicing responsibility to a more generic role such as a Billing Agent. |
| ReserveAllocator | Informs the market of reserve requirements, receives tenders against the requirements and in compliance with the prequalification criteria, determines what tenders meet requirements and assigns tenders. |
| ResourceProvider | A role that manages a resource object and provides the schedules for it |
| SchedulingCoordinator | A party that is responsible for the schedule information and its exchange on behalf of a Balance Responsible Party. For example in the Polish market a Scheduling Coordinator is responsible for information interchange for scheduling and settlement. |
| SystemOperator | A party that is responsible for a stable power system operation(including the organisation of physical balance) through a transmission grid in a geographical area. The System Operator will also determine and be responsible for cross border capacity and exchanges. If necessary they may reduce allocated capacity to ensure operational stability. Transmission as mentioned above means "the transport of electricity on the extra high or high voltage network with a view to its delivery to final customers or to distributors. Operation of transmission includes as well the tasks of system operation concerning its management of energy flows, reliability of the system and availability of all necessary system services." (definition taken from the ENTSO-E RGCE Operation handbook Glossary).<b><i>Note: </i></b>additional obligations may be imposed through local market rules. |
| TradeResponsibleParty | A party who can be brought to rights, legally and financially, for any imbalance between energy nominated and consumed for all associated Accounting Points.<b><i>Note:</i></b>A power exchange without any privileged responsibilities acts as a Trade Responsible Party.<b><i>Additional information:</i></b>This is a type of Balance Responsible Party. |
| TransmissionCapacityAllocator | Manages the allocation of transmission capacity for an Allocated Capacity Area.<b><i>For explicit auctions:</i></b>The Transmission Capacity Allocator manages, on behalf of the System Operators, the allocation of available transmission capacity for an Allocated capacity Area. They offer the available transmission capacity to the market, allocates the available transmission capacity to individual Capacity Traders and calculates the billing amount of already allocated capacities to the Capacity Traders. |
| balancingAuthority | Balancing authority. |
| competitiveRetailer | Competitive retailer. |
| complianceMonitor | Compliance monitor. |
| distributionProvider | Distribution provider. |
| energyServiceConsumer | Energy service consumer. |
| generatorOperator | Generator merchant operator. |
| generatorOwner | Generator merchant owner. |
| interchangeAuthority | Interchange authority. |
| loadServingEntity | Load serving entity. |
| planningAuthority | Planning authority. |
| purchasingSellingEntity | Purchasing selling entity. |
| reliabilityAuthority | Reliability authority. |
| resourcePlanner | Resource planner. |
| standardsDeveloper | Standards developer. |
| transmissionOperator | Transmission operator. |
| transmissionOwner | Transmission owner. |
| transmissionPlanner | Transmission planner. |
| transmissionServiceProvider | Transmission service provider. |

CIM17v40-MarketScheduleServices
### MarketScheduleServices


| name | description |
|------|-------------|
| retrieveDefaultBidCurves | |
| retrieveMPMResults | |
| retrieveMarketAwards | |
| retrieveSchedulePrices | |
| retrieveStartUpShutDownInstructions | |

CIM17v40-MarketStatementDescription
### MarketStatementDescription

Description of market statement


| name | description |
|------|-------------|
| DAILY_INITIAL_CREDIT | |
| DAILY_INITIAL_MARKET | |
| DAILY_RECALC_MARKET | |
| MONTHLY_INITIAL_MARKET | |
| MONTHLY_RECALC_MARKET | |

CIM17v40-MarketStatementDocStatus
### MarketStatementDocStatus

market statement document status


| name | description |
|------|-------------|
| APPROVED | |
| CANCELLED | |

CIM17v40-MarketStatementDocType
### MarketStatementDocType

market statement document type


| name | description |
|------|-------------|
| CREDIT | |
| MARKET_INITIAL | |
| MARKET_RECALC | |

CIM17v40-MarketStatementLineItemAliasName
### MarketStatementLineItemAliasName

market statement line item alias name


| name | description |
|------|-------------|
| CHARGE_CODE_INTERVAL_DETAIL | |
| CHARGE_CODE_INTERVAL_TOTAL | |
| CHARGE_CODE_SUMMARY | |
| CHARGE_GROUP | |
| PARENT_CHARGE_GROUP | |
| TRADE_DATE | |

CIM17v40-MarketType
### (Attribute) MarketType

Market type.


| name | description |
|------|-------------|
| DAM | Day ahead market. |
| HAM | Hour Ahead Market. |
| RTM | Real time market. |
| RUC | Residual Unit Commitment. |

CIM17v40-MeasurementKind
### (Attribute) MeasurementKind

Kind of read / measured value.


| name | description |
|------|-------------|
| alarm | A measurement related to an alarm |
| apTitle | An application name which is making or has made a request |
| apparentPowerFactor | The ratio of real energy (usually net Wh) to apparent energy (kVAh) |
| applicationContext | Information that describes the logical context in which a request, measurement, or command is made. |
| assetNumber | An asset identifier |
| audibleVolume | Sound |
| bandwidth | A measurement of dataflow |
| batteryCarryover | An estimate of the battery ride through capacity |
| batteryVoltage | Battery voltage |
| billCarryover | Customer�s bill for the (Currency) |
| billLastPeriod | Customer�s bill for the previous billing period (Currency) |
| billToDate | Customer�s bill, as known thus far within the present billing period (Currency) |
| broadcastAddress | A message target address implying all endpoint units within range of a particular sender |
| connectionFee | Monthly fee for connection to commodity. |
| currency | funds |
| current | The flow of electrons |
| currentAngle | A phase current zerocross timing measurement releative to a reference voltage zerocross |
| currentImbalance | A measurement of the departure of a phase current relative to the average current of all phases |
| dataOverflowAlarm | An indication of or measurement of a loss of data |
| date | A measurement of the date and/or time in a clock, or a time stamp indicating when data was captured, when a maximum or minimum occurred, or to commemorate some other important aspect of a measurement |
| demand | The measurement of maximum power flow which is computed as energy usage over time, the dimensions of which are defined by a tariff |
| demandLimit | A threshold setting that determines the trip point that if exceeded would trigger a demand limiting action or alarm |
| demandReset | A count of the number of times demand has been reset (remotely, locally, and/or automatically.) |
| deviceAddressType1 | Endpoint target address Type1 |
| deviceAddressType2 | Endpoint target address Type2 |
| deviceAddressType3 | Endpoint target address Type3 |
| deviceAddressType4 | Endpoint target address Type4 |
| deviceClass | A unique identifier for the Endpoint�s configuration |
| diagnostic | A measurement related to equipment diagnostics |
| distance | A linear distance or range radius |
| distortionPowerFactor | The ratio of the distortion VAh to the apparent VAh |
| distortionVoltAmp | A measurement in which a V<sup>2</sup> I<sup>2</sup> term has both real and reactive components removed leaving only distortion. For example, distortion VAh = Sqrt( (V<sup>2</sup>h)(I<sup>2</sup>h) � (Wh)<sup>2</sup> � (VArh)<sup>2</sup>) |
| electronicSerialNumber | A device serial number |
| emergencyLimit | A setting that indicates an emergency limit |
| encoderTamper | An indication of tampering with a meter encoder |
| endDeviceID | A unique identifier of the endDevice � the device providing measurements or under control of the network |
| energization | Pertaining to the presence of voltage |
| energizationLoadSide | Measuring the presence or absence of voltage on the load side of an electricity meter |
| energy | Scalar quantity which may be increased or decreased in a system when it receives or produces work, respectively |
| fan | A forced air moving device |
| frequency | Reciprocal of the period |
| frequencyExcursion | A measurement of the departure of the frequency from the nominal frequency |
| fund | Duplicate with �currency� |
| groupAddressType1 | Group target address Type1 |
| groupAddressType2 | Group target address Type2 |
| groupAddressType3 | Group target address Type3 |
| groupAddressType4 | Group target address Type4 |
| ieee1366ASAI | A measurement of IEEE-1366 Average Service Availability Index |
| ieee1366ASIDI | A measurement of the IEEE-1366 Average Service Interruption Duration Index |
| ieee1366ASIFI | A measurement of the IEEE-1366 Average Service Interruption Frequency Index |
| ieee1366CAIDI | A measurement of the IEEE-1366 Customer average interruption duration index |
| ieee1366CAIFI | A measurement of the IEEE-1366 Customer average interruption frequency index |
| ieee1366CEMIn | A measurement of the IEEE-1366 Customers Experiencing Multiple Interruptions |
| ieee1366CEMSMIn | A measurement of the IEEE-1366 Customers Experiencing Multiple Sustained and Momentary Interruptions |
| ieee1366CTAIDI | A measurement of the IEEE-1366 Customer Total Average Interruption Duration Index |
| ieee1366MAIFI | A measurement of the IEEE-1366 Momentary Average Interruption Frequency Index |
| ieee1366MAIFIe | A measurement of the IEEE-1366 Momentary Average event Interruption Frequency Index |
| ieee1366MomentaryInterruption | IEEE-1366 Momentary Interruption count |
| ieee1366MomentaryInterruptionEvent | IEEE-1366 Momentary Interruption event count |
| ieee1366SAIDI | IEEE-1366 System Average Interruption Duration Index |
| ieee1366SAIFI | IEEE-1366 System Average Interruption Frequency Index |
| ieee1366SustainedInterruption | IEEE-1366 Sustained Interruption duration |
| interruptionBehaviour | A measurement related to power interruptions (Note: often an interruption count or duration.) |
| inversionTamper | A measurement related to inversion tamper (Note: typically a count of inversions) |
| ipAddress | An IP address for the endpoint |
| lineLoss | An energy, power, voltage, or current loss attributed to transmission or distribution line impedance |
| loadInterrupt | A measurement related to load interruption (Note: typically a load interruption count or measurement of duration) |
| loadShed | A measurement related to load shed (Note: typically a load shed count or load shed duration) |
| loss | A quantity lost due to �technical� reasons (such as line loss) or �non-technical� reasons (such as theft.) |
| macAddress | A MAC address for the endpoint |
| maintenance | A measurement related to the pending maintenance of equipment |
| mfgAssignedConfigurationID | The configuration given to a device at time of manufacture |
| mfgAssignedPhysicalSerialNumber | The serial number assigned to a device at time of manufacture |
| mfgAssignedProductNumber | The product number assigned to a device at time of manufacture |
| mfgAssignedUniqueCommunicationAddress | A communication address assigned to a device at time of manufacture |
| multiCastAddress | A message target address implying a large group of endpoint units within range of a particular sender |
| negativeSequence | A quantity that has a rotation sequence which is opposite to that of the power system |
| none | Not Applicable |
| oneWayAddress | A communication address of a network endpoint used in one-way communication |
| phasorPowerFactor | The ratio of real energy (usually net Wh) to phasor apparent energy (kVAh) |
| phasorReactivePower | The ratio of real energy (usually net Wh) to phasor reactive energy (kVAh) |
| physicalTamper | A measurement related to physical tampering (Note: typically a tamper count) |
| positiveSequence | A quantity that has a rotation sequence in agreement with that of the power system |
| power | The derivative of energy with respect to time, where the energy is being transferred or transformed. |
| powerFactor | The ratio of real energy (usually net Wh) to apparent energy (kVAh) |
| powerLossTamper | Tamper indicated while power was out |
| powerOutage | A measurement related to power outages (Note: typically a status) |
| powerQuality | A measurement related to power quality |
| powerRestoration | A measurement related to power restoration (Note: typically a status) |
| programmed | A measurement related to device programming (Note: typically a status measurement) |
| pushbutton | A measurement related to pushbutton (Note: typically a status or count) |
| quantityPower | A power measurement of Qh, where Qh is defined to be half of the sum of the Wh measurements on each phase plus the squareroot of 3 over two times the sum of the VArh measurements on each phase. |
| relayActivation | A measurement related to relay activations |
| relayCycle | A measurement related to relay cycling (Note1: one open and one closure together is one cycle, Note2: Usually expressed as a count) |
| removalTamper | An indication of equipment tampering that shows equipment was moved or opened |
| reprogrammingTamper | An indication of equipment tampering that shows equipment has been reprogrammed |
| reverseRotationTamper | An indication of tampering as evidenced by reverse power flow |
| sag | A temporary dip in the supply voltage below the nominal value |
| signalStrength | A measurement of RF signal strength |
| signaltoNoiseRatio | A measurement of received (RF) signal strength divided by the (RF) noise floor |
| swell | A temporary rise of the supply voltage over the nominal value |
| switchArmed | A measurement of the switch arm condition |
| switchDisabled | A measurement of the switch enablement status |
| switchPosition | A physical or logical switch position status which includes �opened� and �closed�, but for some products may also include �armed,� or other states that indicate a temporary state due to some condition. |
| tamper | An indication of equipment tampering |
| tapPosition | Tap changer position |
| tariffRate | An energy price defined in a contract. The rate might be a price for energy, for power (usually expressed as a demand value), or some other measurement. The rate might be currency based, or as a code, or as a component of a larger tariff description. |
| temperature | A quantity proportional to the energy of a system |
| totalHarmonicDistortion | The ratio of the sum of the harmonics to the fundamental. (THD may measure either voltage or current, and may isolated to a given phase) |
| transformerLoss | A measurement of the energy or power loss in a transformer due to inefficiency |
| twoWayAddress | A communication address used for bidirectional communication |
| unipedeVoltageDip10to15 | A voltage dip classification per EN50160 or a similar national standard measuring the number of dips in the 10-15% range |
| unipedeVoltageDip15to30 | A voltage dip classification per EN50160 or a similar national standard measuring the number of dips in the 15-30% range |
| unipedeVoltageDip30to60 | A voltage dip classification per EN50160 or a similar national standard measuring the number of dips in the 30-60% range |
| unipedeVoltageDip60to90 | A voltage dip classification per EN50160 or a similar national standard measuring the number of dips in the 60-90% rangeA voltage dip classification per EN50160 or a similar national standard measuring the number of dips in the 60-90% range |
| unipedeVoltageDip90to100 | A voltage dip classification per EN50160 or a similar national standard measuring the number of dips in the 90-100% range |
| voltage | The difference in electric potential between two points |
| voltageAngle | A phase voltage zerocross timing measurement relative to a reference voltage zerocross |
| voltageExcursion | A measurement of the departure of the voltage from the nominal voltage |
| voltageImbalance | A measurement of the departure of a phase voltage relative to the average voltage of all phases. |
| volume | fluid volume |
| volumetricFlow | A fluid flow rate |
| watchdogTimeout | A reset triggered by a hardware �watchdog� circuit |
| zeroFlowDuration | The amount of time that current flow drops to a zero level or level below the ability of the sensor to sense |
| zeroSequence | The zero sequence current is the vector sum of the phase currents |

CIM17v40-MeasurementKind-Old
### MeasurementKind-Old

Kind of read / measured value.


| name | description |
|------|-------------|
| alarm | A measurement related to an alarm |
| apTitle | An application name which is making or has made a request |
| apparentPowerFactor | The ratio of real energy (usually net Wh) to apparent energy (kVAh) |
| applicationContext | Information that describes the logical context in which a request, measurement, or command is made. |
| assetNumber | An asset identifier |
| audibleVolume | Sound |
| bandwidth | A measurement of dataflow |
| batteryCarryover | An estimate of the battery ride through capacity |
| batteryVoltage | Battery voltage |
| billCarryover | Customer�s bill for the (Currency) |
| billLastPeriod | Customer�s bill for the previous billing period (Currency) |
| billToDate | Customer�s bill, as known thus far within the present billing period (Currency) |
| broadcastAddress | A message target address implying all endpoint units within range of a particular sender |
| connectionFee | Monthly fee for connection to commodity. |
| currency | funds |
| current | The flow of electrons |
| currentAngle | A phase current zerocross timing measurement releative to a reference voltage zerocross |
| currentImbalance | A measurement of the departure of a phase current relative to the average current of all phases |
| dataOverflowAlarm | An indication of or measurement of a loss of data |
| date | A measurement of the date and/or time in a clock, or a time stamp indicating when data was captured, when a maximum or minimum occurred, or to commemorate some other important aspect of a measurement |
| demand | The measurement of maximum power flow which is computed as energy usage over time, the dimensions of which are defined by a tariff |
| demandLimit | A threshold setting that determines the trip point that if exceeded would trigger a demand limiting action or alarm |
| demandReset | A count of the number of times demand has been reset (remotely, locally, and/or automatically.) |
| deviceAddressType1 | Endpoint target address Type1 |
| deviceAddressType2 | Endpoint target address Type2 |
| deviceAddressType3 | Endpoint target address Type3 |
| deviceAddressType4 | Endpoint target address Type4 |
| deviceClass | A unique identifier for the Endpoint�s configuration |
| diagnostic | A measurement related to equipment diagnostics |
| distance | A linear distance or range radius |
| distortionPowerFactor | The ratio of the distortion VAh to the apparent VAh |
| distortionVoltAmp | A measurement in which a V<sup>2</sup> I<sup>2</sup> term has both real and reactive components removed leaving only distortion. For example, distortion VAh = Sqrt( (V<sup>2</sup>h)(I<sup>2</sup>h) � (Wh)<sup>2</sup> � (VArh)<sup>2</sup>) |
| electronicSerialNumber | A device serial number |
| emergencyLimit | A setting that indicates an emergency limit |
| encoderTamper | An indication of tampering with a meter encoder |
| endDeviceID | A unique identifier of the endDevice � the device providing measurements or under control of the network |
| energization | Pertaining to the presence of voltage |
| energizationLoadSide | Measuring the presence or absence of voltage on the load side of an electricity meter |
| energy | Scalar quantity which may be increased or decreased in a system when it receives or produces work, respectively |
| fan | A forced air moving device |
| frequency | Reciprocal of the period |
| frequencyExcursion | A measurement of the departure of the frequency from the nominal frequency |
| fund | Duplicate with �currency� |
| groupAddressType1 | Group target address Type1 |
| groupAddressType2 | Group target address Type2 |
| groupAddressType3 | Group target address Type3 |
| groupAddressType4 | Group target address Type4 |
| ieee1366ASAI | A measurement of IEEE-1366 Average Service Availability Index |
| ieee1366ASIDI | A measurement of the IEEE-1366 Average Service Interruption Duration Index |
| ieee1366ASIFI | A measurement of the IEEE-1366 Average Service Interruption Frequency Index |
| ieee1366CAIDI | A measurement of the IEEE-1366 Customer average interruption duration index |
| ieee1366CAIFI | A measurement of the IEEE-1366 Customer average interruption frequency index |
| ieee1366CEMIn | A measurement of the IEEE-1366 Customers Experiencing Multiple Interruptions |
| ieee1366CEMSMIn | A measurement of the IEEE-1366 Customers Experiencing Multiple Sustained and Momentary Interruptions |
| ieee1366CTAIDI | A measurement of the IEEE-1366 Customer Total Average Interruption Duration Index |
| ieee1366MAIFI | A measurement of the IEEE-1366 Momentary Average Interruption Frequency Index |
| ieee1366MAIFIe | A measurement of the IEEE-1366 Momentary Average event Interruption Frequency Index |
| ieee1366MomentaryInterruption | IEEE-1366 Momentary Interruption count |
| ieee1366MomentaryInterruptionEvent | IEEE-1366 Momentary Interruption event count |
| ieee1366SAIDI | IEEE-1366 System Average Interruption Duration Index |
| ieee1366SAIFI | IEEE-1366 System Average Interruption Frequency Index |
| ieee1366SustainedInterruption | IEEE-1366 Sustained Interruption duration |
| interruptionBehaviour | A measurement related to power interruptions (Note: often an interruption count or duration.) |
| inversionTamper | A measurement related to inversion tamper (Note: typically a count of inversions) |
| ipAddress | An IP address for the endpoint |
| lineLoss | An energy, power, voltage, or current loss attributed to transmission or distribution line impedance |
| loadInterrupt | A measurement related to load interruption (Note: typically a load interruption count or measurement of duration) |
| loadShed | A measurement related to load shed (Note: typically a load shed count or load shed duration) |
| loss | A quantity lost due to �technical� reasons (such as line loss) or �non-technical� reasons (such as theft.) |
| macAddress | A MAC address for the endpoint |
| maintenance | A measurement related to the pending maintenance of equipment |
| mfgAssignedConfigurationID | The configuration given to a device at time of manufacture |
| mfgAssignedPhysicalSerialNumber | The serial number assigned to a device at time of manufacture |
| mfgAssignedProductNumber | The product number assigned to a device at time of manufacture |
| mfgAssignedUniqueCommunicationAddress | A communication address assigned to a device at time of manufacture |
| multiCastAddress | A message target address implying a large group of endpoint units within range of a particular sender |
| negativeSequence | A quantity that has a rotation sequence which is opposite to that of the power system |
| none | Not Applicable |
| oneWayAddress | A communication address of a network endpoint used in one-way communication |
| phasorPowerFactor | The ratio of real energy (usually net Wh) to phasor apparent energy (kVAh) |
| phasorReactivePower | The ratio of real energy (usually net Wh) to phasor reactive energy (kVAh) |
| physicalTamper | A measurement related to physical tampering (Note: typically a tamper count) |
| positiveSequence | A quantity that has a rotation sequence in agreement with that of the power system |
| power | The derivative of energy with respect to time, where the energy is being transferred or transformed. |
| powerFactor | The ratio of real energy (usually net Wh) to apparent energy (kVAh) |
| powerLossTamper | Tamper indicated while power was out |
| powerOutage | A measurement related to power outages (Note: typically a status) |
| powerQuality | A measurement related to power quality |
| powerRestoration | A measurement related to power restoration (Note: typically a status) |
| programmed | A measurement related to device programming (Note: typically a status measurement) |
| pushbutton | A measurement related to pushbutton (Note: typically a status or count) |
| quantityPower | A power measurement of Qh, where Qh is defined to be half of the sum of the Wh measurements on each phase plus the squareroot of 3 over two times the sum of the VArh measurements on each phase. |
| relayActivation | A measurement related to relay activations |
| relayCycle | A measurement related to relay cycling (Note1: one open and one closure together is one cycle, Note2: Usually expressed as a count) |
| removalTamper | An indication of equipment tampering that shows equipment was moved or opened |
| reprogrammingTamper | An indication of equipment tampering that shows equipment has been reprogrammed |
| reverseRotationTamper | An indication of tampering as evidenced by reverse power flow |
| sag | A temporary dip in the supply voltage below the nominal value |
| signalStrength | A measurement of RF signal strength |
| signaltoNoiseRatio | A measurement of received (RF) signal strength divided by the (RF) noise floor |
| swell | A temporary rise of the supply voltage over the nominal value |
| switchArmed | A measurement of the switch arm condition |
| switchDisabled | A measurement of the switch enablement status |
| switchPosition | A physical or logical switch position status which includes �opened� and �closed�, but for some products may also include �armed,� or other states that indicate a temporary state due to some condition. |
| tamper | An indication of equipment tampering |
| tapPosition | Tap changer position |
| tariffRate | An energy price defined in a contract. The rate might be a price for energy, for power (usually expressed as a demand value), or some other measurement. The rate might be currency based, or as a code, or as a component of a larger tariff description. |
| temperature | A quantity proportional to the energy of a system |
| totalHarmonicDistortion | The ratio of the sum of the harmonics to the fundamental. (THD may measure either voltage or current, and may isolated to a given phase) |
| transformerLoss | A measurement of the energy or power loss in a transformer due to inefficiency |
| twoWayAddress | A communication address used for bidirectional communication |
| unipedeVoltageDip10to15 | A voltage dip classification per EN50160 or a similar national standard measuring the number of dips in the 10-15% range |
| unipedeVoltageDip15to30 | A voltage dip classification per EN50160 or a similar national standard measuring the number of dips in the 15-30% range |
| unipedeVoltageDip30to60 | A voltage dip classification per EN50160 or a similar national standard measuring the number of dips in the 30-60% range |
| unipedeVoltageDip60to90 | A voltage dip classification per EN50160 or a similar national standard measuring the number of dips in the 60-90% rangeA voltage dip classification per EN50160 or a similar national standard measuring the number of dips in the 60-90% range |
| unipedeVoltageDip90to100 | A voltage dip classification per EN50160 or a similar national standard measuring the number of dips in the 90-100% range |
| voltage | The difference in electric potential between two points |
| voltageAngle | A phase voltage zerocross timing measurement relative to a reference voltage zerocross |
| voltageExcursion | A measurement of the departure of the voltage from the nominal voltage |
| voltageImbalance | A measurement of the departure of a phase voltage relative to the average voltage of all phases. |
| volume | fluid volume |
| volumetricFlow | A fluid flow rate |
| watchdogTimeout | A reset triggered by a hardware �watchdog� circuit |
| zeroFlowDuration | The amount of time that current flow drops to a zero level or level below the ability of the sensor to sense |
| zeroSequence | The zero sequence current is the vector sum of the phase currents |

CIM17v40-MeasurementTypeEMS
### MeasurementTypeEMS

Path Flow - PF

Path Inflow Limit - PIL

Path Inflow Available Limit - PIAL

Path Inflow Armed Limit - PIML

Path Outflow Limit - POL

Path Outflow Available Limit - POAL

Path Outflow Armed Limit - OARL

Generation Output - GO

Generation Max Operating Limit - GMOL

Generation Min Operating Limit - GNOL

Generation Regulation - GR

Generation Status - GS

Pump Production - PP

System Load - SL

System ACE - ACE

System INADV - INADV


| name | description |
|------|-------------|
| ACE | |
| GMOL | |
| GNOL | |
| GO | |
| GR | |
| GS | |
| INADV | |
| OARL | |
| PF | |
| PIAL | |
| PIL | |
| PIML | |
| POAL | |
| POL | |
| PP | |
| SL | |

CIM17v40-MeasuringPeriodKind
### (Attribute) MeasuringPeriodKind

Kind of period for reading / measuring values.


| name | description |
|------|-------------|
| fifteenMinute | 15-minute |
| fiveMinute | 5-minute |
| fixedBlock10Min | 10-minute Fixed Block |
| fixedBlock15Min | 15-minute Fixed Block |
| fixedBlock1Min | 1-minute Fixed Block |
| fixedBlock20Min | 20-minute Fixed Block |
| fixedBlock30Min | 30-minute Fixed Block |
| fixedBlock5Min | 5-minute Fixed Block |
| fixedBlock60Min | 60-minute Fixed Block |
| none | Not applicable. |
| oneMinute | 1-minute |
| present | Within the present period of time |
| previous | Shifted within the previous monthly cycle and data set |
| rollingBlock10MinIntvl1MinSubIntvl | 10-minute Rolling Block with 1-minute sub-intervals |
| rollingBlock10MinIntvl2MinSubIntvl | 10-minute Rolling Block with 2-minute sub-intervals |
| rollingBlock10MinIntvl5MinSubIntvl | 10-minute Rolling Block with 5-minute sub-intervals |
| rollingBlock15MinIntvl1MinSubIntvl | 15-minute Rolling Block with 1-minute sub-intervals |
| rollingBlock15MinIntvl3MinSubIntvl | 15-minute Rolling Block with 3-minute sub-intervals |
| rollingBlock15MinIntvl5MinSubIntvl | 15-minute Rolling Block with 5-minute sub-intervals |
| rollingBlock30MinIntvl10MinSubIntvl | 30-minute Rolling Block with 10-minute sub-intervals |
| rollingBlock30MinIntvl15MinSubIntvl | 30-minute Rolling Block with 15-minute sub-intervals |
| rollingBlock30MinIntvl2MinSubIntvl | 30-minute Rolling Block with 2-minute sub-intervals |
| rollingBlock30MinIntvl3MinSubIntvl | 30-minute Rolling Block with 3-minute sub-intervals |
| rollingBlock30MinIntvl5MinSubIntvl | 30-minute Rolling Block with 5-minute sub-intervals. |
| rollingBlock30MinIntvl6MinSubIntvl | 30-minute Rolling Block with 6-minute sub-intervals |
| rollingBlock5MinIntvl1MinSubIntvl | 5-minute Rolling Block with 1-minute sub-intervals |
| rollingBlock60MinIntvl10MinSubIntvl | 60-minute Rolling Block with 10-minute sub-intervals |
| rollingBlock60MinIntvl12MinSubIntvl | 60-minute Rolling Block with 12-minute sub-intervals |
| rollingBlock60MinIntvl15MinSubIntvl | 60-minute Rolling Block with 15-minute sub-intervals |
| rollingBlock60MinIntvl20MinSubIntvl | 60-minute Rolling Block with 20-minute sub-intervals |
| rollingBlock60MinIntvl30MinSubIntvl | 60-minute Rolling Block with 30-minute sub-intervals |
| rollingBlock60MinIntvl4MinSubIntvl | 60-minute Rolling Block with 4-minute sub-intervals |
| rollingBlock60MinIntvl5MinSubIntvl | 60-minute Rolling Block with 5-minute sub-intervals |
| rollingBlock60MinIntvl6MinSubIntvl | 60-minute Rolling Block with 6-minute sub-intervals |
| sixtyMinute | 60-minute |
| tenMinute | 10-minute |
| thirtyMinute | 30-minute |
| threeMinute | 3-minute |
| twentyMinute | 20-minute interval |
| twentyfourHour | 24-hour |
| twoMinute | 2-minute |

CIM17v40-MediumKind
### (Attribute) MediumKind

Kind of medium.


| name | description |
|------|-------------|
| SF6 | Medium is SF6. |
| SF6CF4 | Medium is SF6CF4. |
| SF6N2 | Medium is SF6N2. |
| air | Medium is air. |
| gas | Medium is gas. |
| liquid | Medium is liquid. |
| mineralOil | Medium is mineral oil. |
| solid | Medium is solid. |

CIM17v40-MeterMultiplierKind
### (Attribute) MeterMultiplierKind

Kind of meter multiplier.


| name | description |
|------|-------------|
| ctRatio | Current transformer ratio used to convert associated quantities to real measurements. |
| kE | Test constant. |
| kH | Meter kh (watthour) constant. The number of watthours that must be applied to the meter to cause one disk revolution for an electromechanical meter or the number of watthours represented by one increment pulse for an electronic meter. |
| kR | Register multiplier. The number to multiply the register reading by in order to get kWh. |
| ptRatio | Potential transformer ratio used to convert associated quantities to real measurements. |
| transformerRatio | Product of the CT ratio and PT ratio. |

CIM17v40-MktAccountKind
### (Attribute) MktAccountKind

Kind of Market account.


| name | description |
|------|-------------|
| estimate | |
| normal | |
| reversal | |
| statistical | |

CIM17v40-MktBillMediaKind
### (Attribute) MktBillMediaKind

Kind of bill media.


| name | description |
|------|-------------|
| electronic | |
| other | |
| paper | |

CIM17v40-MktInvoiceLineItemKind
### (Attribute) MktInvoiceLineItemKind

Kind of invoice line item.


| name | description |
|------|-------------|
| initial | |
| other | |
| recalculation | |

CIM17v40-MktSubClassType
### MktSubClassType


| name | description |
|------|-------------|
| Branch_Group_Derates | |
| Day_Ahead_Final_Market_Info | |
| Day_Ahead_Forecast_Information | |
| Day_Ahead_Interim_Market_Info | |
| Day_Ahead_RMR | |
| Forecasted_UDC_Direct_Access_Load | |
| Hour_Ahead_Market_Info | |
| Hourly_Expost_Market_Info | |
| Public_Bid_Data | |
| TTC/ATC_Forecast_Information | |
| TTC/ATC_Hourly_Forecast | |
| Ten_Min_Expost_Market_Info | |

CIM17v40-NotificationTriggerKind
### (Attribute) NotificationTriggerKind

Kind of trigger to notify customer.


| name | description |
|------|-------------|
| etrChange | Notify customer if estimated restoration time changes. |
| informDispatched | Notify customer that a crew has been dispatched to investigate the problem. |
| initialEtr | Notify customer for the first time that estimated restoration time is available. |
| powerOut | Notify customer of planned outage. |
| powerRestored | Notify customer when power has been restored. |

CIM17v40-OASISBidReportType
### OASISBidReportType


| name | description |
|------|-------------|
| BIDS_PUBLIC | |

CIM17v40-OASISDataItems
### OASISDataItems


| name | description |
|------|-------------|
| AS_CLEAR_ASMP_IFM | |
| AS_CLEAR_ASMP_RTM | |
| AS_CLEAR_COST_IFM | |
| AS_CLEAR_COST_RTM | |
| AS_CLEAR_MW_IFM | |
| AS_CLEAR_MW_RTM | |
| AS_GEN_TOTAL_MW_IFM | |
| AS_GEN_TOTAL_MW_RTM | |
| AS_IMP_TOTAL_MW_IFM | |
| AS_IMP_TOTAL_MW_RTM | |
| AS_LOAD_TOTAL_MW_IFM | |
| AS_LOAD_TOTAL_MW_RTM | |
| AS_REGION_REQ_MAX | |
| AS_REGION_REQ_MIN | |
| AS_REGION_value | |
| AS_SELF_MW_IFM | |
| AS_SELF_MW_RTM | |
| AS_TOTAL_MW | |
| AS_TOTAL_MW_IFM | |
| AS_TOTAL_MW_RTM | |
| AS_TYPE | |
| AS_USER_RATE | |
| CA_value | |
| CMMT_MINLOAD_MLC | |
| CMMT_MINLOAD_MW | |
| CMMT_RA_MLC | |
| CMMT_RA_MW | |
| CMMT_RA_START_COST | |
| CMMT_RA_UNITS | |
| CMMT_TOTAL_MW | |
| CMMT_TOTAL_START_COST | |
| CMMT_TOTAL_UNITS | |
| CRR_CAT | |
| CRR_MARKET_value | |
| CRR_MW | |
| CRR_NSR | |
| CRR_OPTION | |
| CRR_OWNER | |
| CRR_SEGMENT | |
| CRR_TERM | |
| CRR_TOU | |
| CRR_TYPE | |
| ENE_EA_DA | |
| ENE_EA_EXCEPT | |
| ENE_EA_HASP | |
| ENE_EA_MLE | |
| ENE_EA_MSSLF | |
| ENE_EA_OPTIMAL | |
| ENE_EA_RAMP_DEV | |
| ENE_EA_RAMP_STD | |
| ENE_EA_RESIDUAL | |
| ENE_EA_RMR | |
| ENE_EA_SELF | |
| ENE_EA_SLIC | |
| ENE_EXP_CLEAR_HASP | |
| ENE_EXP_CLEAR_IFM | |
| ENE_EXP_CLEAR_RTM | |
| ENE_GEN_CLEAR_HASP | |
| ENE_GEN_CLEAR_IFM | |
| ENE_GEN_CLEAR_RTM | |
| ENE_IMP_CLEAR_HASP | |
| ENE_IMP_CLEAR_IFM | |
| ENE_IMP_CLEAR_RTM | |
| ENE_LOAD_ACTUAL | |
| ENE_LOAD_CLEAR_HASP | |
| ENE_LOAD_CLEAR_IFM | |
| ENE_LOAD_CLEAR_RTM | |
| ENE_LOAD_FCST | |
| ENE_PEAK_HOUR | |
| ENE_PEAK_LOAD | |
| FUEL_REGION_value | |
| INVT_DATETIME | |
| LOAD_ACTUAL | |
| LOAD_CLEAR_RTM | |
| LOSS_TOTAL_COST_HASP | |
| LOSS_TOTAL_COST_RTM | |
| LOSS_TOTAL_MW_HASP | |
| LOSS_TOTAL_MW_RTM | |
| MPM_FLAG | |
| OP_RSRV_TOTAL | |
| PRC_NG | |
| PRC_SHADOW | |
| RATING_ATC | |
| RMR_DETER_DAM | |
| RMR_DETER_HASP | |
| RMR_DISPATCH_DAM | |
| RMR_DISPATCH_HASP | |
| RMR_TOTAL | |
| RMR_TOTAL_AVAIL | |
| RUC_GEN_CLEAR_RUC | |
| RUC_IMP_CLEAR_RUC | |
| RUC_LOAD_CLEAR_RUC | |
| RUC_ZONE_value | |
| TAC_AREA_value | |
| TINTRFCE_value | |
| TRNS_AS_IMPORT | |
| TRNS_ENE_IMPORT | |
| TRNS_EQUIP_value | |
| TRNS_RATING_CBM | |
| TRNS_RATING_DIRECTION | |
| TRNS_RATING_OTC | |
| TRNS_RATING_OTC_DERATE | |
| TRNS_RATING_TTC | |
| TRNS_TI_value | |
| TRNS_TR_ENTMTS | |
| TRNS_TR_USEAGE | |

CIM17v40-OASISErrCode
### OASISErrCode


| name | description |
|------|-------------|
| 1000 | |
| 1001 | |
| 1002 | |
| 1003 | |
| 1004 | |
| 1005 | |
| 1006 | |
| 1007 | |
| 1008 | |
| 1009 | |
| 1010 | |

CIM17v40-OASISErrDescription
### OASISErrDescription


| name | description |
|------|-------------|
| Data can be requested for period of 31 days only | |
| Exceptions in reading and writing of XML files | |
| Invalid date format, please use valid date format | |
| No data returned for the specified selection | |
| Out of memory exception | |
| Report name does not exit, please use valid report name | |
| Required file does not exist | |
| System Error | |
| Timed out waiting for query response | |
| Validation exception during transformation of XML | |

CIM17v40-OASISIntervalType
### OASISIntervalType


| name | description |
|------|-------------|
| BEGINNING | |
| ENDING | |

CIM17v40-OASISMarketType
### OASISMarketType


| name | description |
|------|-------------|
| All | |
| HASP | |
| IFM | |
| N/A | |
| RTM | |
| RUC | |

CIM17v40-OASISMasterType
### OASISMasterType


| name | description |
|------|-------------|
| ATL_APNODE | |
| ATL_AS_REGION | |
| ATL_AS_REGION_MAP | |
| ATL_HUB | |
| ATL_LAP | |
| ATL_LDF | |
| ATL_PNODE | |
| ATL_PNODE_MAP | |
| ATL_PUB | |
| ATL_PUB_SCHED | |
| ATL_RESOURCE | |
| ATL_RUC_ZONE | |
| ATL_RUC_ZONE_MAP | |
| ATL_STAT | |
| ATL_TAC_AREA | |
| ATL_TAC_AREA_MAP | |
| ATL_TI | |
| ATL_TIEPOINT | |
| ATL_XREF | |

CIM17v40-OASISMeasType
### OASISMeasType


| name | description |
|------|-------------|
| FACTOR | |
| FLAG | |
| INTEGER | |
| MW | |
| MWh | |
| US$ | |
| US$/MW | |
| US$/MWh | |

CIM17v40-OASISReportType
### OASISReportType


| name | description |
|------|-------------|
| AS_DA_RESULT | |
| AS_OP_RSRV | |
| AS_REQ | |
| AS_RTM_RESULT | |
| BIDS_PUBLIC | |
| CMMT_RA_MLC | |
| CMMT_RMR | |
| CRR_CLEARING | |
| CRR_INVENTORY | |
| ENE_EA | |
| ENE_HASP | |
| ENE_IFM | |
| ENE_MPM | |
| ENE_RTM | |
| ENE_RUC | |
| LOSS_DA_HASP | |
| LOSS_RTM | |
| PRC_AS | |
| PRC_CNSTR | |
| PRC_FUEL | |
| PRC_HRLY_LMP | |
| PRC_INTVL_LMP | |
| SLD_FCST | |
| SLD_FCST_PEAK | |
| SLD_MKTS | |
| TRNS_ATC | |
| TRNS_OUTAGE | |
| TRNS_USAGE | |

CIM17v40-OASISStatusType
### OASISStatusType


| name | description |
|------|-------------|
| Data_Transfer_Procedure_Initiated | |
| Data_Transfer_Succesful | |
| Forced_Termination | |
| Obsolete | |
| Push_Failed | |
| Valid | |

CIM17v40-OilAnalysisFluidAnalogKind
### (Attribute) OilAnalysisFluidAnalogKind

Analogs representing oil fluid test analysis result.


| name | description |
|------|-------------|
| acidNumber | Acid neutralization number (in milligram of KOH/gram). |
| additiveDBDS | Dibenzyl disulfide (DBDS) concentration (in ppm, specificially in milligram/kilogram). |
| aromatics | Concentration of aromatic compounds determined using infrared spectroscopy (in percent). |
| carbonyl | Concentration of carbonyl compounds (aldehydes and ketones) determined using infrared spectroscopy (in percent). |
| density | Density (in gram/millilitre). |
| dielectricBreakdown | Dielectric breakdown, for electrode gap size and temperature specified by selected standard (in kV). |
| dissipationFactor | Fluid dissipation factor in absolute value, not a percentage. (Multiplying this value by 100 would result in dissipation factor percent). |
| dissipationFactorPercent | Fluid dissipation factor (in percent). Commonly used in Asia. Dissipation factor is also known as loss factor or tan delta. |
| duration61125MethodC | Duration of oxidation stablity test performed according to IEC 61125, method C. This value should accompany values resulting from testing according to IEC 61125, method C to allow interpretation. Standard specified values are: 164, 332, and 500, but others can be used if agreed upon. |
| firePoint | Fire point (in �C). Fire point is when fire is sustained (oil catches fire). Can only be done by means of open cup test, which is commonly used in US. |
| flashPointClosedCup | Flash point (in �C) determined via closed cup test. Flash point occurs when enough vapors have accumulated to sustain a flash. Closed cup is used in Europe. |
| flashPointOpenCup | Flash point (in �C) determined via open cup test. Flash point occurs when enough vapors have accumulated to sustain a flash. Open cup is used in US. |
| inductionTime | Oxidation induction time (in hours). Typically performed on new oil,but can be done on used oil. |
| inhibitor61125MethodC | Amount of inhibitor used in oxidation stablity test performed according to IEC 61125, method C. This value should accompany values resulting from testing according to IEC 61125, method C to allow interpretation. |
| interfacialTension | Interfacial tension (in dyne/centimetre or milliNewton/metre, which are the same). |
| kinematicViscosity | Kinematic viscosity (in millimetre2/second). Kinematic viscosity is the ratio of - absolute (or dynamic) viscosity to density. |
| oxidation | Measure of oxidation stability (in hours). |
| oxidationInhibitorD2668 | 2,6-ditertiary-butyl para-cresol and 2,6-ditertiary-butyl phenol concentration (in percent by weight). |
| oxidationInhibitorDBP | 2,6-ditertiary-butyl phenol (DBP) oxidation inhibitor concentration (in percent by weight). |
| oxidationInhibitorDBPC | 2,6-ditertiarybutyl para-cresol (DBPC) oxidation inhibitor concentration (in percent by weight). |
| passivatorBTA | Metal passivator BTA content (in milligram/kilogram). |
| passivatorContent | Total passivator content (in milligram/kilogram). |
| passivatorIrgamet39 | Irgamet 39 metal passivator content (in ppm, specifically milligram/kilogram). |
| passivatorTTA | Metal passivator TTA (Irgamet39 in solid form) content (in milligram/kilogram). |
| petroleumOrigin | Characterization of the carbon-type composition of insulating oils by petroleum origin. |
| pourPoint | Pour point (in �C). The pour point of a liquid is the temperature at which it becomes semi solid and loses its flow characteristics. |
| pourPointAutomatic | Pour point (in �C) determined by automatic method. The pour point of a liquid is the temperature at which it becomes semi solid and loses its flow characteristics. |
| powerFactorPercent | Fluid power factor at specified temperature (in percent). Commonly used in US. (Note: Fluid power factor is very similar to fluid dissapation factor, but fluid power factor is cosine of the phase angle between an AC voltage applied to oil and the resulting current (where dissipation factor is the tangent). For values up to 0.005, fluid power factor and dissapation factor are very close. There is a conversion equation between the two). |
| resistivity | Resistivity at 90�C (in gigohm-metre). |
| sedimentAndSludgePercent | Sediment and sludge (in percent). |
| sludge | Sludge (in percent by mass). Typically performed on new oil,but can be done on used oil. |
| solubleAcids | Soluble acids (in milligram of KOH/gram). Typically performed on new oil,but can be done on used oil. |
| specificGravity | Specific gravity corrected to 15�C. Also known as relative density. It is a ratio of density of tested oil to density of water at a specific temperature. |
| staticElectrification | Static electrification tendency (in microcoulombs per metre3). Also called static charging tendency and electrostatic charging tendency (ECT). |
| totalAcids | Total acids (soluble plus volatile) (in milligram of KOH/gram). Typically performed on new oil,but can be done on used oil. |
| volatileAcids | Volatile acids (in milligram of KOH/gram). Typically performed on new oil,but can be done on used oil. |

CIM17v40-OilAnalysisFluidDiscreteKind
### (Attribute) OilAnalysisFluidDiscreteKind

Discretes representing oil fluid test analysis result.


| name | description |
|------|-------------|
| colorNumber | Fluid color index number. Color numbers are expressed in 0.5 intervals and value specified is "less-than". For example, a value of '2.5' means the color index number is between 2.0 and 2.5.Possible values: 0.5, 1.0, 1.5, 2.0, 2.5, 3.0, 3.5, 4.0, 4.5, 5.0, 5.5, 6.0, 6.5, 7.0, 7.5, 8.0. |
| colorNumberPlatinumCobaltScale | Fluid color index on the platinum cobalt scale.Possible values: 5, 10, 15, 20, 25, 30, 35, 40, 50, 60, 70, 100, 150, 200, 250, 300, 350, 400, 450. |
| corrosiveSulphurBy51353 | Corrosive sulphur test result using silver strip test.Possible values: absent, present. |
| corrosiveSulphurBy62535 | Corrosive sulphur test result using covered (copper) conductor deposition test.Possible values: potentiallyCorrosive, nonCorrosive. |
| corrosiveSulphurByD1275 | Corrosive sulphur test result using bare copper strip test.Possible values: corrosive, nonCorrosive. |
| sludgePrecipitation | Sludge precipitation test results.Possible values: present, notPresent. |
| tarnishLevel | Tarnish level indicated by corrosive sulphur test.Possible values: 1A, 1B, 2A, 2B, 2C, 2D, 2E, 3A, 3B, 4A, 4B, 4C. |

CIM17v40-OilAnalysisGasAnalogKind
### (Attribute) OilAnalysisGasAnalogKind

Analogs representing oil dissolved gas analysis result.


| name | description |
|------|-------------|
| acetylene | C2H2 concentration (in ppm, specifically in microlitre/litre). |
| butane | C4H10 concentration (in ppm, specifically in microlitre/litre). |
| carbon | C? concentration (in ppm, specifically in microlitre/litre). |
| carbon3 | C3 concentration (in ppm, specifically in microlitre/litre). |
| carbon4 | C4 concentration (in ppm, specifically in microlitre/litre). |
| carbonDioxide | CO2 concentration (in ppm, specifically in microlitre/litre). |
| carbonMonoxide | CO concentration (in ppm, specifically in microlitre/litre). |
| equivalentTCGPercent | Equivalent Total Combustible Gas (ETCG) percent.An estimate, calculated from the dissolved-gas concentrations and the oil sample temperature, of what the TCG would be in a gas space in equilibrium with the oil. ETCG reflects what the TCG would be in air spaces near the oil. |
| estimatedSafeHandlingLimit | Estimated Safe Handling Limit (ESHL) (in percent). Estimated safe handling limit is an estimate of the lower flammability limit (LFL) of the combustible gas mixture which the dissolved gas in the oil would give off by the oil if exposed to air.Expressed in percent like the equivalent total combustible gas percent, it is calculated from the dissolved-gas concentrations, the oil sample temperature, and the lower flammability limits of the individual combustible gases. |
| ethane | C2H6 concentration (in ppm, specifically in microlitre/litre). |
| ethylene | C2H4 concentration (in ppm, specifically in microlitre/litre). |
| hydran | Measured composite of dissolved fault gas concentrations (in ppm, specifically in microlitre/litre). Relative sensitivity- H2: 100 % of concentration- CO: 15 � 4 % of concentration- C2H2: 8 � 2 % of concentration- C2H4: 1.5 � 0.5 % of concentration. |
| hydranPredicted | Predicted hydran value (in ppm, specifically in microlitre/litre), calculated based on individual measured dissolved gas concentrations.- H2: 100 % of concentration- CO: 15 � 4 % of concentration- C2H2: 8 � 2 % of concentration- C2H4: 1.5 � 0.5 % of concentration |
| hydrogen | H2 concentration (in ppm, specifically in microlitre/litre). |
| isobutane | isoC4 (C4H10) concentration (in ppm, specifically in microlitre/litre). Isobutane is also known as methylpropane. |
| methane | CH4 concentration (in ppm, specifically in microlitre/litre). |
| nitrogen | N2 concentration (in ppm, specifically in microlitre/litre). |
| oxygen | O2 concentration (in ppm, specifically in microlitre/litre). |
| propane | C3H8 concentration (in ppm, specifically in microlitre/litre). |
| propene | C3H6 concentration (in ppm, specifically in microlitre/litre). |
| totalCombustibleGasPercent | Total Combustible Gas (TCG) measured in headspace (in percent by volume). |
| totalDissolvedCombustibleGas | Total dissolved combustible gas concentration (in ppm, specifically in microlitre/litre). Calculated by adding the ppm of combustible gasses: hydrogen (H2), methane (CH4), ethane (C2H6), ethylene (C2H4), acetylene (C2H2), and carbon monoxide (CO). |
| totalDissolvedGasPercent | Total dissolved gas in oil (in percent by volume). Derived from the total area of all the gas peaks in the chromatogram. |
| totalHeatGas | Sum of concentrations of methane, ethane, and ethylene (in ppm, specifically in microlitre/litre). Used in some diagnostic gas ratios, especially THG/acetylene, which compares �heat gas� to �arcing gas.� |
| totalPartialPressure | Total partial pressure (in Pa).Calculated value reflecting total of partial pressures of all combustible gasses. |

CIM17v40-OilAnalysisMetalsAnalogKind
### (Attribute) OilAnalysisMetalsAnalogKind

Analogs representing oil metals and elements analysis result.


| name | description |
|------|-------------|
| aluminum | Aluminum concentration (in ppb, specifically in microgram/litre). |
| aluminumParticulate | Aluminum concentration of particles larger than 0.45 microns (in ppb,specifically in microgram/litre). |
| barium | Barium concentration (in ppb, specifically in microgram/litre). |
| boron | Boron concentration (in ppb, specifically in microgram/litre). |
| cadmium | Cadmium concentration (in ppb, specifically in microgram/litre). |
| calcium | Calcium concentration (in ppb, specifically in microgram/litre). |
| chromium | Chromium concentration (in ppb, specifically in microgram/litre). |
| copper | Copper concentration (in ppb, specifically in microgram/litre). |
| copperParticulate | Copper concentration of particles larger than 0.45 microns (in ppb,specifically in microgram/litre). |
| iron | Iron concentration (in ppb, specifically in microgram/litre). |
| ironParticulate | Iron concentration of particles larger than 0.45 microns (in ppb, specifically in microgram/litre). |
| lead | Lead concentration (in ppb, specifically in microgram/litre). |
| leadParticulate | Lead concentration of particles larger than 0.45 microns (in ppb, specifically in microgram/litre). |
| lithium | Lithium concentration (in ppb, specifically in microgram/litre). |
| magnesium | Magnesium concentration (in ppb, specifically in microgram/litre). |
| molybdenum | Molybdenum concentration (in ppb, specifically in microgram/litre). |
| nickel | Nickel concentration (in ppb, specifically in microgram/litre). |
| phosphorus | Phosphorus concentration (in ppb, specifically in microgram/litre). |
| silicon | Silicon concentration (in ppb, specifically in microgram/litre). |
| silver | Silver concentration (in ppb, specifically in microgram/litre). |
| silverParticulate | Silver concentration of particles larger than 0.45 microns (in ppb, specifically in microgram/litre). |
| sodium | Sodium concentration (in ppb, specifically in microgram/litre). |
| tin | Tin concentration (in ppb, specifically in microgram/litre). |
| titanium | Titanium concentration (in ppb, specifically in microgram/litre). |
| tungsten | Tungsten concentration (in ppb, specifically in microgram/litre). |
| vanadium | Vanadium concentration (in ppb, specifically in microgram/litre). |
| zinc | Zinc concentration (in ppb, specifically in microgram/litre). |
| zincParticulate | Zinc concentration of particles larger than 0.45 microns (in ppb, specifically in microgram/litre). |

CIM17v40-OilAnalysisMoistureAnalogKind
### (Attribute) OilAnalysisMoistureAnalogKind

Analogs representing oil moisture analysis result.


| name | description |
|------|-------------|
| dewPoint | Dew point (in �C). Is usually a negative value. |
| relativeSaturation | Relative saturation of water in fluid (in percent). |
| relativeSaturationCalculated | Calculated relative saturation of water in fluid (in percent). |
| waterContent | Moisture measured via coulometric Karl Fischer titration (in ppm, specifically milligram/kilogram). |
| waterContentMonitoredViaAluminumOxide | Water content by aluminum oxide sensor (in ppm, specifically milligram/kilogram). |
| waterContentMonitoredViaCapacitance | Water content by capacitance sensor (in ppm, specifically milligram/kilogram). |
| waterContentMonitoredViaInfrared | Water content by infrared sensor (in ppm, specifically milligram/kilogram). |
| waterContentMonitoredViaOther | Water content by other sensor (in ppm, specifically milligram/kilogram). |

CIM17v40-OilAnalysisPCBAnalogKind
### (Attribute) OilAnalysisPCBAnalogKind

Analogs representing oil PCB analysis result.


| name | description |
|------|-------------|
| aroclor1016 | Concentration of Aroclor 1016 (in ppm, specifically in mg/kg). |
| aroclor1221 | Concentration of Aroclor 1221 (in ppm, specifically in mg/kg). |
| aroclor1242 | Concentration of Aroclor 1242 (in ppm, specifically in mg/kg). |
| aroclor1254 | Concentration of Aroclor 1254 (in ppm, specifically in mg/kg). |
| aroclor1260 | Concentration of Aroclor 1260 (in ppm, specifically in mg/kg). |
| totalPCB | Total arochlor (PCB) content (in ppm, specifically in mg/kg). Is the sum of Aroclor 1221, Aroclor 1242, Aroclor 1254, Aroclor 1260, Aroclor 1016. |

CIM17v40-OilAnalysisPCBDiscreteKind
### (Attribute) OilAnalysisPCBDiscreteKind

Discretes representing oil PCB test analysis result.


| name | description |
|------|-------------|
| testKitPCB | Possible values: <blank>, <50, >50. |

CIM17v40-OilAnalysisPaperAnalogKind
### (Attribute) OilAnalysisPaperAnalogKind

Analogs representing oil paper degradation analysis result.


| name | description |
|------|-------------|
| acetylfuran | 2-acetylfuran (2ACF) (in ppb). Also known as: 2-acetylfuran, furyl methyl ketone, 2-furyl methyl ketone, methyl 2-furyl ketone, and 1-(2-furanyl)ethanone. |
| degreeOfPolymerization | Direct measurement of degree of polymerization (DP) (unitless). |
| degreeOfPolymerizationCalculated | Calculated degree of polymerization (DP) calculated using the Chendong equation (unitless). |
| ethanol | Concentration of ethanol (in ppb, specifically microgram/kilogram). |
| furfural | 2-furaldehyde (2FAL) (in ppb). Also known as: 2-furfural, 2-furaldehyde, 2-furanaldehyde, fural, furfuraldehyde, furaldehyde, and 2-furancarboxaldehyde. |
| furfurylAlcohol | Furfuryl alcohol (2FOL) (in ppb). Also known as: 2-furyl alcohol, 2-furfurol, 2-furylmethanol, 2-hydroxymethylfuran, 2-furancarbinol, furancarbinol, 2-furanmethanol, furanmethanol, furfural alcohol, and alpha-furylcarbinol. |
| hydroxymethylfurfural | 5-hydroxymethyl-2-furaldehyde (5H2F) (in ppb). Also known as: 5-hydroxymethyl-2-furfural, 5-hydroxymethyl-2-furaldehyde, 5-hydroxymethylfurfuraldehyde, and 5-hydroxymethylfurfural. |
| methanol | Concentration of methanol (in ppb, specifically microgram/kilogram). |
| methylfurfural | 5-methyl-2-furaldehyde (5M2F) (in ppb). Also known as: 5-methyl-2-furfural, 5-methyl-2-furaldehyde, 5-methyl-2-furfuraldehyde, and 5-methylfurfural. |
| solidInsulationDielectricStrength | Dielectric breakdown of solid electrical insulating materials (in kV). |
| tensileStrength | Tensile strength (in kilonewtons/metre). |
| totalFuran | Total furan (in ppb). Is the total of the concentrations of 5-hydroxymethyl-2-furaldehyde (5H2F), furfuryl alcohol (2FOL), 2-furaldehyde (2FAL), 2-acetylfuran (2ACF), 5-methyl-2-furaldehyde (5M2F). |

CIM17v40-OilAnalysisParticleAnalogKind
### (Attribute) OilAnalysisParticleAnalogKind

Analogs representing oil particulate analysis result.


| name | description |
|------|-------------|
| carbonPercent | Percent of particles which are carbon. |
| count100Plus | Count of particles 100 microns and larger in a 1 millilitre sample. |
| count10Plus | Count of particles 10 microns and larger in a 1 millilitre sample. |
| count14Plus | Count of particles 14 microns and larger in a 1 millilitre sample. |
| count15Plus | Count of particles 15 microns and larger in a 1 millilitre sample. |
| count21Plus | Count of particles 21 microns and larger in a 1 millilitre sample. |
| count25Plus | Count of particles 25 microns and larger in a 1 millilitre sample. |
| count2Plus | Count of particles 2 microns and larger in a 1 millilitre sample. |
| count38Plus | Count of particles 38 microns and larger in a 1 millilitre sample. |
| count4Plus | Count of particles 4 microns and larger in a 1 millilitre sample. |
| count50Plus | Count of particles 50 microns and larger in a 1 millilitre sample. |
| count5Plus | Count of particles 5 microns and larger in a 1 millilitre sample. |
| count6Plus | Count of particles 6 microns and larger in a 1 millilitre sample. |
| count70Plus | Count of particles 70 microns and larger in a 1 millilitre sample. |
| fibrePercent | Percent of particles which are fibres. |
| metalPercent | Percent of particles which are metal. |
| otherPercent | Percent of particles which are 'other'. |

CIM17v40-OilAnalysisParticleDiscreteKind
### (Attribute) OilAnalysisParticleDiscreteKind

Discretes representing oil particulate analysis result.


| name | description |
|------|-------------|
| opacity | Opacity of oil.Possible values: any integer. |

CIM17v40-OilPreservationKind
### (Attribute) OilPreservationKind

Kind of oil preservation.


| name | description |
|------|-------------|
| conservator | |
| freeBreathing | |
| nitrogenBlanket | |
| other | |

CIM17v40-OilSampleLocation
### (Attribute) OilSampleLocation

Locations where oil can be sampled.


| name | description |
|------|-------------|
| oilDrainageDevice | Sample from oil drainage device. |
| oilSampleValve | Sample from oil sample valve. |
| other | Sample from other location. |

CIM17v40-OilTemperatureSource
### (Attribute) OilTemperatureSource

Sources for oil temperature.


| name | description |
|------|-------------|
| infraredGun | Oil temperature from infrared gun. |
| other | Oil temperature from other souce. |
| topOilTemperatureGauge | Oil temperature from top oil temperature gauge. |

CIM17v40-OnOff
### (Attribute) OnOff

ON

OFF


| name | description |
|------|-------------|
| OFF | |
| ON | |

CIM17v40-OperatingMechanismKind
### (Attribute) OperatingMechanismKind

Kinds of operating mechanisms.


| name | description |
|------|-------------|
| capacitorTrip | Capacitor trip mechanism. |
| hydraulic | Hydraulic mechanism. |
| pneudraulic | Pneudraulic mechanism. |
| pneumatic | Pneumatic mechanism. |
| solenoid | Solenoid mechanism. |
| spring | Spring mechanism. |
| springHandCrank | Spring hand-crank mechanism. |
| springHydraulic | Spring hydraulic mechanism. |
| springMotor | Spring motor mechanism. |

CIM17v40-OperationalLimitDirectionKind
### (Attribute) OperationalLimitDirectionKind

The direction attribute describes the side of a limit that is a violation.


| name | description |
|------|-------------|
| absoluteValue | An absoluteValue limit means that a monitored absolute value above the limit value is a violation. |
| high | High means that a monitored value above the limit value is a violation. If applied to a terminal flow, the positive direction is into the terminal. |
| low | Low means a monitored value below the limit is a violation. If applied to a terminal flow, the positive direction is into the terminal. |

CIM17v40-OrganisationCode
### OrganisationCode

organization code


| name | description |
|------|-------------|
| BILL_TO | |
| PAY_TO | |
| PROVIDED_BY | |
| SOLD_TO | |

CIM17v40-OrganisationType
### OrganisationType

organization type


| name | description |
|------|-------------|
| CUSTOMER | |
| RTO | |

CIM17v40-OrientationKind
### (Attribute) OrientationKind

The orientation of the coordinate system with respect to top, left, and the coordinate number system.


| name | description |
|------|-------------|
| negative | For 2D diagrams, a negative orientation gives the left-hand orientation (favoured by computer graphics displays) with X values increasing from left to right and Y values increasing from top to bottom. This is also known as a left hand orientation. |
| positive | For 2D diagrams, a positive orientation will result in X values increasing from left to right and Y values increasing from bottom to top. This is also known as a right hand orientation. |

CIM17v40-OutageCauseKind
### (Attribute) OutageCauseKind

This enumeration describes the primary cause of the outage - planned, unplanned, etc.


| name | description |
|------|-------------|
| animal | This outage was caused by an animal is was unplanned. As such it is treated as a forced outage and is probably classified as "trouble" with a Trouble Ticket as well as a work/service order. The primary difference between this and an unplanned outage is the reason for the outage. If an animal caused this and perished as a result, the utility may have other actions that are required to be taken by the EPA or other groups with whom the utility has an agreement. |
| lightingStrike | Outage is caused by a lighting strike |
| lineDown | The outage is caused by a line down |
| poleDown | The outage is caused by a pole down |
| treeDown | The outage is caused by a tree down |

CIM17v40-OutageStatusKind
### (Attribute) OutageStatusKind

This defines if the outage have been predicted or confirmed


| name | description |
|------|-------------|
| closed | The outage has been fully restored, the crews have been released and the outage is shown as closed |
| confirmed | the outage has been verified |
| partiallyRestored | Some of the usage points affected by the outage have been restored but other usage points are still out of power. |
| predicted | the outage may not be real since it has not been verified - it is only thought to be an outage. |
| restored | All usage points associated with the outage have been restored |

CIM17v40-PSREventKind
### (Attribute) PSREventKind

Kind of power system resource (PSR) event.


| name | description |
|------|-------------|
| inService | Power system resource state change to in service. |
| other | Other power system resource state change. |
| outOfService | Power system resource state change to out of service. |
| pendingAdd | Power system resource state change to pending add. |
| pendingRemove | Power system resource state change to pending remove. |
| pendingReplace | Power system resource state change to pending replace. |
| unknown | Unknown power system resource state change. |

CIM17v40-ParticipationCategoryMPM
### (Attribute) ParticipationCategoryMPM

For example:

'Y' - Participates in both LMPM and SMPM

'N' - Not included in LMP price measures

'S' - Participates in SMPM price measures

'L' - Participates in LMPM price measures


| name | description |
|------|-------------|
| L | |
| N | |
| S | |
| Y | |

CIM17v40-PassIndicatorType
### (Attribute) PassIndicatorType

Defines the individual passes that produce results per execution type/market type.


| name | description |
|------|-------------|
| DA | Day Ahead |
| HA-SCUC | Hour Ahead Security Constrained Unit Commitment |
| MPM-1 | Market Power Mitigation Pass 1 |
| MPM-2 | Market Power Mitigation Pass 2 |
| MPM-3 | Market Power Mitigation Pass 3 |
| MPM-4 | Market Power Mitigation Pass 4 |
| RTED | Real Time Economic Dispatch |
| RTPD | Real Time Pre Dispatch |
| RUC | Residual Unit Commitment |

CIM17v40-PetersenCoilModeKind
### (Attribute) PetersenCoilModeKind

The mode of operation for a Petersen coil.


| name | description |
|------|-------------|
| automaticPositioning | Automatic positioning. |
| fixed | Fixed position. |
| manual | Manual positioning. |

CIM17v40-PhaseCode
### (Attribute) PhaseCode

An unordered enumeration of phase identifiers. Allows designation of phases for both transmission and distribution equipment, circuits and loads. The enumeration, by itself, does not describe how the phases are connected together or connected to ground. Ground is not explicitly denoted as a phase.

Residential and small commercial loads are often served from single-phase, or split-phase, secondary circuits. For the example of s12N, phases 1 and 2 refer to hot wires that are 180 degrees out of phase, while N refers to the neutral wire. Through single-phase transformer connections, these secondary circuits may be served from one or two of the primary phases A, B, and C. For three-phase loads, use the A, B, C phase codes instead of s12N.

The integer values are from IEC 61968-9 to support revenue metering applications.


| name | description |
|------|-------------|
| A | Phase A. |
| AB | Phases A and B. |
| ABC | Phases A, B, and C. |
| ABCN | Phases A, B, C, and N. |
| ABN | Phases A, B, and neutral. |
| AC | Phases A and C. |
| ACN | Phases A, C and neutral. |
| AN | Phases A and neutral. |
| B | Phase B. |
| BC | Phases B and C. |
| BCN | Phases B, C, and neutral. |
| BN | Phases B and neutral. |
| C | Phase C. |
| CN | Phases C and neutral. |
| N | Neutral phase. |
| X | Unknown non-neutral phase. |
| XN | Unknown non-neutral phase plus neutral. |
| XY | Two unknown non-neutral phases. |
| XYN | Two unknown non-neutral phases plus neutral. |
| none | No phases specified. |
| s1 | Secondary phase 1. |
| s12 | Secondary phase 1 and 2. |
| s12N | Secondary phases 1, 2, and neutral. |
| s1N | Secondary phase 1 and neutral. |
| s2 | Secondary phase 2. |
| s2N | Secondary phase 2 and neutral. |

CIM17v40-PhaseConnectedFaultKind
### (Attribute) PhaseConnectedFaultKind

The type of fault connection among phases.


| name | description |
|------|-------------|
| lineOpen | The fault is when the conductor path is broken between two terminals. Additional coexisting faults may be required if the broken conductor also causes connections to grounds or other lines or phases. |
| lineToGround | The fault connects the indicated phases to ground. The line to line fault impedance is not used and assumed infinite. The full ground impedance is connected between each phase specified in the fault and ground, but not between the phases. |
| lineToLine | The fault connects the specified phases together without a connection to ground. The ground impedance of this fault is ignored. The line to line impedance is connected between each of the phases specified in the fault. For example three times for a three phase fault, one time for a two phase fault. A single phase fault should not be specified. |
| lineToLineToGround | The fault connects the indicated phases to ground and to each other. The line to line impedance is connected between each of the phases specified in the fault in a full mesh. For example three times for a three phase fault, one time for a two phase fault. A single phase fault should not be specified. The full ground impedance is connected between each phase specified in the fault and ground. |

CIM17v40-PhaseShuntConnectionKind
### (Attribute) PhaseShuntConnectionKind

The configuration of phase connections for a single terminal device such as a load or capacitor.


| name | description |
|------|-------------|
| D | Delta connection. |
| G | Ground connection; use when explicit connection to ground needs to be expressed in combination with the phase code, such as for electrical wire/cable or for meters. |
| I | Independent winding, for single-phase connections. |
| Y | Wye connection. |
| Yn | Wye, with neutral brought out for grounding. |

CIM17v40-PinBranchGroupKind
### (Attribute) PinBranchGroupKind

Categorisation of type of compare done on a branch group.


| name | description |
|------|-------------|
| activePower | Active power in the branch group. |
| reactivePower | Reactive power in the branch group. |

CIM17v40-PinEquipmentKind
### (Attribute) PinEquipmentKind

Categorisation of type of compare done on Equipment.


| name | description |
|------|-------------|
| activePowerLimit | Compare load flow result against the active limit for active power for the given equipment. |
| apparentPowerLimit | Compare load flow result against the active limit for apparent power for the given equipment. |
| connected | Check if all terminal on the equipment is connected. |
| currentLimit | Compare load flow result against the active current limit for the equipment. |
| inService | Check if equipment is in service, True if in service otherwise false. |
| ratedCurrent | Compare load flow result against rated current on the equipment (switch). |
| voltageLimit | Compare load flow result against the active voltage limit for the equipment. |

CIM17v40-PinTerminalKind
### (Attribute) PinTerminalKind

Categorisation of type of compare done on Terminal.


| name | description |
|------|-------------|
| activePower | Active Power on the Terminal. |
| apparentPower | Apparent Power on the Terminal. |
| reactivePower | Reactive Power on the Terminal. |
| voltage | Voltage on the Terminal. |

CIM17v40-PoleBaseKind
### (Attribute) PoleBaseKind

Kind of base for poles.


| name | description |
|------|-------------|
| asphalt | |
| cement | |
| dirt | |
| other | |
| unknown | |

CIM17v40-PolePreservativeKind
### (Attribute) PolePreservativeKind

Preservative kind for poles.


| name | description |
|------|-------------|
| cellon | |
| chemonite | |
| creosote | |
| naphthena | |
| other | |
| penta | |
| unknown | |

CIM17v40-PoleTreatmentKind
### (Attribute) PoleTreatmentKind

Kind of treatment for poles.


| name | description |
|------|-------------|
| butt | |
| full | |
| grayStain | |
| greenStain | |
| natural | |
| other | |
| penta | |
| unknown | |

CIM17v40-PotentialTransformerKind
### (Attribute) PotentialTransformerKind

The construction kind of the potential transformer.


| name | description |
|------|-------------|
| capacitiveCoupling | The potential transformer is using capacitive coupling to create secondary voltage. |
| inductive | The potential transformer is using induction coils to create secondary voltage. |

CIM17v40-PriceSetFlag
### PriceSetFlag

Y - indicates a resource is capable of setting the Markte Clearing Price

S - indicates the resource must submit bids for energy at $ 0

N - indicates the resource does not have to submit bids for energy at $ 0


| name | description |
|------|-------------|
| N | |
| S | |
| Y | |

CIM17v40-PriceTypeKind
### (Attribute) PriceTypeKind

Value of this enumeration for different prices include "total" for the complete/full/all-in price, "congestion" for the congestion cost associated with the total price, the "loss" for the loss price associated with the total price, "capacity" for prices related to installed or reserved capacity, "mileage" for use-based accounting, "system" for system-wide/copper-plate prices, and "delivery" for distribution-based prices.


| name | description |
|------|-------------|
| capacity | |
| congestion | |
| delivery | |
| loss | |
| mileage | |
| system | |
| total | |

CIM17v40-ProcedureKind
### (Attribute) ProcedureKind

Kind of procedure.


| name | description |
|------|-------------|
| diagnosis | Diagnosis procedure. |
| inspection | Inspection procedure. |
| maintenance | Maintenance procedure. |
| other | Other procedure. |
| test | Test procedure. |

CIM17v40-ProjectStatusKind
### ProjectStatusKind


| name | description |
|------|-------------|
| cancelled | |
| closed | |
| draft | |
| frozen | |

CIM17v40-ProtectiveActionAdjustmentKind
### (Attribute) ProtectiveActionAdjustmentKind

Categorisation of different protective action adjustments that can be performed on equipment.


| name | description |
|------|-------------|
| byPercentage | The adjustment is in percentage of the active value. |
| byValue | The adjustment is in given by a value that defined the changes that will be done to the active value. |
| measurement | The equipment will operating on a value given by a measurement. |
| setValue | The equipment will operate on the new value. |

CIM17v40-PurposeFlagType
### (Attribute) PurposeFlagType

MPM Purpose Flag, for example:

Nature of threshold data:

'M' - Mitigation threshold

'R' - Reporting threshold


| name | description |
|------|-------------|
| M | |
| R | |

CIM17v40-RampCurveType
### (Attribute) RampCurveType

For example:

0 - Fixed ramp rate independent of rate function unit MW output

1 - Static ramp rates as a function of unit MW output only

2 - Dynamic ramp rates as a function of unit MW output and ramping time


| name | description |
|------|-------------|
| 0 | Fixed ramp rate independent of rate function unit MW output |
| 1 | Static ramp rates as a function of unit MW output only |
| 2 | Dynamic ramp rates as a function of unit MW output and ramping time |

CIM17v40-RampRateCondition
### (Attribute) RampRateCondition

Ramp rate condition.


| name | description |
|------|-------------|
| BEST | |
| NA | not applicable |
| NORMAL | |
| WORST | |

CIM17v40-RampRateType
### (Attribute) RampRateType

Ramp rate curve type.


| name | description |
|------|-------------|
| INTERTIE | Intertie ramp rate. |
| LD_DROP | Load drop ramp rate. |
| LD_PICKUP | Load pick up rate. |
| OP | Operational ramp rate. |
| OP_RES | Operating reserve ramp rate. |
| REG | Regulating ramp rate. |

CIM17v40-RandomisationKind
### (Attribute) RandomisationKind

Kind of randomisation to be applied to control the timing of end device control commands and/or the definition of demand response and load control events. Value other than 'none' is typically used to mitigate potential deleterious effects of simultaneous operation of multiple devices.


| name | description |
|------|-------------|
| default | Randomisation of start and/or end times involving the operation of one or more devices is controlled by default settings for the device(s). |
| end | End time of an event or control action affecting one or more devices is randomised to prevent simultaneous operation. |
| none | Neither the start time nor the end time of an event or control action affecting one or more devices is randomised. |
| start | Start time of an event or control action affecting one or more multiple devices is randomised. |
| startAndEnd | Both the start time and the end time of an event or control action affecting one or more devices are randomised to prevent simultaneous operation. |

CIM17v40-ReadingReasonKind
### (Attribute) ReadingReasonKind

Reason for the reading being taken.


| name | description |
|------|-------------|
| billing | Reading(s) taken or to be taken in response to a billing-related inquiry by a customer or other party. A variant of 'inquiry'. |
| demandReset | Reading(s) taken or to be taken in conjunction with the resetting of one or more demand registers in a meter. |
| inquiry | Reading(s) taken or to be taken in response to an inquiry by a customer or other party. |
| installation | Reading(s) taken or to be taken in conjunction with installation of a meter. |
| loadManagement | Reading(s) taken or to be taken to support management of loads on distribution networks or devices. |
| loadResearch | Reading(s) taken or to be taken to support research and analysis of loads on distribution networks or devices. |
| moveIn | Reading(s) taken or to be taken in conjunction with a customer move-in event. |
| moveOut | Reading(s) taken or to be taken in conjunction with a customer move-out event. |
| other | Reading(s) taken or to be taken for some other reason or purpose. |
| removal | Reading(s) taken or to be taken in conjunction with removal of a meter. |
| serviceConnect | Reading(s) taken or to be taken in conjunction with a connection or re-connection of service. |
| serviceDisconnect | Reading(s) taken or to be taken in conjunction with a disconnection of service. |

CIM17v40-RegulatingControlModeKind
### (Attribute) RegulatingControlModeKind

The kind of regulation model. For example regulating voltage, reactive power, active power, etc.


| name | description |
|------|-------------|
| activePower | Active power is specified. |
| admittance | Admittance is specified. |
| currentFlow | Current flow is specified. |
| powerFactor | Power factor is specified. |
| reactivePower | Reactive power is specified. |
| temperature | Control switches on/off based on the local temperature (i.e., a thermostat). |
| timeScheduled | Control switches on/off by time of day. The times may change on the weekend, or in different seasons. |
| voltage | Voltage is specified. |

CIM17v40-RegulationBranchKind
### (Attribute) RegulationBranchKind

Kind of regulation branch for shunt impedance.


| name | description |
|------|-------------|
| breaker | |
| fuse | |
| line | |
| other | |
| recloser | |
| sectionner | |
| switch | |
| transformer | |

CIM17v40-RelativeDisplacementKind
### (Attribute) RelativeDisplacementKind

The types of relative displacement


| name | description |
|------|-------------|
| centreEarth | |
| ground | |
| seaLevel | |

CIM17v40-RemedialActionSchemeKind
### (Attribute) RemedialActionSchemeKind

Classification of Remedial Action Scheme.


| name | description |
|------|-------------|
| rAP | Remedial Action Plan (RAP). |
| rAS | Remedial Action Scheme (RAS). |

CIM17v40-RemoteSignalKind
### (Attribute) RemoteSignalKind

Type of input signal coming from remote bus.


| name | description |
|------|-------------|
| remoteBranchCurrentAmplitude | Input is branch current amplitude from remote terminal bus. |
| remoteBusFrequency | Input is frequency from remote terminal bus. |
| remoteBusFrequencyDeviation | Input is frequency deviation from remote terminal bus. |
| remoteBusVoltage | Input is voltage from remote terminal bus. |
| remoteBusVoltageAmplitude | Input is voltage amplitude from remote terminal bus. |
| remoteBusVoltageAmplitudeDerivative | Input is branch current amplitude derivative from remote terminal bus. |
| remoteBusVoltageFrequency | Input is voltage frequency from remote terminal bus. |
| remoteBusVoltageFrequencyDeviation | Input is voltage frequency deviation from remote terminal bus. |
| remotePuBusVoltageDerivative | Input is PU voltage derivative from remote terminal bus. |

CIM17v40-RemoteUnitType
### (Attribute) RemoteUnitType

Type of remote unit.


| name | description |
|------|-------------|
| ControlCenter | Control centre. |
| IED | Intelligent electronic device (IED). |
| RTU | Remote terminal unit. |
| SubstationControlSystem | Substation control system. |

CIM17v40-ReportingMethodKind
### (Attribute) ReportingMethodKind

Method by which information is gathered from station.


| name | description |
|------|-------------|
| automated | Station automatically reports. |
| manual | Station must be physically visited to gather observations. |
| queried | Station must be queried to obtain observations. |

CIM17v40-RequestorRmrTest
### RequestorRmrTest

MP

ISO


| name | description |
|------|-------------|
| ISO | |
| MP | |

CIM17v40-ReserveRequirementType
### (Attribute) ReserveRequirementType

For example:

Operating Reserve, Regulation, Contingency


| name | description |
|------|-------------|
| CONT | Contingency |
| OPRSV | Operating Reserve |
| REG | Regulation |

CIM17v40-ResourceAssnType
### (Attribute) ResourceAssnType

For example:

Asset Owner Sink designator for use by CRR

Asset Owner Source designator for use by CRR

Reliability Must Run

Scheduling Coordinator

Load Serving Entity


| name | description |
|------|-------------|
| CSNK | |
| CSRC | |
| LSE | |
| RMR | |
| SC | |

CIM17v40-ResourceCapacityType
### (Attribute) ResourceCapacityType

Resource capacity type.


| name | description |
|------|-------------|
| FO | Flexible Offer. |
| MO | Must Offer. |
| NR | Non spinning reserve. |
| RA | Resource Adequacy. |
| RD | Regulation Down. |
| RMR | Reliability Must Run. |
| RU | Regulation Up. |
| SR | Spinning reserve. |

CIM17v40-ResourceCertificationCategory
### ResourceCertificationCategory


| name | description |
|------|-------------|
| DAM | |
| GT | Generic |
| RC | |
| RTM | |

CIM17v40-ResourceCertificationKind
### (Attribute) ResourceCertificationKind

Types used for resource certification.


| name | description |
|------|-------------|
| BLACKSTART | Black start |
| Capacity | |
| DemandSideResponse | Demand Side Reponse (DSR) |
| Energy | |
| IntermittentResource | Intermittent resource |
| NonSpinningReserve | Non Spinning Reserve (NR, NONSPIN) |
| RegulationDown | Regulation Down (RD, REGDN) |
| RegulationUp | Regulation Up (RU, REGUP) |
| ReliabilityMustRun | Reliability Must Run (RMR) |
| ReliabilityUnitCommitment | Reliability unit commitment (RUC) |
| SpinningReserve | Spinning Reserve (SR, RRSPIN) |
| SynchronousCondenser | Synchronous Condenser (SYNCCOND) |

CIM17v40-ResourceCertificationType
### ResourceCertificationType


| name | description |
|------|-------------|
| GT | Generic Type |
| IR | Intermittent Resource |
| NR | GenericRegulationSpinningNon-spinningIntermittent Resource |
| RG | Regulating |
| SR | Spinning Reserve |

CIM17v40-ResourceLimitIndicator
### (Attribute) ResourceLimitIndicator

Locational AS Flags indicating whether the Upper or Lower Bound limit of the AS regional procurement is binding.


| name | description |
|------|-------------|
| LOWER | |
| UPPER | |

CIM17v40-ResourceRegistrationStatus
### (Attribute) ResourceRegistrationStatus

Types of resource registration status, for example:

Active

Mothballed

Planned

Decommissioned


| name | description |
|------|-------------|
| Active | Resource registration is active |
| Decommissioned | Resource registration status is decommissioned |
| Mothballed | Resource registration has been suspended |
| Planned | Registration status is in the planning stage |

CIM17v40-ResultsConstraintType
### (Attribute) ResultsConstraintType

Market results binding constraint types.


| name | description |
|------|-------------|
| Actual | Actual. |
| Contingency | Contingency. |
| FG_act | Flowgate actual base case |
| Interface | Interface. |

CIM17v40-RetiredReasonKind
### (Attribute) RetiredReasonKind

Reason asset retired.


| name | description |
|------|-------------|
| environmental | Retired due to environmental reasons. |
| excessiveMaintenance | Retired due to excessive maintainance issues. |
| facilitiesUpgrade | Retired due to facility upgrade. |
| failed | Retired because of failure. |
| obsolescence | Retired due to obsolescence. |
| other | Retired due to other reasons. |
| sold | Retired and sold. |

CIM17v40-RevenueKind
### (Attribute) RevenueKind

Accounting classification of the type of revenue collected for the customer agreement, typically used to break down accounts for revenue accounting.


| name | description |
|------|-------------|
| commercial | Commercial revenue. |
| industrial | Industrial revenue. |
| irrigation | Irrigation revenue. |
| nonResidential | Non-residential revenue. |
| other | Other revenue kind. |
| residential | Residential revenue. |
| streetLight | Streetlight revenue. |

CIM17v40-RevisionKind
### (Attribute) RevisionKind

List of the kinds of revisions that can be made to a SwitchingStep.


| name | description |
|------|-------------|
| added | |
| void | |

CIM17v40-RiskScoreKind
### (Attribute) RiskScoreKind

Types of risk scores.


| name | description |
|------|-------------|
| customerRisk | Customer risk score. |
| financialRisk | Financial risk score. |
| safetyRisk | Safety risk score. |

CIM17v40-RotorKind
### (Attribute) RotorKind

Type of rotor on physical machine.


| name | description |
|------|-------------|
| roundRotor | Round rotor type of synchronous machine. |
| salientPole | Salient pole type of synchronous machine. |

CIM17v40-SVCControlMode
### (Attribute) SVCControlMode

Static VAr Compensator control mode.


| name | description |
|------|-------------|
| reactivePower | Reactive power control. |
| voltage | Voltage control. |

CIM17v40-SampleContainerType
### (Attribute) SampleContainerType

Types of sample containers.


| name | description |
|------|-------------|
| glassCan | Glass can container. |
| metalCan | Metal can container. |
| syringe | Syringe. |

CIM17v40-ScaleKind
### (Attribute) ScaleKind

Kinds of scaling.


| name | description |
|------|-------------|
| exponential | Exponential scale. |
| linear | Linear scale. |

CIM17v40-SchedClassType
### SchedClassType


| name | description |
|------|-------------|
| F | |
| P | |
| R | |

CIM17v40-SealConditionKind
### (Attribute) SealConditionKind

Kind of seal condition.


| name | description |
|------|-------------|
| broken | Seal is broken. |
| locked | Seal is locked. |
| missing | Seal is missing. |
| open | Seal is open. |
| other | Other kind of seal condition. |

CIM17v40-SealKind
### (Attribute) SealKind

Kind of seal.


| name | description |
|------|-------------|
| lead | Lead seal. |
| lock | Lock seal. |
| other | Other kind of seal. |
| steel | Steel seal. |

CIM17v40-SegmentCurveType
### SegmentCurveType


| name | description |
|------|-------------|
| CONSULTATIVE | |
| COST | |

CIM17v40-SelfSchedReferenceType
### (Attribute) SelfSchedReferenceType

Indication of which type of self schedule is being referenced.


| name | description |
|------|-------------|
| ETC | Existing transmission contract. |
| TOR | Transmission ownership right. |

CIM17v40-SelfSchedTypeCleanBid
### SelfSchedTypeCleanBid


| name | description |
|------|-------------|
| BAS | |
| ETC | |
| IFM | |
| LOF | |
| LPT | |
| PT | |
| RA | RA Obligations |
| RMT | |
| SP | Self-Provision |
| TOR | |
| WHL | |

CIM17v40-SelfSchedTypeRawBid
### SelfSchedTypeRawBid


| name | description |
|------|-------------|
| BAS | |
| ETC | |
| LOF | |
| LPT | |
| PT | |
| RA | RA Obligations |
| RMT | |
| SP | Self-Provision |
| TOR | |
| WHL | |

CIM17v40-SelfScheduleBreakdownType
### (Attribute) SelfScheduleBreakdownType

Self schedule breakdown type.


| name | description |
|------|-------------|
| ETC | Existing transmission contract. |
| LPT | Low price taker. |
| TOR | Transmission ownership right. |

CIM17v40-SelfScheduleType
### SelfScheduleType

self schedule types

PT

ETC

TOR

RMR

RMT

RGMR

ORFC

SP


| name | description |
|------|-------------|
| BAS | Base Schedule |
| ETC | |
| IFM | |
| LOF | Lay-off schedule |
| ORFC | |
| PT | |
| PUMP_ETC | |
| PUMP_TOR | |
| RA | RA Obligations |
| RGMR | |
| RMR | |
| RMT | |
| RUC | |
| SP | Self-Provision |
| TOR | |
| WHL | |

CIM17v40-SelfScheduleTypeMB
### SelfScheduleTypeMB

Self Schedule Types applicable to Mitigated Bid


| name | description |
|------|-------------|
| RMR | |

CIM17v40-ServiceKind
### (Attribute) ServiceKind

Kind of service.


| name | description |
|------|-------------|
| air | Air service. |
| electricity | Electricity service. |
| gas | Gas service. |
| heat | Heat service. |
| heatingFluid | Heating fluid service. |
| internet | Internet service. |
| naturalGas | Natural gas service. |
| other | Other kind of service. |
| propane | Propane service. |
| rates | Rates (e.g. tax, charge, toll, duty, tariff, etc.) service. |
| refuse | Refuse (waster) service. |
| sewerage | Sewerage service. |
| steam | Steam service. |
| time | Time service. |
| tvLicence | TV license service. |
| water | Water service. |

CIM17v40-ServiceMultiplierKind
### (Attribute) ServiceMultiplierKind

Kind of service multiplier.


| name | description |
|------|-------------|
| ctRatio | Current transformer ratio used to convert associated quantities to real measurements. |
| ptRatio | Voltage transformer ratio used to convert associated quantities to real measurements. |
| transformerRatio | Product of the CT ratio and PT ratio. |

CIM17v40-ServiceRequestKind
### (Attribute) ServiceRequestKind

Kinds of service requests


| name | description |
|------|-------------|
| connect | Physically connect the service. |
| construction | The construction work requested. |
| disconnect | Physically disconnect the service. |
| inspection | Inspection work. |
| newservice | A new service is requested by the customer |
| other | Other kind of work. |
| reconnect | Physically reconnect the service. |
| repair | Repair work. |
| replace | replace an asset |
| test | Test work. |
| turn-off | Temporarily turn off the service but leave the connection in place. |
| turn-on | Turn on the service. |

CIM17v40-ShortCircuitRotorKind
### (Attribute) ShortCircuitRotorKind

Type of rotor, used by short circuit applications.


| name | description |
|------|-------------|
| salientPole1 | Salient pole 1 in IEC 60909. |
| salientPole2 | Salient pole 2 in IEC 60909. |
| turboSeries1 | Turbo Series 1 in IEC 60909. |
| turboSeries2 | Turbo series 2 in IEC 60909. |

CIM17v40-ShuntImpedanceControlKind
### (Attribute) ShuntImpedanceControlKind

Kind of control for shunt impedance.


| name | description |
|------|-------------|
| fixed | |
| localOnly | |
| remoteOnly | |
| remoteWithLocalOverride | |

CIM17v40-ShuntImpedanceLocalControlKind
### (Attribute) ShuntImpedanceLocalControlKind

Kind of local control for shunt impedance.


| name | description |
|------|-------------|
| current | |
| none | |
| powerFactor | |
| reactivePower | |
| temperature | |
| time | |
| voltage | |

CIM17v40-SinglePhaseKind
### (Attribute) SinglePhaseKind

Enumeration of single phase identifiers. Allows designation of single phases for both transmission and distribution equipment, circuits and loads.


| name | description |
|------|-------------|
| A | Phase A. |
| B | Phase B. |
| C | Phase C. |
| N | Neutral. |
| s1 | Secondary phase 1. |
| s2 | Secondary phase 2. |

CIM17v40-SkillLevelKind
### (Attribute) SkillLevelKind

Kind of skill level.


| name | description |
|------|-------------|
| apprentice | |
| master | |
| other | |
| standard | |

CIM17v40-Source
### (Attribute) Source

Source gives information related to the origin of a value.


| name | description |
|------|-------------|
| DEFAULTED | The value contains a default value. |
| PROCESS | The value is provided by input from the process I/O or being calculated from some function. |
| SUBSTITUTED | The value is provided by input of an operator or by an automatic source. |

CIM17v40-SourceSinkFlag
### SourceSinkFlag


| name | description |
|------|-------------|
| CSNK | |
| CSRC | |

CIM17v40-SourceSinkType
### SourceSinkType


| name | description |
|------|-------------|
| Neither | |
| Sink | |
| Source | |

CIM17v40-SpaceAnalogKind
### (Attribute) SpaceAnalogKind

Kinds of analogs (floats) measuring a space condition.


| name | description |
|------|-------------|
| magneticFieldDirection | |
| magneticFieldStrength | |

CIM17v40-SpinningEventNameType
### SpinningEventNameType


| name | description |
|------|-------------|
| EASTERN | |
| PJM | |
| RFC-SR | |
| SOUTH-S | |

CIM17v40-SpinningEventType
### SpinningEventType


| name | description |
|------|-------------|
| AA | |
| CA | |
| RZ | |

CIM17v40-StaticLoadModelKind
### (Attribute) StaticLoadModelKind

Type of static load model.


| name | description |
|------|-------------|
| constantZ | The load is represented as a constant impedance. ConstantZ equations are used for active and reactive power and no attributes are required. |
| exponential | This model is an exponential representation of the load. Exponential equations for active and reactive power are used and the following attributes are required:kp1, kp2, kp3, kpf, ep1, ep2, ep3kq1, kq2, kq3, kqf, eq1, eq2, eq3. |
| zIP1 | This model integrates the frequency-dependent load (primarily motors). ZIP1 equations for active and reactive power are used and the following attributes are required:kp1, kp2, kp3, kpfkq1, kq2, kq3, kqf. |
| zIP2 | This model separates the frequency-dependent load (primarily motors) from other load. ZIP2 equations for active and reactive power are used and the following attributes are required:kp1, kp2, kp3, kq4, kpfkq1, kq2, kq3, kq4, kqf. |

CIM17v40-StreetlightLampKind
### (Attribute) StreetlightLampKind

Kind of lamp for the streetlight.


| name | description |
|------|-------------|
| highPressureSodium | |
| mercuryVapor | |
| metalHalide | |
| other | |

CIM17v40-StructureMaterialKind
### (Attribute) StructureMaterialKind

Kind of material used for structures.


| name | description |
|------|-------------|
| concrete | |
| other | |
| steel | |
| wood | |

CIM17v40-StructureSupportKind
### (Attribute) StructureSupportKind

Kind of structure support.


| name | description |
|------|-------------|
| anchor | |
| guy | |

CIM17v40-SupplierKind
### (Attribute) SupplierKind

Kind of supplier.


| name | description |
|------|-------------|
| lse | Load Serving Entity |
| mdma | Meter Data Management Agent (MDMA) reads meters, validates meter data, and estimates missing data to be used in various applications |
| msp | Managed service provider (MSP) delivers services, such as network, application, infrastructure and security, via ongoing and regular support and active administration |
| other | Other kind of supplier. |
| retailer | Entity that sells the service, but does not deliver to the customer; applies to the deregulated markets. |
| utility | Entity that delivers the service to the customer. |

CIM17v40-SwitchActionKind
### (Attribute) SwitchActionKind

Kind of action on switch.


| name | description |
|------|-------------|
| close | Close the switch. |
| disableReclosing | Disable (automatic) switch reclosing. |
| enableReclosing | Enable (automatic) switch reclosing. |
| open | Open the switch. |

CIM17v40-SwitchStatusType
### (Attribute) SwitchStatusType

Circuit Breaker Status (closed or open) of the circuit breaker.


| name | description |
|------|-------------|
| Closed | Closed status. |
| Open | Open status. |

CIM17v40-SynchronousMachineKind
### (Attribute) SynchronousMachineKind

Synchronous machine type.


| name | description |
|------|-------------|
| condenser | Indicates the synchronous machine can operate as a condenser. |
| generator | Indicates the synchronous machine can operate as a generator. |
| generatorOrCondenser | Indicates the synchronous machine can operate as a generator or as a condenser. |
| generatorOrCondenserOrMotor | Indicates the synchronous machine can operate as a generator or as a condenser or as a motor. |
| generatorOrMotor | Indicates the synchronous machine can operate as a generator or as a motor. |
| motor | Indicates the synchronous machine can operate as a motor. |
| motorOrCondenser | Indicates the synchronous machine can operate as a motor or as a condenser. |

CIM17v40-SynchronousMachineModelKind
### (Attribute) SynchronousMachineModelKind

Type of synchronous machine model used in dynamic simulation applications.


| name | description |
|------|-------------|
| subtransient | Subtransient synchronous machine model. |
| subtransientSimplified | Simplified version of subtransient synchronous machine model where magnetic coupling between the direct- and quadrature- axes is ignored. |
| subtransientSimplifiedDirectAxis | Simplified version of a subtransient synchronous machine model with no damper circuit on the direct-axis. |
| subtransientTypeF | WECC type F variant of subtransient synchronous machine model. |
| subtransientTypeJ | WECC type J variant of subtransient synchronous machine model. |

CIM17v40-SynchronousMachineOperatingMode
### (Attribute) SynchronousMachineOperatingMode

Synchronous machine operating mode.


| name | description |
|------|-------------|
| condenser | Operating as condenser. |
| generator | Operating as generator. |
| motor | Operating as motor. |

CIM17v40-SystemType
### SystemType


| name | description |
|------|-------------|
| OASIS | |

CIM17v40-TAPPIStandardEditionKind
### (Attribute) TAPPIStandardEditionKind

List of editions for TAPPI standards.


| name | description |
|------|-------------|
| 2009 | 2009 standard edition. |
| none | No standard edition. |
| unknown | Unknown standard edition. |

CIM17v40-TAPPIStandardKind
### (Attribute) TAPPIStandardKind

List of TAPPI standards.


| name | description |
|------|-------------|
| T494 | Tensile properties of paper and paperboard(using constant rate of elongation apparatus), Test Method TAPPI/ANSI T 494 om-13. |

CIM17v40-TRType
### (Attribute) TRType

Transmission Contract Right type -for example:

individual or chain of contract rights


| name | description |
|------|-------------|
| CHAIN | TR chain |
| INDIVIDUAL | Individual TR |

CIM17v40-TagActionKind
### (Attribute) TagActionKind

Kind of action on tag.


| name | description |
|------|-------------|
| place | Place the tag. |
| remove | Remove the tag. |
| verify | Verify the tag. |

CIM17v40-TempEquipActionKind
### (Attribute) TempEquipActionKind

Kind of action on temporary equipment (such as cut, jumper, ground, energy source).


| name | description |
|------|-------------|
| connect | Connect the temp equipment to its terminal |
| disconnect | Disconnect the temp equipment from its terminal |
| place | Place the jumper (close) or the cut (open). |
| remove | Remove the jumper (open) or the cut (close). |

CIM17v40-TenderKind
### (Attribute) TenderKind

Kind of tender.


| name | description |
|------|-------------|
| card | Payment method by means of a credit or debit card. |
| cash | Payment method by means of cash. |
| cheque | Payment method by means of a cheque. |
| other | Other payment method such as electronic finds transfer. |
| unspecified | Payment method is not known. |

CIM17v40-TestKind
### (Attribute) TestKind

The test applied to determine if the condition is met.


| name | description |
|------|-------------|
| equalTo | |
| greaterThan | |
| greaterThanOrEqualTo | |
| lessThan | |
| lessThanOrEqualTo | |

CIM17v40-TestMethod
### (Attribute) TestMethod

Possible test methods.


| name | description |
|------|-------------|
| 60567ByDisplacement | 60567 by displacement method. |
| 60567ByPartition | 60567 by partition method. |
| 60567ByVacuum | 60567 by vacuum method. |
| 60970Automatic | Automatic method. |
| 60970Manual1 | Manual method 1. |
| 60970Manual2 | Manual method 2. |
| 61125A | 61125A method. |
| 61125B | 61125B method. |
| 61125C | 61125C method. |
| 62270AnnexA | 62270 Annex A method. |
| 62535AnnexA | 62535 Annex A method. |
| 62535Main | 62535 main method. |
| D1275A | D1275A method. |
| D1275B | D1275B method. |
| D3612A | D3612A method. |
| D3612B | D3612B method. |
| D3612C | D3612C method. |

CIM17v40-TestReason
### (Attribute) TestReason

Reason for test.


| name | description |
|------|-------------|
| postOilTreatment | Test after oil treatment. |
| postOperationFault | Test after operation fault. |
| postRepair | Test after repair. |
| routine | Routine test. |

CIM17v40-TestVariantKind
### (Attribute) TestVariantKind

Test variants.


| name | description |
|------|-------------|
| 0C | Testing done at temperature of 0�C. |
| 100C | Testing done at temperature of 100�C. |
| 164hours | Measurements taken at 164 hours. |
| 1mm | Specimen of 1 mm thickness used in testing. |
| 25C | Testing done at temperature of 25�C. |
| 2mm | Specimen of 2 mm thickness used in testing. |
| 30C | Testing done at temperature of 30�C. |
| 40C | Testing done at temperature of 40�C. |
| 72hours | Measurements taken at 72 hours. |
| minus30C | Testing done at temperature of -30�C. |
| minus40C | Testing done at temperature of -40�C. |

CIM17v40-TimeIntervalKind
### (Attribute) TimeIntervalKind

Specifies the unit of time for the intervals in the schedule.


| name | description |
|------|-------------|
| D | Day |
| M | Month |
| Y | Year |
| h | Hour |
| m | Minute |
| s | Second |

CIM17v40-TimeOfUse
### (Attribute) TimeOfUse

Time of Use used by a CRR definition for specifying the time the CRR spans. ON - CRR spans the on peak hours of the day, OFF - CRR spans the off peak hours of the day, 24HR - CRR spans the entire day.


| name | description |
|------|-------------|
| 24HR | Time of use spans the entire day, 24 hours. |
| OFF | Time of use spans only the off peak hours of the day. |
| ON | Time of use spans only the on peak hours of the day. |

CIM17v40-TimePeriodUnit
### TimePeriodUnit

Units in which reporting frequency is specified.


| name | description |
|------|-------------|
| days | |
| hours | |
| minutes | |
| months | |
| seconds | |
| weeks | |

CIM17v40-TimeZoneType
### TimeZoneType


| name | description |
|------|-------------|
| PPT | |

CIM17v40-TowerConstructionKind
### (Attribute) TowerConstructionKind

Kind of tower construction.


| name | description |
|------|-------------|
| suspension | |
| tension | |

CIM17v40-TradeProductType
### TradeProductType


| name | description |
|------|-------------|
| APN | Energy Trades at Aggregated Pricing Nodes |
| CAP | Capacity type trade |
| NRT | Non-Spinning Reserve Trade |
| PHY | Physical Energy Tra |
| RDT | Regulation Down Trade |
| RUT | Regulation Up Trade |
| SRT | Spinning Reserve Trade |

CIM17v40-TradeStatusType
### TradeStatusType

RJ - Rejected Trade

I - Invalid Trade

V - Valid Trade

M - Modified Trade

CV - Conditionally Valid Trade

CM - Conditionally Modified Trade

CI - Conditionally Invalid Trade

CX - Cancelled Trade

O - Obsolete Trade

MT - Matched Trade

U - Unmatched Trade


| name | description |
|------|-------------|
| CI | |
| CM | |
| CV | |
| CX | |
| I | |
| M | |
| MT | |
| O | |
| RJ | |
| U | |
| V | |

CIM17v40-TradeType
### (Attribute) TradeType

Trade type.


| name | description |
|------|-------------|
| AST | Ancillary Services Trade. |
| IST | InterSC Trade. |
| UCT | Unit Commitment Trade. |

CIM17v40-TransactionKind
### (Attribute) TransactionKind

Kind of transaction.


| name | description |
|------|-------------|
| accountPayment | Payment against a specified account. |
| auxiliaryChargePayment | Payment against a specified auxiliary account. |
| diversePayment | Payment against an item other than an account. |
| meterConfigurationToken | Issue of token that will alter the meter configuration. |
| other | Other kind of transaction. |
| serviceChargePayment | Payment for a service. |
| taxChargePayment | Payment for a tax. |
| tokenCancellation | Cancellation of a previously issued token. |
| tokenExchange | Exchange of a previously issued token for a new token. |
| tokenFreeIssue | Issue of a free credit token where the donor is the supplier. |
| tokenGrant | Issue of a free credit token where the donor is a 3rd party. |
| tokenSalePayment | Payment for a credit token sale to a customer. |
| transactionReversal | Reversal of a previous transaction. |

CIM17v40-TransformerApplicationKind
### (Attribute) TransformerApplicationKind

Classifications of network roles in which transformers can be deployed. The classifications are intended to reflect both criticality of transformer in network operations and typical usage experienced by transformer.

Note: This enumeration provides essential information to asset health analytics. The existing list is a starting point and is anticipated to be fleshed out further as requirements are better understood (PAB 2016/01/09).


| name | description |
|------|-------------|
| distribution | Transformer between one distribution voltage level and another distribution voltage level. |
| generatorStepUp | Transformer is generator step-up transformer. |
| transmissionBusToBus | Transformer between bus at one transmission voltage level and a bus at another transmission voltage level. |
| transmissionBusToDistribution | Transformer between bus at transmission voltage level and bus at distribution voltage level. |

CIM17v40-TransformerConstructionKind
### (Attribute) TransformerConstructionKind

Kind of transformer construction.


| name | description |
|------|-------------|
| aerial | |
| dryType | |
| network | |
| onePhase | |
| overhead | |
| padmountDeadFront | |
| padmountFeedThrough | |
| padmountLiveFront | |
| padmountLoopThrough | |
| padmounted | |
| subway | |
| threePhase | |
| underground | |
| unknown | |
| vault | |
| vaultThreePhase | |

CIM17v40-TransformerControlMode
### (deprecated, Attribute) TransformerControlMode

Control modes for a transformer.


| name | description |
|------|-------------|
| reactive | Reactive power flow control. |
| volt | Voltage control. |

CIM17v40-TransformerCoreKind
### (Attribute) TransformerCoreKind

Kind of transformer construction.


| name | description |
|------|-------------|
| core | |
| shell | |

CIM17v40-TransformerFailureReasonKind
### (Attribute) TransformerFailureReasonKind

Reason for transformer failure.

Note: This enumeration provides essential information to asset health analytics. The existing list is a starting point and is anticipated to be fleshed out further as requirements are better understood. (PAB 2016/01/09).


| name | description |
|------|-------------|
| bushingFailure | Bushing-caused failure. |
| lossOfOil | Loss-of-oil-caused faliure. |
| oilRelatedFailure | Oil-related failure. |
| poorOilQuality | Oil quality-related failure. |

CIM17v40-TransformerFunctionKind
### (Attribute) TransformerFunctionKind

Function of a transformer.


| name | description |
|------|-------------|
| autotransformer | |
| other | |
| powerTransformer | |
| secondaryTransformer | |
| voltageRegulator | |

CIM17v40-TransformerMaintenanceKind
### (Attribute) TransformerMaintenanceKind

Kinds of transformer maintenance.

BreakerMaintenanceKind enumeration

Possible types of breaker maintenance work.


| name | description |
|------|-------------|

CIM17v40-TransformerRepairItemKind
### (Attribute) TransformerRepairItemKind

Transformer components and problem areas which can be the focus of a repair work task.

WorkTimeScheduleKind enumeration

Kind of work schedule.


| name | description |
|------|-------------|

CIM17v40-TransmissionModeKind
### (Attribute) TransmissionModeKind

Transmission mode for end device display controls, applicable to premises area network (PAN) devices.


| name | description |
|------|-------------|
| anonymous | Message transmission mode whereby messages or commands are broadcast to unspecified devices listening for such communications. |
| both | Message transmission mode whereby messages or commands are sent by both 'normal' and 'anonymous' methods. |
| normal | Message transmission mode whereby messages or commands are sent to specific devices. |

CIM17v40-TroubleCallKind
### TroubleCallKind

Describes the type of Trouble, based on customer input.


| name | description |
|------|-------------|
| lineDown | The customer is reporting a line down |
| powerOut | The customer is reporting an outage. |

CIM17v40-TroubleReportingKind
### (Attribute) TroubleReportingKind

Kind of trouble reporting.


| name | description |
|------|-------------|
| app | |
| call | Trouble call received by customer service representative. |
| email | Trouble reported by email. |
| ivr | Trouble reported through interactive voice response system. |
| letter | Trouble reported by letter. |
| other | Trouble reported by other means. |
| sms | |
| web | |

CIM17v40-TroubleSymptomsExtentKind
### (Attribute) TroubleSymptomsExtentKind

The enumerated values that define the extent of the problem.


| name | description |
|------|-------------|
| entireNeighbourhood | |
| neighbour | |
| ok | |
| other | |
| singleCustomer | |

CIM17v40-TroubleSymptomsLightKind
### (Attribute) TroubleSymptomsLightKind

The list of values that define the light problem.


| name | description |
|------|-------------|
| allOut | |
| dim | |
| flickering | |
| ok | |
| other | |
| partOut | |

CIM17v40-TroubleSymptomsPoleKind
### (Attribute) TroubleSymptomsPoleKind

The list of values that define the Pole problem.


| name | description |
|------|-------------|
| down | |
| hit | |
| leaning | |
| ok | |
| other | |

CIM17v40-TroubleSymptomsTransformerKind
### (Attribute) TroubleSymptomsTransformerKind

The list of items that define the transformer problem.


| name | description |
|------|-------------|
| burning | |
| ok | |
| other | |

CIM17v40-TroubleSymptomsTree_Kind
### (Attribute) TroubleSymptomsTree_Kind

The list of items that define the tree problem.


| name | description |
|------|-------------|
| limbOnService | |
| limbOnWire | |
| ok | |
| other | |

CIM17v40-TroubleSymptomsWireKind
### (Attribute) TroubleSymptomsWireKind

The list of items that define the wire problem.


| name | description |
|------|-------------|
| digIn | |
| ok | |
| other | |
| serviceDown | |
| wireDown | |
| wireburning | |

CIM17v40-UKMinistryOfDefenceStandardEditionKind
### (Attribute) UKMinistryOfDefenceStandardEditionKind

List of editions for UK Ministry of Defence standards.


| name | description |
|------|-------------|
| Issue 1 | Issue 1 standard edition. |
| none | No standard edition. |
| unknown | Unknown standard edition. |

CIM17v40-UKMinistryofDefenceStandardKind
### (Attribute) UKMinistryofDefenceStandardKind

List of UK Ministry of Defence standards.


| name | description |
|------|-------------|
| 05-50 (Part 65) | Ministry of Defence, Defence Standard 05-50 (Part 65)/Issue 1 METHODS FOR TESTING FUELS, LUBRICANTS AND ASSOCIATED PRODUCTS. |

CIM17v40-UOMType
### UOMType


| name | description |
|------|-------------|
| $/lb | |
| $/mmBTU | |
| FACTOR | |
| FLAG | |
| INTEGER | |
| MW | |
| MWh | |
| US$ | |
| US$/MW | |
| US$/MWh | |

CIM17v40-UncertaintyKind
### UncertaintyKind

The type of uncertainty for a reading.


| name | description |
|------|-------------|
| estimated | The value is estimated. |
| interpolated | The value is interpolated. |
| standard | The value has standard uncertainty consistent with National Weather Service practises given the instrument and manner of observation. |
| unknown | The process of value calculation or measurement is unknown. |

CIM17v40-UndergroundStructureKind
### (Attribute) UndergroundStructureKind

Kind of underground structure.


| name | description |
|------|-------------|
| burd | |
| enclosure | |
| handhole | |
| manhole | |
| pad | |
| pullbox | |
| subsurfaceEnclosure | |
| trench | |
| tunnel | |
| vault | |

CIM17v40-UnitMultiplier
### (Attribute) UnitMultiplier

The unit multipliers defined for the CIM. When applied to unit symbols, the unit symbol is treated as a derived unit. Regardless of the contents of the unit symbol text, the unit symbol shall be treated as if it were a single-character unit symbol. Unit symbols should not contain multipliers, and it should be left to the multiplier to define the multiple for an entire data type.

For example, if a unit symbol is "m2Pers" and the multiplier is "k", then the value is k(m**2/s), and the multiplier applies to the entire final value, not to any individual part of the value. This can be conceptualized by substituting a derived unit symbol for the unit type. If one imagines that the symbol "�" represents the derived unit "m2Pers", then applying the multiplier "k" can be conceptualized simply as "k�".

For example, the SI unit for mass is "kg" and not "g". If the unit symbol is defined as "kg", then the multiplier is applied to "kg" as a whole and does not replace the "k" in front of the "g". In this case, the multiplier of "m" would be used with the unit symbol of "kg" to represent one gram. As a text string, this violates the instructions in IEC 80000-1. However, because the unit symbol in CIM is treated as a derived unit instead of as an SI unit, it makes more sense to conceptualize the "kg" as if it were replaced by one of the proposed replacements for the SI mass symbol. If one imagines that the "kg" were replaced by a symbol "�", then it is easier to conceptualize the multiplier "m" as creating the proper unit "m�", and not the forbidden unit "mkg".


| name | description |
|------|-------------|
| E | Exa 10**18. |
| G | Giga 10**9. |
| M | Mega 10**6. |
| P | Peta 10**15. |
| T | Tera 10**12. |
| Y | Yotta 10**24. |
| Z | Zetta 10**21. |
| a | Atto 10**-18. |
| c | Centi 10**-2. |
| d | Deci 10**-1. |
| da | Deca 10**1. |
| f | Femto 10**-15. |
| h | Hecto 10**2. |
| k | Kilo 10**3. |
| m | Milli 10**-3. |
| micro | Micro 10**-6. |
| n | Nano 10**-9. |
| none | No multiplier or equivalently multiply by 1. |
| p | Pico 10**-12. |
| y | Yocto 10**-24. |
| z | Zepto 10**-21. |

CIM17v40-UnitRegulationKind
### (Attribute) UnitRegulationKind

Unit regulation kind.


| name | description |
|------|-------------|
| 0 | Unit is not on regulation. |
| 1 | Unit is on AGC and regulating. |
| 2 | Unit is suppose to be on regulation but it is not under regulation now. |

CIM17v40-UnitSymbol
### (Attribute) UnitSymbol

The derived units defined for usage in the CIM. In some cases, the derived unit is equal to an SI unit. Whenever possible, the standard derived symbol is used instead of the formula for the derived unit. For example, the unit symbol Farad is defined as "F" instead of "CPerV". In cases where a standard symbol does not exist for a derived unit, the formula for the unit is used as the unit symbol. For example, density does not have a standard symbol and so it is represented as "kgPerm3". With the exception of the "kg", which is an SI unit, the unit symbols do not contain multipliers and therefore represent the base derived unit to which a multiplier can be applied as a whole.

Every unit symbol is treated as an unparseable text as if it were a single-letter symbol. The meaning of each unit symbol is defined by the accompanying descriptive text and not by the text contents of the unit symbol.

To allow the widest possible range of serializations without requiring special character handling, several substitutions are made which deviate from the format described in IEC 80000-1. The division symbol "/" is replaced by the letters "Per". Exponents are written in plain text after the unit as "m3" instead of being formatted as "m" with a superscript of 3 or introducing a symbol as in "m^3". The degree symbol "�" is replaced with the letters "deg". Any clarification of the meaning for a substitution is included in the description for the unit symbol.

Non-SI units are included in list of unit symbols to allow sources of data to be correctly labelled with their non-SI units (for example, a GPS sensor that is reporting numbers that represent feet instead of meters). This allows software to use the unit symbol information correctly convert and scale the raw data of those sources into SI-based units.

The integer values are used for harmonization with IEC 61850.


| name | description |
|------|-------------|
| A | Current in amperes. |
| A2 | Amperes squared (A�). |
| A2h | Ampere-squared hour, ampere-squared hour. |
| A2s | Ampere squared time in square amperes (A�s). |
| APerA | Current, ratio of amperages. Note: Users may need to supply a prefix such as �m� to show rates such as �mA/A�. |
| APerm | A/m, magnetic field strength, amperes per metre. |
| Ah | Ampere-hours, ampere-hours. |
| As | Ampere seconds (A�s). |
| Bq | Radioactivity in becquerels (1/s). |
| Btu | Energy, British Thermal Units. |
| C | Electric charge in coulombs (A�s). |
| CPerkg | Exposure (x rays), coulombs per kilogram. |
| CPerm2 | Surface charge density, coulombs per square metre. |
| CPerm3 | Electric charge density, coulombs per cubic metre. |
| F | Electric capacitance in farads (C/V). |
| FPerm | Permittivity, farads per metre. |
| G | Magnetic flux density, gausses (1 G = 10-4 T). |
| Gy | Absorbed dose in grays (J/kg). |
| GyPers | Absorbed dose rate, grays per second. |
| H | Electric inductance in henrys (Wb/A). |
| HPerm | Permeability, henrys per metre. |
| Hz | Frequency in hertz (1/s). |
| HzPerHz | Frequency, rate of frequency change. Note: Users may need to supply a prefix such as �m� to show rates such as �mHz/Hz�. |
| HzPers | Rate of change of frequency in hertz per second. |
| J | Energy in joules (N�m = C�V = W�s). |
| JPerK | Heat capacity in joules/kelvin. |
| JPerkg | Specific energy, Joules / kg. |
| JPerkgK | Specific heat capacity, specific entropy, joules per kilogram Kelvin. |
| JPerm2 | Insulation energy density, joules per square metre or watt second per square metre. |
| JPerm3 | Energy density, joules per cubic metre. |
| JPermol | Molar energy, joules per mole. |
| JPermolK | Molar entropy, molar heat capacity, joules per mole kelvin. |
| JPers | Energy rate in joules per second (J/s). |
| K | Temperature in kelvins. |
| KPers | Temperature change rate in kelvins per second. |
| M | Length, nautical miles (1 M = 1852 m). |
| Mx | Magnetic flux, maxwells (1 Mx = 10-8 Wb). |
| N | Force in newtons (kg�m/s�). |
| NPerm | Surface tension, newton per metre. |
| Nm | Moment of force, newton metres. |
| Oe | Magnetic field in oersteds, (1 Oe = (103/4p) A/m). |
| Pa | Pressure in pascals (N/m�). Note: the absolute or relative measurement of pressure is implied with this entry. See below for more explicit forms. |
| PaPers | Pressure change rate in pascals per second. |
| Pas | Dynamic viscosity, pascal seconds. |
| Q | Quantity power, Q. |
| Qh | Quantity energy, Qh. |
| S | Conductance in siemens. |
| SPerm | Conductance per length (F/m). |
| Sv | Dose equivalent in sieverts (J/kg). |
| T | Magnetic flux density in teslas (Wb/m2). |
| V | Electric potential in volts (W/A). |
| V2 | Volt squared (W�/A�). |
| V2h | Volt-squared hour, volt-squared-hours. |
| VA | Apparent power in volt amperes. See also real power and reactive power. |
| VAh | Apparent energy in volt ampere hours. |
| VAr | Reactive power in volt amperes reactive. The �reactive� or �imaginary� component of electrical power (VIsin(phi)). (See also real power and apparent power).Note: Different meter designs use different methods to arrive at their results. Some meters may compute reactive power as an arithmetic value, while others compute the value vectorially. The data consumer should determine the method in use and the suitability of the measurement for the intended purpose. |
| VArh | Reactive energy in volt ampere reactive hours. |
| VPerHz | Magnetic flux in volt per hertz. |
| VPerV | Voltage, ratio of voltages. Note: Users may need to supply a prefix such as �m� to show rates such as �mV/V�. |
| VPerVA | Power factor, PF, the ratio of the active power to the apparent power. Note: The sign convention used for power factor will differ between IEC meters and EEI (ANSI) meters. It is assumed that the data consumers understand the type of meter being used and agree on the sign convention in use at any given utility. |
| VPerVAr | Power factor, PF, the ratio of the active power to the apparent power. Note: The sign convention used for power factor will differ between IEC meters and EEI (ANSI) meters. It is assumed that the data consumers understand the type of meter being used and agree on the sign convention in use at any given utility. |
| VPerm | Electric field strength, volts per metre. |
| Vh | Volt-hour, Volt hours. |
| Vs | Volt seconds (Ws/A). |
| W | Real power in watts (J/s). Electrical power may have real and reactive components. The real portion of electrical power (I&#178;R or VIcos(phi)), is expressed in Watts. See also apparent power and reactive power. |
| WPerA | Active power per current flow, watts per Ampere. |
| WPerW | Signal Strength, ratio of power. Note: Users may need to supply a prefix such as �m� to show rates such as �mW/W�. |
| WPerm2 | Heat flux density, irradiance, watts per square metre. |
| WPerm2sr | Radiance, watts per square metre steradian. |
| WPermK | Thermal conductivity in watt/metres kelvin. |
| WPers | Ramp rate in watts per second. |
| WPersr | Radiant intensity, watts per steradian. |
| Wb | Magnetic flux in webers (V�s). |
| Wh | Real energy in watt hours. |
| anglemin | Plane angle, minutes. |
| anglesec | Plane angle, seconds. |
| bar | Pressure in bars, (1 bar = 100 kPa). |
| cd | Luminous intensity in candelas. |
| charPers | Data rate (baud) in characters per second. |
| character | Number of characters. |
| cosPhi | Power factor, dimensionless.Note 1: This definition of power factor only holds for balanced systems. See the alternative definition under code 153.Note 2�: Beware of differing sign conventions in use between the IEC and EEI. It is assumed that the data consumer understands the type of meter in use and the sign convention in use by the utility. |
| count | Amount of substance, Counter value. |
| d | Time in days, day = 24 h = 86400 s. |
| dB | Sound pressure level in decibels. Note: multiplier �d� is included in this unit symbol for compatibility with IEC 61850-7-3. |
| dBm | Power level (logarithmic ratio of signal strength , Bel-mW), normalized to 1mW. Note: multiplier �d� is included in this unit symbol for compatibility with IEC 61850-7-3. |
| deg | Plane angle in degrees. |
| degC | Relative temperature in degrees Celsius.In the SI unit system the symbol is �C. Electric charge is measured in coulomb that has the unit symbol C. To distinguish degree Celsius from coulomb the symbol used in the UML is degC. The reason for not using �C is that the special character � is difficult to manage in software. |
| ft3 | Volume, cubic feet. |
| gPerg | Concentration, The ratio of the mass of a solute divided by the mass of the solution. Note: Users may need use a prefix such a ��� to express a quantity such as ��g/g�. |
| gal | Volume in gallons, US gallon (1 gal = 231 in3 = 128 fl ounce). |
| h | Time in hours, hour = 60 min = 3600 s. |
| ha | Area, hectares. |
| kat | Catalytic activity, katal = mol / s. |
| katPerm3 | Catalytic activity concentration, katals per cubic metre. |
| kg | Mass in kilograms. Note: multiplier �k� is included in this unit symbol for compatibility with IEC 61850-7-3. |
| kgPerJ | Weight per energy in kilograms per joule (kg/J). Note: multiplier �k� is included in this unit symbol for compatibility with IEC 61850-7-3. |
| kgPerm3 | Density in kilogram/cubic metres (kg/m�). Note: multiplier �k� is included in this unit symbol for compatibility with IEC 61850-7-3. |
| kgm | Moment of mass in kilogram metres (kg�m) (first moment of mass). Note: multiplier �k� is included in this unit symbol for compatibility with IEC 61850-7-3. |
| kgm2 | Moment of mass in kilogram square metres (kg�m�) (Second moment of mass, commonly called the moment of inertia). Note: multiplier �k� is included in this unit symbol for compatibility with IEC 61850-7-3. |
| kn | Speed, knots (1 kn = 1852/3600) m/s. |
| l | Volume in litres, litre = dm3 = m3/1000. |
| lPerh | Volumetric flow rate, litres per hour. |
| lPerl | Concentration, The ratio of the volume of a solute divided by the volume of the solution. Note: Users may need use a prefix such a ��� to express a quantity such as ��L/L�. |
| lPers | Volumetric flow rate in litres per second. |
| lm | Luminous flux in lumens (cd�sr). |
| lx | Illuminance in lux (lm/m�). |
| m | Length in metres. |
| m2 | Area in square metres (m�). |
| m2Pers | Viscosity in square metres / second (m�/s). |
| m3 | Volume in cubic metres (m�). |
| m3Compensated | Volume, cubic metres, with the value compensated for weather effects. |
| m3Perh | Volumetric flow rate, cubic metres per hour. |
| m3Perkg | Specific volume, cubic metres per kilogram, v. |
| m3Pers | Volumetric flow rate in cubic metres per second (m�/s). |
| m3Uncompensated | Volume, cubic metres, with the value uncompensated for weather effects. |
| mPerm3 | Fuel efficiency in metres per cubic metres (m/m�). |
| mPers | Velocity in metres per second (m/s). |
| mPers2 | Acceleration in metres per second squared (m/s�). |
| min | Time in minutes, minute = 60 s. |
| mmHg | Pressure, millimetres of mercury (1 mmHg is approximately 133.3 Pa). |
| mol | Amount of substance in moles. |
| molPerkg | Concentration, Molality, the amount of solute in moles and the amount of solvent in kilograms. |
| molPerm3 | Concentration, The amount of substance concentration, (c), the amount of solvent in moles divided by the volume of solution in m�. |
| molPermol | Concentration, Molar fraction, the ratio of the molar amount of a solute divided by the molar amount of the solution. |
| none | Dimension less quantity, e.g. count, per unit, etc. |
| ohm | Electric resistance in ohms (V/A). |
| ohmPerm | Electric resistance per length in ohms per metre ((V/A)/m). |
| ohmm | Resistivity, ohm metres, (rho). |
| onePerHz | Reciprocal of frequency (1/Hz). |
| onePerm | Wavenumber, reciprocal metres, (1/m). |
| ppm | Concentration in parts per million. |
| rad | Plane angle in radians (m/m). |
| radPers | Angular velocity in radians per second (rad/s). |
| radPers2 | Angular acceleration, radians per second squared. |
| rev | Amount of rotation, revolutions. |
| rotPers | Rotations per second (1/s). See also Hz (1/s). |
| s | Time in seconds. |
| sPers | Time, Ratio of time. Note: Users may need to supply a prefix such as �&#181;� to show rates such as �&#181;s/s�. |
| sr | Solid angle in steradians (m2/m2). |
| therm | Energy, therms. |
| tonne | Mass in tons, �tonne� or �metric ton� (1000 kg = 1 Mg). |

CIM17v40-UnitType
### (Attribute) UnitType

Combined Cycle

Gas Turbine

Hydro Turbine

Other

Photovoltaic

Hydro Pump-Turbine

Reciprocating Engine

Steam Turbine

Synchronous Condenser

Wind Turbine


| name | description |
|------|-------------|
| CCYC | Combined Cycle |
| GTUR | Gas Turbine |
| HYDR | Hydro Turbine |
| OTHR | Other |
| PHOT | Photovoltaic |
| PTUR | Hydro Pump-Turbine |
| RECP | Reciprocating Engine |
| STUR | Steam Turbine |
| SYNC | Synchronous Condenser |
| WIND | Wind Turbine |

CIM17v40-UnitTypeEMS
### UnitTypeEMS

MW

FLAG


| name | description |
|------|-------------|
| FLAG | |
| MW | |

CIM17v40-UsagePointConnectedKind
### (Attribute) UsagePointConnectedKind

State of the usage point with respect to connection to the network.


| name | description |
|------|-------------|
| connected | The usage point is connected to the network and able to receive or send the applicable commodity (electricity, gas, water, etc.). |
| logicallyDisconnected | The usage point has been disconnected through operation of a disconnect function within the meter present at the usage point. The usage point is unable to receive or send the applicable commodity (electricity, gas, water, etc.) A logical disconnect can often be achieved without utilising a field crew. |
| physicallyDisconnected | The usage point has been disconnected from the network at a point upstream of the meter. The usage point is unable to receive or send the applicable commodity (electricity, gas, water, etc.). A physical disconnect is often achieved by utilising a field crew. |

CIM17v40-Validity
### (Attribute) Validity

Validity for MeasurementValue.


| name | description |
|------|-------------|
| GOOD | The value is marked good if no abnormal condition of the acquisition function or the information source is detected. |
| INVALID | The value is marked invalid when a supervision function recognises abnormal conditions of the acquisition function or the information source (missing or non-operating updating devices). The value is not defined under this condition. The mark invalid is used to indicate to the client that the value may be incorrect and shall not be used. |
| QUESTIONABLE | The value is marked questionable if a supervision function detects an abnormal behaviour, however the value could still be valid. The client is responsible for determining whether or not values marked "questionable" should be used. |

CIM17v40-VehicleUsageKind
### (Attribute) VehicleUsageKind

Usage of a vehicle.


| name | description |
|------|-------------|
| contractor | Contractor vehicle. |
| crew | Crew vehicle. |
| other | Other vehicle. |
| user | User vehicle. |

CIM17v40-VsPpccControlKind
### (Attribute) VsPpccControlKind

Types applicable to the control of real power and/or DC voltage by voltage source converter.


| name | description |
|------|-------------|
| pPcc | Control is real power at point of common coupling. The target value is provided by ACDCConverter.targetPpcc. |
| pPccAndUdcDroop | Control is active power at point of common coupling and local DC voltage, with the droop. Target values are provided by ACDCConverter.targetPpcc, ACDCConverter.targetUdc and VsConverter.droop. |
| pPccAndUdcDroopPilot | Control is active power at point of common coupling and the pilot DC voltage, with the droop. The mode is used for Multi Terminal High Voltage DC (MTDC) systems where multiple HVDC Substations are connected to the HVDC transmission lines. The pilot voltage is then used to coordinate the control the DC voltage across the HVDC substations. Targets are provided by ACDCConverter.targetPpcc, ACDCConverter.targetUdc and VsConverter.droop. |
| pPccAndUdcDroopWithCompensation | Control is active power at point of common coupling and compensated DC voltage, with the droop. Compensation factor is the resistance, as an approximation of the DC voltage of a common (real or virtual) node in the DC network. Targets are provided by ACDCConverter.targetPpcc, ACDCConverter.targetUdc, VsConverter.droop and VsConverter.droopCompensation. |
| phasePcc | Control is phase at point of common coupling. Target is provided by VsConverter.targetPhasePcc. |
| udc | Control is DC voltage with target value provided by ACDCConverter.targetUdc. |

CIM17v40-VsQpccControlKind
### (Attribute) VsQpccControlKind

Kind of reactive power control at point of common coupling for a voltage source converter.


| name | description |
|------|-------------|
| powerFactorPcc | Control is power factor at point of common coupling. Target is provided by VsConverter.targetPowerFactorPcc. |
| pulseWidthModulation | No explicit control. Pulse-modulation factor is directly set in magnitude (VsConverter.targetPWMfactor) and phase (VsConverter.targetPhasePcc). |
| reactivePcc | Control is reactive power at point of common coupling. Target is provided by VsConverter.targetQpcc. |
| voltagePcc | Control is voltage at point of common coupling. Target is provided by VsConverter.targetUpcc. |

CIM17v40-WEPStandardEditionKind
### (Attribute) WEPStandardEditionKind

List of editions for WEP standards.


| name | description |
|------|-------------|
| none | No edition. |
| unknown | Unknown edition. |

CIM17v40-WEPStandardKind
### (Attribute) WEPStandardKind

List of WEP standards.


| name | description |
|------|-------------|
| 12, 1254E | Westinghouse Engineering Procedure 12,1254E. |

CIM17v40-WeatherCodeKind
### (Attribute) WeatherCodeKind

Kinds of weather conditions.


| name | description |
|------|-------------|
| blowingDust | "BD" weather code ("Blowing Dust"). |
| blowingSand | "BN" weather code ("Blowing Sand"). |
| blowingSnow | "BS" weather code ("Blowing Snow"). |
| cloudy | |
| drizzle | "L" weather code ("Drizzle"). |
| fog | "F weather code ("Fog |
| freezingDrizzle | "ZL" weather code ("Freezing Drizzle"). |
| freezingRain | "ZR" weather code ("Freezing Rain"). |
| freezingSpray | "ZF" weather code ("Freezing Spray"). |
| frost | "FR" weather code ("Frost"). |
| hail | "A" weather code ("Hail"). |
| haze | "H" weather code ("Haze"). |
| iceCrystals | "IC" weather code ("Ice Crystals"). |
| iceFog | "IF" weather code ("Ice Fog"). |
| mist | "BR" weather code ("Mist"), |
| rain | "R" weather code ("Rain"). |
| rainShowers | "RW" weather code ("Rain Showers"). |
| rainSnowMix | "RS" weather code ("Rain/Snow Mix"). |
| sleet | "IP" weather code ("Ice Pellets/Sleet"). |
| smoke | "K" weather code ("Smoke"). |
| snow | "S" weather code ("Snow"). |
| snowShowers | "SW" weather code ("Snow Showers"). |
| snowSleetMix | "SI" weather code ("Snow/Sleet Mix"). |
| sunny | |
| thunderStorms | "T" weather code ("Thunder Storms"). |
| volcanicAsh | "VA" weather code ("Volcanic Ash"). |
| waterSpouts | "WP" weather code ("Water Spouts") |
| wintryMix | "WS" weather code ("Wintry Mix"). |

CIM17v40-WindGenUnitKind
### (Attribute) WindGenUnitKind

Kind of wind generating unit.


| name | description |
|------|-------------|
| offshore | The wind generating unit is located offshore. |
| onshore | The wind generating unit is located onshore. |

CIM17v40-WindLookupTableFunctionKind
### (Attribute) WindLookupTableFunctionKind

Function of the lookup table.


| name | description |
|------|-------------|
| ipmax | Lookup table for voltage dependency of active current limits (i<sub>pmax</sub>(u<sub>WT</sub>)). It is used for the current limitation model, IEC 61400-27-1:2015, 5.6.5.8. |
| iqmax | Lookup table for voltage dependency of reactive current limits (i<sub>qmax</sub>(u<sub>WT</sub>)). It is used for the current limitation model, IEC 61400-27-1:2015, 5.6.5.8. |
| omegap | Power vs. speed lookup table (omega(p)). It is used for the P control model type 3, IEC 61400-27-1:2015, 5.6.5.4. |
| prr | Power versus speed change (negative slip) lookup table (p<sub>rr</sub>(deltaomega)). It is used for the rotor resistance control model, IEC 61400-27-1:2015, 5.6.5.3. |
| pwp | Power vs. frequency lookup table (p<sub>WPbias</sub>(f)). It is used for the wind power plant frequency and active power control model, IEC 61400-27-1:2015, Annex D. |
| qmaxp | Lookup table for active power dependency of reactive power maximum limit (q<sub>maxp</sub>(p)). It is used for the QP and QU limitation model, IEC 61400-27-1:2015, 5.6.5.10. |
| qmaxu | Lookup table for voltage dependency of reactive power maximum limit (q<sub>maxu</sub>(p)). It is used for the QP and QU limitation model, IEC 61400-27-1:2015, 5.6.5.10. |
| qminp | Lookup table for active power dependency of reactive power minimum limit (q<sub>minp</sub>(p)). It is used for the QP and QU limitation model, IEC 61400-27-1:2015, 5.6.5.10. |
| qminu | Lookup table for voltage dependency of reactive power minimum limit (q<sub>minu</sub>(p)). It is used for the QP and QU limitation model, IEC 61400-27-1:2015, 5.6.5.10. |
| qwp | Look up table for the UQ static mode (q<sub>WP</sub>(u<sub>err</sub>)). It is used for the voltage and reactive power control model, IEC 61400-27-1:2015, Annex D. |
| tcwdu | Crowbar duration versus voltage variation look-up table (T<sub>CW</sub>(du)). It is a case-dependent parameter. It is used for the type 3B generator set model, IEC 61400-27-1:2015, 5.6.3.3. |
| tduwt | Lookup table to determine the duration of the power reduction after a voltage dip, depending on the size of the voltage dip (T<sub>d</sub>(u<sub>WT</sub>)). It is a type-dependent parameter. It is used for the pitch control power model, IEC 61400-27-1:2015, 5.6.5.1. |
| tfover | Disconnection time versus over-frequency lookup table (T<sub>fover</sub>(f<sub>WT</sub>)). It is used for the grid protection model, IEC 61400-27-1:2015, 5.6.6. |
| tfunder | Disconnection time versus under-frequency lookup table (T<sub>funder</sub>(f<sub>WT</sub>)). It is used for the grid protection model, IEC 61400-27-1:2015, 5.6.6. |
| tuover | Disconnection time versus over-voltage lookup table (T<sub>uover</sub>(u<sub>WT</sub>)). It is used for the grid protection model, IEC 61400-27-1:2015, 5.6.6. |
| tuunder | Disconnection time versus under-voltage lookup table (T<sub>uunder</sub>(u<sub>WT</sub>)). It is used for the grid protection model, IEC 61400-27-1:2015, 5.6.6. |

CIM17v40-WindPlantQcontrolModeKind
### (Attribute) WindPlantQcontrolModeKind

Reactive power/voltage controller mode.


| name | description |
|------|-------------|
| powerFactor | Power factor reference. |
| reactivePower | Reactive power reference. |
| uqStatic | UQ static. |
| voltageControl | Voltage control. |

CIM17v40-WindQcontrolModeKind
### (Attribute) WindQcontrolModeKind

General wind turbine Q control modes <i>M</i><i><sub>qG</sub></i><i>.</i>


| name | description |
|------|-------------|
| openLoopReactivePower | Open loop reactive power control (only used with closed loop at plant level) (<i>M</i><i><sub>qG</sub></i><sub> </sub>equals 2). |
| openLooppowerFactor | Open loop power factor control (<i>M</i><i><sub>qG</sub></i><sub> </sub>equals 4). |
| powerFactor | Power factor control (<i>M</i><i><sub>qG</sub></i><sub> </sub>equals 3). |
| reactivePower | Reactive power control (<i>M</i><i><sub>qG</sub></i> equals 1). |
| voltage | Voltage control (<i>M</i><i><sub>qG</sub></i> equals 0). |

CIM17v40-WindUVRTQcontrolModeKind
### (Attribute) WindUVRTQcontrolModeKind

UVRT Q control modes <i>M</i><i><sub>qUVRT</sub></i><i>.</i>


| name | description |
|------|-------------|
| mode0 | Voltage-dependent reactive current injection (<i>M</i><i><sub>qUVRT</sub></i> <sub> </sub>equals 0). |
| mode1 | Reactive current injection controlled as the pre-fault value plus an additional voltage dependent reactive current injection (<i>M</i><i><sub>qUVRT</sub></i> equals 1). |
| mode2 | Reactive current injection controlled as the pre-fault value plus an additional voltage-dependent reactive current injection during fault, and as the pre-fault value plus an additional constant reactive current injection post fault (<i>M</i><i><sub>qUVRT</sub></i><sub> </sub>equals 2). |

CIM17v40-WindingConnection
### (Attribute) WindingConnection

Winding connection type.


| name | description |
|------|-------------|
| A | Autotransformer common winding. |
| D | Delta. |
| I | Independent winding, for single-phase connections. |
| Y | Wye. |
| Yn | Wye, with neutral brought out for grounding. |
| Z | ZigZag. |
| Zn | ZigZag, with neutral brought out for grounding. |

CIM17v40-WindingInsulationKind
### (Attribute) WindingInsulationKind

Insulation kind for windings.


| name | description |
|------|-------------|
| nomex | |
| other | |
| paper | |
| thermallyUpgradedPaper | |

CIM17v40-WireInsulationKind
### (Attribute) WireInsulationKind

Kind of wire insulation.


| name | description |
|------|-------------|
| asbestosAndVarnishedCambric | Asbestos and varnished cambric wire insulation. |
| beltedPilc | Belted pilc wire insulation. |
| butyl | Butyl wire insulation. |
| crosslinkedPolyethylene | Crosslinked polyethylene wire insulation. |
| ethylenePropyleneRubber | Ethylene propylene rubber wire insulation. |
| highMolecularWeightPolyethylene | High nolecular weight polyethylene wire insulation. |
| highPressureFluidFilled | High pressure fluid filled wire insulation. |
| lowCapacitanceRubber | Low capacitance rubber wire insulation. |
| oilPaper | Oil paper wire insulation. |
| other | Other kind of wire insulation. |
| ozoneResistantRubber | Ozone resistant rubber wire insulation. |
| rubber | Rubber wire insulation. |
| siliconRubber | Silicon rubber wire insulation. |
| treeResistantHighMolecularWeightPolyethylene | Tree resistant high molecular weight polyethylene wire insulation. |
| treeRetardantCrosslinkedPolyethylene | Tree retardant crosslinked polyethylene wire insulation. |
| unbeltedPilc | Unbelted pilc wire insulation. |
| varnishedCambricCloth | Varnished cambric cloth wire insulation. |
| varnishedDacronGlass | Varnished dacron glass wire insulation. |

CIM17v40-WireMaterialKind
### (Attribute) WireMaterialKind

Kind of wire material.


| name | description |
|------|-------------|
| aaac | Aluminum-alloy conductor steel reinforced. |
| acsr | Aluminum conductor steel reinforced. |
| aluminum | Aluminum wire. |
| aluminumAlloy | Aluminum-alloy wire. |
| aluminumAlloySteel | Aluminum-alloy-steel wire. |
| aluminumSteel | Aluminum-steel wire. |
| copper | Copper wire. |
| other | Other wire material. |
| steel | Steel wire. |

CIM17v40-WireUsageKind
### (Attribute) WireUsageKind

Kind of wire usage.


| name | description |
|------|-------------|
| distribution | Wire is used in medium voltage network. |
| other | Other kind of wire usage. |
| secondary | Wire is used in low voltage circuit. |
| transmission | Wire is used in extra-high voltage or high voltage network. |

CIM17v40-WorkActionKind
### (Attribute) WorkActionKind

Kinds of activities to be performed on a Compatible Unit.


| name | description |
|------|-------------|
| abandon | Leave it in place but not use it. |
| install | Install. |
| remove | Remove. |
| transfer | Remove from one and install at another loctation. |

CIM17v40-WorkStatusKind
### (Attribute) WorkStatusKind

Kind of status, specific to work.


| name | description |
|------|-------------|
| approved | Work has been approved. |
| cancelled | Work has been canceled. |
| closed | Work has been closed (typically by a person responsible for work management) and is ready for billing. |
| completed | Work has been completed, i.e., crew can leave the work location and is available for another work. |
| dispatched | Crew has been dispatched. |
| enroute | Crew is 'en route'. |
| inProgress | Work is in progress. |
| onSite | Crew is on the site. |
| scheduled | Work has been scheduled. |
| waitingOnApproval | Work approval is pending. |
| waitingOnMaterial | Work has been waiting on material. |
| waitingToBeScheduled | Work needs to be scheduled. |

CIM17v40-WorkTaskKind
### (Attribute) WorkTaskKind

Kinds of work tasks.


| name | description |
|------|-------------|
| exchange | Work task deals with exchange of assets. |
| install | Work task deals with installation of assets. |
| investigate | Work task deals with investigation about assets. |
| remove | Work task deals with removal of assets. |

CIM17v40-WorkTimeScheduleKind
### (Attribute) WorkTimeScheduleKind

Kind of work schedule.


| name | description |
|------|-------------|
| actual | Actual work time schedule. |
| earliest | Earliest work time schedule. |
| estimate | Estimate work time schedule. |
| immediate | ??. |
| latest | Latest work time schedule. |
| request | Request work time schedule. |

CIM17v40-YesNo
### (Attribute) YesNo

Used as a flag set to Yes or No.


| name | description |
|------|-------------|
| NO | |
| YES | |

CIM17v40-ZoneKind
### (Attribute) ZoneKind

Kind of zone.


| name | description |
|------|-------------|
| electricalNetwork | |
| other | |
| specialRestrictionLand | |
| weatherZone | |

CIM17v40-ZoneType
### ZoneType

zone type


| name | description |
|------|-------------|
| ASREGION | ancillary service region |
| DCA | designated congestion area |
| LOADZONE | load zone |
| RUCZONE | RUC zone |
| TRADINGHUB | trading hub |

CIM17v40-runTypeCAISO
### runTypeCAISO

S - Scheduling

P - Pricing


| name | description |
|------|-------------|
| P | |
| S | |


## Datatypes

## CIM17v40-ActivePower
### ActivePower

Product of RMS value of the voltage and the RMS value of the in-phase component of the current.


XSD type: `float`

## CIM17v40-ActivePowerChangeRate
### ActivePowerChangeRate

Rate of change of active power per time.


XSD type: `float`

## CIM17v40-ActivePowerPerCurrentFlow
### ActivePowerPerCurrentFlow

Active power variation with current flow.


XSD type: `float`

## CIM17v40-ActivePowerPerFrequency
### ActivePowerPerFrequency

Active power variation with frequency.


XSD type: `float`

## CIM17v40-AngleDegrees
### AngleDegrees

Measurement of angle in degrees.


XSD type: `float`

## CIM17v40-AngleRadians
### AngleRadians

Phase angle in radians.


XSD type: `float`

## CIM17v40-ApparentPower
### ApparentPower

Product of the RMS value of the voltage and the RMS value of the current.


XSD type: `float`

## CIM17v40-Area
### Area

Area.


XSD type: `float`

## CIM17v40-Bearing
### Bearing

The bearing in degrees (with 360 degrees being True North). Measured in degrees clockwise from True North. 0 degrees indicates no direction being given.


XSD type: `float`

## CIM17v40-Capacitance
### Capacitance

Capacitive part of reactance (imaginary part of impedance), at rated frequency.


XSD type: `float`

## CIM17v40-CapacitancePerLength
### CapacitancePerLength

Capacitance per unit of length.


XSD type: `float`

## CIM17v40-Classification
### Classification

Classification of level. Specify as 1..n, with 1 being the most detailed, highest priority, etc as described on the attribute using this data type.


XSD type: `integer`

## CIM17v40-Conductance
### Conductance

Factor by which voltage must be multiplied to give corresponding power lost from a circuit. Real part of admittance.


XSD type: `float`

## CIM17v40-ConductancePerLength
### ConductancePerLength

Real part of admittance per unit of length.


XSD type: `float`

## CIM17v40-CostPerEnergyUnit
### CostPerEnergyUnit

Cost, in units of currency, per quantity of electrical energy generated.


XSD type: `float`

## CIM17v40-CostPerHeatUnit
### CostPerHeatUnit

Cost, in units of currency, per quantity of heat generated.


XSD type: `float`

## CIM17v40-CostPerVolume
### CostPerVolume

Cost per unit volume.


XSD type: `float`

## CIM17v40-CostRate
### CostRate

Cost, in units of currency, per elapsed time.


XSD type: `float`

## CIM17v40-CurrentFlow
### CurrentFlow

Electrical current with sign convention: positive flow is out of the conducting equipment into the connectivity node. Can be both AC and DC.


XSD type: `float`

## CIM17v40-Displacement
### Displacement

Unit of displacement relative to a reference position, hence can be negative.


XSD type: `float`

## CIM17v40-Emission
### Emission

Quantity of emission per fuel heat content.


XSD type: `float`

## CIM17v40-Frequency
### Frequency

Cycles per second.


XSD type: `float`

## CIM17v40-HeatRate
### HeatRate

Heat generated, in energy per time unit of elapsed time.


XSD type: `float`

## CIM17v40-Hours
### Hours

Time specified in hours.


XSD type: `float`

## CIM17v40-Impedance
### Impedance

Ratio of voltage to current.


XSD type: `float`

## CIM17v40-Inductance
### Inductance

Inductive part of reactance (imaginary part of impedance), at rated frequency.


XSD type: `float`

## CIM17v40-InductancePerLength
### InductancePerLength

Inductance per unit of length.


XSD type: `float`

## CIM17v40-KiloActivePower
### KiloActivePower

Active power in kilowatts.


XSD type: `float`

## CIM17v40-Length
### Length

Unit of length. It shall be a positive value or zero.


XSD type: `float`

## CIM17v40-MagneticField
### MagneticField

Magnetic field in nanotesla.


XSD type: `float`

## CIM17v40-Mass
### Mass

Mass.


XSD type: `float`

## CIM17v40-Minutes
### Minutes

Time in minutes.


XSD type: `float`

## CIM17v40-Money
### Money

Amount of money.


XSD type: `decimal`

## CIM17v40-PU
### PU

Per Unit - a positive or negative value referred to a defined base. Values typically range from -10 to +10.


XSD type: `float`

## CIM17v40-ParticulateDensity
### ParticulateDensity

Particulate density as kg/m<sup>3</sup>.


XSD type: `float`

## CIM17v40-PerCent
### PerCent

Percentage on a defined base. For example, specify as 100 to indicate at the defined base.


XSD type: `float`

## CIM17v40-Pressure
### Pressure

Pressure in pascals.


XSD type: `float`

## CIM17v40-Reactance
### Reactance

Reactance (imaginary part of impedance), at rated frequency.


XSD type: `float`

## CIM17v40-ReactancePerLength
### ReactancePerLength

Reactance (imaginary part of impedance) per unit of length, at rated frequency.


XSD type: `float`

## CIM17v40-ReactivePower
### ReactivePower

Product of RMS value of the voltage and the RMS value of the quadrature component of the current.


XSD type: `float`

## CIM17v40-RealEnergy
### RealEnergy

Real electrical energy.


XSD type: `float`

## CIM17v40-Resistance
### Resistance

Resistance (real part of impedance).


XSD type: `float`

## CIM17v40-ResistancePerLength
### ResistancePerLength

Resistance (real part of impedance) per unit of length.


XSD type: `float`

## CIM17v40-RotationSpeed
### RotationSpeed

Number of revolutions per second.


XSD type: `float`

## CIM17v40-Seconds
### Seconds

Time, in seconds.


XSD type: `float`

## CIM17v40-Speed
### Speed

Distance per unit of time.


XSD type: `float`

## CIM17v40-Susceptance
### Susceptance

Imaginary part of admittance.


XSD type: `float`

## CIM17v40-SusceptancePerLength
### SusceptancePerLength

Imaginary part of admittance per unit of length.


XSD type: `float`

## CIM17v40-Temperature
### Temperature

Value of temperature in degrees Celsius.


XSD type: `float`

## CIM17v40-Voltage
### Voltage

Electrical voltage, can be both AC and DC.


XSD type: `float`

## CIM17v40-VoltagePerReactivePower
### VoltagePerReactivePower

Voltage variation with reactive power.


XSD type: `float`

## CIM17v40-Volume
### Volume

Volume.


XSD type: `float`

## CIM17v40-VolumeFlowRate
### VolumeFlowRate

Volume per time.


XSD type: `float`

## CIM17v40-WaterLevel
### WaterLevel

Reservoir water level referred to a given datum such as mean sea level.


XSD type: `float`


## Primitive Types

## CIM17v40-Boolean
### Boolean

A type with the value space "true" and "false".


XSD type: `boolean`

## CIM17v40-Date
### Date

Date as "yyyy-mm-dd", which conforms with ISO 8601. UTC time zone is specified as "yyyy-mm-ddZ". A local timezone relative UTC is specified as "yyyy-mm-dd(+/-)hh:mm".


XSD type: `date`

## CIM17v40-DateTime
### DateTime

Date and time as "yyyy-mm-ddThh:mm:ss.sss", which conforms with ISO 8601. UTC time zone is specified as "yyyy-mm-ddThh:mm:ss.sssZ". A local timezone relative UTC is specified as "yyyy-mm-ddThh:mm:ss.sss-hh:mm". The second component (shown here as "ss.sss") could have any number of digits in its fractional part to allow any kind of precision beyond seconds.


XSD type: `dateTime`

## CIM17v40-Decimal
### Decimal

Decimal is the base-10 notational system for representing real numbers.


XSD type: `decimal`

## CIM17v40-Duration
### Duration

Duration as "PnYnMnDTnHnMnS" which conforms to ISO 8601, where nY expresses a number of years, nM a number of months, nD a number of days. The letter T separates the date expression from the time expression and, after it, nH identifies a number of hours, nM a number of minutes and nS a number of seconds. The number of seconds could be expressed as a decimal number, but all other numbers are integers.


XSD type: `duration`

## CIM17v40-Float
### Float

A floating point number. The range is unspecified and not limited.


XSD type: `float`

## CIM17v40-Integer
### Integer

An integer number. The range is unspecified and not limited.


XSD type: `integer`

## CIM17v40-MonthDay
### MonthDay

MonthDay format as "--mm-dd", which conforms with XSD data type gMonthDay.


XSD type: `gMonthDay`

## CIM17v40-String
### String

A string consisting of a sequence of characters. The character encoding is UTF-8. The string length is unspecified and unlimited.


XSD type: `string`

## CIM17v40-Time
### Time

Time as "hh:mm:ss.sss", which conforms with ISO 8601. UTC time zone is specified as "hh:mm:ss.sssZ". A local timezone relative UTC is specified as "hh:mm:ss.sss�hh:mm". The second component (shown here as "ss.sss") could have any number of digits in its fractional part to allow any kind of precision beyond seconds.


XSD type: `time`
